/*!
 * https://github.com/YouCanBookMe/react-datetime
 */

.amis-scope .rdt {
  position: relative;
}

.amis-scope .rdtPicker {
  display: none;
  position: absolute;
  width: 250px;
  padding: 4px;
  margin-top: 1px;
  z-index: 99999 !important;
  background: #fff;
  box-shadow: 0 1px 3px rgba(0,0,0,.1);
  border: 1px solid #f9f9f9;
}

.amis-scope .rdtOpen .rdtPicker {
  display: block;
}

.amis-scope .rdtStatic .rdtPicker {
  box-shadow: none;
  position: static;
}

.amis-scope .rdtPicker .rdtTimeToggle {
  text-align: center;
}

.amis-scope .rdtPicker table {
  width: 100%;
  margin: 0;
}

.amis-scope .rdtPicker td,
.amis-scope .rdtPicker th {
  text-align: center;
  height: 28px;
}

.amis-scope .rdtPicker td {
  cursor: pointer;
}

.amis-scope .rdtPicker td.rdtDay:hover,
.amis-scope .rdtPicker td.rdtHour:hover,
.amis-scope .rdtPicker td.rdtMinute:hover,
.amis-scope .rdtPicker td.rdtSecond:hover,
.amis-scope .rdtPicker .rdtTimeToggle:hover {
  background: #eeeeee;
  cursor: pointer;
}

.amis-scope .rdtPicker td.rdtOld,
.amis-scope .rdtPicker td.rdtNew {
  color: #999999;
}

.amis-scope .rdtPicker td.rdtToday {
  position: relative;
}

.amis-scope .rdtPicker td.rdtToday:before {
  content: '';
  display: inline-block;
  border-left: 7px solid transparent;
  border-bottom: 7px solid #428bca;
  border-top-color: rgba(0, 0, 0, 0.2);
  position: absolute;
  bottom: 4px;
  right: 4px;
}

.amis-scope .rdtPicker td.rdtActive,
.amis-scope .rdtPicker td.rdtActive:hover {
  background-color: #428bca;
  color: #fff;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
}

.amis-scope .rdtPicker td.rdtActive.rdtToday:before {
  border-bottom-color: #fff;
}

.amis-scope .rdtPicker td.rdtDisabled,
.amis-scope .rdtPicker td.rdtDisabled:hover {
  background: none;
  color: #999999;
  cursor: not-allowed;
}

.amis-scope .rdtPicker td span.rdtOld {
  color: #999999;
}

.amis-scope .rdtPicker td span.rdtDisabled,
.amis-scope .rdtPicker td span.rdtDisabled:hover {
  background: none;
  color: #999999;
  cursor: not-allowed;
}

.amis-scope .rdtPicker th {
  border-bottom: 1px solid #f9f9f9;
}

.amis-scope .rdtPicker .dow {
  width: 14.2857%;
  border-bottom: none;
  cursor: default;
}

.amis-scope .rdtPicker th.rdtSwitch {
  width: 100px;
}

.amis-scope .rdtPicker th.rdtNext,
.amis-scope .rdtPicker th.rdtPrev {
  font-size: 21px;
  vertical-align: top;
}

.amis-scope .rdtPrev span,
.amis-scope .rdtNext span {
  display: block;
  -webkit-touch-callout: none;
  /* iOS Safari */
  -webkit-user-select: none;
  /* Chrome/Safari/Opera */
  -khtml-user-select: none;
  /* Konqueror */
  -moz-user-select: none;
  /* Firefox */
  -ms-user-select: none;
  /* Internet Explorer/Edge */
  user-select: none;
}

.amis-scope .rdtPicker th.rdtDisabled,
.amis-scope .rdtPicker th.rdtDisabled:hover {
  background: none;
  color: #999999;
  cursor: not-allowed;
}

.amis-scope .rdtPicker thead tr:first-child th {
  cursor: pointer;
}

.amis-scope .rdtPicker thead tr:first-child th:hover {
  background: #eeeeee;
}

.amis-scope .rdtPicker tfoot {
  border-top: 1px solid #f9f9f9;
}

.amis-scope .rdtPicker button {
  border: none;
  background: none;
  cursor: pointer;
}

.amis-scope .rdtPicker button:hover {
  background-color: #eee;
}

.amis-scope .rdtPicker thead button {
  width: 100%;
  height: 100%;
}

.amis-scope td.rdtMonth,
.amis-scope td.rdtYear {
  height: 50px;
  width: 25%;
  cursor: pointer;
}

.amis-scope td.rdtMonth:hover,
.amis-scope td.rdtYear:hover {
  background: #eee;
}

.amis-scope .rdtCounters {
  display: inline-block;
}

.amis-scope .rdtCounters > div {
  float: left;
}

.amis-scope .rdtCounter {
  height: 100px;
}

.amis-scope .rdtCounter {
  width: 40px;
}

.amis-scope .rdtCounterSeparator {
  line-height: 100px;
}

.amis-scope .rdtCounter .rdtBtn {
  height: 40%;
  line-height: 40px;
  cursor: pointer;
  display: block;
  -webkit-touch-callout: none;
  /* iOS Safari */
  -webkit-user-select: none;
  /* Chrome/Safari/Opera */
  -khtml-user-select: none;
  /* Konqueror */
  -moz-user-select: none;
  /* Firefox */
  -ms-user-select: none;
  /* Internet Explorer/Edge */
  user-select: none;
}

.amis-scope .rdtCounter .rdtBtn:hover {
  background: #eee;
}

.amis-scope .rdtCounter .rdtCount {
  height: 20%;
  font-size: 1.2em;
}

.amis-scope .rdtMilli {
  vertical-align: middle;
  padding-left: 8px;
  width: 48px;
}

.amis-scope .rdtMilli input {
  width: 100%;
  font-size: 1.2em;
  margin-top: 37px;
}

.amis-scope .rdtTime td {
  cursor: default;
}

/*!
 * Cropper.js v1.5.12
 * https://fengyuanchen.github.io/cropperjs
 *
 * Copyright 2015-present Chen Fengyuan
 * Released under the MIT license
 *
 * Date: 2021-06-12T08:00:11.623Z
 */

.amis-scope .cropper-container {
  direction: ltr;
  font-size: 0;
  line-height: 0;
  position: relative;
  -ms-touch-action: none;
  touch-action: none;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}

.amis-scope .cropper-container img {
  display: block;
  height: 100%;
  image-orientation: 0deg;
  max-height: none !important;
  max-width: none !important;
  min-height: 0 !important;
  min-width: 0 !important;
  width: 100%;
}

.amis-scope .cropper-wrap-box,
.amis-scope .cropper-canvas,
.amis-scope .cropper-drag-box,
.amis-scope .cropper-crop-box,
.amis-scope .cropper-modal {
  bottom: 0;
  left: 0;
  position: absolute;
  right: 0;
  top: 0;
}

.amis-scope .cropper-wrap-box,
.amis-scope .cropper-canvas {
  overflow: hidden;
}

.amis-scope .cropper-drag-box {
  background-color: #fff;
  opacity: 0;
}

.amis-scope .cropper-modal {
  background-color: #000;
  opacity: 0.5;
}

.amis-scope .cropper-view-box {
  display: block;
  height: 100%;
  outline: 1px solid #39f;
  outline-color: rgba(51, 153, 255, 0.75);
  overflow: hidden;
  width: 100%;
}

.amis-scope .cropper-dashed {
  border: 0 dashed #eee;
  display: block;
  opacity: 0.5;
  position: absolute;
}

.amis-scope .cropper-dashed.dashed-h {
  border-bottom-width: 1px;
  border-top-width: 1px;
  height: calc(100% / 3);
  left: 0;
  top: calc(100% / 3);
  width: 100%;
}

.amis-scope .cropper-dashed.dashed-v {
  border-left-width: 1px;
  border-right-width: 1px;
  height: 100%;
  left: calc(100% / 3);
  top: 0;
  width: calc(100% / 3);
}

.amis-scope .cropper-center {
  display: block;
  height: 0;
  left: 50%;
  opacity: 0.75;
  position: absolute;
  top: 50%;
  width: 0;
}

.amis-scope .cropper-center::before,
.amis-scope .cropper-center::after {
  background-color: #eee;
  content: ' ';
  display: block;
  position: absolute;
}

.amis-scope .cropper-center::before {
  height: 1px;
  left: -3px;
  top: 0;
  width: 7px;
}

.amis-scope .cropper-center::after {
  height: 7px;
  left: 0;
  top: -3px;
  width: 1px;
}

.amis-scope .cropper-face,
.amis-scope .cropper-line,
.amis-scope .cropper-point {
  display: block;
  height: 100%;
  opacity: 0.1;
  position: absolute;
  width: 100%;
}

.amis-scope .cropper-face {
  background-color: #fff;
  left: 0;
  top: 0;
}

.amis-scope .cropper-line {
  background-color: #39f;
}

.amis-scope .cropper-line.line-e {
  cursor: ew-resize;
  right: -3px;
  top: 0;
  width: 5px;
}

.amis-scope .cropper-line.line-n {
  cursor: ns-resize;
  height: 5px;
  left: 0;
  top: -3px;
}

.amis-scope .cropper-line.line-w {
  cursor: ew-resize;
  left: -3px;
  top: 0;
  width: 5px;
}

.amis-scope .cropper-line.line-s {
  bottom: -3px;
  cursor: ns-resize;
  height: 5px;
  left: 0;
}

.amis-scope .cropper-point {
  background-color: #39f;
  height: 5px;
  opacity: 0.75;
  width: 5px;
}

.amis-scope .cropper-point.point-e {
  cursor: ew-resize;
  margin-top: -3px;
  right: -3px;
  top: 50%;
}

.amis-scope .cropper-point.point-n {
  cursor: ns-resize;
  left: 50%;
  margin-left: -3px;
  top: -3px;
}

.amis-scope .cropper-point.point-w {
  cursor: ew-resize;
  left: -3px;
  margin-top: -3px;
  top: 50%;
}

.amis-scope .cropper-point.point-s {
  bottom: -3px;
  cursor: s-resize;
  left: 50%;
  margin-left: -3px;
}

.amis-scope .cropper-point.point-ne {
  cursor: nesw-resize;
  right: -3px;
  top: -3px;
}

.amis-scope .cropper-point.point-nw {
  cursor: nwse-resize;
  left: -3px;
  top: -3px;
}

.amis-scope .cropper-point.point-sw {
  bottom: -3px;
  cursor: nesw-resize;
  left: -3px;
}

.amis-scope .cropper-point.point-se {
  bottom: -3px;
  cursor: nwse-resize;
  height: 20px;
  opacity: 1;
  right: -3px;
  width: 20px;
}

@media (min-width: 768px) {
  .amis-scope .cropper-point.point-se {
    height: 15px;
    width: 15px;
  }
}

@media (min-width: 992px) {
  .amis-scope .cropper-point.point-se {
    height: 10px;
    width: 10px;
  }
}

@media (min-width: 1200px) {
  .amis-scope .cropper-point.point-se {
    height: 5px;
    opacity: 0.75;
    width: 5px;
  }
}

.amis-scope .cropper-point.point-se::before {
  background-color: #39f;
  bottom: -50%;
  content: ' ';
  display: block;
  height: 200%;
  opacity: 0;
  position: absolute;
  right: -50%;
  width: 200%;
}

.amis-scope .cropper-invisible {
  opacity: 0;
}

.amis-scope .cropper-bg {
  background-image: url('data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQAQMAAAAlPW0iAAAAA3NCSVQICAjb4U/gAAAABlBMVEXMzMz////TjRV2AAAACXBIWXMAAArrAAAK6wGCiw1aAAAAHHRFWHRTb2Z0d2FyZQBBZG9iZSBGaXJld29ya3MgQ1M26LyyjAAAABFJREFUCJlj+M/AgBVhF/0PAH6/D/HkDxOGAAAAAElFTkSuQmCC');
}

.amis-scope .cropper-hide {
  display: block;
  height: 0;
  position: absolute;
  width: 0;
}

.amis-scope .cropper-hidden {
  display: none !important;
}

.amis-scope .cropper-move {
  cursor: move;
}

.amis-scope .cropper-crop {
  cursor: crosshair;
}

.amis-scope .cropper-disabled .cropper-drag-box,
.amis-scope .cropper-disabled .cropper-face,
.amis-scope .cropper-disabled .cropper-line,
.amis-scope .cropper-disabled .cropper-point {
  cursor: not-allowed;
}

@charset "UTF-8";

.amis-scope .video-react .video-react-control:before,
.amis-scope .video-react .video-react-big-play-button:before {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
}

.amis-scope .video-react .video-react-control:before,
.amis-scope .video-react .video-react-big-play-button:before {
  text-align: center;
}

@font-face {
  font-family: "video-react";
  src: url(data:application/vnd.ms-fontobject;base64, ?#iefix) format("eot");
}

@font-face {
  font-family: "video-react";
  src: url(data:application/font-woff;base64, ) format("woff"), url(data:application/x-font-ttf;base64, ) format("truetype");
  font-weight: normal;
  font-style: normal;
}

.amis-scope .video-react-icon,
.amis-scope .video-react .video-react-closed-caption,
.amis-scope .video-react .video-react-bezel .video-react-bezel-icon,
.amis-scope .video-react .video-react-volume-level,
.amis-scope .video-react .video-react-mute-control,
.amis-scope .video-react .video-react-volume-menu-button,
.amis-scope .video-react .video-react-play-control,
.amis-scope .video-react .video-react-play-progress,
.amis-scope .video-react .video-react-big-play-button {
  /* use !important to prevent issues with browser extensions that change fonts */
  font-family: "video-react" !important;
  speak: none;
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  /* Better Font Rendering =========== */
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}

.amis-scope .video-react-icon-play-arrow:before,
.amis-scope .video-react .video-react-bezel .video-react-bezel-icon-play:before,
.amis-scope .video-react .video-react-play-control:before,
.amis-scope .video-react .video-react-big-play-button:before {
  content: "";
}

.amis-scope .video-react-icon-play-circle-filled:before {
  content: "";
}

.amis-scope .video-react-icon-play-circle-outline:before {
  content: "";
}

.amis-scope .video-react-icon-pause:before,
.amis-scope .video-react .video-react-bezel .video-react-bezel-icon-pause:before,
.amis-scope .video-react .video-react-play-control.video-react-playing:before {
  content: "";
}

.amis-scope .video-react-icon-pause-circle-filled:before {
  content: "";
}

.amis-scope .video-react-icon-pause-circle-outline:before {
  content: "";
}

.amis-scope .video-react-icon-stop:before {
  content: "";
}

.amis-scope .video-react-icon-fast-rewind:before,
.amis-scope .video-react .video-react-bezel .video-react-bezel-icon-fast-rewind:before {
  content: "";
}

.amis-scope .video-react-icon-fast-forward:before,
.amis-scope .video-react .video-react-bezel .video-react-bezel-icon-fast-forward:before {
  content: "";
}

.amis-scope .video-react-icon-skip-previous:before {
  content: "";
}

.amis-scope .video-react-icon-skip-next:before {
  content: "";
}

.amis-scope .video-react-icon-replay-5:before,
.amis-scope .video-react .video-react-bezel .video-react-bezel-icon-replay-5:before {
  content: "";
}

.amis-scope .video-react-icon-replay-10:before,
.amis-scope .video-react .video-react-bezel .video-react-bezel-icon-replay-10:before {
  content: "";
}

.amis-scope .video-react-icon-replay-30:before,
.amis-scope .video-react .video-react-bezel .video-react-bezel-icon-replay-30:before {
  content: "";
}

.amis-scope .video-react-icon-forward-5:before,
.amis-scope .video-react .video-react-bezel .video-react-bezel-icon-forward-5:before {
  content: "";
}

.amis-scope .video-react-icon-forward-10:before,
.amis-scope .video-react .video-react-bezel .video-react-bezel-icon-forward-10:before {
  content: "";
}

.amis-scope .video-react-icon-forward-30:before,
.amis-scope .video-react .video-react-bezel .video-react-bezel-icon-forward-30:before {
  content: "";
}

.amis-scope .video-react-icon-volume-off:before,
.amis-scope .video-react .video-react-bezel .video-react-bezel-icon-volume-off:before,
.amis-scope .video-react .video-react-mute-control.video-react-vol-muted:before,
.amis-scope .video-react .video-react-volume-menu-button.video-react-vol-muted:before {
  content: "";
}

.amis-scope .video-react-icon-volume-mute:before,
.amis-scope .video-react .video-react-mute-control.video-react-vol-0:before,
.amis-scope .video-react .video-react-volume-menu-button.video-react-vol-0:before {
  content: "";
}

.amis-scope .video-react-icon-volume-down:before,
.amis-scope .video-react .video-react-bezel .video-react-bezel-icon-volume-down:before,
.amis-scope .video-react .video-react-mute-control.video-react-vol-2:before,
.amis-scope .video-react .video-react-volume-menu-button.video-react-vol-2:before,
.amis-scope .video-react .video-react-mute-control.video-react-vol-1:before,
.amis-scope .video-react .video-react-volume-menu-button.video-react-vol-1:before {
  content: "";
}

.amis-scope .video-react-icon-volume-up:before,
.amis-scope .video-react .video-react-bezel .video-react-bezel-icon-volume-up:before,
.amis-scope .video-react .video-react-mute-control:before,
.amis-scope .video-react .video-react-volume-menu-button:before {
  content: "";
}

.amis-scope .video-react-icon-fullscreen:before {
  content: "";
}

.amis-scope .video-react-icon-fullscreen-exit:before {
  content: "";
}

.amis-scope .video-react-icon-closed-caption:before,
.amis-scope .video-react .video-react-closed-caption:before {
  content: "";
}

.amis-scope .video-react-icon-hd:before {
  content: "";
}

.amis-scope .video-react-icon-settings:before {
  content: "";
}

.amis-scope .video-react-icon-share:before {
  content: "";
}

.amis-scope .video-react-icon-info:before {
  content: "";
}

.amis-scope .video-react-icon-info-outline:before {
  content: "";
}

.amis-scope .video-react-icon-close:before {
  content: "";
}

.amis-scope .video-react-icon-circle:before,
.amis-scope .video-react .video-react-volume-level:before,
.amis-scope .video-react .video-react-play-progress:before {
  content: "";
}

.amis-scope .video-react-icon-circle-outline:before {
  content: "";
}

.amis-scope .video-react-icon-circle-inner-circle:before {
  content: "";
}

.amis-scope .video-react {
  display: block;
  vertical-align: top;
  box-sizing: border-box;
  color: #fff;
  background-color: #000;
  position: relative;
  font-size: 10px;
  line-height: 1;
  font-family: serif, Times, "Times New Roman";
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}

.amis-scope .video-react:-moz-full-screen {
  position: absolute;
}

.amis-scope .video-react:-webkit-full-screen {
  width: 100% !important;
  height: 100% !important;
}

.amis-scope .video-react *,
.amis-scope .video-react *:before,
.amis-scope .video-react *:after {
  box-sizing: inherit;
}

.amis-scope .video-react ul {
  font-family: inherit;
  font-size: inherit;
  line-height: inherit;
  list-style-position: outside;
  margin-left: 0;
  margin-right: 0;
  margin-top: 0;
  margin-bottom: 0;
}

.amis-scope .video-react.video-react-fluid,
.amis-scope .video-react.video-react-16-9,
.amis-scope .video-react.video-react-4-3 {
  width: 100%;
  max-width: 100%;
  height: 0;
}

.amis-scope .video-react.video-react-16-9 {
  padding-top: 56.25%;
}

.amis-scope .video-react.video-react-4-3 {
  padding-top: 75%;
}

.amis-scope .video-react.video-react-fill {
  width: 100%;
  height: 100%;
}

.amis-scope .video-react .video-react-video {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
}

.amis-scope .video-react.video-react-fullscreen {
  width: 100% !important;
  height: 100% !important;
  padding-top: 0 !important;
}

.amis-scope .video-react.video-react-fullscreen.video-react-user-inactive {
  cursor: none;
}

.amis-scope.video-react-full-window {
  padding: 0;
  margin: 0;
  height: 100%;
  overflow-y: auto;
}

.amis-scope.video-react-full-window .video-react-fullscreen {
  position: fixed;
  overflow: hidden;
  z-index: 1000;
  left: 0;
  top: 0;
  bottom: 0;
  right: 0;
}

.amis-scope .video-react button {
  background: none;
  border: none;
  color: inherit;
  display: inline-block;
  cursor: pointer;
  overflow: visible;
  font-size: inherit;
  line-height: inherit;
  text-transform: none;
  text-decoration: none;
  transition: none;
  -webkit-appearance: none;
  -moz-appearance: none;
  appearance: none;
}

.amis-scope .video-react .video-react-loading-spinner {
  display: none;
  position: absolute;
  top: 50%;
  left: 50%;
  margin: -25px 0 0 -25px;
  opacity: 0.85;
  text-align: left;
  border: 6px solid rgba(43, 51, 63, 0.7);
  box-sizing: border-box;
  background-clip: padding-box;
  width: 50px;
  height: 50px;
  border-radius: 25px;
}

.amis-scope .video-react .video-react-loading-spinner:before,
.amis-scope .video-react .video-react-loading-spinner:after {
  content: "";
  position: absolute;
  margin: -6px;
  box-sizing: inherit;
  width: inherit;
  height: inherit;
  border-radius: inherit;
  opacity: 1;
  border: inherit;
  border-color: transparent;
  border-top-color: white;
  -webkit-animation: video-react-spinner-spin 1.1s cubic-bezier(0.6, 0.2, 0, 0.8) infinite, video-react-spinner-fade 1.1s linear infinite;
  animation: video-react-spinner-spin 1.1s cubic-bezier(0.6, 0.2, 0, 0.8) infinite, video-react-spinner-fade 1.1s linear infinite;
}

.amis-scope .video-react-seeking .video-react-loading-spinner,
.amis-scope .video-react-waiting .video-react-loading-spinner {
  display: block;
}

.amis-scope .video-react-seeking .video-react-loading-spinner:before,
.amis-scope .video-react-waiting .video-react-loading-spinner:before {
  border-top-color: white;
}

.amis-scope .video-react-seeking .video-react-loading-spinner:after,
.amis-scope .video-react-waiting .video-react-loading-spinner:after {
  border-top-color: white;
  -webkit-animation-delay: 0.44s;
  animation-delay: 0.44s;
}

@keyframes video-react-spinner-spin {
  100% {
    transform: rotate(360deg);
  }
}

@-webkit-keyframes video-react-spinner-spin {
  100% {
    -webkit-transform: rotate(360deg);
  }
}

@keyframes video-react-spinner-fade {
  0% {
    border-top-color: #73859f;
  }

  20% {
    border-top-color: #73859f;
  }

  35% {
    border-top-color: white;
  }

  60% {
    border-top-color: #73859f;
  }

  100% {
    border-top-color: #73859f;
  }
}

@-webkit-keyframes video-react-spinner-fade {
  0% {
    border-top-color: #73859f;
  }

  20% {
    border-top-color: #73859f;
  }

  35% {
    border-top-color: white;
  }

  60% {
    border-top-color: #73859f;
  }

  100% {
    border-top-color: #73859f;
  }
}

.amis-scope .video-react .video-react-big-play-button {
  font-size: 3em;
  line-height: 1.5em;
  height: 1.5em;
  width: 3em;
  display: block;
  position: absolute;
  top: 10px;
  left: 10px;
  padding: 0;
  cursor: pointer;
  opacity: 1;
  border: 0.06666em solid #fff;
  background-color: #2B333F;
  background-color: rgba(43, 51, 63, 0.7);
  -webkit-border-radius: 0.3em;
  -moz-border-radius: 0.3em;
  border-radius: 0.3em;
  -webkit-transition: all 0.4s;
  -moz-transition: all 0.4s;
  -o-transition: all 0.4s;
  transition: all 0.4s;
}

.amis-scope .video-react .video-react-big-play-button.video-react-big-play-button-center {
  top: 50%;
  left: 50%;
  margin-top: -0.75em;
  margin-left: -1.5em;
}

.amis-scope .video-react .video-react-big-play-button.big-play-button-hide {
  display: none;
}

.amis-scope .video-react:hover .video-react-big-play-button,
.amis-scope .video-react .video-react-big-play-button:focus {
  outline: 0;
  border-color: #fff;
  background-color: #73859f;
  background-color: rgba(115, 133, 159, 0.5);
  -webkit-transition: all 0s;
  -moz-transition: all 0s;
  -o-transition: all 0s;
  transition: all 0s;
}

.amis-scope .video-react-menu-button {
  cursor: pointer;
}

.amis-scope .video-react-menu-button.video-react-disabled {
  cursor: default;
}

.amis-scope .video-react-menu .video-react-menu-content {
  display: block;
  padding: 0;
  margin: 0;
  overflow: auto;
  font-family: serif, Times, "Times New Roman";
}

.amis-scope .video-react-menu li {
  list-style: none;
  margin: 0;
  padding: 0.2em 0;
  line-height: 1.4em;
  font-size: 1.2em;
  text-align: center;
}

.amis-scope .video-react-menu li:focus,
.amis-scope .video-react-menu li:hover {
  outline: 0;
  background-color: #73859f;
  background-color: rgba(115, 133, 159, 0.5);
}

.amis-scope .video-react-menu li.video-react-selected,
.amis-scope .video-react-menu li.video-react-selected:focus,
.amis-scope .video-react-menu li.video-react-selected:hover {
  background-color: #fff;
  color: #2B333F;
}

.amis-scope .video-react-menu li.vjs-menu-title {
  text-align: center;
  text-transform: uppercase;
  font-size: 1em;
  line-height: 2em;
  padding: 0;
  margin: 0 0 0.3em 0;
  font-weight: bold;
  cursor: default;
}

.amis-scope .video-react-scrubbing .vjs-menu-button:hover .video-react-menu {
  display: none;
}

.amis-scope .video-react .video-react-menu-button-popup .video-react-menu {
  display: none;
  position: absolute;
  bottom: 0;
  width: 10em;
  left: -3em;
  height: 0em;
  margin-bottom: 1.5em;
  border-top-color: rgba(43, 51, 63, 0.7);
}

.amis-scope .video-react .video-react-menu-button-popup .video-react-menu .video-react-menu-content {
  background-color: #2B333F;
  background-color: rgba(43, 51, 63, 0.7);
  position: absolute;
  width: 100%;
  bottom: 1.5em;
  max-height: 15em;
}

.amis-scope .video-react-menu-button-popup .video-react-menu.video-react-lock-showing {
  display: block;
}

.amis-scope .video-react .video-react-menu-button-inline {
  -webkit-transition: all 0.4s;
  -moz-transition: all 0.4s;
  -o-transition: all 0.4s;
  transition: all 0.4s;
  overflow: hidden;
}

.amis-scope .video-react .video-react-menu-button-inline:before {
  width: 2.222222222em;
}

.amis-scope .video-react .video-react-menu-button-inline:hover,
.amis-scope .video-react .video-react-menu-button-inline:focus,
.amis-scope .video-react .video-react-menu-button-inline.video-react-slider-active {
  width: 12em;
}

.amis-scope .video-react .video-react-menu-button-inline:hover .video-react-menu,
.amis-scope .video-react .video-react-menu-button-inline:focus .video-react-menu,
.amis-scope .video-react .video-react-menu-button-inline.video-react-slider-active .video-react-menu {
  display: block;
  opacity: 1;
}

.amis-scope .video-react .video-react-menu-button-inline.video-react-slider-active {
  -webkit-transition: none;
  -moz-transition: none;
  -o-transition: none;
  transition: none;
}

.amis-scope .video-react .video-react-menu-button-inline .video-react-menu {
  opacity: 0;
  height: 100%;
  width: auto;
  position: absolute;
  left: 4em;
  top: 0;
  padding: 0;
  margin: 0;
  -webkit-transition: all 0.4s;
  -moz-transition: all 0.4s;
  -o-transition: all 0.4s;
  transition: all 0.4s;
}

.amis-scope .video-react .video-react-menu-button-inline .video-react-menu-content {
  width: auto;
  height: 100%;
  margin: 0;
  overflow: hidden;
}

.amis-scope .video-react-no-flex .video-react-menu-button-inline .video-react-menu {
  display: block;
  opacity: 1;
  position: relative;
  width: auto;
}

.amis-scope .video-react-no-flex .video-react-menu-button-inline:hover,
.amis-scope .video-react-no-flex .video-react-menu-button-inline:focus,
.amis-scope .video-react-no-flex .video-react-menu-button-inline.video-react-slider-active {
  width: auto;
}

.amis-scope .video-react .video-react-poster {
  display: inline-block;
  vertical-align: middle;
  background-repeat: no-repeat;
  background-position: 50% 50%;
  background-size: contain;
  background-color: #000000;
  cursor: pointer;
  margin: 0;
  padding: 0;
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  height: 100%;
}

.amis-scope .video-react .video-react-poster img {
  display: block;
  vertical-align: middle;
  margin: 0 auto;
  max-height: 100%;
  padding: 0;
  width: 100%;
}

.amis-scope .video-react .video-react-slider {
  outline: 0;
  position: relative;
  cursor: pointer;
  padding: 0;
  margin: 0 0.45em 0 0.45em;
  background-color: #73859f;
  background-color: rgba(115, 133, 159, 0.5);
}

.amis-scope .video-react .video-react-slider:focus {
  -webkit-box-shadow: 0 0 1em #fff;
  -moz-box-shadow: 0 0 1em #fff;
  box-shadow: 0 0 1em #fff;
}

.amis-scope .video-react .video-react-control {
  outline: none;
  position: relative;
  text-align: center;
  margin: 0;
  padding: 0;
  height: 100%;
  width: 4em;
  -webkit-box-flex: none;
  -moz-box-flex: none;
  -webkit-flex: none;
  -ms-flex: none;
  flex: none;
}

.amis-scope .video-react .video-react-control:before {
  font-size: 1.8em;
  line-height: 1.67;
}

.amis-scope .video-react .video-react-control:focus:before,
.amis-scope .video-react .video-react-control:hover:before,
.amis-scope .video-react .video-react-control:focus {
  text-shadow: 0em 0em 1em #fff, 0em 0em 0.5em #fff;
}

.amis-scope .video-react .video-react-control-text {
  border: 0;
  clip: rect(0 0 0 0);
  height: 1px;
  margin: -1px;
  overflow: hidden;
  padding: 0;
  position: absolute;
  width: 1px;
}

.amis-scope .video-react-no-flex .video-react-control {
  display: table-cell;
  vertical-align: middle;
}

.amis-scope .video-react .video-react-control-bar {
  display: none;
  width: 100%;
  position: absolute;
  bottom: 0;
  left: 0;
  right: 0;
  height: 3em;
  background-color: #2B333F;
  background-color: rgba(43, 51, 63, 0.7);
}

.amis-scope .video-react-has-started .video-react-control-bar {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  visibility: visible;
  opacity: 1;
  -webkit-transition: visibility 0.1s, opacity 0.1s;
  -moz-transition: visibility 0.1s, opacity 0.1s;
  -o-transition: visibility 0.1s, opacity 0.1s;
  transition: visibility 0.1s, opacity 0.1s;
}

.amis-scope .video-react-has-started.video-react-user-inactive.video-react-playing .video-react-control-bar.video-react-control-bar-auto-hide {
  visibility: visible;
  opacity: 0;
  -webkit-transition: visibility 1s, opacity 1s;
  -moz-transition: visibility 1s, opacity 1s;
  -o-transition: visibility 1s, opacity 1s;
  transition: visibility 1s, opacity 1s;
}

.amis-scope .video-react-controls-disabled .video-react-control-bar,
.amis-scope .video-react-using-native-controls .video-react-control-bar,
.amis-scope .video-react-error .video-react-control-bar {
  display: none !important;
}

.amis-scope .video-react-audio.video-react-has-started.video-react-user-inactive.video-react-playing .video-react-control-bar {
  opacity: 1;
  visibility: visible;
}

.amis-scope .video-react-has-started.video-react-no-flex .video-react-control-bar {
  display: table;
}

.amis-scope .video-react .video-react-progress-control {
  -webkit-box-flex: auto;
  -moz-box-flex: auto;
  -webkit-flex: auto;
  -ms-flex: auto;
  flex: auto;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  min-width: 4em;
}

.amis-scope .video-react-live .video-react-progress-control {
  display: none;
}

.amis-scope .video-react .video-react-progress-holder {
  -webkit-box-flex: auto;
  -moz-box-flex: auto;
  -webkit-flex: auto;
  -ms-flex: auto;
  flex: auto;
  -webkit-transition: all 0.2s;
  -moz-transition: all 0.2s;
  -o-transition: all 0.2s;
  transition: all 0.2s;
  height: 0.3em;
}

.amis-scope .video-react .video-react-progress-control:hover .video-react-progress-holder {
  font-size: 1.6666666667em;
}

/* If we let the font size grow as much as everything else, the current time tooltip ends up
 ginormous. If you'd like to enable the current time tooltip all the time, this should be disabled
 to avoid a weird hitch when you roll off the hover. */

.amis-scope .video-react .video-react-progress-control:hover .video-react-time-tooltip,
.amis-scope .video-react .video-react-progress-control:hover .video-react-mouse-display:after,
.amis-scope .video-react .video-react-progress-control:hover .video-react-play-progress:after {
  visibility: visible;
  font-size: 0.6em;
}

.amis-scope .video-react .video-react-progress-holder .video-react-play-progress,
.amis-scope .video-react .video-react-progress-holder .video-react-load-progress,
.amis-scope .video-react .video-react-progress-holder .video-react-tooltip-progress-bar,
.amis-scope .video-react .video-react-progress-holder .video-react-load-progress div {
  position: absolute;
  display: block;
  height: 0.3em;
  margin: 0;
  padding: 0;
  width: 0;
  left: 0;
  top: 0;
}

.amis-scope .video-react .video-react-play-progress {
  background-color: #fff;
}

.amis-scope .video-react .video-react-play-progress:before {
  position: absolute;
  top: -0.3333333333em;
  right: -0.5em;
  font-size: 0.9em;
}

.amis-scope .video-react .video-react-time-tooltip,
.amis-scope .video-react .video-react-mouse-display:after,
.amis-scope .video-react .video-react-play-progress:after {
  visibility: hidden;
  pointer-events: none;
  position: absolute;
  top: -3.4em;
  right: -1.9em;
  font-size: 0.9em;
  color: #000;
  content: attr(data-current-time);
  padding: 6px 8px 8px 8px;
  background-color: #fff;
  background-color: rgba(255, 255, 255, 0.8);
  -webkit-border-radius: 0.3em;
  -moz-border-radius: 0.3em;
  border-radius: 0.3em;
}

.amis-scope .video-react .video-react-time-tooltip,
.amis-scope .video-react .video-react-play-progress:before,
.amis-scope .video-react .video-react-play-progress:after {
  z-index: 1;
}

.amis-scope .video-react .video-react-progress-control .video-react-keep-tooltips-inside:after {
  display: none;
}

.amis-scope .video-react .video-react-load-progress {
  background: #bfc7d3;
  background: rgba(115, 133, 159, 0.5);
}

.amis-scope .video-react .video-react-load-progress div {
  background: white;
  background: rgba(115, 133, 159, 0.75);
}

.amis-scope .video-react.video-react-no-flex .video-react-progress-control {
  width: auto;
}

.amis-scope .video-react .video-react-time-tooltip {
  display: inline-block;
  height: 2.4em;
  position: relative;
  float: right;
  right: -1.9em;
}

.amis-scope .video-react .video-react-tooltip-progress-bar {
  visibility: hidden;
}

.amis-scope .video-react .video-react-progress-control .video-react-mouse-display {
  display: none;
  position: absolute;
  width: 1px;
  height: 100%;
  background-color: #000;
  z-index: 1;
}

.amis-scope .video-react-no-flex .video-react-progress-control .video-react-mouse-display {
  z-index: 0;
}

.amis-scope .video-react .video-react-progress-control:hover .video-react-mouse-display {
  display: block;
}

.amis-scope .video-react.video-react-user-inactive .video-react-progress-control .video-react-mouse-display,
.amis-scope .video-react.video-react-user-inactive .video-react-progress-control .video-react-mouse-display:after {
  visibility: hidden;
  opacity: 0;
  -webkit-transition: visibility 1s, opacity 1s;
  -moz-transition: visibility 1s, opacity 1s;
  -o-transition: visibility 1s, opacity 1s;
  transition: visibility 1s, opacity 1s;
}

.amis-scope .video-react.video-react-user-inactive.video-react-no-flex .video-react-progress-control .video-react-mouse-display,
.amis-scope .video-react.video-react-user-inactive.video-react-no-flex .video-react-progress-control .video-react-mouse-display:after {
  display: none;
}

.amis-scope .video-react .video-react-mouse-display .video-react-time-tooltip,
.amis-scope .video-react .video-react-progress-control .video-react-mouse-display:after {
  color: #fff;
  background-color: #000;
  background-color: rgba(0, 0, 0, 0.8);
}

.amis-scope .video-react .video-react-play-control {
  cursor: pointer;
  -webkit-box-flex: none;
  -moz-box-flex: none;
  -webkit-flex: none;
  -ms-flex: none;
  flex: none;
}

.amis-scope .video-react .video-react-fullscreen-control {
  cursor: pointer;
  -webkit-box-flex: none;
  -moz-box-flex: none;
  -webkit-flex: none;
  -ms-flex: none;
  flex: none;
}

.amis-scope .video-react.video-react-fullscreen {
  position: fixed;
  left: 0;
  top: 0;
  bottom: 0;
  right: 0;
  z-index: 9999;
}

.amis-scope .video-react .video-react-time-control {
  -webkit-box-flex: none;
  -moz-box-flex: none;
  -webkit-flex: none;
  -ms-flex: none;
  flex: none;
  font-size: 1em;
  line-height: 3em;
  min-width: 2em;
  width: auto;
  padding-left: 1em;
  padding-right: 1em;
}

.amis-scope .video-react .video-react-time-divider {
  line-height: 3em;
  min-width: initial;
  padding: 0;
}

.amis-scope .video-react .video-react-mute-control,
.amis-scope .video-react .video-react-volume-menu-button {
  cursor: pointer;
  -webkit-box-flex: none;
  -moz-box-flex: none;
  -webkit-flex: none;
  -ms-flex: none;
  flex: none;
}

.amis-scope .video-react .video-react-volume-control {
  width: 5em;
  -webkit-box-flex: none;
  -moz-box-flex: none;
  -webkit-flex: none;
  -ms-flex: none;
  flex: none;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}

.amis-scope .video-react .video-react-volume-bar {
  margin: 1.35em 0.45em;
}

.amis-scope .video-react .video-react-volume-bar.video-react-slider-horizontal {
  width: 5em;
  height: 0.3em;
}

.amis-scope .video-react .video-react-volume-bar.video-react-slider-horizontal .video-react-volume-level {
  width: 100%;
}

.amis-scope .video-react .video-react-volume-bar.video-react-slider-vertical {
  width: 0.3em;
  height: 5em;
  margin: 1.35em auto;
}

.amis-scope .video-react .video-react-volume-bar.video-react-slider-vertical .video-react-volume-level {
  height: 100%;
}

.amis-scope .video-react .video-react-volume-level {
  position: absolute;
  bottom: 0;
  left: 0;
  background-color: #fff;
}

.amis-scope .video-react .video-react-volume-level:before {
  position: absolute;
  font-size: 0.9em;
}

.amis-scope .video-react .video-react-slider-vertical .video-react-volume-level {
  width: 0.3em;
}

.amis-scope .video-react .video-react-slider-vertical .video-react-volume-level:before {
  top: -0.5em;
  left: -0.3em;
}

.amis-scope .video-react .video-react-slider-horizontal .video-react-volume-level {
  height: 0.3em;
}

.amis-scope .video-react .video-react-slider-horizontal .video-react-volume-level:before {
  top: -0.3em;
  right: -0.5em;
}

.amis-scope .video-react .video-react-menu-button-popup.video-react-volume-menu-button .video-react-menu {
  display: block;
  width: 0;
  height: 0;
  border-top-color: transparent;
}

.amis-scope .video-react .video-react-menu-button-popup.video-react-volume-menu-button-vertical .video-react-menu {
  left: 0.5em;
  height: 8em;
}

.amis-scope .video-react .video-react-menu-button-popup.video-react-volume-menu-button-horizontal .video-react-menu {
  left: -2em;
}

.amis-scope .video-react .video-react-menu-button-popup.video-react-volume-menu-button .video-react-menu-content {
  height: 0;
  width: 0;
  overflow-x: hidden;
  overflow-y: hidden;
}

.amis-scope .video-react .video-react-volume-menu-button-vertical:hover .video-react-menu-content,
.amis-scope .video-react .video-react-volume-menu-button-vertical:focus .video-react-menu-content,
.amis-scope .video-react .video-react-volume-menu-button-vertical.video-react-slider-active .video-react-menu-content,
.amis-scope .video-react .video-react-volume-menu-button-vertical .video-react-lock-showing .video-react-menu-content {
  height: 8em;
  width: 2.9em;
}

.amis-scope .video-react .video-react-volume-menu-button-horizontal:hover .video-react-menu-content,
.amis-scope .video-react .video-react-volume-menu-button-horizontal:focus .video-react-menu-content,
.amis-scope .video-react .video-react-volume-menu-button-horizontal .video-react-slider-active .video-react-menu-content,
.amis-scope .video-react .video-react-volume-menu-button-horizontal .video-react-lock-showing .video-react-menu-content {
  height: 2.9em;
  width: 8em;
}

.amis-scope .video-react .video-react-volume-menu-button.video-react-menu-button-inline .video-react-menu-content {
  background-color: transparent !important;
}

.amis-scope .video-react .video-react-playback-rate .video-react-playback-rate-value {
  line-height: 3em;
  text-align: center;
}

.amis-scope .video-react .video-react-playback-rate .video-react-menu {
  width: 4em;
  left: 0em;
}

.amis-scope .video-react .video-react-bezel {
  position: absolute;
  left: 50%;
  top: 50%;
  width: 52px;
  height: 52px;
  z-index: 17;
  margin-left: -26px;
  margin-top: -26px;
  background: rgba(0, 0, 0, 0.5);
  border-radius: 26px;
}

.amis-scope .video-react .video-react-bezel.video-react-bezel-animation {
  -moz-animation: video-react-bezel-fadeout 0.5s linear 1 normal forwards;
  -webkit-animation: video-react-bezel-fadeout 0.5s linear 1 normal forwards;
  animation: video-react-bezel-fadeout 0.5s linear 1 normal forwards;
  pointer-events: none;
}

.amis-scope .video-react .video-react-bezel.video-react-bezel-animation-alt {
  -moz-animation: video-react-bezel-fadeout-alt 0.5s linear 1 normal forwards;
  -webkit-animation: video-react-bezel-fadeout-alt 0.5s linear 1 normal forwards;
  animation: video-react-bezel-fadeout-alt 0.5s linear 1 normal forwards;
  pointer-events: none;
}

.amis-scope .video-react .video-react-bezel .video-react-bezel-icon {
  width: 36px;
  height: 36px;
  margin: 8px;
  font-size: 26px;
  line-height: 36px;
  text-align: center;
}

@keyframes video-react-bezel-fadeout {
  0% {
    opacity: 1;
  }

  to {
    opacity: 0;
    transform: scale(2);
  }
}

@keyframes video-react-bezel-fadeout-alt {
  0% {
    opacity: 1;
  }

  to {
    opacity: 0;
    transform: scale(2);
  }
}

.amis-scope .video-react .video-react-closed-caption {
  cursor: pointer;
  -webkit-box-flex: none;
  -moz-box-flex: none;
  -webkit-flex: none;
  -ms-flex: none;
  flex: none;
}

.amis-scope .video-react video::-webkit-media-text-track-container {
  -webkit-transform: translateY(-30px);
  transform: translateY(-30px);
}

/*!
 * Font Awesome Free 5.15.4 by @fontawesome - https://fontawesome.com
 * License - https://fontawesome.com/license/free (Icons: CC BY 4.0, Fonts: SIL OFL 1.1, Code: MIT License)
 */

.fa,
.fas,
.far,
.fal,
.fad,
.fab {
  -moz-osx-font-smoothing: grayscale;
  -webkit-font-smoothing: antialiased;
  display: inline-block;
  font-style: normal;
  font-variant: normal;
  text-rendering: auto;
  line-height: 1;
}

.fa-lg {
  font-size: 1.33333em;
  line-height: 0.75em;
  vertical-align: -.0667em;
}

.fa-xs {
  font-size: .75em;
}

.fa-sm {
  font-size: .875em;
}

.fa-1x {
  font-size: 1em;
}

.fa-2x {
  font-size: 2em;
}

.fa-3x {
  font-size: 3em;
}

.fa-4x {
  font-size: 4em;
}

.fa-5x {
  font-size: 5em;
}

.fa-6x {
  font-size: 6em;
}

.fa-7x {
  font-size: 7em;
}

.fa-8x {
  font-size: 8em;
}

.fa-9x {
  font-size: 9em;
}

.fa-10x {
  font-size: 10em;
}

.fa-fw {
  text-align: center;
  width: 1.25em;
}

.fa-ul {
  list-style-type: none;
  margin-left: 2.5em;
  padding-left: 0;
}

.fa-ul > li {
  position: relative;
}

.fa-li {
  left: -2em;
  position: absolute;
  text-align: center;
  width: 2em;
  line-height: inherit;
}

.fa-border {
  border: solid 0.08em #eee;
  border-radius: .1em;
  padding: .2em .25em .15em;
}

.fa-pull-left {
  float: left;
}

.fa-pull-right {
  float: right;
}

.fa.fa-pull-left,
.fas.fa-pull-left,
.far.fa-pull-left,
.fal.fa-pull-left,
.fab.fa-pull-left {
  margin-right: .3em;
}

.fa.fa-pull-right,
.fas.fa-pull-right,
.far.fa-pull-right,
.fal.fa-pull-right,
.fab.fa-pull-right {
  margin-left: .3em;
}

.fa-spin {
  -webkit-animation: fa-spin 2s infinite linear;
  animation: fa-spin 2s infinite linear;
}

.fa-pulse {
  -webkit-animation: fa-spin 1s infinite steps(8);
  animation: fa-spin 1s infinite steps(8);
}

@-webkit-keyframes fa-spin {
  0% {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg);
  }

  100% {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}

@keyframes fa-spin {
  0% {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg);
  }

  100% {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}

.fa-rotate-90 {
  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=1)";
  -webkit-transform: rotate(90deg);
  transform: rotate(90deg);
}

.fa-rotate-180 {
  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=2)";
  -webkit-transform: rotate(180deg);
  transform: rotate(180deg);
}

.fa-rotate-270 {
  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=3)";
  -webkit-transform: rotate(270deg);
  transform: rotate(270deg);
}

.fa-flip-horizontal {
  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=0, mirror=1)";
  -webkit-transform: scale(-1, 1);
  transform: scale(-1, 1);
}

.fa-flip-vertical {
  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=2, mirror=1)";
  -webkit-transform: scale(1, -1);
  transform: scale(1, -1);
}

.fa-flip-both,
.fa-flip-horizontal.fa-flip-vertical {
  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=2, mirror=1)";
  -webkit-transform: scale(-1, -1);
  transform: scale(-1, -1);
}

:root .fa-rotate-90,
:root .fa-rotate-180,
:root .fa-rotate-270,
:root .fa-flip-horizontal,
:root .fa-flip-vertical,
:root .fa-flip-both {
  -webkit-filter: none;
  filter: none;
}

.fa-stack {
  display: inline-block;
  height: 2em;
  line-height: 2em;
  position: relative;
  vertical-align: middle;
  width: 2.5em;
}

.fa-stack-1x,
.fa-stack-2x {
  left: 0;
  position: absolute;
  text-align: center;
  width: 100%;
}

.fa-stack-1x {
  line-height: inherit;
}

.fa-stack-2x {
  font-size: 2em;
}

.fa-inverse {
  color: #fff;
}

/* Font Awesome uses the Unicode Private Use Area (PUA) to ensure screen
readers do not read off random characters that represent icons */

.fa-500px:before {
  content: "\f26e";
}

.fa-accessible-icon:before {
  content: "\f368";
}

.fa-accusoft:before {
  content: "\f369";
}

.fa-acquisitions-incorporated:before {
  content: "\f6af";
}

.fa-ad:before {
  content: "\f641";
}

.fa-address-book:before {
  content: "\f2b9";
}

.fa-address-card:before {
  content: "\f2bb";
}

.fa-adjust:before {
  content: "\f042";
}

.fa-adn:before {
  content: "\f170";
}

.fa-adversal:before {
  content: "\f36a";
}

.fa-affiliatetheme:before {
  content: "\f36b";
}

.fa-air-freshener:before {
  content: "\f5d0";
}

.fa-airbnb:before {
  content: "\f834";
}

.fa-algolia:before {
  content: "\f36c";
}

.fa-align-center:before {
  content: "\f037";
}

.fa-align-justify:before {
  content: "\f039";
}

.fa-align-left:before {
  content: "\f036";
}

.fa-align-right:before {
  content: "\f038";
}

.fa-alipay:before {
  content: "\f642";
}

.fa-allergies:before {
  content: "\f461";
}

.fa-amazon:before {
  content: "\f270";
}

.fa-amazon-pay:before {
  content: "\f42c";
}

.fa-ambulance:before {
  content: "\f0f9";
}

.fa-american-sign-language-interpreting:before {
  content: "\f2a3";
}

.fa-amilia:before {
  content: "\f36d";
}

.fa-anchor:before {
  content: "\f13d";
}

.fa-android:before {
  content: "\f17b";
}

.fa-angellist:before {
  content: "\f209";
}

.fa-angle-double-down:before {
  content: "\f103";
}

.fa-angle-double-left:before {
  content: "\f100";
}

.fa-angle-double-right:before {
  content: "\f101";
}

.fa-angle-double-up:before {
  content: "\f102";
}

.fa-angle-down:before {
  content: "\f107";
}

.fa-angle-left:before {
  content: "\f104";
}

.fa-angle-right:before {
  content: "\f105";
}

.fa-angle-up:before {
  content: "\f106";
}

.fa-angry:before {
  content: "\f556";
}

.fa-angrycreative:before {
  content: "\f36e";
}

.fa-angular:before {
  content: "\f420";
}

.fa-ankh:before {
  content: "\f644";
}

.fa-app-store:before {
  content: "\f36f";
}

.fa-app-store-ios:before {
  content: "\f370";
}

.fa-apper:before {
  content: "\f371";
}

.fa-apple:before {
  content: "\f179";
}

.fa-apple-alt:before {
  content: "\f5d1";
}

.fa-apple-pay:before {
  content: "\f415";
}

.fa-archive:before {
  content: "\f187";
}

.fa-archway:before {
  content: "\f557";
}

.fa-arrow-alt-circle-down:before {
  content: "\f358";
}

.fa-arrow-alt-circle-left:before {
  content: "\f359";
}

.fa-arrow-alt-circle-right:before {
  content: "\f35a";
}

.fa-arrow-alt-circle-up:before {
  content: "\f35b";
}

.fa-arrow-circle-down:before {
  content: "\f0ab";
}

.fa-arrow-circle-left:before {
  content: "\f0a8";
}

.fa-arrow-circle-right:before {
  content: "\f0a9";
}

.fa-arrow-circle-up:before {
  content: "\f0aa";
}

.fa-arrow-down:before {
  content: "\f063";
}

.fa-arrow-left:before {
  content: "\f060";
}

.fa-arrow-right:before {
  content: "\f061";
}

.fa-arrow-up:before {
  content: "\f062";
}

.fa-arrows-alt:before {
  content: "\f0b2";
}

.fa-arrows-alt-h:before {
  content: "\f337";
}

.fa-arrows-alt-v:before {
  content: "\f338";
}

.fa-artstation:before {
  content: "\f77a";
}

.fa-assistive-listening-systems:before {
  content: "\f2a2";
}

.fa-asterisk:before {
  content: "\f069";
}

.fa-asymmetrik:before {
  content: "\f372";
}

.fa-at:before {
  content: "\f1fa";
}

.fa-atlas:before {
  content: "\f558";
}

.fa-atlassian:before {
  content: "\f77b";
}

.fa-atom:before {
  content: "\f5d2";
}

.fa-audible:before {
  content: "\f373";
}

.fa-audio-description:before {
  content: "\f29e";
}

.fa-autoprefixer:before {
  content: "\f41c";
}

.fa-avianex:before {
  content: "\f374";
}

.fa-aviato:before {
  content: "\f421";
}

.fa-award:before {
  content: "\f559";
}

.fa-aws:before {
  content: "\f375";
}

.fa-baby:before {
  content: "\f77c";
}

.fa-baby-carriage:before {
  content: "\f77d";
}

.fa-backspace:before {
  content: "\f55a";
}

.fa-backward:before {
  content: "\f04a";
}

.fa-bacon:before {
  content: "\f7e5";
}

.fa-bacteria:before {
  content: "\e059";
}

.fa-bacterium:before {
  content: "\e05a";
}

.fa-bahai:before {
  content: "\f666";
}

.fa-balance-scale:before {
  content: "\f24e";
}

.fa-balance-scale-left:before {
  content: "\f515";
}

.fa-balance-scale-right:before {
  content: "\f516";
}

.fa-ban:before {
  content: "\f05e";
}

.fa-band-aid:before {
  content: "\f462";
}

.fa-bandcamp:before {
  content: "\f2d5";
}

.fa-barcode:before {
  content: "\f02a";
}

.fa-bars:before {
  content: "\f0c9";
}

.fa-baseball-ball:before {
  content: "\f433";
}

.fa-basketball-ball:before {
  content: "\f434";
}

.fa-bath:before {
  content: "\f2cd";
}

.fa-battery-empty:before {
  content: "\f244";
}

.fa-battery-full:before {
  content: "\f240";
}

.fa-battery-half:before {
  content: "\f242";
}

.fa-battery-quarter:before {
  content: "\f243";
}

.fa-battery-three-quarters:before {
  content: "\f241";
}

.fa-battle-net:before {
  content: "\f835";
}

.fa-bed:before {
  content: "\f236";
}

.fa-beer:before {
  content: "\f0fc";
}

.fa-behance:before {
  content: "\f1b4";
}

.fa-behance-square:before {
  content: "\f1b5";
}

.fa-bell:before {
  content: "\f0f3";
}

.fa-bell-slash:before {
  content: "\f1f6";
}

.fa-bezier-curve:before {
  content: "\f55b";
}

.fa-bible:before {
  content: "\f647";
}

.fa-bicycle:before {
  content: "\f206";
}

.fa-biking:before {
  content: "\f84a";
}

.fa-bimobject:before {
  content: "\f378";
}

.fa-binoculars:before {
  content: "\f1e5";
}

.fa-biohazard:before {
  content: "\f780";
}

.fa-birthday-cake:before {
  content: "\f1fd";
}

.fa-bitbucket:before {
  content: "\f171";
}

.fa-bitcoin:before {
  content: "\f379";
}

.fa-bity:before {
  content: "\f37a";
}

.fa-black-tie:before {
  content: "\f27e";
}

.fa-blackberry:before {
  content: "\f37b";
}

.fa-blender:before {
  content: "\f517";
}

.fa-blender-phone:before {
  content: "\f6b6";
}

.fa-blind:before {
  content: "\f29d";
}

.fa-blog:before {
  content: "\f781";
}

.fa-blogger:before {
  content: "\f37c";
}

.fa-blogger-b:before {
  content: "\f37d";
}

.fa-bluetooth:before {
  content: "\f293";
}

.fa-bluetooth-b:before {
  content: "\f294";
}

.fa-bold:before {
  content: "\f032";
}

.fa-bolt:before {
  content: "\f0e7";
}

.fa-bomb:before {
  content: "\f1e2";
}

.fa-bone:before {
  content: "\f5d7";
}

.fa-bong:before {
  content: "\f55c";
}

.fa-book:before {
  content: "\f02d";
}

.fa-book-dead:before {
  content: "\f6b7";
}

.fa-book-medical:before {
  content: "\f7e6";
}

.fa-book-open:before {
  content: "\f518";
}

.fa-book-reader:before {
  content: "\f5da";
}

.fa-bookmark:before {
  content: "\f02e";
}

.fa-bootstrap:before {
  content: "\f836";
}

.fa-border-all:before {
  content: "\f84c";
}

.fa-border-none:before {
  content: "\f850";
}

.fa-border-style:before {
  content: "\f853";
}

.fa-bowling-ball:before {
  content: "\f436";
}

.fa-box:before {
  content: "\f466";
}

.fa-box-open:before {
  content: "\f49e";
}

.fa-box-tissue:before {
  content: "\e05b";
}

.fa-boxes:before {
  content: "\f468";
}

.fa-braille:before {
  content: "\f2a1";
}

.fa-brain:before {
  content: "\f5dc";
}

.fa-bread-slice:before {
  content: "\f7ec";
}

.fa-briefcase:before {
  content: "\f0b1";
}

.fa-briefcase-medical:before {
  content: "\f469";
}

.fa-broadcast-tower:before {
  content: "\f519";
}

.fa-broom:before {
  content: "\f51a";
}

.fa-brush:before {
  content: "\f55d";
}

.fa-btc:before {
  content: "\f15a";
}

.fa-buffer:before {
  content: "\f837";
}

.fa-bug:before {
  content: "\f188";
}

.fa-building:before {
  content: "\f1ad";
}

.fa-bullhorn:before {
  content: "\f0a1";
}

.fa-bullseye:before {
  content: "\f140";
}

.fa-burn:before {
  content: "\f46a";
}

.fa-buromobelexperte:before {
  content: "\f37f";
}

.fa-bus:before {
  content: "\f207";
}

.fa-bus-alt:before {
  content: "\f55e";
}

.fa-business-time:before {
  content: "\f64a";
}

.fa-buy-n-large:before {
  content: "\f8a6";
}

.fa-buysellads:before {
  content: "\f20d";
}

.fa-calculator:before {
  content: "\f1ec";
}

.fa-calendar:before {
  content: "\f133";
}

.fa-calendar-alt:before {
  content: "\f073";
}

.fa-calendar-check:before {
  content: "\f274";
}

.fa-calendar-day:before {
  content: "\f783";
}

.fa-calendar-minus:before {
  content: "\f272";
}

.fa-calendar-plus:before {
  content: "\f271";
}

.fa-calendar-times:before {
  content: "\f273";
}

.fa-calendar-week:before {
  content: "\f784";
}

.fa-camera:before {
  content: "\f030";
}

.fa-camera-retro:before {
  content: "\f083";
}

.fa-campground:before {
  content: "\f6bb";
}

.fa-canadian-maple-leaf:before {
  content: "\f785";
}

.fa-candy-cane:before {
  content: "\f786";
}

.fa-cannabis:before {
  content: "\f55f";
}

.fa-capsules:before {
  content: "\f46b";
}

.fa-car:before {
  content: "\f1b9";
}

.fa-car-alt:before {
  content: "\f5de";
}

.fa-car-battery:before {
  content: "\f5df";
}

.fa-car-crash:before {
  content: "\f5e1";
}

.fa-car-side:before {
  content: "\f5e4";
}

.fa-caravan:before {
  content: "\f8ff";
}

.fa-caret-down:before {
  content: "\f0d7";
}

.fa-caret-left:before {
  content: "\f0d9";
}

.fa-caret-right:before {
  content: "\f0da";
}

.fa-caret-square-down:before {
  content: "\f150";
}

.fa-caret-square-left:before {
  content: "\f191";
}

.fa-caret-square-right:before {
  content: "\f152";
}

.fa-caret-square-up:before {
  content: "\f151";
}

.fa-caret-up:before {
  content: "\f0d8";
}

.fa-carrot:before {
  content: "\f787";
}

.fa-cart-arrow-down:before {
  content: "\f218";
}

.fa-cart-plus:before {
  content: "\f217";
}

.fa-cash-register:before {
  content: "\f788";
}

.fa-cat:before {
  content: "\f6be";
}

.fa-cc-amazon-pay:before {
  content: "\f42d";
}

.fa-cc-amex:before {
  content: "\f1f3";
}

.fa-cc-apple-pay:before {
  content: "\f416";
}

.fa-cc-diners-club:before {
  content: "\f24c";
}

.fa-cc-discover:before {
  content: "\f1f2";
}

.fa-cc-jcb:before {
  content: "\f24b";
}

.fa-cc-mastercard:before {
  content: "\f1f1";
}

.fa-cc-paypal:before {
  content: "\f1f4";
}

.fa-cc-stripe:before {
  content: "\f1f5";
}

.fa-cc-visa:before {
  content: "\f1f0";
}

.fa-centercode:before {
  content: "\f380";
}

.fa-centos:before {
  content: "\f789";
}

.fa-certificate:before {
  content: "\f0a3";
}

.fa-chair:before {
  content: "\f6c0";
}

.fa-chalkboard:before {
  content: "\f51b";
}

.fa-chalkboard-teacher:before {
  content: "\f51c";
}

.fa-charging-station:before {
  content: "\f5e7";
}

.fa-chart-area:before {
  content: "\f1fe";
}

.fa-chart-bar:before {
  content: "\f080";
}

.fa-chart-line:before {
  content: "\f201";
}

.fa-chart-pie:before {
  content: "\f200";
}

.fa-check:before {
  content: "\f00c";
}

.fa-check-circle:before {
  content: "\f058";
}

.fa-check-double:before {
  content: "\f560";
}

.fa-check-square:before {
  content: "\f14a";
}

.fa-cheese:before {
  content: "\f7ef";
}

.fa-chess:before {
  content: "\f439";
}

.fa-chess-bishop:before {
  content: "\f43a";
}

.fa-chess-board:before {
  content: "\f43c";
}

.fa-chess-king:before {
  content: "\f43f";
}

.fa-chess-knight:before {
  content: "\f441";
}

.fa-chess-pawn:before {
  content: "\f443";
}

.fa-chess-queen:before {
  content: "\f445";
}

.fa-chess-rook:before {
  content: "\f447";
}

.fa-chevron-circle-down:before {
  content: "\f13a";
}

.fa-chevron-circle-left:before {
  content: "\f137";
}

.fa-chevron-circle-right:before {
  content: "\f138";
}

.fa-chevron-circle-up:before {
  content: "\f139";
}

.fa-chevron-down:before {
  content: "\f078";
}

.fa-chevron-left:before {
  content: "\f053";
}

.fa-chevron-right:before {
  content: "\f054";
}

.fa-chevron-up:before {
  content: "\f077";
}

.fa-child:before {
  content: "\f1ae";
}

.fa-chrome:before {
  content: "\f268";
}

.fa-chromecast:before {
  content: "\f838";
}

.fa-church:before {
  content: "\f51d";
}

.fa-circle:before {
  content: "\f111";
}

.fa-circle-notch:before {
  content: "\f1ce";
}

.fa-city:before {
  content: "\f64f";
}

.fa-clinic-medical:before {
  content: "\f7f2";
}

.fa-clipboard:before {
  content: "\f328";
}

.fa-clipboard-check:before {
  content: "\f46c";
}

.fa-clipboard-list:before {
  content: "\f46d";
}

.fa-clock:before {
  content: "\f017";
}

.fa-clone:before {
  content: "\f24d";
}

.fa-closed-captioning:before {
  content: "\f20a";
}

.fa-cloud:before {
  content: "\f0c2";
}

.fa-cloud-download-alt:before {
  content: "\f381";
}

.fa-cloud-meatball:before {
  content: "\f73b";
}

.fa-cloud-moon:before {
  content: "\f6c3";
}

.fa-cloud-moon-rain:before {
  content: "\f73c";
}

.fa-cloud-rain:before {
  content: "\f73d";
}

.fa-cloud-showers-heavy:before {
  content: "\f740";
}

.fa-cloud-sun:before {
  content: "\f6c4";
}

.fa-cloud-sun-rain:before {
  content: "\f743";
}

.fa-cloud-upload-alt:before {
  content: "\f382";
}

.fa-cloudflare:before {
  content: "\e07d";
}

.fa-cloudscale:before {
  content: "\f383";
}

.fa-cloudsmith:before {
  content: "\f384";
}

.fa-cloudversify:before {
  content: "\f385";
}

.fa-cocktail:before {
  content: "\f561";
}

.fa-code:before {
  content: "\f121";
}

.fa-code-branch:before {
  content: "\f126";
}

.fa-codepen:before {
  content: "\f1cb";
}

.fa-codiepie:before {
  content: "\f284";
}

.fa-coffee:before {
  content: "\f0f4";
}

.fa-cog:before {
  content: "\f013";
}

.fa-cogs:before {
  content: "\f085";
}

.fa-coins:before {
  content: "\f51e";
}

.fa-columns:before {
  content: "\f0db";
}

.fa-comment:before {
  content: "\f075";
}

.fa-comment-alt:before {
  content: "\f27a";
}

.fa-comment-dollar:before {
  content: "\f651";
}

.fa-comment-dots:before {
  content: "\f4ad";
}

.fa-comment-medical:before {
  content: "\f7f5";
}

.fa-comment-slash:before {
  content: "\f4b3";
}

.fa-comments:before {
  content: "\f086";
}

.fa-comments-dollar:before {
  content: "\f653";
}

.fa-compact-disc:before {
  content: "\f51f";
}

.fa-compass:before {
  content: "\f14e";
}

.fa-compress:before {
  content: "\f066";
}

.fa-compress-alt:before {
  content: "\f422";
}

.fa-compress-arrows-alt:before {
  content: "\f78c";
}

.fa-concierge-bell:before {
  content: "\f562";
}

.fa-confluence:before {
  content: "\f78d";
}

.fa-connectdevelop:before {
  content: "\f20e";
}

.fa-contao:before {
  content: "\f26d";
}

.fa-cookie:before {
  content: "\f563";
}

.fa-cookie-bite:before {
  content: "\f564";
}

.fa-copy:before {
  content: "\f0c5";
}

.fa-copyright:before {
  content: "\f1f9";
}

.fa-cotton-bureau:before {
  content: "\f89e";
}

.fa-couch:before {
  content: "\f4b8";
}

.fa-cpanel:before {
  content: "\f388";
}

.fa-creative-commons:before {
  content: "\f25e";
}

.fa-creative-commons-by:before {
  content: "\f4e7";
}

.fa-creative-commons-nc:before {
  content: "\f4e8";
}

.fa-creative-commons-nc-eu:before {
  content: "\f4e9";
}

.fa-creative-commons-nc-jp:before {
  content: "\f4ea";
}

.fa-creative-commons-nd:before {
  content: "\f4eb";
}

.fa-creative-commons-pd:before {
  content: "\f4ec";
}

.fa-creative-commons-pd-alt:before {
  content: "\f4ed";
}

.fa-creative-commons-remix:before {
  content: "\f4ee";
}

.fa-creative-commons-sa:before {
  content: "\f4ef";
}

.fa-creative-commons-sampling:before {
  content: "\f4f0";
}

.fa-creative-commons-sampling-plus:before {
  content: "\f4f1";
}

.fa-creative-commons-share:before {
  content: "\f4f2";
}

.fa-creative-commons-zero:before {
  content: "\f4f3";
}

.fa-credit-card:before {
  content: "\f09d";
}

.fa-critical-role:before {
  content: "\f6c9";
}

.fa-crop:before {
  content: "\f125";
}

.fa-crop-alt:before {
  content: "\f565";
}

.fa-cross:before {
  content: "\f654";
}

.fa-crosshairs:before {
  content: "\f05b";
}

.fa-crow:before {
  content: "\f520";
}

.fa-crown:before {
  content: "\f521";
}

.fa-crutch:before {
  content: "\f7f7";
}

.fa-css3:before {
  content: "\f13c";
}

.fa-css3-alt:before {
  content: "\f38b";
}

.fa-cube:before {
  content: "\f1b2";
}

.fa-cubes:before {
  content: "\f1b3";
}

.fa-cut:before {
  content: "\f0c4";
}

.fa-cuttlefish:before {
  content: "\f38c";
}

.fa-d-and-d:before {
  content: "\f38d";
}

.fa-d-and-d-beyond:before {
  content: "\f6ca";
}

.fa-dailymotion:before {
  content: "\e052";
}

.fa-dashcube:before {
  content: "\f210";
}

.fa-database:before {
  content: "\f1c0";
}

.fa-deaf:before {
  content: "\f2a4";
}

.fa-deezer:before {
  content: "\e077";
}

.fa-delicious:before {
  content: "\f1a5";
}

.fa-democrat:before {
  content: "\f747";
}

.fa-deploydog:before {
  content: "\f38e";
}

.fa-deskpro:before {
  content: "\f38f";
}

.fa-desktop:before {
  content: "\f108";
}

.fa-dev:before {
  content: "\f6cc";
}

.fa-deviantart:before {
  content: "\f1bd";
}

.fa-dharmachakra:before {
  content: "\f655";
}

.fa-dhl:before {
  content: "\f790";
}

.fa-diagnoses:before {
  content: "\f470";
}

.fa-diaspora:before {
  content: "\f791";
}

.fa-dice:before {
  content: "\f522";
}

.fa-dice-d20:before {
  content: "\f6cf";
}

.fa-dice-d6:before {
  content: "\f6d1";
}

.fa-dice-five:before {
  content: "\f523";
}

.fa-dice-four:before {
  content: "\f524";
}

.fa-dice-one:before {
  content: "\f525";
}

.fa-dice-six:before {
  content: "\f526";
}

.fa-dice-three:before {
  content: "\f527";
}

.fa-dice-two:before {
  content: "\f528";
}

.fa-digg:before {
  content: "\f1a6";
}

.fa-digital-ocean:before {
  content: "\f391";
}

.fa-digital-tachograph:before {
  content: "\f566";
}

.fa-directions:before {
  content: "\f5eb";
}

.fa-discord:before {
  content: "\f392";
}

.fa-discourse:before {
  content: "\f393";
}

.fa-disease:before {
  content: "\f7fa";
}

.fa-divide:before {
  content: "\f529";
}

.fa-dizzy:before {
  content: "\f567";
}

.fa-dna:before {
  content: "\f471";
}

.fa-dochub:before {
  content: "\f394";
}

.fa-docker:before {
  content: "\f395";
}

.fa-dog:before {
  content: "\f6d3";
}

.fa-dollar-sign:before {
  content: "\f155";
}

.fa-dolly:before {
  content: "\f472";
}

.fa-dolly-flatbed:before {
  content: "\f474";
}

.fa-donate:before {
  content: "\f4b9";
}

.fa-door-closed:before {
  content: "\f52a";
}

.fa-door-open:before {
  content: "\f52b";
}

.fa-dot-circle:before {
  content: "\f192";
}

.fa-dove:before {
  content: "\f4ba";
}

.fa-download:before {
  content: "\f019";
}

.fa-draft2digital:before {
  content: "\f396";
}

.fa-drafting-compass:before {
  content: "\f568";
}

.fa-dragon:before {
  content: "\f6d5";
}

.fa-draw-polygon:before {
  content: "\f5ee";
}

.fa-dribbble:before {
  content: "\f17d";
}

.fa-dribbble-square:before {
  content: "\f397";
}

.fa-dropbox:before {
  content: "\f16b";
}

.fa-drum:before {
  content: "\f569";
}

.fa-drum-steelpan:before {
  content: "\f56a";
}

.fa-drumstick-bite:before {
  content: "\f6d7";
}

.fa-drupal:before {
  content: "\f1a9";
}

.fa-dumbbell:before {
  content: "\f44b";
}

.fa-dumpster:before {
  content: "\f793";
}

.fa-dumpster-fire:before {
  content: "\f794";
}

.fa-dungeon:before {
  content: "\f6d9";
}

.fa-dyalog:before {
  content: "\f399";
}

.fa-earlybirds:before {
  content: "\f39a";
}

.fa-ebay:before {
  content: "\f4f4";
}

.fa-edge:before {
  content: "\f282";
}

.fa-edge-legacy:before {
  content: "\e078";
}

.fa-edit:before {
  content: "\f044";
}

.fa-egg:before {
  content: "\f7fb";
}

.fa-eject:before {
  content: "\f052";
}

.fa-elementor:before {
  content: "\f430";
}

.fa-ellipsis-h:before {
  content: "\f141";
}

.fa-ellipsis-v:before {
  content: "\f142";
}

.fa-ello:before {
  content: "\f5f1";
}

.fa-ember:before {
  content: "\f423";
}

.fa-empire:before {
  content: "\f1d1";
}

.fa-envelope:before {
  content: "\f0e0";
}

.fa-envelope-open:before {
  content: "\f2b6";
}

.fa-envelope-open-text:before {
  content: "\f658";
}

.fa-envelope-square:before {
  content: "\f199";
}

.fa-envira:before {
  content: "\f299";
}

.fa-equals:before {
  content: "\f52c";
}

.fa-eraser:before {
  content: "\f12d";
}

.fa-erlang:before {
  content: "\f39d";
}

.fa-ethereum:before {
  content: "\f42e";
}

.fa-ethernet:before {
  content: "\f796";
}

.fa-etsy:before {
  content: "\f2d7";
}

.fa-euro-sign:before {
  content: "\f153";
}

.fa-evernote:before {
  content: "\f839";
}

.fa-exchange-alt:before {
  content: "\f362";
}

.fa-exclamation:before {
  content: "\f12a";
}

.fa-exclamation-circle:before {
  content: "\f06a";
}

.fa-exclamation-triangle:before {
  content: "\f071";
}

.fa-expand:before {
  content: "\f065";
}

.fa-expand-alt:before {
  content: "\f424";
}

.fa-expand-arrows-alt:before {
  content: "\f31e";
}

.fa-expeditedssl:before {
  content: "\f23e";
}

.fa-external-link-alt:before {
  content: "\f35d";
}

.fa-external-link-square-alt:before {
  content: "\f360";
}

.fa-eye:before {
  content: "\f06e";
}

.fa-eye-dropper:before {
  content: "\f1fb";
}

.fa-eye-slash:before {
  content: "\f070";
}

.fa-facebook:before {
  content: "\f09a";
}

.fa-facebook-f:before {
  content: "\f39e";
}

.fa-facebook-messenger:before {
  content: "\f39f";
}

.fa-facebook-square:before {
  content: "\f082";
}

.fa-fan:before {
  content: "\f863";
}

.fa-fantasy-flight-games:before {
  content: "\f6dc";
}

.fa-fast-backward:before {
  content: "\f049";
}

.fa-fast-forward:before {
  content: "\f050";
}

.fa-faucet:before {
  content: "\e005";
}

.fa-fax:before {
  content: "\f1ac";
}

.fa-feather:before {
  content: "\f52d";
}

.fa-feather-alt:before {
  content: "\f56b";
}

.fa-fedex:before {
  content: "\f797";
}

.fa-fedora:before {
  content: "\f798";
}

.fa-female:before {
  content: "\f182";
}

.fa-fighter-jet:before {
  content: "\f0fb";
}

.fa-figma:before {
  content: "\f799";
}

.fa-file:before {
  content: "\f15b";
}

.fa-file-alt:before {
  content: "\f15c";
}

.fa-file-archive:before {
  content: "\f1c6";
}

.fa-file-audio:before {
  content: "\f1c7";
}

.fa-file-code:before {
  content: "\f1c9";
}

.fa-file-contract:before {
  content: "\f56c";
}

.fa-file-csv:before {
  content: "\f6dd";
}

.fa-file-download:before {
  content: "\f56d";
}

.fa-file-excel:before {
  content: "\f1c3";
}

.fa-file-export:before {
  content: "\f56e";
}

.fa-file-image:before {
  content: "\f1c5";
}

.fa-file-import:before {
  content: "\f56f";
}

.fa-file-invoice:before {
  content: "\f570";
}

.fa-file-invoice-dollar:before {
  content: "\f571";
}

.fa-file-medical:before {
  content: "\f477";
}

.fa-file-medical-alt:before {
  content: "\f478";
}

.fa-file-pdf:before {
  content: "\f1c1";
}

.fa-file-powerpoint:before {
  content: "\f1c4";
}

.fa-file-prescription:before {
  content: "\f572";
}

.fa-file-signature:before {
  content: "\f573";
}

.fa-file-upload:before {
  content: "\f574";
}

.fa-file-video:before {
  content: "\f1c8";
}

.fa-file-word:before {
  content: "\f1c2";
}

.fa-fill:before {
  content: "\f575";
}

.fa-fill-drip:before {
  content: "\f576";
}

.fa-film:before {
  content: "\f008";
}

.fa-filter:before {
  content: "\f0b0";
}

.fa-fingerprint:before {
  content: "\f577";
}

.fa-fire:before {
  content: "\f06d";
}

.fa-fire-alt:before {
  content: "\f7e4";
}

.fa-fire-extinguisher:before {
  content: "\f134";
}

.fa-firefox:before {
  content: "\f269";
}

.fa-firefox-browser:before {
  content: "\e007";
}

.fa-first-aid:before {
  content: "\f479";
}

.fa-first-order:before {
  content: "\f2b0";
}

.fa-first-order-alt:before {
  content: "\f50a";
}

.fa-firstdraft:before {
  content: "\f3a1";
}

.fa-fish:before {
  content: "\f578";
}

.fa-fist-raised:before {
  content: "\f6de";
}

.fa-flag:before {
  content: "\f024";
}

.fa-flag-checkered:before {
  content: "\f11e";
}

.fa-flag-usa:before {
  content: "\f74d";
}

.fa-flask:before {
  content: "\f0c3";
}

.fa-flickr:before {
  content: "\f16e";
}

.fa-flipboard:before {
  content: "\f44d";
}

.fa-flushed:before {
  content: "\f579";
}

.fa-fly:before {
  content: "\f417";
}

.fa-folder:before {
  content: "\f07b";
}

.fa-folder-minus:before {
  content: "\f65d";
}

.fa-folder-open:before {
  content: "\f07c";
}

.fa-folder-plus:before {
  content: "\f65e";
}

.fa-font:before {
  content: "\f031";
}

.fa-font-awesome:before {
  content: "\f2b4";
}

.fa-font-awesome-alt:before {
  content: "\f35c";
}

.fa-font-awesome-flag:before {
  content: "\f425";
}

.fa-font-awesome-logo-full:before {
  content: "\f4e6";
}

.fa-fonticons:before {
  content: "\f280";
}

.fa-fonticons-fi:before {
  content: "\f3a2";
}

.fa-football-ball:before {
  content: "\f44e";
}

.fa-fort-awesome:before {
  content: "\f286";
}

.fa-fort-awesome-alt:before {
  content: "\f3a3";
}

.fa-forumbee:before {
  content: "\f211";
}

.fa-forward:before {
  content: "\f04e";
}

.fa-foursquare:before {
  content: "\f180";
}

.fa-free-code-camp:before {
  content: "\f2c5";
}

.fa-freebsd:before {
  content: "\f3a4";
}

.fa-frog:before {
  content: "\f52e";
}

.fa-frown:before {
  content: "\f119";
}

.fa-frown-open:before {
  content: "\f57a";
}

.fa-fulcrum:before {
  content: "\f50b";
}

.fa-funnel-dollar:before {
  content: "\f662";
}

.fa-futbol:before {
  content: "\f1e3";
}

.fa-galactic-republic:before {
  content: "\f50c";
}

.fa-galactic-senate:before {
  content: "\f50d";
}

.fa-gamepad:before {
  content: "\f11b";
}

.fa-gas-pump:before {
  content: "\f52f";
}

.fa-gavel:before {
  content: "\f0e3";
}

.fa-gem:before {
  content: "\f3a5";
}

.fa-genderless:before {
  content: "\f22d";
}

.fa-get-pocket:before {
  content: "\f265";
}

.fa-gg:before {
  content: "\f260";
}

.fa-gg-circle:before {
  content: "\f261";
}

.fa-ghost:before {
  content: "\f6e2";
}

.fa-gift:before {
  content: "\f06b";
}

.fa-gifts:before {
  content: "\f79c";
}

.fa-git:before {
  content: "\f1d3";
}

.fa-git-alt:before {
  content: "\f841";
}

.fa-git-square:before {
  content: "\f1d2";
}

.fa-github:before {
  content: "\f09b";
}

.fa-github-alt:before {
  content: "\f113";
}

.fa-github-square:before {
  content: "\f092";
}

.fa-gitkraken:before {
  content: "\f3a6";
}

.fa-gitlab:before {
  content: "\f296";
}

.fa-gitter:before {
  content: "\f426";
}

.fa-glass-cheers:before {
  content: "\f79f";
}

.fa-glass-martini:before {
  content: "\f000";
}

.fa-glass-martini-alt:before {
  content: "\f57b";
}

.fa-glass-whiskey:before {
  content: "\f7a0";
}

.fa-glasses:before {
  content: "\f530";
}

.fa-glide:before {
  content: "\f2a5";
}

.fa-glide-g:before {
  content: "\f2a6";
}

.fa-globe:before {
  content: "\f0ac";
}

.fa-globe-africa:before {
  content: "\f57c";
}

.fa-globe-americas:before {
  content: "\f57d";
}

.fa-globe-asia:before {
  content: "\f57e";
}

.fa-globe-europe:before {
  content: "\f7a2";
}

.fa-gofore:before {
  content: "\f3a7";
}

.fa-golf-ball:before {
  content: "\f450";
}

.fa-goodreads:before {
  content: "\f3a8";
}

.fa-goodreads-g:before {
  content: "\f3a9";
}

.fa-google:before {
  content: "\f1a0";
}

.fa-google-drive:before {
  content: "\f3aa";
}

.fa-google-pay:before {
  content: "\e079";
}

.fa-google-play:before {
  content: "\f3ab";
}

.fa-google-plus:before {
  content: "\f2b3";
}

.fa-google-plus-g:before {
  content: "\f0d5";
}

.fa-google-plus-square:before {
  content: "\f0d4";
}

.fa-google-wallet:before {
  content: "\f1ee";
}

.fa-gopuram:before {
  content: "\f664";
}

.fa-graduation-cap:before {
  content: "\f19d";
}

.fa-gratipay:before {
  content: "\f184";
}

.fa-grav:before {
  content: "\f2d6";
}

.fa-greater-than:before {
  content: "\f531";
}

.fa-greater-than-equal:before {
  content: "\f532";
}

.fa-grimace:before {
  content: "\f57f";
}

.fa-grin:before {
  content: "\f580";
}

.fa-grin-alt:before {
  content: "\f581";
}

.fa-grin-beam:before {
  content: "\f582";
}

.fa-grin-beam-sweat:before {
  content: "\f583";
}

.fa-grin-hearts:before {
  content: "\f584";
}

.fa-grin-squint:before {
  content: "\f585";
}

.fa-grin-squint-tears:before {
  content: "\f586";
}

.fa-grin-stars:before {
  content: "\f587";
}

.fa-grin-tears:before {
  content: "\f588";
}

.fa-grin-tongue:before {
  content: "\f589";
}

.fa-grin-tongue-squint:before {
  content: "\f58a";
}

.fa-grin-tongue-wink:before {
  content: "\f58b";
}

.fa-grin-wink:before {
  content: "\f58c";
}

.fa-grip-horizontal:before {
  content: "\f58d";
}

.fa-grip-lines:before {
  content: "\f7a4";
}

.fa-grip-lines-vertical:before {
  content: "\f7a5";
}

.fa-grip-vertical:before {
  content: "\f58e";
}

.fa-gripfire:before {
  content: "\f3ac";
}

.fa-grunt:before {
  content: "\f3ad";
}

.fa-guilded:before {
  content: "\e07e";
}

.fa-guitar:before {
  content: "\f7a6";
}

.fa-gulp:before {
  content: "\f3ae";
}

.fa-h-square:before {
  content: "\f0fd";
}

.fa-hacker-news:before {
  content: "\f1d4";
}

.fa-hacker-news-square:before {
  content: "\f3af";
}

.fa-hackerrank:before {
  content: "\f5f7";
}

.fa-hamburger:before {
  content: "\f805";
}

.fa-hammer:before {
  content: "\f6e3";
}

.fa-hamsa:before {
  content: "\f665";
}

.fa-hand-holding:before {
  content: "\f4bd";
}

.fa-hand-holding-heart:before {
  content: "\f4be";
}

.fa-hand-holding-medical:before {
  content: "\e05c";
}

.fa-hand-holding-usd:before {
  content: "\f4c0";
}

.fa-hand-holding-water:before {
  content: "\f4c1";
}

.fa-hand-lizard:before {
  content: "\f258";
}

.fa-hand-middle-finger:before {
  content: "\f806";
}

.fa-hand-paper:before {
  content: "\f256";
}

.fa-hand-peace:before {
  content: "\f25b";
}

.fa-hand-point-down:before {
  content: "\f0a7";
}

.fa-hand-point-left:before {
  content: "\f0a5";
}

.fa-hand-point-right:before {
  content: "\f0a4";
}

.fa-hand-point-up:before {
  content: "\f0a6";
}

.fa-hand-pointer:before {
  content: "\f25a";
}

.fa-hand-rock:before {
  content: "\f255";
}

.fa-hand-scissors:before {
  content: "\f257";
}

.fa-hand-sparkles:before {
  content: "\e05d";
}

.fa-hand-spock:before {
  content: "\f259";
}

.fa-hands:before {
  content: "\f4c2";
}

.fa-hands-helping:before {
  content: "\f4c4";
}

.fa-hands-wash:before {
  content: "\e05e";
}

.fa-handshake:before {
  content: "\f2b5";
}

.fa-handshake-alt-slash:before {
  content: "\e05f";
}

.fa-handshake-slash:before {
  content: "\e060";
}

.fa-hanukiah:before {
  content: "\f6e6";
}

.fa-hard-hat:before {
  content: "\f807";
}

.fa-hashtag:before {
  content: "\f292";
}

.fa-hat-cowboy:before {
  content: "\f8c0";
}

.fa-hat-cowboy-side:before {
  content: "\f8c1";
}

.fa-hat-wizard:before {
  content: "\f6e8";
}

.fa-hdd:before {
  content: "\f0a0";
}

.fa-head-side-cough:before {
  content: "\e061";
}

.fa-head-side-cough-slash:before {
  content: "\e062";
}

.fa-head-side-mask:before {
  content: "\e063";
}

.fa-head-side-virus:before {
  content: "\e064";
}

.fa-heading:before {
  content: "\f1dc";
}

.fa-headphones:before {
  content: "\f025";
}

.fa-headphones-alt:before {
  content: "\f58f";
}

.fa-headset:before {
  content: "\f590";
}

.fa-heart:before {
  content: "\f004";
}

.fa-heart-broken:before {
  content: "\f7a9";
}

.fa-heartbeat:before {
  content: "\f21e";
}

.fa-helicopter:before {
  content: "\f533";
}

.fa-highlighter:before {
  content: "\f591";
}

.fa-hiking:before {
  content: "\f6ec";
}

.fa-hippo:before {
  content: "\f6ed";
}

.fa-hips:before {
  content: "\f452";
}

.fa-hire-a-helper:before {
  content: "\f3b0";
}

.fa-history:before {
  content: "\f1da";
}

.fa-hive:before {
  content: "\e07f";
}

.fa-hockey-puck:before {
  content: "\f453";
}

.fa-holly-berry:before {
  content: "\f7aa";
}

.fa-home:before {
  content: "\f015";
}

.fa-hooli:before {
  content: "\f427";
}

.fa-hornbill:before {
  content: "\f592";
}

.fa-horse:before {
  content: "\f6f0";
}

.fa-horse-head:before {
  content: "\f7ab";
}

.fa-hospital:before {
  content: "\f0f8";
}

.fa-hospital-alt:before {
  content: "\f47d";
}

.fa-hospital-symbol:before {
  content: "\f47e";
}

.fa-hospital-user:before {
  content: "\f80d";
}

.fa-hot-tub:before {
  content: "\f593";
}

.fa-hotdog:before {
  content: "\f80f";
}

.fa-hotel:before {
  content: "\f594";
}

.fa-hotjar:before {
  content: "\f3b1";
}

.fa-hourglass:before {
  content: "\f254";
}

.fa-hourglass-end:before {
  content: "\f253";
}

.fa-hourglass-half:before {
  content: "\f252";
}

.fa-hourglass-start:before {
  content: "\f251";
}

.fa-house-damage:before {
  content: "\f6f1";
}

.fa-house-user:before {
  content: "\e065";
}

.fa-houzz:before {
  content: "\f27c";
}

.fa-hryvnia:before {
  content: "\f6f2";
}

.fa-html5:before {
  content: "\f13b";
}

.fa-hubspot:before {
  content: "\f3b2";
}

.fa-i-cursor:before {
  content: "\f246";
}

.fa-ice-cream:before {
  content: "\f810";
}

.fa-icicles:before {
  content: "\f7ad";
}

.fa-icons:before {
  content: "\f86d";
}

.fa-id-badge:before {
  content: "\f2c1";
}

.fa-id-card:before {
  content: "\f2c2";
}

.fa-id-card-alt:before {
  content: "\f47f";
}

.fa-ideal:before {
  content: "\e013";
}

.fa-igloo:before {
  content: "\f7ae";
}

.fa-image:before {
  content: "\f03e";
}

.fa-images:before {
  content: "\f302";
}

.fa-imdb:before {
  content: "\f2d8";
}

.fa-inbox:before {
  content: "\f01c";
}

.fa-indent:before {
  content: "\f03c";
}

.fa-industry:before {
  content: "\f275";
}

.fa-infinity:before {
  content: "\f534";
}

.fa-info:before {
  content: "\f129";
}

.fa-info-circle:before {
  content: "\f05a";
}

.fa-innosoft:before {
  content: "\e080";
}

.fa-instagram:before {
  content: "\f16d";
}

.fa-instagram-square:before {
  content: "\e055";
}

.fa-instalod:before {
  content: "\e081";
}

.fa-intercom:before {
  content: "\f7af";
}

.fa-internet-explorer:before {
  content: "\f26b";
}

.fa-invision:before {
  content: "\f7b0";
}

.fa-ioxhost:before {
  content: "\f208";
}

.fa-italic:before {
  content: "\f033";
}

.fa-itch-io:before {
  content: "\f83a";
}

.fa-itunes:before {
  content: "\f3b4";
}

.fa-itunes-note:before {
  content: "\f3b5";
}

.fa-java:before {
  content: "\f4e4";
}

.fa-jedi:before {
  content: "\f669";
}

.fa-jedi-order:before {
  content: "\f50e";
}

.fa-jenkins:before {
  content: "\f3b6";
}

.fa-jira:before {
  content: "\f7b1";
}

.fa-joget:before {
  content: "\f3b7";
}

.fa-joint:before {
  content: "\f595";
}

.fa-joomla:before {
  content: "\f1aa";
}

.fa-journal-whills:before {
  content: "\f66a";
}

.fa-js:before {
  content: "\f3b8";
}

.fa-js-square:before {
  content: "\f3b9";
}

.fa-jsfiddle:before {
  content: "\f1cc";
}

.fa-kaaba:before {
  content: "\f66b";
}

.fa-kaggle:before {
  content: "\f5fa";
}

.fa-key:before {
  content: "\f084";
}

.fa-keybase:before {
  content: "\f4f5";
}

.fa-keyboard:before {
  content: "\f11c";
}

.fa-keycdn:before {
  content: "\f3ba";
}

.fa-khanda:before {
  content: "\f66d";
}

.fa-kickstarter:before {
  content: "\f3bb";
}

.fa-kickstarter-k:before {
  content: "\f3bc";
}

.fa-kiss:before {
  content: "\f596";
}

.fa-kiss-beam:before {
  content: "\f597";
}

.fa-kiss-wink-heart:before {
  content: "\f598";
}

.fa-kiwi-bird:before {
  content: "\f535";
}

.fa-korvue:before {
  content: "\f42f";
}

.fa-landmark:before {
  content: "\f66f";
}

.fa-language:before {
  content: "\f1ab";
}

.fa-laptop:before {
  content: "\f109";
}

.fa-laptop-code:before {
  content: "\f5fc";
}

.fa-laptop-house:before {
  content: "\e066";
}

.fa-laptop-medical:before {
  content: "\f812";
}

.fa-laravel:before {
  content: "\f3bd";
}

.fa-lastfm:before {
  content: "\f202";
}

.fa-lastfm-square:before {
  content: "\f203";
}

.fa-laugh:before {
  content: "\f599";
}

.fa-laugh-beam:before {
  content: "\f59a";
}

.fa-laugh-squint:before {
  content: "\f59b";
}

.fa-laugh-wink:before {
  content: "\f59c";
}

.fa-layer-group:before {
  content: "\f5fd";
}

.fa-leaf:before {
  content: "\f06c";
}

.fa-leanpub:before {
  content: "\f212";
}

.fa-lemon:before {
  content: "\f094";
}

.fa-less:before {
  content: "\f41d";
}

.fa-less-than:before {
  content: "\f536";
}

.fa-less-than-equal:before {
  content: "\f537";
}

.fa-level-down-alt:before {
  content: "\f3be";
}

.fa-level-up-alt:before {
  content: "\f3bf";
}

.fa-life-ring:before {
  content: "\f1cd";
}

.fa-lightbulb:before {
  content: "\f0eb";
}

.fa-line:before {
  content: "\f3c0";
}

.fa-link:before {
  content: "\f0c1";
}

.fa-linkedin:before {
  content: "\f08c";
}

.fa-linkedin-in:before {
  content: "\f0e1";
}

.fa-linode:before {
  content: "\f2b8";
}

.fa-linux:before {
  content: "\f17c";
}

.fa-lira-sign:before {
  content: "\f195";
}

.fa-list:before {
  content: "\f03a";
}

.fa-list-alt:before {
  content: "\f022";
}

.fa-list-ol:before {
  content: "\f0cb";
}

.fa-list-ul:before {
  content: "\f0ca";
}

.fa-location-arrow:before {
  content: "\f124";
}

.fa-lock:before {
  content: "\f023";
}

.fa-lock-open:before {
  content: "\f3c1";
}

.fa-long-arrow-alt-down:before {
  content: "\f309";
}

.fa-long-arrow-alt-left:before {
  content: "\f30a";
}

.fa-long-arrow-alt-right:before {
  content: "\f30b";
}

.fa-long-arrow-alt-up:before {
  content: "\f30c";
}

.fa-low-vision:before {
  content: "\f2a8";
}

.fa-luggage-cart:before {
  content: "\f59d";
}

.fa-lungs:before {
  content: "\f604";
}

.fa-lungs-virus:before {
  content: "\e067";
}

.fa-lyft:before {
  content: "\f3c3";
}

.fa-magento:before {
  content: "\f3c4";
}

.fa-magic:before {
  content: "\f0d0";
}

.fa-magnet:before {
  content: "\f076";
}

.fa-mail-bulk:before {
  content: "\f674";
}

.fa-mailchimp:before {
  content: "\f59e";
}

.fa-male:before {
  content: "\f183";
}

.fa-mandalorian:before {
  content: "\f50f";
}

.fa-map:before {
  content: "\f279";
}

.fa-map-marked:before {
  content: "\f59f";
}

.fa-map-marked-alt:before {
  content: "\f5a0";
}

.fa-map-marker:before {
  content: "\f041";
}

.fa-map-marker-alt:before {
  content: "\f3c5";
}

.fa-map-pin:before {
  content: "\f276";
}

.fa-map-signs:before {
  content: "\f277";
}

.fa-markdown:before {
  content: "\f60f";
}

.fa-marker:before {
  content: "\f5a1";
}

.fa-mars:before {
  content: "\f222";
}

.fa-mars-double:before {
  content: "\f227";
}

.fa-mars-stroke:before {
  content: "\f229";
}

.fa-mars-stroke-h:before {
  content: "\f22b";
}

.fa-mars-stroke-v:before {
  content: "\f22a";
}

.fa-mask:before {
  content: "\f6fa";
}

.fa-mastodon:before {
  content: "\f4f6";
}

.fa-maxcdn:before {
  content: "\f136";
}

.fa-mdb:before {
  content: "\f8ca";
}

.fa-medal:before {
  content: "\f5a2";
}

.fa-medapps:before {
  content: "\f3c6";
}

.fa-medium:before {
  content: "\f23a";
}

.fa-medium-m:before {
  content: "\f3c7";
}

.fa-medkit:before {
  content: "\f0fa";
}

.fa-medrt:before {
  content: "\f3c8";
}

.fa-meetup:before {
  content: "\f2e0";
}

.fa-megaport:before {
  content: "\f5a3";
}

.fa-meh:before {
  content: "\f11a";
}

.fa-meh-blank:before {
  content: "\f5a4";
}

.fa-meh-rolling-eyes:before {
  content: "\f5a5";
}

.fa-memory:before {
  content: "\f538";
}

.fa-mendeley:before {
  content: "\f7b3";
}

.fa-menorah:before {
  content: "\f676";
}

.fa-mercury:before {
  content: "\f223";
}

.fa-meteor:before {
  content: "\f753";
}

.fa-microblog:before {
  content: "\e01a";
}

.fa-microchip:before {
  content: "\f2db";
}

.fa-microphone:before {
  content: "\f130";
}

.fa-microphone-alt:before {
  content: "\f3c9";
}

.fa-microphone-alt-slash:before {
  content: "\f539";
}

.fa-microphone-slash:before {
  content: "\f131";
}

.fa-microscope:before {
  content: "\f610";
}

.fa-microsoft:before {
  content: "\f3ca";
}

.fa-minus:before {
  content: "\f068";
}

.fa-minus-circle:before {
  content: "\f056";
}

.fa-minus-square:before {
  content: "\f146";
}

.fa-mitten:before {
  content: "\f7b5";
}

.fa-mix:before {
  content: "\f3cb";
}

.fa-mixcloud:before {
  content: "\f289";
}

.fa-mixer:before {
  content: "\e056";
}

.fa-mizuni:before {
  content: "\f3cc";
}

.fa-mobile:before {
  content: "\f10b";
}

.fa-mobile-alt:before {
  content: "\f3cd";
}

.fa-modx:before {
  content: "\f285";
}

.fa-monero:before {
  content: "\f3d0";
}

.fa-money-bill:before {
  content: "\f0d6";
}

.fa-money-bill-alt:before {
  content: "\f3d1";
}

.fa-money-bill-wave:before {
  content: "\f53a";
}

.fa-money-bill-wave-alt:before {
  content: "\f53b";
}

.fa-money-check:before {
  content: "\f53c";
}

.fa-money-check-alt:before {
  content: "\f53d";
}

.fa-monument:before {
  content: "\f5a6";
}

.fa-moon:before {
  content: "\f186";
}

.fa-mortar-pestle:before {
  content: "\f5a7";
}

.fa-mosque:before {
  content: "\f678";
}

.fa-motorcycle:before {
  content: "\f21c";
}

.fa-mountain:before {
  content: "\f6fc";
}

.fa-mouse:before {
  content: "\f8cc";
}

.fa-mouse-pointer:before {
  content: "\f245";
}

.fa-mug-hot:before {
  content: "\f7b6";
}

.fa-music:before {
  content: "\f001";
}

.fa-napster:before {
  content: "\f3d2";
}

.fa-neos:before {
  content: "\f612";
}

.fa-network-wired:before {
  content: "\f6ff";
}

.fa-neuter:before {
  content: "\f22c";
}

.fa-newspaper:before {
  content: "\f1ea";
}

.fa-nimblr:before {
  content: "\f5a8";
}

.fa-node:before {
  content: "\f419";
}

.fa-node-js:before {
  content: "\f3d3";
}

.fa-not-equal:before {
  content: "\f53e";
}

.fa-notes-medical:before {
  content: "\f481";
}

.fa-npm:before {
  content: "\f3d4";
}

.fa-ns8:before {
  content: "\f3d5";
}

.fa-nutritionix:before {
  content: "\f3d6";
}

.fa-object-group:before {
  content: "\f247";
}

.fa-object-ungroup:before {
  content: "\f248";
}

.fa-octopus-deploy:before {
  content: "\e082";
}

.fa-odnoklassniki:before {
  content: "\f263";
}

.fa-odnoklassniki-square:before {
  content: "\f264";
}

.fa-oil-can:before {
  content: "\f613";
}

.fa-old-republic:before {
  content: "\f510";
}

.fa-om:before {
  content: "\f679";
}

.fa-opencart:before {
  content: "\f23d";
}

.fa-openid:before {
  content: "\f19b";
}

.fa-opera:before {
  content: "\f26a";
}

.fa-optin-monster:before {
  content: "\f23c";
}

.fa-orcid:before {
  content: "\f8d2";
}

.fa-osi:before {
  content: "\f41a";
}

.fa-otter:before {
  content: "\f700";
}

.fa-outdent:before {
  content: "\f03b";
}

.fa-page4:before {
  content: "\f3d7";
}

.fa-pagelines:before {
  content: "\f18c";
}

.fa-pager:before {
  content: "\f815";
}

.fa-paint-brush:before {
  content: "\f1fc";
}

.fa-paint-roller:before {
  content: "\f5aa";
}

.fa-palette:before {
  content: "\f53f";
}

.fa-palfed:before {
  content: "\f3d8";
}

.fa-pallet:before {
  content: "\f482";
}

.fa-paper-plane:before {
  content: "\f1d8";
}

.fa-paperclip:before {
  content: "\f0c6";
}

.fa-parachute-box:before {
  content: "\f4cd";
}

.fa-paragraph:before {
  content: "\f1dd";
}

.fa-parking:before {
  content: "\f540";
}

.fa-passport:before {
  content: "\f5ab";
}

.fa-pastafarianism:before {
  content: "\f67b";
}

.fa-paste:before {
  content: "\f0ea";
}

.fa-patreon:before {
  content: "\f3d9";
}

.fa-pause:before {
  content: "\f04c";
}

.fa-pause-circle:before {
  content: "\f28b";
}

.fa-paw:before {
  content: "\f1b0";
}

.fa-paypal:before {
  content: "\f1ed";
}

.fa-peace:before {
  content: "\f67c";
}

.fa-pen:before {
  content: "\f304";
}

.fa-pen-alt:before {
  content: "\f305";
}

.fa-pen-fancy:before {
  content: "\f5ac";
}

.fa-pen-nib:before {
  content: "\f5ad";
}

.fa-pen-square:before {
  content: "\f14b";
}

.fa-pencil-alt:before {
  content: "\f303";
}

.fa-pencil-ruler:before {
  content: "\f5ae";
}

.fa-penny-arcade:before {
  content: "\f704";
}

.fa-people-arrows:before {
  content: "\e068";
}

.fa-people-carry:before {
  content: "\f4ce";
}

.fa-pepper-hot:before {
  content: "\f816";
}

.fa-perbyte:before {
  content: "\e083";
}

.fa-percent:before {
  content: "\f295";
}

.fa-percentage:before {
  content: "\f541";
}

.fa-periscope:before {
  content: "\f3da";
}

.fa-person-booth:before {
  content: "\f756";
}

.fa-phabricator:before {
  content: "\f3db";
}

.fa-phoenix-framework:before {
  content: "\f3dc";
}

.fa-phoenix-squadron:before {
  content: "\f511";
}

.fa-phone:before {
  content: "\f095";
}

.fa-phone-alt:before {
  content: "\f879";
}

.fa-phone-slash:before {
  content: "\f3dd";
}

.fa-phone-square:before {
  content: "\f098";
}

.fa-phone-square-alt:before {
  content: "\f87b";
}

.fa-phone-volume:before {
  content: "\f2a0";
}

.fa-photo-video:before {
  content: "\f87c";
}

.fa-php:before {
  content: "\f457";
}

.fa-pied-piper:before {
  content: "\f2ae";
}

.fa-pied-piper-alt:before {
  content: "\f1a8";
}

.fa-pied-piper-hat:before {
  content: "\f4e5";
}

.fa-pied-piper-pp:before {
  content: "\f1a7";
}

.fa-pied-piper-square:before {
  content: "\e01e";
}

.fa-piggy-bank:before {
  content: "\f4d3";
}

.fa-pills:before {
  content: "\f484";
}

.fa-pinterest:before {
  content: "\f0d2";
}

.fa-pinterest-p:before {
  content: "\f231";
}

.fa-pinterest-square:before {
  content: "\f0d3";
}

.fa-pizza-slice:before {
  content: "\f818";
}

.fa-place-of-worship:before {
  content: "\f67f";
}

.fa-plane:before {
  content: "\f072";
}

.fa-plane-arrival:before {
  content: "\f5af";
}

.fa-plane-departure:before {
  content: "\f5b0";
}

.fa-plane-slash:before {
  content: "\e069";
}

.fa-play:before {
  content: "\f04b";
}

.fa-play-circle:before {
  content: "\f144";
}

.fa-playstation:before {
  content: "\f3df";
}

.fa-plug:before {
  content: "\f1e6";
}

.fa-plus:before {
  content: "\f067";
}

.fa-plus-circle:before {
  content: "\f055";
}

.fa-plus-square:before {
  content: "\f0fe";
}

.fa-podcast:before {
  content: "\f2ce";
}

.fa-poll:before {
  content: "\f681";
}

.fa-poll-h:before {
  content: "\f682";
}

.fa-poo:before {
  content: "\f2fe";
}

.fa-poo-storm:before {
  content: "\f75a";
}

.fa-poop:before {
  content: "\f619";
}

.fa-portrait:before {
  content: "\f3e0";
}

.fa-pound-sign:before {
  content: "\f154";
}

.fa-power-off:before {
  content: "\f011";
}

.fa-pray:before {
  content: "\f683";
}

.fa-praying-hands:before {
  content: "\f684";
}

.fa-prescription:before {
  content: "\f5b1";
}

.fa-prescription-bottle:before {
  content: "\f485";
}

.fa-prescription-bottle-alt:before {
  content: "\f486";
}

.fa-print:before {
  content: "\f02f";
}

.fa-procedures:before {
  content: "\f487";
}

.fa-product-hunt:before {
  content: "\f288";
}

.fa-project-diagram:before {
  content: "\f542";
}

.fa-pump-medical:before {
  content: "\e06a";
}

.fa-pump-soap:before {
  content: "\e06b";
}

.fa-pushed:before {
  content: "\f3e1";
}

.fa-puzzle-piece:before {
  content: "\f12e";
}

.fa-python:before {
  content: "\f3e2";
}

.fa-qq:before {
  content: "\f1d6";
}

.fa-qrcode:before {
  content: "\f029";
}

.fa-question:before {
  content: "\f128";
}

.fa-question-circle:before {
  content: "\f059";
}

.fa-quidditch:before {
  content: "\f458";
}

.fa-quinscape:before {
  content: "\f459";
}

.fa-quora:before {
  content: "\f2c4";
}

.fa-quote-left:before {
  content: "\f10d";
}

.fa-quote-right:before {
  content: "\f10e";
}

.fa-quran:before {
  content: "\f687";
}

.fa-r-project:before {
  content: "\f4f7";
}

.fa-radiation:before {
  content: "\f7b9";
}

.fa-radiation-alt:before {
  content: "\f7ba";
}

.fa-rainbow:before {
  content: "\f75b";
}

.fa-random:before {
  content: "\f074";
}

.fa-raspberry-pi:before {
  content: "\f7bb";
}

.fa-ravelry:before {
  content: "\f2d9";
}

.fa-react:before {
  content: "\f41b";
}

.fa-reacteurope:before {
  content: "\f75d";
}

.fa-readme:before {
  content: "\f4d5";
}

.fa-rebel:before {
  content: "\f1d0";
}

.fa-receipt:before {
  content: "\f543";
}

.fa-record-vinyl:before {
  content: "\f8d9";
}

.fa-recycle:before {
  content: "\f1b8";
}

.fa-red-river:before {
  content: "\f3e3";
}

.fa-reddit:before {
  content: "\f1a1";
}

.fa-reddit-alien:before {
  content: "\f281";
}

.fa-reddit-square:before {
  content: "\f1a2";
}

.fa-redhat:before {
  content: "\f7bc";
}

.fa-redo:before {
  content: "\f01e";
}

.fa-redo-alt:before {
  content: "\f2f9";
}

.fa-registered:before {
  content: "\f25d";
}

.fa-remove-format:before {
  content: "\f87d";
}

.fa-renren:before {
  content: "\f18b";
}

.fa-reply:before {
  content: "\f3e5";
}

.fa-reply-all:before {
  content: "\f122";
}

.fa-replyd:before {
  content: "\f3e6";
}

.fa-republican:before {
  content: "\f75e";
}

.fa-researchgate:before {
  content: "\f4f8";
}

.fa-resolving:before {
  content: "\f3e7";
}

.fa-restroom:before {
  content: "\f7bd";
}

.fa-retweet:before {
  content: "\f079";
}

.fa-rev:before {
  content: "\f5b2";
}

.fa-ribbon:before {
  content: "\f4d6";
}

.fa-ring:before {
  content: "\f70b";
}

.fa-road:before {
  content: "\f018";
}

.fa-robot:before {
  content: "\f544";
}

.fa-rocket:before {
  content: "\f135";
}

.fa-rocketchat:before {
  content: "\f3e8";
}

.fa-rockrms:before {
  content: "\f3e9";
}

.fa-route:before {
  content: "\f4d7";
}

.fa-rss:before {
  content: "\f09e";
}

.fa-rss-square:before {
  content: "\f143";
}

.fa-ruble-sign:before {
  content: "\f158";
}

.fa-ruler:before {
  content: "\f545";
}

.fa-ruler-combined:before {
  content: "\f546";
}

.fa-ruler-horizontal:before {
  content: "\f547";
}

.fa-ruler-vertical:before {
  content: "\f548";
}

.fa-running:before {
  content: "\f70c";
}

.fa-rupee-sign:before {
  content: "\f156";
}

.fa-rust:before {
  content: "\e07a";
}

.fa-sad-cry:before {
  content: "\f5b3";
}

.fa-sad-tear:before {
  content: "\f5b4";
}

.fa-safari:before {
  content: "\f267";
}

.fa-salesforce:before {
  content: "\f83b";
}

.fa-sass:before {
  content: "\f41e";
}

.fa-satellite:before {
  content: "\f7bf";
}

.fa-satellite-dish:before {
  content: "\f7c0";
}

.fa-save:before {
  content: "\f0c7";
}

.fa-schlix:before {
  content: "\f3ea";
}

.fa-school:before {
  content: "\f549";
}

.fa-screwdriver:before {
  content: "\f54a";
}

.fa-scribd:before {
  content: "\f28a";
}

.fa-scroll:before {
  content: "\f70e";
}

.fa-sd-card:before {
  content: "\f7c2";
}

.fa-search:before {
  content: "\f002";
}

.fa-search-dollar:before {
  content: "\f688";
}

.fa-search-location:before {
  content: "\f689";
}

.fa-search-minus:before {
  content: "\f010";
}

.fa-search-plus:before {
  content: "\f00e";
}

.fa-searchengin:before {
  content: "\f3eb";
}

.fa-seedling:before {
  content: "\f4d8";
}

.fa-sellcast:before {
  content: "\f2da";
}

.fa-sellsy:before {
  content: "\f213";
}

.fa-server:before {
  content: "\f233";
}

.fa-servicestack:before {
  content: "\f3ec";
}

.fa-shapes:before {
  content: "\f61f";
}

.fa-share:before {
  content: "\f064";
}

.fa-share-alt:before {
  content: "\f1e0";
}

.fa-share-alt-square:before {
  content: "\f1e1";
}

.fa-share-square:before {
  content: "\f14d";
}

.fa-shekel-sign:before {
  content: "\f20b";
}

.fa-shield-alt:before {
  content: "\f3ed";
}

.fa-shield-virus:before {
  content: "\e06c";
}

.fa-ship:before {
  content: "\f21a";
}

.fa-shipping-fast:before {
  content: "\f48b";
}

.fa-shirtsinbulk:before {
  content: "\f214";
}

.fa-shoe-prints:before {
  content: "\f54b";
}

.fa-shopify:before {
  content: "\e057";
}

.fa-shopping-bag:before {
  content: "\f290";
}

.fa-shopping-basket:before {
  content: "\f291";
}

.fa-shopping-cart:before {
  content: "\f07a";
}

.fa-shopware:before {
  content: "\f5b5";
}

.fa-shower:before {
  content: "\f2cc";
}

.fa-shuttle-van:before {
  content: "\f5b6";
}

.fa-sign:before {
  content: "\f4d9";
}

.fa-sign-in-alt:before {
  content: "\f2f6";
}

.fa-sign-language:before {
  content: "\f2a7";
}

.fa-sign-out-alt:before {
  content: "\f2f5";
}

.fa-signal:before {
  content: "\f012";
}

.fa-signature:before {
  content: "\f5b7";
}

.fa-sim-card:before {
  content: "\f7c4";
}

.fa-simplybuilt:before {
  content: "\f215";
}

.fa-sink:before {
  content: "\e06d";
}

.fa-sistrix:before {
  content: "\f3ee";
}

.fa-sitemap:before {
  content: "\f0e8";
}

.fa-sith:before {
  content: "\f512";
}

.fa-skating:before {
  content: "\f7c5";
}

.fa-sketch:before {
  content: "\f7c6";
}

.fa-skiing:before {
  content: "\f7c9";
}

.fa-skiing-nordic:before {
  content: "\f7ca";
}

.fa-skull:before {
  content: "\f54c";
}

.fa-skull-crossbones:before {
  content: "\f714";
}

.fa-skyatlas:before {
  content: "\f216";
}

.fa-skype:before {
  content: "\f17e";
}

.fa-slack:before {
  content: "\f198";
}

.fa-slack-hash:before {
  content: "\f3ef";
}

.fa-slash:before {
  content: "\f715";
}

.fa-sleigh:before {
  content: "\f7cc";
}

.fa-sliders-h:before {
  content: "\f1de";
}

.fa-slideshare:before {
  content: "\f1e7";
}

.fa-smile:before {
  content: "\f118";
}

.fa-smile-beam:before {
  content: "\f5b8";
}

.fa-smile-wink:before {
  content: "\f4da";
}

.fa-smog:before {
  content: "\f75f";
}

.fa-smoking:before {
  content: "\f48d";
}

.fa-smoking-ban:before {
  content: "\f54d";
}

.fa-sms:before {
  content: "\f7cd";
}

.fa-snapchat:before {
  content: "\f2ab";
}

.fa-snapchat-ghost:before {
  content: "\f2ac";
}

.fa-snapchat-square:before {
  content: "\f2ad";
}

.fa-snowboarding:before {
  content: "\f7ce";
}

.fa-snowflake:before {
  content: "\f2dc";
}

.fa-snowman:before {
  content: "\f7d0";
}

.fa-snowplow:before {
  content: "\f7d2";
}

.fa-soap:before {
  content: "\e06e";
}

.fa-socks:before {
  content: "\f696";
}

.fa-solar-panel:before {
  content: "\f5ba";
}

.fa-sort:before {
  content: "\f0dc";
}

.fa-sort-alpha-down:before {
  content: "\f15d";
}

.fa-sort-alpha-down-alt:before {
  content: "\f881";
}

.fa-sort-alpha-up:before {
  content: "\f15e";
}

.fa-sort-alpha-up-alt:before {
  content: "\f882";
}

.fa-sort-amount-down:before {
  content: "\f160";
}

.fa-sort-amount-down-alt:before {
  content: "\f884";
}

.fa-sort-amount-up:before {
  content: "\f161";
}

.fa-sort-amount-up-alt:before {
  content: "\f885";
}

.fa-sort-down:before {
  content: "\f0dd";
}

.fa-sort-numeric-down:before {
  content: "\f162";
}

.fa-sort-numeric-down-alt:before {
  content: "\f886";
}

.fa-sort-numeric-up:before {
  content: "\f163";
}

.fa-sort-numeric-up-alt:before {
  content: "\f887";
}

.fa-sort-up:before {
  content: "\f0de";
}

.fa-soundcloud:before {
  content: "\f1be";
}

.fa-sourcetree:before {
  content: "\f7d3";
}

.fa-spa:before {
  content: "\f5bb";
}

.fa-space-shuttle:before {
  content: "\f197";
}

.fa-speakap:before {
  content: "\f3f3";
}

.fa-speaker-deck:before {
  content: "\f83c";
}

.fa-spell-check:before {
  content: "\f891";
}

.fa-spider:before {
  content: "\f717";
}

.fa-spinner:before {
  content: "\f110";
}

.fa-splotch:before {
  content: "\f5bc";
}

.fa-spotify:before {
  content: "\f1bc";
}

.fa-spray-can:before {
  content: "\f5bd";
}

.fa-square:before {
  content: "\f0c8";
}

.fa-square-full:before {
  content: "\f45c";
}

.fa-square-root-alt:before {
  content: "\f698";
}

.fa-squarespace:before {
  content: "\f5be";
}

.fa-stack-exchange:before {
  content: "\f18d";
}

.fa-stack-overflow:before {
  content: "\f16c";
}

.fa-stackpath:before {
  content: "\f842";
}

.fa-stamp:before {
  content: "\f5bf";
}

.fa-star:before {
  content: "\f005";
}

.fa-star-and-crescent:before {
  content: "\f699";
}

.fa-star-half:before {
  content: "\f089";
}

.fa-star-half-alt:before {
  content: "\f5c0";
}

.fa-star-of-david:before {
  content: "\f69a";
}

.fa-star-of-life:before {
  content: "\f621";
}

.fa-staylinked:before {
  content: "\f3f5";
}

.fa-steam:before {
  content: "\f1b6";
}

.fa-steam-square:before {
  content: "\f1b7";
}

.fa-steam-symbol:before {
  content: "\f3f6";
}

.fa-step-backward:before {
  content: "\f048";
}

.fa-step-forward:before {
  content: "\f051";
}

.fa-stethoscope:before {
  content: "\f0f1";
}

.fa-sticker-mule:before {
  content: "\f3f7";
}

.fa-sticky-note:before {
  content: "\f249";
}

.fa-stop:before {
  content: "\f04d";
}

.fa-stop-circle:before {
  content: "\f28d";
}

.fa-stopwatch:before {
  content: "\f2f2";
}

.fa-stopwatch-20:before {
  content: "\e06f";
}

.fa-store:before {
  content: "\f54e";
}

.fa-store-alt:before {
  content: "\f54f";
}

.fa-store-alt-slash:before {
  content: "\e070";
}

.fa-store-slash:before {
  content: "\e071";
}

.fa-strava:before {
  content: "\f428";
}

.fa-stream:before {
  content: "\f550";
}

.fa-street-view:before {
  content: "\f21d";
}

.fa-strikethrough:before {
  content: "\f0cc";
}

.fa-stripe:before {
  content: "\f429";
}

.fa-stripe-s:before {
  content: "\f42a";
}

.fa-stroopwafel:before {
  content: "\f551";
}

.fa-studiovinari:before {
  content: "\f3f8";
}

.fa-stumbleupon:before {
  content: "\f1a4";
}

.fa-stumbleupon-circle:before {
  content: "\f1a3";
}

.fa-subscript:before {
  content: "\f12c";
}

.fa-subway:before {
  content: "\f239";
}

.fa-suitcase:before {
  content: "\f0f2";
}

.fa-suitcase-rolling:before {
  content: "\f5c1";
}

.fa-sun:before {
  content: "\f185";
}

.fa-superpowers:before {
  content: "\f2dd";
}

.fa-superscript:before {
  content: "\f12b";
}

.fa-supple:before {
  content: "\f3f9";
}

.fa-surprise:before {
  content: "\f5c2";
}

.fa-suse:before {
  content: "\f7d6";
}

.fa-swatchbook:before {
  content: "\f5c3";
}

.fa-swift:before {
  content: "\f8e1";
}

.fa-swimmer:before {
  content: "\f5c4";
}

.fa-swimming-pool:before {
  content: "\f5c5";
}

.fa-symfony:before {
  content: "\f83d";
}

.fa-synagogue:before {
  content: "\f69b";
}

.fa-sync:before {
  content: "\f021";
}

.fa-sync-alt:before {
  content: "\f2f1";
}

.fa-syringe:before {
  content: "\f48e";
}

.fa-table:before {
  content: "\f0ce";
}

.fa-table-tennis:before {
  content: "\f45d";
}

.fa-tablet:before {
  content: "\f10a";
}

.fa-tablet-alt:before {
  content: "\f3fa";
}

.fa-tablets:before {
  content: "\f490";
}

.fa-tachometer-alt:before {
  content: "\f3fd";
}

.fa-tag:before {
  content: "\f02b";
}

.fa-tags:before {
  content: "\f02c";
}

.fa-tape:before {
  content: "\f4db";
}

.fa-tasks:before {
  content: "\f0ae";
}

.fa-taxi:before {
  content: "\f1ba";
}

.fa-teamspeak:before {
  content: "\f4f9";
}

.fa-teeth:before {
  content: "\f62e";
}

.fa-teeth-open:before {
  content: "\f62f";
}

.fa-telegram:before {
  content: "\f2c6";
}

.fa-telegram-plane:before {
  content: "\f3fe";
}

.fa-temperature-high:before {
  content: "\f769";
}

.fa-temperature-low:before {
  content: "\f76b";
}

.fa-tencent-weibo:before {
  content: "\f1d5";
}

.fa-tenge:before {
  content: "\f7d7";
}

.fa-terminal:before {
  content: "\f120";
}

.fa-text-height:before {
  content: "\f034";
}

.fa-text-width:before {
  content: "\f035";
}

.fa-th:before {
  content: "\f00a";
}

.fa-th-large:before {
  content: "\f009";
}

.fa-th-list:before {
  content: "\f00b";
}

.fa-the-red-yeti:before {
  content: "\f69d";
}

.fa-theater-masks:before {
  content: "\f630";
}

.fa-themeco:before {
  content: "\f5c6";
}

.fa-themeisle:before {
  content: "\f2b2";
}

.fa-thermometer:before {
  content: "\f491";
}

.fa-thermometer-empty:before {
  content: "\f2cb";
}

.fa-thermometer-full:before {
  content: "\f2c7";
}

.fa-thermometer-half:before {
  content: "\f2c9";
}

.fa-thermometer-quarter:before {
  content: "\f2ca";
}

.fa-thermometer-three-quarters:before {
  content: "\f2c8";
}

.fa-think-peaks:before {
  content: "\f731";
}

.fa-thumbs-down:before {
  content: "\f165";
}

.fa-thumbs-up:before {
  content: "\f164";
}

.fa-thumbtack:before {
  content: "\f08d";
}

.fa-ticket-alt:before {
  content: "\f3ff";
}

.fa-tiktok:before {
  content: "\e07b";
}

.fa-times:before {
  content: "\f00d";
}

.fa-times-circle:before {
  content: "\f057";
}

.fa-tint:before {
  content: "\f043";
}

.fa-tint-slash:before {
  content: "\f5c7";
}

.fa-tired:before {
  content: "\f5c8";
}

.fa-toggle-off:before {
  content: "\f204";
}

.fa-toggle-on:before {
  content: "\f205";
}

.fa-toilet:before {
  content: "\f7d8";
}

.fa-toilet-paper:before {
  content: "\f71e";
}

.fa-toilet-paper-slash:before {
  content: "\e072";
}

.fa-toolbox:before {
  content: "\f552";
}

.fa-tools:before {
  content: "\f7d9";
}

.fa-tooth:before {
  content: "\f5c9";
}

.fa-torah:before {
  content: "\f6a0";
}

.fa-torii-gate:before {
  content: "\f6a1";
}

.fa-tractor:before {
  content: "\f722";
}

.fa-trade-federation:before {
  content: "\f513";
}

.fa-trademark:before {
  content: "\f25c";
}

.fa-traffic-light:before {
  content: "\f637";
}

.fa-trailer:before {
  content: "\e041";
}

.fa-train:before {
  content: "\f238";
}

.fa-tram:before {
  content: "\f7da";
}

.fa-transgender:before {
  content: "\f224";
}

.fa-transgender-alt:before {
  content: "\f225";
}

.fa-trash:before {
  content: "\f1f8";
}

.fa-trash-alt:before {
  content: "\f2ed";
}

.fa-trash-restore:before {
  content: "\f829";
}

.fa-trash-restore-alt:before {
  content: "\f82a";
}

.fa-tree:before {
  content: "\f1bb";
}

.fa-trello:before {
  content: "\f181";
}

.fa-trophy:before {
  content: "\f091";
}

.fa-truck:before {
  content: "\f0d1";
}

.fa-truck-loading:before {
  content: "\f4de";
}

.fa-truck-monster:before {
  content: "\f63b";
}

.fa-truck-moving:before {
  content: "\f4df";
}

.fa-truck-pickup:before {
  content: "\f63c";
}

.fa-tshirt:before {
  content: "\f553";
}

.fa-tty:before {
  content: "\f1e4";
}

.fa-tumblr:before {
  content: "\f173";
}

.fa-tumblr-square:before {
  content: "\f174";
}

.fa-tv:before {
  content: "\f26c";
}

.fa-twitch:before {
  content: "\f1e8";
}

.fa-twitter:before {
  content: "\f099";
}

.fa-twitter-square:before {
  content: "\f081";
}

.fa-typo3:before {
  content: "\f42b";
}

.fa-uber:before {
  content: "\f402";
}

.fa-ubuntu:before {
  content: "\f7df";
}

.fa-uikit:before {
  content: "\f403";
}

.fa-umbraco:before {
  content: "\f8e8";
}

.fa-umbrella:before {
  content: "\f0e9";
}

.fa-umbrella-beach:before {
  content: "\f5ca";
}

.fa-uncharted:before {
  content: "\e084";
}

.fa-underline:before {
  content: "\f0cd";
}

.fa-undo:before {
  content: "\f0e2";
}

.fa-undo-alt:before {
  content: "\f2ea";
}

.fa-uniregistry:before {
  content: "\f404";
}

.fa-unity:before {
  content: "\e049";
}

.fa-universal-access:before {
  content: "\f29a";
}

.fa-university:before {
  content: "\f19c";
}

.fa-unlink:before {
  content: "\f127";
}

.fa-unlock:before {
  content: "\f09c";
}

.fa-unlock-alt:before {
  content: "\f13e";
}

.fa-unsplash:before {
  content: "\e07c";
}

.fa-untappd:before {
  content: "\f405";
}

.fa-upload:before {
  content: "\f093";
}

.fa-ups:before {
  content: "\f7e0";
}

.fa-usb:before {
  content: "\f287";
}

.fa-user:before {
  content: "\f007";
}

.fa-user-alt:before {
  content: "\f406";
}

.fa-user-alt-slash:before {
  content: "\f4fa";
}

.fa-user-astronaut:before {
  content: "\f4fb";
}

.fa-user-check:before {
  content: "\f4fc";
}

.fa-user-circle:before {
  content: "\f2bd";
}

.fa-user-clock:before {
  content: "\f4fd";
}

.fa-user-cog:before {
  content: "\f4fe";
}

.fa-user-edit:before {
  content: "\f4ff";
}

.fa-user-friends:before {
  content: "\f500";
}

.fa-user-graduate:before {
  content: "\f501";
}

.fa-user-injured:before {
  content: "\f728";
}

.fa-user-lock:before {
  content: "\f502";
}

.fa-user-md:before {
  content: "\f0f0";
}

.fa-user-minus:before {
  content: "\f503";
}

.fa-user-ninja:before {
  content: "\f504";
}

.fa-user-nurse:before {
  content: "\f82f";
}

.fa-user-plus:before {
  content: "\f234";
}

.fa-user-secret:before {
  content: "\f21b";
}

.fa-user-shield:before {
  content: "\f505";
}

.fa-user-slash:before {
  content: "\f506";
}

.fa-user-tag:before {
  content: "\f507";
}

.fa-user-tie:before {
  content: "\f508";
}

.fa-user-times:before {
  content: "\f235";
}

.fa-users:before {
  content: "\f0c0";
}

.fa-users-cog:before {
  content: "\f509";
}

.fa-users-slash:before {
  content: "\e073";
}

.fa-usps:before {
  content: "\f7e1";
}

.fa-ussunnah:before {
  content: "\f407";
}

.fa-utensil-spoon:before {
  content: "\f2e5";
}

.fa-utensils:before {
  content: "\f2e7";
}

.fa-vaadin:before {
  content: "\f408";
}

.fa-vector-square:before {
  content: "\f5cb";
}

.fa-venus:before {
  content: "\f221";
}

.fa-venus-double:before {
  content: "\f226";
}

.fa-venus-mars:before {
  content: "\f228";
}

.fa-vest:before {
  content: "\e085";
}

.fa-vest-patches:before {
  content: "\e086";
}

.fa-viacoin:before {
  content: "\f237";
}

.fa-viadeo:before {
  content: "\f2a9";
}

.fa-viadeo-square:before {
  content: "\f2aa";
}

.fa-vial:before {
  content: "\f492";
}

.fa-vials:before {
  content: "\f493";
}

.fa-viber:before {
  content: "\f409";
}

.fa-video:before {
  content: "\f03d";
}

.fa-video-slash:before {
  content: "\f4e2";
}

.fa-vihara:before {
  content: "\f6a7";
}

.fa-vimeo:before {
  content: "\f40a";
}

.fa-vimeo-square:before {
  content: "\f194";
}

.fa-vimeo-v:before {
  content: "\f27d";
}

.fa-vine:before {
  content: "\f1ca";
}

.fa-virus:before {
  content: "\e074";
}

.fa-virus-slash:before {
  content: "\e075";
}

.fa-viruses:before {
  content: "\e076";
}

.fa-vk:before {
  content: "\f189";
}

.fa-vnv:before {
  content: "\f40b";
}

.fa-voicemail:before {
  content: "\f897";
}

.fa-volleyball-ball:before {
  content: "\f45f";
}

.fa-volume-down:before {
  content: "\f027";
}

.fa-volume-mute:before {
  content: "\f6a9";
}

.fa-volume-off:before {
  content: "\f026";
}

.fa-volume-up:before {
  content: "\f028";
}

.fa-vote-yea:before {
  content: "\f772";
}

.fa-vr-cardboard:before {
  content: "\f729";
}

.fa-vuejs:before {
  content: "\f41f";
}

.fa-walking:before {
  content: "\f554";
}

.fa-wallet:before {
  content: "\f555";
}

.fa-warehouse:before {
  content: "\f494";
}

.fa-watchman-monitoring:before {
  content: "\e087";
}

.fa-water:before {
  content: "\f773";
}

.fa-wave-square:before {
  content: "\f83e";
}

.fa-waze:before {
  content: "\f83f";
}

.fa-weebly:before {
  content: "\f5cc";
}

.fa-weibo:before {
  content: "\f18a";
}

.fa-weight:before {
  content: "\f496";
}

.fa-weight-hanging:before {
  content: "\f5cd";
}

.fa-weixin:before {
  content: "\f1d7";
}

.fa-whatsapp:before {
  content: "\f232";
}

.fa-whatsapp-square:before {
  content: "\f40c";
}

.fa-wheelchair:before {
  content: "\f193";
}

.fa-whmcs:before {
  content: "\f40d";
}

.fa-wifi:before {
  content: "\f1eb";
}

.fa-wikipedia-w:before {
  content: "\f266";
}

.fa-wind:before {
  content: "\f72e";
}

.fa-window-close:before {
  content: "\f410";
}

.fa-window-maximize:before {
  content: "\f2d0";
}

.fa-window-minimize:before {
  content: "\f2d1";
}

.fa-window-restore:before {
  content: "\f2d2";
}

.fa-windows:before {
  content: "\f17a";
}

.fa-wine-bottle:before {
  content: "\f72f";
}

.fa-wine-glass:before {
  content: "\f4e3";
}

.fa-wine-glass-alt:before {
  content: "\f5ce";
}

.fa-wix:before {
  content: "\f5cf";
}

.fa-wizards-of-the-coast:before {
  content: "\f730";
}

.fa-wodu:before {
  content: "\e088";
}

.fa-wolf-pack-battalion:before {
  content: "\f514";
}

.fa-won-sign:before {
  content: "\f159";
}

.fa-wordpress:before {
  content: "\f19a";
}

.fa-wordpress-simple:before {
  content: "\f411";
}

.fa-wpbeginner:before {
  content: "\f297";
}

.fa-wpexplorer:before {
  content: "\f2de";
}

.fa-wpforms:before {
  content: "\f298";
}

.fa-wpressr:before {
  content: "\f3e4";
}

.fa-wrench:before {
  content: "\f0ad";
}

.fa-x-ray:before {
  content: "\f497";
}

.fa-xbox:before {
  content: "\f412";
}

.fa-xing:before {
  content: "\f168";
}

.fa-xing-square:before {
  content: "\f169";
}

.fa-y-combinator:before {
  content: "\f23b";
}

.fa-yahoo:before {
  content: "\f19e";
}

.fa-yammer:before {
  content: "\f840";
}

.fa-yandex:before {
  content: "\f413";
}

.fa-yandex-international:before {
  content: "\f414";
}

.fa-yarn:before {
  content: "\f7e3";
}

.fa-yelp:before {
  content: "\f1e9";
}

.fa-yen-sign:before {
  content: "\f157";
}

.fa-yin-yang:before {
  content: "\f6ad";
}

.fa-yoast:before {
  content: "\f2b1";
}

.fa-youtube:before {
  content: "\f167";
}

.fa-youtube-square:before {
  content: "\f431";
}

.fa-zhihu:before {
  content: "\f63f";
}

.amis-scope .sr-only {
  border: 0;
  clip: rect(0, 0, 0, 0);
  height: 1px;
  margin: -1px;
  overflow: hidden;
  padding: 0;
  position: absolute;
  width: 1px;
}

.amis-scope .sr-only-focusable:active,
.amis-scope .sr-only-focusable:focus {
  clip: auto;
  height: auto;
  margin: 0;
  overflow: visible;
  position: static;
  width: auto;
}

@font-face {
  font-family: 'Font Awesome 5 Brands';
  font-style: normal;
  font-weight: 400;
  font-display: block;
  src: url("./thirds/@fortawesome/fontawesome-free/webfonts/fa-brands-400.eot");
  src: url("./thirds/@fortawesome/fontawesome-free/webfonts/fa-brands-400.eot?#iefix") format("embedded-opentype"), url("./thirds/@fortawesome/fontawesome-free/webfonts/fa-brands-400.woff2") format("woff2"), url("./thirds/@fortawesome/fontawesome-free/webfonts/fa-brands-400.woff") format("woff"), url("./thirds/@fortawesome/fontawesome-free/webfonts/fa-brands-400.ttf") format("truetype"), url("./thirds/@fortawesome/fontawesome-free/webfonts/fa-brands-400.svg#fontawesome") format("svg");
}

.fab {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

@font-face {
  font-family: 'Font Awesome 5 Free';
  font-style: normal;
  font-weight: 400;
  font-display: block;
  src: url("./thirds/@fortawesome/fontawesome-free/webfonts/fa-regular-400.eot");
  src: url("./thirds/@fortawesome/fontawesome-free/webfonts/fa-regular-400.eot?#iefix") format("embedded-opentype"), url("./thirds/@fortawesome/fontawesome-free/webfonts/fa-regular-400.woff2") format("woff2"), url("./thirds/@fortawesome/fontawesome-free/webfonts/fa-regular-400.woff") format("woff"), url("./thirds/@fortawesome/fontawesome-free/webfonts/fa-regular-400.ttf") format("truetype"), url("./thirds/@fortawesome/fontawesome-free/webfonts/fa-regular-400.svg#fontawesome") format("svg");
}

.far {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

@font-face {
  font-family: 'Font Awesome 5 Free';
  font-style: normal;
  font-weight: 900;
  font-display: block;
  src: url("./thirds/@fortawesome/fontawesome-free/webfonts/fa-solid-900.eot");
  src: url("./thirds/@fortawesome/fontawesome-free/webfonts/fa-solid-900.eot?#iefix") format("embedded-opentype"), url("./thirds/@fortawesome/fontawesome-free/webfonts/fa-solid-900.woff2") format("woff2"), url("./thirds/@fortawesome/fontawesome-free/webfonts/fa-solid-900.woff") format("woff"), url("./thirds/@fortawesome/fontawesome-free/webfonts/fa-solid-900.ttf") format("truetype"), url("./thirds/@fortawesome/fontawesome-free/webfonts/fa-solid-900.svg#fontawesome") format("svg");
}

.fa,
.fas {
  font-family: 'Font Awesome 5 Free';
  font-weight: 900;
}

/*!
 * Font Awesome Free 5.15.4 by @fontawesome - https://fontawesome.com
 * License - https://fontawesome.com/license/free (Icons: CC BY 4.0, Fonts: SIL OFL 1.1, Code: MIT License)
 */

.fa.fa-glass:before {
  content: "\f000";
}

.fa.fa-meetup {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-star-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-star-o:before {
  content: "\f005";
}

.fa.fa-remove:before {
  content: "\f00d";
}

.fa.fa-close:before {
  content: "\f00d";
}

.fa.fa-gear:before {
  content: "\f013";
}

.fa.fa-trash-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-trash-o:before {
  content: "\f2ed";
}

.fa.fa-file-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-file-o:before {
  content: "\f15b";
}

.fa.fa-clock-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-clock-o:before {
  content: "\f017";
}

.fa.fa-arrow-circle-o-down {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-arrow-circle-o-down:before {
  content: "\f358";
}

.fa.fa-arrow-circle-o-up {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-arrow-circle-o-up:before {
  content: "\f35b";
}

.fa.fa-play-circle-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-play-circle-o:before {
  content: "\f144";
}

.fa.fa-repeat:before {
  content: "\f01e";
}

.fa.fa-rotate-right:before {
  content: "\f01e";
}

.fa.fa-refresh:before {
  content: "\f021";
}

.fa.fa-list-alt {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-dedent:before {
  content: "\f03b";
}

.fa.fa-video-camera:before {
  content: "\f03d";
}

.fa.fa-picture-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-picture-o:before {
  content: "\f03e";
}

.fa.fa-photo {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-photo:before {
  content: "\f03e";
}

.fa.fa-image {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-image:before {
  content: "\f03e";
}

.fa.fa-pencil:before {
  content: "\f303";
}

.fa.fa-map-marker:before {
  content: "\f3c5";
}

.fa.fa-pencil-square-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-pencil-square-o:before {
  content: "\f044";
}

.fa.fa-share-square-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-share-square-o:before {
  content: "\f14d";
}

.fa.fa-check-square-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-check-square-o:before {
  content: "\f14a";
}

.fa.fa-arrows:before {
  content: "\f0b2";
}

.fa.fa-times-circle-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-times-circle-o:before {
  content: "\f057";
}

.fa.fa-check-circle-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-check-circle-o:before {
  content: "\f058";
}

.fa.fa-mail-forward:before {
  content: "\f064";
}

.fa.fa-expand:before {
  content: "\f424";
}

.fa.fa-compress:before {
  content: "\f422";
}

.fa.fa-eye {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-eye-slash {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-warning:before {
  content: "\f071";
}

.fa.fa-calendar:before {
  content: "\f073";
}

.fa.fa-arrows-v:before {
  content: "\f338";
}

.fa.fa-arrows-h:before {
  content: "\f337";
}

.fa.fa-bar-chart {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-bar-chart:before {
  content: "\f080";
}

.fa.fa-bar-chart-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-bar-chart-o:before {
  content: "\f080";
}

.fa.fa-twitter-square {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-facebook-square {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-gears:before {
  content: "\f085";
}

.fa.fa-thumbs-o-up {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-thumbs-o-up:before {
  content: "\f164";
}

.fa.fa-thumbs-o-down {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-thumbs-o-down:before {
  content: "\f165";
}

.fa.fa-heart-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-heart-o:before {
  content: "\f004";
}

.fa.fa-sign-out:before {
  content: "\f2f5";
}

.fa.fa-linkedin-square {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-linkedin-square:before {
  content: "\f08c";
}

.fa.fa-thumb-tack:before {
  content: "\f08d";
}

.fa.fa-external-link:before {
  content: "\f35d";
}

.fa.fa-sign-in:before {
  content: "\f2f6";
}

.fa.fa-github-square {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-lemon-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-lemon-o:before {
  content: "\f094";
}

.fa.fa-square-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-square-o:before {
  content: "\f0c8";
}

.fa.fa-bookmark-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-bookmark-o:before {
  content: "\f02e";
}

.fa.fa-twitter {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-facebook {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-facebook:before {
  content: "\f39e";
}

.fa.fa-facebook-f {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-facebook-f:before {
  content: "\f39e";
}

.fa.fa-github {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-credit-card {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-feed:before {
  content: "\f09e";
}

.fa.fa-hdd-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-hdd-o:before {
  content: "\f0a0";
}

.fa.fa-hand-o-right {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-hand-o-right:before {
  content: "\f0a4";
}

.fa.fa-hand-o-left {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-hand-o-left:before {
  content: "\f0a5";
}

.fa.fa-hand-o-up {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-hand-o-up:before {
  content: "\f0a6";
}

.fa.fa-hand-o-down {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-hand-o-down:before {
  content: "\f0a7";
}

.fa.fa-arrows-alt:before {
  content: "\f31e";
}

.fa.fa-group:before {
  content: "\f0c0";
}

.fa.fa-chain:before {
  content: "\f0c1";
}

.fa.fa-scissors:before {
  content: "\f0c4";
}

.fa.fa-files-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-files-o:before {
  content: "\f0c5";
}

.fa.fa-floppy-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-floppy-o:before {
  content: "\f0c7";
}

.fa.fa-navicon:before {
  content: "\f0c9";
}

.fa.fa-reorder:before {
  content: "\f0c9";
}

.fa.fa-pinterest {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-pinterest-square {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-google-plus-square {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-google-plus {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-google-plus:before {
  content: "\f0d5";
}

.fa.fa-money {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-money:before {
  content: "\f3d1";
}

.fa.fa-unsorted:before {
  content: "\f0dc";
}

.fa.fa-sort-desc:before {
  content: "\f0dd";
}

.fa.fa-sort-asc:before {
  content: "\f0de";
}

.fa.fa-linkedin {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-linkedin:before {
  content: "\f0e1";
}

.fa.fa-rotate-left:before {
  content: "\f0e2";
}

.fa.fa-legal:before {
  content: "\f0e3";
}

.fa.fa-tachometer:before {
  content: "\f3fd";
}

.fa.fa-dashboard:before {
  content: "\f3fd";
}

.fa.fa-comment-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-comment-o:before {
  content: "\f075";
}

.fa.fa-comments-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-comments-o:before {
  content: "\f086";
}

.fa.fa-flash:before {
  content: "\f0e7";
}

.fa.fa-clipboard {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-paste {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-paste:before {
  content: "\f328";
}

.fa.fa-lightbulb-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-lightbulb-o:before {
  content: "\f0eb";
}

.fa.fa-exchange:before {
  content: "\f362";
}

.fa.fa-cloud-download:before {
  content: "\f381";
}

.fa.fa-cloud-upload:before {
  content: "\f382";
}

.fa.fa-bell-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-bell-o:before {
  content: "\f0f3";
}

.fa.fa-cutlery:before {
  content: "\f2e7";
}

.fa.fa-file-text-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-file-text-o:before {
  content: "\f15c";
}

.fa.fa-building-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-building-o:before {
  content: "\f1ad";
}

.fa.fa-hospital-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-hospital-o:before {
  content: "\f0f8";
}

.fa.fa-tablet:before {
  content: "\f3fa";
}

.fa.fa-mobile:before {
  content: "\f3cd";
}

.fa.fa-mobile-phone:before {
  content: "\f3cd";
}

.fa.fa-circle-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-circle-o:before {
  content: "\f111";
}

.fa.fa-mail-reply:before {
  content: "\f3e5";
}

.fa.fa-github-alt {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-folder-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-folder-o:before {
  content: "\f07b";
}

.fa.fa-folder-open-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-folder-open-o:before {
  content: "\f07c";
}

.fa.fa-smile-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-smile-o:before {
  content: "\f118";
}

.fa.fa-frown-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-frown-o:before {
  content: "\f119";
}

.fa.fa-meh-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-meh-o:before {
  content: "\f11a";
}

.fa.fa-keyboard-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-keyboard-o:before {
  content: "\f11c";
}

.fa.fa-flag-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-flag-o:before {
  content: "\f024";
}

.fa.fa-mail-reply-all:before {
  content: "\f122";
}

.fa.fa-star-half-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-star-half-o:before {
  content: "\f089";
}

.fa.fa-star-half-empty {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-star-half-empty:before {
  content: "\f089";
}

.fa.fa-star-half-full {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-star-half-full:before {
  content: "\f089";
}

.fa.fa-code-fork:before {
  content: "\f126";
}

.fa.fa-chain-broken:before {
  content: "\f127";
}

.fa.fa-shield:before {
  content: "\f3ed";
}

.fa.fa-calendar-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-calendar-o:before {
  content: "\f133";
}

.fa.fa-maxcdn {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-html5 {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-css3 {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-ticket:before {
  content: "\f3ff";
}

.fa.fa-minus-square-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-minus-square-o:before {
  content: "\f146";
}

.fa.fa-level-up:before {
  content: "\f3bf";
}

.fa.fa-level-down:before {
  content: "\f3be";
}

.fa.fa-pencil-square:before {
  content: "\f14b";
}

.fa.fa-external-link-square:before {
  content: "\f360";
}

.fa.fa-compass {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-caret-square-o-down {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-caret-square-o-down:before {
  content: "\f150";
}

.fa.fa-toggle-down {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-toggle-down:before {
  content: "\f150";
}

.fa.fa-caret-square-o-up {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-caret-square-o-up:before {
  content: "\f151";
}

.fa.fa-toggle-up {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-toggle-up:before {
  content: "\f151";
}

.fa.fa-caret-square-o-right {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-caret-square-o-right:before {
  content: "\f152";
}

.fa.fa-toggle-right {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-toggle-right:before {
  content: "\f152";
}

.fa.fa-eur:before {
  content: "\f153";
}

.fa.fa-euro:before {
  content: "\f153";
}

.fa.fa-gbp:before {
  content: "\f154";
}

.fa.fa-usd:before {
  content: "\f155";
}

.fa.fa-dollar:before {
  content: "\f155";
}

.fa.fa-inr:before {
  content: "\f156";
}

.fa.fa-rupee:before {
  content: "\f156";
}

.fa.fa-jpy:before {
  content: "\f157";
}

.fa.fa-cny:before {
  content: "\f157";
}

.fa.fa-rmb:before {
  content: "\f157";
}

.fa.fa-yen:before {
  content: "\f157";
}

.fa.fa-rub:before {
  content: "\f158";
}

.fa.fa-ruble:before {
  content: "\f158";
}

.fa.fa-rouble:before {
  content: "\f158";
}

.fa.fa-krw:before {
  content: "\f159";
}

.fa.fa-won:before {
  content: "\f159";
}

.fa.fa-btc {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-bitcoin {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-bitcoin:before {
  content: "\f15a";
}

.fa.fa-file-text:before {
  content: "\f15c";
}

.fa.fa-sort-alpha-asc:before {
  content: "\f15d";
}

.fa.fa-sort-alpha-desc:before {
  content: "\f881";
}

.fa.fa-sort-amount-asc:before {
  content: "\f160";
}

.fa.fa-sort-amount-desc:before {
  content: "\f884";
}

.fa.fa-sort-numeric-asc:before {
  content: "\f162";
}

.fa.fa-sort-numeric-desc:before {
  content: "\f886";
}

.fa.fa-youtube-square {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-youtube {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-xing {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-xing-square {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-youtube-play {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-youtube-play:before {
  content: "\f167";
}

.fa.fa-dropbox {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-stack-overflow {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-instagram {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-flickr {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-adn {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-bitbucket {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-bitbucket-square {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-bitbucket-square:before {
  content: "\f171";
}

.fa.fa-tumblr {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-tumblr-square {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-long-arrow-down:before {
  content: "\f309";
}

.fa.fa-long-arrow-up:before {
  content: "\f30c";
}

.fa.fa-long-arrow-left:before {
  content: "\f30a";
}

.fa.fa-long-arrow-right:before {
  content: "\f30b";
}

.fa.fa-apple {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-windows {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-android {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-linux {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-dribbble {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-skype {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-foursquare {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-trello {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-gratipay {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-gittip {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-gittip:before {
  content: "\f184";
}

.fa.fa-sun-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-sun-o:before {
  content: "\f185";
}

.fa.fa-moon-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-moon-o:before {
  content: "\f186";
}

.fa.fa-vk {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-weibo {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-renren {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-pagelines {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-stack-exchange {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-arrow-circle-o-right {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-arrow-circle-o-right:before {
  content: "\f35a";
}

.fa.fa-arrow-circle-o-left {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-arrow-circle-o-left:before {
  content: "\f359";
}

.fa.fa-caret-square-o-left {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-caret-square-o-left:before {
  content: "\f191";
}

.fa.fa-toggle-left {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-toggle-left:before {
  content: "\f191";
}

.fa.fa-dot-circle-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-dot-circle-o:before {
  content: "\f192";
}

.fa.fa-vimeo-square {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-try:before {
  content: "\f195";
}

.fa.fa-turkish-lira:before {
  content: "\f195";
}

.fa.fa-plus-square-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-plus-square-o:before {
  content: "\f0fe";
}

.fa.fa-slack {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-wordpress {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-openid {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-institution:before {
  content: "\f19c";
}

.fa.fa-bank:before {
  content: "\f19c";
}

.fa.fa-mortar-board:before {
  content: "\f19d";
}

.fa.fa-yahoo {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-google {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-reddit {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-reddit-square {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-stumbleupon-circle {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-stumbleupon {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-delicious {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-digg {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-pied-piper-pp {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-pied-piper-alt {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-drupal {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-joomla {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-spoon:before {
  content: "\f2e5";
}

.fa.fa-behance {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-behance-square {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-steam {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-steam-square {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-automobile:before {
  content: "\f1b9";
}

.fa.fa-envelope-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-envelope-o:before {
  content: "\f0e0";
}

.fa.fa-spotify {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-deviantart {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-soundcloud {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-file-pdf-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-file-pdf-o:before {
  content: "\f1c1";
}

.fa.fa-file-word-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-file-word-o:before {
  content: "\f1c2";
}

.fa.fa-file-excel-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-file-excel-o:before {
  content: "\f1c3";
}

.fa.fa-file-powerpoint-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-file-powerpoint-o:before {
  content: "\f1c4";
}

.fa.fa-file-image-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-file-image-o:before {
  content: "\f1c5";
}

.fa.fa-file-photo-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-file-photo-o:before {
  content: "\f1c5";
}

.fa.fa-file-picture-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-file-picture-o:before {
  content: "\f1c5";
}

.fa.fa-file-archive-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-file-archive-o:before {
  content: "\f1c6";
}

.fa.fa-file-zip-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-file-zip-o:before {
  content: "\f1c6";
}

.fa.fa-file-audio-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-file-audio-o:before {
  content: "\f1c7";
}

.fa.fa-file-sound-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-file-sound-o:before {
  content: "\f1c7";
}

.fa.fa-file-video-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-file-video-o:before {
  content: "\f1c8";
}

.fa.fa-file-movie-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-file-movie-o:before {
  content: "\f1c8";
}

.fa.fa-file-code-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-file-code-o:before {
  content: "\f1c9";
}

.fa.fa-vine {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-codepen {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-jsfiddle {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-life-ring {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-life-bouy {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-life-bouy:before {
  content: "\f1cd";
}

.fa.fa-life-buoy {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-life-buoy:before {
  content: "\f1cd";
}

.fa.fa-life-saver {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-life-saver:before {
  content: "\f1cd";
}

.fa.fa-support {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-support:before {
  content: "\f1cd";
}

.fa.fa-circle-o-notch:before {
  content: "\f1ce";
}

.fa.fa-rebel {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-ra {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-ra:before {
  content: "\f1d0";
}

.fa.fa-resistance {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-resistance:before {
  content: "\f1d0";
}

.fa.fa-empire {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-ge {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-ge:before {
  content: "\f1d1";
}

.fa.fa-git-square {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-git {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-hacker-news {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-y-combinator-square {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-y-combinator-square:before {
  content: "\f1d4";
}

.fa.fa-yc-square {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-yc-square:before {
  content: "\f1d4";
}

.fa.fa-tencent-weibo {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-qq {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-weixin {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-wechat {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-wechat:before {
  content: "\f1d7";
}

.fa.fa-send:before {
  content: "\f1d8";
}

.fa.fa-paper-plane-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-paper-plane-o:before {
  content: "\f1d8";
}

.fa.fa-send-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-send-o:before {
  content: "\f1d8";
}

.fa.fa-circle-thin {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-circle-thin:before {
  content: "\f111";
}

.fa.fa-header:before {
  content: "\f1dc";
}

.fa.fa-sliders:before {
  content: "\f1de";
}

.fa.fa-futbol-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-futbol-o:before {
  content: "\f1e3";
}

.fa.fa-soccer-ball-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-soccer-ball-o:before {
  content: "\f1e3";
}

.fa.fa-slideshare {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-twitch {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-yelp {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-newspaper-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-newspaper-o:before {
  content: "\f1ea";
}

.fa.fa-paypal {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-google-wallet {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-cc-visa {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-cc-mastercard {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-cc-discover {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-cc-amex {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-cc-paypal {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-cc-stripe {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-bell-slash-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-bell-slash-o:before {
  content: "\f1f6";
}

.fa.fa-trash:before {
  content: "\f2ed";
}

.fa.fa-copyright {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-eyedropper:before {
  content: "\f1fb";
}

.fa.fa-area-chart:before {
  content: "\f1fe";
}

.fa.fa-pie-chart:before {
  content: "\f200";
}

.fa.fa-line-chart:before {
  content: "\f201";
}

.fa.fa-lastfm {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-lastfm-square {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-ioxhost {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-angellist {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-cc {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-cc:before {
  content: "\f20a";
}

.fa.fa-ils:before {
  content: "\f20b";
}

.fa.fa-shekel:before {
  content: "\f20b";
}

.fa.fa-sheqel:before {
  content: "\f20b";
}

.fa.fa-meanpath {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-meanpath:before {
  content: "\f2b4";
}

.fa.fa-buysellads {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-connectdevelop {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-dashcube {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-forumbee {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-leanpub {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-sellsy {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-shirtsinbulk {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-simplybuilt {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-skyatlas {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-diamond {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-diamond:before {
  content: "\f3a5";
}

.fa.fa-intersex:before {
  content: "\f224";
}

.fa.fa-facebook-official {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-facebook-official:before {
  content: "\f09a";
}

.fa.fa-pinterest-p {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-whatsapp {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-hotel:before {
  content: "\f236";
}

.fa.fa-viacoin {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-medium {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-y-combinator {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-yc {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-yc:before {
  content: "\f23b";
}

.fa.fa-optin-monster {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-opencart {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-expeditedssl {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-battery-4:before {
  content: "\f240";
}

.fa.fa-battery:before {
  content: "\f240";
}

.fa.fa-battery-3:before {
  content: "\f241";
}

.fa.fa-battery-2:before {
  content: "\f242";
}

.fa.fa-battery-1:before {
  content: "\f243";
}

.fa.fa-battery-0:before {
  content: "\f244";
}

.fa.fa-object-group {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-object-ungroup {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-sticky-note-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-sticky-note-o:before {
  content: "\f249";
}

.fa.fa-cc-jcb {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-cc-diners-club {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-clone {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-hourglass-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-hourglass-o:before {
  content: "\f254";
}

.fa.fa-hourglass-1:before {
  content: "\f251";
}

.fa.fa-hourglass-2:before {
  content: "\f252";
}

.fa.fa-hourglass-3:before {
  content: "\f253";
}

.fa.fa-hand-rock-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-hand-rock-o:before {
  content: "\f255";
}

.fa.fa-hand-grab-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-hand-grab-o:before {
  content: "\f255";
}

.fa.fa-hand-paper-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-hand-paper-o:before {
  content: "\f256";
}

.fa.fa-hand-stop-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-hand-stop-o:before {
  content: "\f256";
}

.fa.fa-hand-scissors-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-hand-scissors-o:before {
  content: "\f257";
}

.fa.fa-hand-lizard-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-hand-lizard-o:before {
  content: "\f258";
}

.fa.fa-hand-spock-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-hand-spock-o:before {
  content: "\f259";
}

.fa.fa-hand-pointer-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-hand-pointer-o:before {
  content: "\f25a";
}

.fa.fa-hand-peace-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-hand-peace-o:before {
  content: "\f25b";
}

.fa.fa-registered {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-creative-commons {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-gg {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-gg-circle {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-tripadvisor {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-odnoklassniki {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-odnoklassniki-square {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-get-pocket {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-wikipedia-w {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-safari {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-chrome {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-firefox {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-opera {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-internet-explorer {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-television:before {
  content: "\f26c";
}

.fa.fa-contao {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-500px {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-amazon {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-calendar-plus-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-calendar-plus-o:before {
  content: "\f271";
}

.fa.fa-calendar-minus-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-calendar-minus-o:before {
  content: "\f272";
}

.fa.fa-calendar-times-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-calendar-times-o:before {
  content: "\f273";
}

.fa.fa-calendar-check-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-calendar-check-o:before {
  content: "\f274";
}

.fa.fa-map-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-map-o:before {
  content: "\f279";
}

.fa.fa-commenting:before {
  content: "\f4ad";
}

.fa.fa-commenting-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-commenting-o:before {
  content: "\f4ad";
}

.fa.fa-houzz {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-vimeo {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-vimeo:before {
  content: "\f27d";
}

.fa.fa-black-tie {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-fonticons {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-reddit-alien {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-edge {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-credit-card-alt:before {
  content: "\f09d";
}

.fa.fa-codiepie {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-modx {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-fort-awesome {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-usb {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-product-hunt {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-mixcloud {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-scribd {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-pause-circle-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-pause-circle-o:before {
  content: "\f28b";
}

.fa.fa-stop-circle-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-stop-circle-o:before {
  content: "\f28d";
}

.fa.fa-bluetooth {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-bluetooth-b {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-gitlab {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-wpbeginner {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-wpforms {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-envira {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-wheelchair-alt {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-wheelchair-alt:before {
  content: "\f368";
}

.fa.fa-question-circle-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-question-circle-o:before {
  content: "\f059";
}

.fa.fa-volume-control-phone:before {
  content: "\f2a0";
}

.fa.fa-asl-interpreting:before {
  content: "\f2a3";
}

.fa.fa-deafness:before {
  content: "\f2a4";
}

.fa.fa-hard-of-hearing:before {
  content: "\f2a4";
}

.fa.fa-glide {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-glide-g {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-signing:before {
  content: "\f2a7";
}

.fa.fa-viadeo {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-viadeo-square {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-snapchat {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-snapchat-ghost {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-snapchat-square {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-pied-piper {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-first-order {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-yoast {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-themeisle {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-google-plus-official {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-google-plus-official:before {
  content: "\f2b3";
}

.fa.fa-google-plus-circle {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-google-plus-circle:before {
  content: "\f2b3";
}

.fa.fa-font-awesome {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-fa {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-fa:before {
  content: "\f2b4";
}

.fa.fa-handshake-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-handshake-o:before {
  content: "\f2b5";
}

.fa.fa-envelope-open-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-envelope-open-o:before {
  content: "\f2b6";
}

.fa.fa-linode {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-address-book-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-address-book-o:before {
  content: "\f2b9";
}

.fa.fa-vcard:before {
  content: "\f2bb";
}

.fa.fa-address-card-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-address-card-o:before {
  content: "\f2bb";
}

.fa.fa-vcard-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-vcard-o:before {
  content: "\f2bb";
}

.fa.fa-user-circle-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-user-circle-o:before {
  content: "\f2bd";
}

.fa.fa-user-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-user-o:before {
  content: "\f007";
}

.fa.fa-id-badge {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-drivers-license:before {
  content: "\f2c2";
}

.fa.fa-id-card-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-id-card-o:before {
  content: "\f2c2";
}

.fa.fa-drivers-license-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-drivers-license-o:before {
  content: "\f2c2";
}

.fa.fa-quora {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-free-code-camp {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-telegram {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-thermometer-4:before {
  content: "\f2c7";
}

.fa.fa-thermometer:before {
  content: "\f2c7";
}

.fa.fa-thermometer-3:before {
  content: "\f2c8";
}

.fa.fa-thermometer-2:before {
  content: "\f2c9";
}

.fa.fa-thermometer-1:before {
  content: "\f2ca";
}

.fa.fa-thermometer-0:before {
  content: "\f2cb";
}

.fa.fa-bathtub:before {
  content: "\f2cd";
}

.fa.fa-s15:before {
  content: "\f2cd";
}

.fa.fa-window-maximize {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-window-restore {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-times-rectangle:before {
  content: "\f410";
}

.fa.fa-window-close-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-window-close-o:before {
  content: "\f410";
}

.fa.fa-times-rectangle-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-times-rectangle-o:before {
  content: "\f410";
}

.fa.fa-bandcamp {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-grav {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-etsy {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-imdb {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-ravelry {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-eercast {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-eercast:before {
  content: "\f2da";
}

.fa.fa-snowflake-o {
  font-family: 'Font Awesome 5 Free';
  font-weight: 400;
}

.fa.fa-snowflake-o:before {
  content: "\f2dc";
}

.fa.fa-superpowers {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-wpexplorer {
  font-family: 'Font Awesome 5 Brands';
  font-weight: 400;
}

.fa.fa-cab:before {
  content: "\f1ba";
}

/**
 * Copyright (c) Tiny Technologies, Inc. All rights reserved.
 * Licensed under the LGPL or a commercial license.
 * For LGPL see License.txt in the project root for license information.
 * For commercial licenses see https://www.tiny.cloud/
 */

.tox {
  box-shadow: none;
  box-sizing: content-box;
  color: #222f3e;
  cursor: auto;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  font-size: 16px;
  font-style: normal;
  font-weight: normal;
  line-height: normal;
  -webkit-tap-highlight-color: transparent;
  text-decoration: none;
  text-shadow: none;
  text-transform: none;
  vertical-align: initial;
  white-space: normal;
}

.tox *:not(svg):not(rect) {
  box-sizing: inherit;
  color: inherit;
  cursor: inherit;
  direction: inherit;
  font-family: inherit;
  font-size: inherit;
  font-style: inherit;
  font-weight: inherit;
  line-height: inherit;
  -webkit-tap-highlight-color: inherit;
  text-align: inherit;
  text-decoration: inherit;
  text-shadow: inherit;
  text-transform: inherit;
  vertical-align: inherit;
  white-space: inherit;
}

.tox *:not(svg):not(rect) {
  /* stylelint-disable-line no-duplicate-selectors */
  background: transparent;
  border: 0;
  box-shadow: none;
  float: none;
  height: auto;
  margin: 0;
  max-width: none;
  outline: 0;
  padding: 0;
  position: static;
  width: auto;
}

.tox:not([dir=rtl]) {
  direction: ltr;
  text-align: left;
}

.tox[dir=rtl] {
  direction: rtl;
  text-align: right;
}

.tox-tinymce {
  border: 1px solid #cccccc;
  border-radius: 0;
  box-shadow: none;
  box-sizing: border-box;
  display: flex;
  flex-direction: column;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  overflow: hidden;
  position: relative;
  visibility: inherit !important;
}

.tox-tinymce-inline {
  border: none;
  box-shadow: none;
}

.tox-tinymce-inline .tox-editor-header {
  background-color: transparent;
  border: 1px solid #cccccc;
  border-radius: 0;
  box-shadow: none;
}

.tox-tinymce-aux {
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  z-index: 1300;
}

.tox-tinymce *:focus,
.tox-tinymce-aux *:focus {
  outline: none;
}

.amis-scope button::-moz-focus-inner {
  border: 0;
}

.tox[dir=rtl] .tox-icon--flip svg {
  transform: rotateY(180deg);
}

.tox .accessibility-issue__header {
  align-items: center;
  display: flex;
  margin-bottom: 4px;
}

.tox .accessibility-issue__description {
  align-items: stretch;
  border: 1px solid #cccccc;
  border-radius: 3px;
  display: flex;
  justify-content: space-between;
}

.tox .accessibility-issue__description > div {
  padding-bottom: 4px;
}

.tox .accessibility-issue__description > div > div {
  align-items: center;
  display: flex;
  margin-bottom: 4px;
}

.tox .accessibility-issue__description > *:last-child:not(:only-child) {
  border-color: #cccccc;
  border-style: solid;
}

.tox .accessibility-issue__repair {
  margin-top: 16px;
}

.tox .tox-dialog__body-content .accessibility-issue--info .accessibility-issue__description {
  background-color: rgba(32, 122, 183, 0.1);
  border-color: rgba(32, 122, 183, 0.4);
  color: #222f3e;
}

.tox .tox-dialog__body-content .accessibility-issue--info .accessibility-issue__description > *:last-child {
  border-color: rgba(32, 122, 183, 0.4);
}

.tox .tox-dialog__body-content .accessibility-issue--info .tox-form__group h2 {
  color: #207ab7;
}

.tox .tox-dialog__body-content .accessibility-issue--info .tox-icon svg {
  fill: #207ab7;
}

.tox .tox-dialog__body-content .accessibility-issue--info a .tox-icon {
  color: #207ab7;
}

.tox .tox-dialog__body-content .accessibility-issue--warn .accessibility-issue__description {
  background-color: rgba(255, 165, 0, 0.1);
  border-color: rgba(255, 165, 0, 0.5);
  color: #222f3e;
}

.tox .tox-dialog__body-content .accessibility-issue--warn .accessibility-issue__description > *:last-child {
  border-color: rgba(255, 165, 0, 0.5);
}

.tox .tox-dialog__body-content .accessibility-issue--warn .tox-form__group h2 {
  color: #cc8500;
}

.tox .tox-dialog__body-content .accessibility-issue--warn .tox-icon svg {
  fill: #cc8500;
}

.tox .tox-dialog__body-content .accessibility-issue--warn a .tox-icon {
  color: #cc8500;
}

.tox .tox-dialog__body-content .accessibility-issue--error .accessibility-issue__description {
  background-color: rgba(204, 0, 0, 0.1);
  border-color: rgba(204, 0, 0, 0.4);
  color: #222f3e;
}

.tox .tox-dialog__body-content .accessibility-issue--error .accessibility-issue__description > *:last-child {
  border-color: rgba(204, 0, 0, 0.4);
}

.tox .tox-dialog__body-content .accessibility-issue--error .tox-form__group h2 {
  color: #c00;
}

.tox .tox-dialog__body-content .accessibility-issue--error .tox-icon svg {
  fill: #c00;
}

.tox .tox-dialog__body-content .accessibility-issue--error a .tox-icon {
  color: #c00;
}

.tox .tox-dialog__body-content .accessibility-issue--success .accessibility-issue__description {
  background-color: rgba(120, 171, 70, 0.1);
  border-color: rgba(120, 171, 70, 0.4);
  color: #222f3e;
}

.tox .tox-dialog__body-content .accessibility-issue--success .accessibility-issue__description > *:last-child {
  border-color: rgba(120, 171, 70, 0.4);
}

.tox .tox-dialog__body-content .accessibility-issue--success .tox-form__group h2 {
  color: #78AB46;
}

.tox .tox-dialog__body-content .accessibility-issue--success .tox-icon svg {
  fill: #78AB46;
}

.tox .tox-dialog__body-content .accessibility-issue--success a .tox-icon {
  color: #78AB46;
}

.tox .tox-dialog__body-content .accessibility-issue__header h1,
.tox .tox-dialog__body-content .tox-form__group .accessibility-issue__description h2 {
  margin-top: 0;
}

.tox:not([dir=rtl]) .tox-dialog__body-content .accessibility-issue__header .tox-button {
  margin-left: 4px;
}

.tox:not([dir=rtl]) .tox-dialog__body-content .accessibility-issue__header > *:nth-last-child(2) {
  margin-left: auto;
}

.tox:not([dir=rtl]) .tox-dialog__body-content .accessibility-issue__description {
  padding: 4px 4px 4px 8px;
}

.tox:not([dir=rtl]) .tox-dialog__body-content .accessibility-issue__description > *:last-child {
  border-left-width: 1px;
  padding-left: 4px;
}

.tox[dir=rtl] .tox-dialog__body-content .accessibility-issue__header .tox-button {
  margin-right: 4px;
}

.tox[dir=rtl] .tox-dialog__body-content .accessibility-issue__header > *:nth-last-child(2) {
  margin-right: auto;
}

.tox[dir=rtl] .tox-dialog__body-content .accessibility-issue__description {
  padding: 4px 8px 4px 4px;
}

.tox[dir=rtl] .tox-dialog__body-content .accessibility-issue__description > *:last-child {
  border-right-width: 1px;
  padding-right: 4px;
}

.tox .tox-anchorbar {
  display: flex;
  flex: 0 0 auto;
}

.tox .tox-bar {
  display: flex;
  flex: 0 0 auto;
}

.tox .tox-button {
  background-color: #207ab7;
  background-image: none;
  background-position: 0 0;
  background-repeat: repeat;
  border-color: #207ab7;
  border-radius: 3px;
  border-style: solid;
  border-width: 1px;
  box-shadow: none;
  box-sizing: border-box;
  color: #fff;
  cursor: pointer;
  display: inline-block;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  font-size: 14px;
  font-style: normal;
  font-weight: bold;
  letter-spacing: normal;
  line-height: 24px;
  margin: 0;
  outline: none;
  padding: 4px 16px;
  text-align: center;
  text-decoration: none;
  text-transform: none;
  white-space: nowrap;
}

.tox .tox-button[disabled] {
  background-color: #207ab7;
  background-image: none;
  border-color: #207ab7;
  box-shadow: none;
  color: rgba(255, 255, 255, 0.5);
  cursor: not-allowed;
}

.tox .tox-button:focus:not(:disabled) {
  background-color: #1c6ca1;
  background-image: none;
  border-color: #1c6ca1;
  box-shadow: none;
  color: #fff;
}

.tox .tox-button:hover:not(:disabled) {
  background-color: #1c6ca1;
  background-image: none;
  border-color: #1c6ca1;
  box-shadow: none;
  color: #fff;
}

.tox .tox-button:active:not(:disabled) {
  background-color: #185d8c;
  background-image: none;
  border-color: #185d8c;
  box-shadow: none;
  color: #fff;
}

.tox .tox-button--secondary {
  background-color: #f0f0f0;
  background-image: none;
  background-position: 0 0;
  background-repeat: repeat;
  border-color: #f0f0f0;
  border-radius: 3px;
  border-style: solid;
  border-width: 1px;
  box-shadow: none;
  color: #222f3e;
  font-size: 14px;
  font-style: normal;
  font-weight: bold;
  letter-spacing: normal;
  outline: none;
  padding: 4px 16px;
  text-decoration: none;
  text-transform: none;
}

.tox .tox-button--secondary[disabled] {
  background-color: #f0f0f0;
  background-image: none;
  border-color: #f0f0f0;
  box-shadow: none;
  color: rgba(34, 47, 62, 0.5);
}

.tox .tox-button--secondary:focus:not(:disabled) {
  background-color: #e3e3e3;
  background-image: none;
  border-color: #e3e3e3;
  box-shadow: none;
  color: #222f3e;
}

.tox .tox-button--secondary:hover:not(:disabled) {
  background-color: #e3e3e3;
  background-image: none;
  border-color: #e3e3e3;
  box-shadow: none;
  color: #222f3e;
}

.tox .tox-button--secondary:active:not(:disabled) {
  background-color: #d6d6d6;
  background-image: none;
  border-color: #d6d6d6;
  box-shadow: none;
  color: #222f3e;
}

.tox .tox-button--icon,
.tox .tox-button.tox-button--icon,
.tox .tox-button.tox-button--secondary.tox-button--icon {
  padding: 4px;
}

.tox .tox-button--icon .tox-icon svg,
.tox .tox-button.tox-button--icon .tox-icon svg,
.tox .tox-button.tox-button--secondary.tox-button--icon .tox-icon svg {
  display: block;
  fill: currentColor;
}

.tox .tox-button-link {
  background: 0;
  border: none;
  box-sizing: border-box;
  cursor: pointer;
  display: inline-block;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  font-size: 16px;
  font-weight: normal;
  line-height: 1.3;
  margin: 0;
  padding: 0;
  white-space: nowrap;
}

.tox .tox-button-link--sm {
  font-size: 14px;
}

.tox .tox-button--naked {
  background-color: transparent;
  border-color: transparent;
  box-shadow: unset;
  color: #222f3e;
}

.tox .tox-button--naked[disabled] {
  background-color: #f0f0f0;
  border-color: #f0f0f0;
  box-shadow: none;
  color: rgba(34, 47, 62, 0.5);
}

.tox .tox-button--naked:hover:not(:disabled) {
  background-color: #e3e3e3;
  border-color: #e3e3e3;
  box-shadow: none;
  color: #222f3e;
}

.tox .tox-button--naked:focus:not(:disabled) {
  background-color: #e3e3e3;
  border-color: #e3e3e3;
  box-shadow: none;
  color: #222f3e;
}

.tox .tox-button--naked:active:not(:disabled) {
  background-color: #d6d6d6;
  border-color: #d6d6d6;
  box-shadow: none;
  color: #222f3e;
}

.tox .tox-button--naked .tox-icon svg {
  fill: currentColor;
}

.tox .tox-button--naked.tox-button--icon:hover:not(:disabled) {
  color: #222f3e;
}

.tox .tox-checkbox {
  align-items: center;
  border-radius: 3px;
  cursor: pointer;
  display: flex;
  height: 36px;
  min-width: 36px;
}

.tox .tox-checkbox__input {
  /* Hide from view but visible to screen readers */
  height: 1px;
  overflow: hidden;
  position: absolute;
  top: auto;
  width: 1px;
}

.tox .tox-checkbox__icons {
  align-items: center;
  border-radius: 3px;
  box-shadow: 0 0 0 2px transparent;
  box-sizing: content-box;
  display: flex;
  height: 24px;
  justify-content: center;
  padding: calc(4px - 1px);
  width: 24px;
}

.tox .tox-checkbox__icons .tox-checkbox-icon__unchecked svg {
  display: block;
  fill: rgba(34, 47, 62, 0.3);
}

.tox .tox-checkbox__icons .tox-checkbox-icon__indeterminate svg {
  display: none;
  fill: #207ab7;
}

.tox .tox-checkbox__icons .tox-checkbox-icon__checked svg {
  display: none;
  fill: #207ab7;
}

.tox .tox-checkbox--disabled {
  color: rgba(34, 47, 62, 0.5);
  cursor: not-allowed;
}

.tox .tox-checkbox--disabled .tox-checkbox__icons .tox-checkbox-icon__checked svg {
  fill: rgba(34, 47, 62, 0.5);
}

.tox .tox-checkbox--disabled .tox-checkbox__icons .tox-checkbox-icon__unchecked svg {
  fill: rgba(34, 47, 62, 0.5);
}

.tox .tox-checkbox--disabled .tox-checkbox__icons .tox-checkbox-icon__indeterminate svg {
  fill: rgba(34, 47, 62, 0.5);
}

.tox input.tox-checkbox__input:checked + .tox-checkbox__icons .tox-checkbox-icon__unchecked svg {
  display: none;
}

.tox input.tox-checkbox__input:checked + .tox-checkbox__icons .tox-checkbox-icon__checked svg {
  display: block;
}

.tox input.tox-checkbox__input:indeterminate + .tox-checkbox__icons .tox-checkbox-icon__unchecked svg {
  display: none;
}

.tox input.tox-checkbox__input:indeterminate + .tox-checkbox__icons .tox-checkbox-icon__indeterminate svg {
  display: block;
}

.tox input.tox-checkbox__input:focus + .tox-checkbox__icons {
  border-radius: 3px;
  box-shadow: inset 0 0 0 1px #207ab7;
  padding: calc(4px - 1px);
}

.tox:not([dir=rtl]) .tox-checkbox__label {
  margin-left: 4px;
}

.tox:not([dir=rtl]) .tox-checkbox__input {
  left: -10000px;
}

.tox:not([dir=rtl]) .tox-bar .tox-checkbox {
  margin-left: 4px;
}

.tox[dir=rtl] .tox-checkbox__label {
  margin-right: 4px;
}

.tox[dir=rtl] .tox-checkbox__input {
  right: -10000px;
}

.tox[dir=rtl] .tox-bar .tox-checkbox {
  margin-right: 4px;
}

.tox {
  /* stylelint-disable-next-line no-descending-specificity */
}

.tox .tox-collection--toolbar .tox-collection__group {
  display: flex;
  padding: 0;
}

.tox .tox-collection--grid .tox-collection__group {
  display: flex;
  flex-wrap: wrap;
  max-height: 208px;
  overflow-x: hidden;
  overflow-y: auto;
  padding: 0;
}

.tox .tox-collection--list .tox-collection__group {
  border-bottom-width: 0;
  border-color: #cccccc;
  border-left-width: 0;
  border-right-width: 0;
  border-style: solid;
  border-top-width: 1px;
  padding: 4px 0;
}

.tox .tox-collection--list .tox-collection__group:first-child {
  border-top-width: 0;
}

.tox .tox-collection__group-heading {
  background-color: #e6e6e6;
  color: rgba(34, 47, 62, 0.7);
  cursor: default;
  font-size: 12px;
  font-style: normal;
  font-weight: normal;
  margin-bottom: 4px;
  margin-top: -4px;
  padding: 4px 8px;
  text-transform: none;
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}

.tox .tox-collection__item {
  align-items: center;
  color: #222f3e;
  cursor: pointer;
  display: flex;
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}

.tox .tox-collection--list .tox-collection__item {
  padding: 4px 8px;
}

.tox .tox-collection--toolbar .tox-collection__item {
  border-radius: 3px;
  padding: 4px;
}

.tox .tox-collection--grid .tox-collection__item {
  border-radius: 3px;
  padding: 4px;
}

.tox .tox-collection--list .tox-collection__item--enabled {
  background-color: #fff;
  color: #222f3e;
}

.tox .tox-collection--list .tox-collection__item--active {
  background-color: #dee0e2;
}

.tox .tox-collection--toolbar .tox-collection__item--enabled {
  background-color: #c8cbcf;
  color: #222f3e;
}

.tox .tox-collection--toolbar .tox-collection__item--active {
  background-color: #dee0e2;
}

.tox .tox-collection--grid .tox-collection__item--enabled {
  background-color: #c8cbcf;
  color: #222f3e;
}

.tox .tox-collection--grid .tox-collection__item--active:not(.tox-collection__item--state-disabled) {
  background-color: #dee0e2;
  color: #222f3e;
}

.tox .tox-collection--list .tox-collection__item--active:not(.tox-collection__item--state-disabled) {
  color: #222f3e;
}

.tox .tox-collection--toolbar .tox-collection__item--active:not(.tox-collection__item--state-disabled) {
  color: #222f3e;
}

.tox .tox-collection__item-icon,
.tox .tox-collection__item-checkmark {
  align-items: center;
  display: flex;
  height: 24px;
  justify-content: center;
  width: 24px;
}

.tox .tox-collection__item-icon svg,
.tox .tox-collection__item-checkmark svg {
  fill: currentColor;
}

.tox .tox-collection--toolbar-lg .tox-collection__item-icon {
  height: 48px;
  width: 48px;
}

.tox .tox-collection__item-label {
  color: currentColor;
  display: inline-block;
  flex: 1;
  -ms-flex-preferred-size: auto;
  font-size: 14px;
  font-style: normal;
  font-weight: normal;
  line-height: 24px;
  text-transform: none;
  word-break: break-all;
}

.tox .tox-collection__item-accessory {
  color: rgba(34, 47, 62, 0.7);
  display: inline-block;
  font-size: 14px;
  height: 24px;
  line-height: 24px;
  text-transform: none;
}

.tox .tox-collection__item-caret {
  align-items: center;
  display: flex;
  min-height: 24px;
}

.tox .tox-collection__item-caret::after {
  content: '';
  font-size: 0;
  min-height: inherit;
}

.tox .tox-collection__item-caret svg {
  fill: #222f3e;
}

.tox .tox-collection__item--state-disabled {
  background-color: transparent;
  color: rgba(34, 47, 62, 0.5);
  cursor: not-allowed;
}

.tox .tox-collection__item--state-disabled .tox-collection__item-caret svg {
  fill: rgba(34, 47, 62, 0.5);
}

.tox .tox-collection--list .tox-collection__item:not(.tox-collection__item--enabled) .tox-collection__item-checkmark svg {
  display: none;
}

.tox .tox-collection--list .tox-collection__item:not(.tox-collection__item--enabled) .tox-collection__item-accessory + .tox-collection__item-checkmark {
  display: none;
}

.tox .tox-collection--horizontal {
  background-color: #fff;
  border: 1px solid #cccccc;
  border-radius: 3px;
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.15);
  display: flex;
  flex: 0 0 auto;
  flex-shrink: 0;
  flex-wrap: nowrap;
  margin-bottom: 0;
  overflow-x: auto;
  padding: 0;
}

.tox .tox-collection--horizontal .tox-collection__group {
  align-items: center;
  display: flex;
  flex-wrap: nowrap;
  margin: 0;
  padding: 0 4px;
}

.tox .tox-collection--horizontal .tox-collection__item {
  height: 34px;
  margin: 2px 0 3px 0;
  padding: 0 4px;
}

.tox .tox-collection--horizontal .tox-collection__item-label {
  white-space: nowrap;
}

.tox .tox-collection--horizontal .tox-collection__item-caret {
  margin-left: 4px;
}

.tox .tox-collection__item-container {
  display: flex;
}

.tox .tox-collection__item-container--row {
  align-items: center;
  flex: 1 1 auto;
  flex-direction: row;
}

.tox .tox-collection__item-container--row.tox-collection__item-container--align-left {
  margin-right: auto;
}

.tox .tox-collection__item-container--row.tox-collection__item-container--align-right {
  justify-content: flex-end;
  margin-left: auto;
}

.tox .tox-collection__item-container--row.tox-collection__item-container--valign-top {
  align-items: flex-start;
  margin-bottom: auto;
}

.tox .tox-collection__item-container--row.tox-collection__item-container--valign-middle {
  align-items: center;
}

.tox .tox-collection__item-container--row.tox-collection__item-container--valign-bottom {
  align-items: flex-end;
  margin-top: auto;
}

.tox .tox-collection__item-container--column {
  -ms-grid-row-align: center;
  align-self: center;
  flex: 1 1 auto;
  flex-direction: column;
}

.tox .tox-collection__item-container--column.tox-collection__item-container--align-left {
  align-items: flex-start;
}

.tox .tox-collection__item-container--column.tox-collection__item-container--align-right {
  align-items: flex-end;
}

.tox .tox-collection__item-container--column.tox-collection__item-container--valign-top {
  align-self: flex-start;
}

.tox .tox-collection__item-container--column.tox-collection__item-container--valign-middle {
  -ms-grid-row-align: center;
  align-self: center;
}

.tox .tox-collection__item-container--column.tox-collection__item-container--valign-bottom {
  align-self: flex-end;
}

.tox:not([dir=rtl]) .tox-collection--horizontal .tox-collection__group:not(:last-of-type) {
  border-right: 1px solid #cccccc;
}

.tox:not([dir=rtl]) .tox-collection--list .tox-collection__item > *:not(:first-child) {
  margin-left: 8px;
}

.tox:not([dir=rtl]) .tox-collection--list .tox-collection__item > .tox-collection__item-label:first-child {
  margin-left: 4px;
}

.tox:not([dir=rtl]) .tox-collection__item-accessory {
  margin-left: 16px;
  text-align: right;
}

.tox:not([dir=rtl]) .tox-collection .tox-collection__item-caret {
  margin-left: 16px;
}

.tox[dir=rtl] .tox-collection--horizontal .tox-collection__group:not(:last-of-type) {
  border-left: 1px solid #cccccc;
}

.tox[dir=rtl] .tox-collection--list .tox-collection__item > *:not(:first-child) {
  margin-right: 8px;
}

.tox[dir=rtl] .tox-collection--list .tox-collection__item > .tox-collection__item-label:first-child {
  margin-right: 4px;
}

.tox[dir=rtl] .tox-collection__item-accessory {
  margin-right: 16px;
  text-align: left;
}

.tox[dir=rtl] .tox-collection .tox-collection__item-caret {
  margin-right: 16px;
  transform: rotateY(180deg);
}

.tox[dir=rtl] .tox-collection--horizontal .tox-collection__item-caret {
  margin-right: 4px;
}

.tox .tox-color-picker-container {
  display: flex;
  flex-direction: row;
  height: 225px;
  margin: 0;
}

.tox .tox-sv-palette {
  box-sizing: border-box;
  display: flex;
  height: 100%;
}

.tox .tox-sv-palette-spectrum {
  height: 100%;
}

.tox .tox-sv-palette,
.tox .tox-sv-palette-spectrum {
  width: 225px;
}

.tox .tox-sv-palette-thumb {
  background: none;
  border: 1px solid black;
  border-radius: 50%;
  box-sizing: content-box;
  height: 12px;
  position: absolute;
  width: 12px;
}

.tox .tox-sv-palette-inner-thumb {
  border: 1px solid white;
  border-radius: 50%;
  height: 10px;
  position: absolute;
  width: 10px;
}

.tox .tox-hue-slider {
  box-sizing: border-box;
  height: 100%;
  width: 25px;
}

.tox .tox-hue-slider-spectrum {
  background: linear-gradient(to bottom, #f00, #ff0080, #f0f, #8000ff, #00f, #0080ff, #0ff, #00ff80, #0f0, #80ff00, #ff0, #ff8000, #f00);
  height: 100%;
  width: 100%;
}

.tox .tox-hue-slider,
.tox .tox-hue-slider-spectrum {
  width: 20px;
}

.tox .tox-hue-slider-thumb {
  background: white;
  border: 1px solid black;
  box-sizing: content-box;
  height: 4px;
  width: 100%;
}

.tox .tox-rgb-form {
  display: flex;
  flex-direction: column;
  justify-content: space-between;
}

.tox .tox-rgb-form div {
  align-items: center;
  display: flex;
  justify-content: space-between;
  margin-bottom: 5px;
  width: inherit;
}

.tox .tox-rgb-form input {
  width: 6em;
}

.tox .tox-rgb-form input.tox-invalid {
  /* Need !important to override Chrome's focus styling unfortunately */
  border: 1px solid red !important;
}

.tox .tox-rgb-form .tox-rgba-preview {
  border: 1px solid black;
  flex-grow: 2;
  margin-bottom: 0;
}

.tox:not([dir=rtl]) .tox-sv-palette {
  margin-right: 15px;
}

.tox:not([dir=rtl]) .tox-hue-slider {
  margin-right: 15px;
}

.tox:not([dir=rtl]) .tox-hue-slider-thumb {
  margin-left: -1px;
}

.tox:not([dir=rtl]) .tox-rgb-form label {
  margin-right: 0.5em;
}

.tox[dir=rtl] .tox-sv-palette {
  margin-left: 15px;
}

.tox[dir=rtl] .tox-hue-slider {
  margin-left: 15px;
}

.tox[dir=rtl] .tox-hue-slider-thumb {
  margin-right: -1px;
}

.tox[dir=rtl] .tox-rgb-form label {
  margin-left: 0.5em;
}

.tox .tox-toolbar .tox-swatches,
.tox .tox-toolbar__primary .tox-swatches,
.tox .tox-toolbar__overflow .tox-swatches {
  margin: 2px 0 3px 4px;
}

.tox .tox-collection--list .tox-collection__group .tox-swatches-menu {
  border: 0;
  margin: -4px 0;
}

.tox .tox-swatches__row {
  display: flex;
}

.tox .tox-swatch {
  height: 30px;
  transition: transform 0.15s, box-shadow 0.15s;
  width: 30px;
}

.tox .tox-swatch:hover,
.tox .tox-swatch:focus {
  box-shadow: 0 0 0 1px rgba(127, 127, 127, 0.3) inset;
  transform: scale(0.8);
}

.tox .tox-swatch--remove {
  align-items: center;
  display: flex;
  justify-content: center;
}

.tox .tox-swatch--remove svg path {
  stroke: #e74c3c;
}

.tox .tox-swatches__picker-btn {
  align-items: center;
  background-color: transparent;
  border: 0;
  cursor: pointer;
  display: flex;
  height: 30px;
  justify-content: center;
  outline: none;
  padding: 0;
  width: 30px;
}

.tox .tox-swatches__picker-btn svg {
  height: 24px;
  width: 24px;
}

.tox .tox-swatches__picker-btn:hover {
  background: #dee0e2;
}

.tox:not([dir=rtl]) .tox-swatches__picker-btn {
  margin-left: auto;
}

.tox[dir=rtl] .tox-swatches__picker-btn {
  margin-right: auto;
}

.tox .tox-comment-thread {
  background: #fff;
  position: relative;
}

.tox .tox-comment-thread > *:not(:first-child) {
  margin-top: 8px;
}

.tox .tox-comment {
  background: #fff;
  border: 1px solid #cccccc;
  border-radius: 3px;
  box-shadow: 0 4px 8px 0 rgba(34, 47, 62, 0.1);
  padding: 8px 8px 16px 8px;
  position: relative;
}

.tox .tox-comment__header {
  align-items: center;
  color: #222f3e;
  display: flex;
  justify-content: space-between;
}

.tox .tox-comment__date {
  color: rgba(34, 47, 62, 0.7);
  font-size: 12px;
}

.tox .tox-comment__body {
  color: #222f3e;
  font-size: 14px;
  font-style: normal;
  font-weight: normal;
  line-height: 1.3;
  margin-top: 8px;
  position: relative;
  text-transform: initial;
}

.tox .tox-comment__body textarea {
  resize: none;
  white-space: normal;
  width: 100%;
}

.tox .tox-comment__expander {
  padding-top: 8px;
}

.tox .tox-comment__expander p {
  color: rgba(34, 47, 62, 0.7);
  font-size: 14px;
  font-style: normal;
}

.tox .tox-comment__body p {
  margin: 0;
}

.tox .tox-comment__buttonspacing {
  padding-top: 16px;
  text-align: center;
}

.tox .tox-comment-thread__overlay::after {
  background: #fff;
  bottom: 0;
  content: "";
  display: flex;
  left: 0;
  opacity: 0.9;
  position: absolute;
  right: 0;
  top: 0;
  z-index: 5;
}

.tox .tox-comment__reply {
  display: flex;
  flex-shrink: 0;
  flex-wrap: wrap;
  justify-content: flex-end;
  margin-top: 8px;
}

.tox .tox-comment__reply > *:first-child {
  margin-bottom: 8px;
  width: 100%;
}

.tox .tox-comment__edit {
  display: flex;
  flex-wrap: wrap;
  justify-content: flex-end;
  margin-top: 16px;
}

.tox .tox-comment__gradient::after {
  background: linear-gradient(rgba(255, 255, 255, 0), #fff);
  bottom: 0;
  content: "";
  display: block;
  height: 5em;
  margin-top: -40px;
  position: absolute;
  width: 100%;
}

.tox .tox-comment__overlay {
  background: #fff;
  bottom: 0;
  display: flex;
  flex-direction: column;
  flex-grow: 1;
  left: 0;
  opacity: 0.9;
  position: absolute;
  right: 0;
  text-align: center;
  top: 0;
  z-index: 5;
}

.tox .tox-comment__loading-text {
  align-items: center;
  color: #222f3e;
  display: flex;
  flex-direction: column;
  position: relative;
}

.tox .tox-comment__loading-text > div {
  padding-bottom: 16px;
}

.tox .tox-comment__overlaytext {
  bottom: 0;
  flex-direction: column;
  font-size: 14px;
  left: 0;
  padding: 1em;
  position: absolute;
  right: 0;
  top: 0;
  z-index: 10;
}

.tox .tox-comment__overlaytext p {
  background-color: #fff;
  box-shadow: 0 0 8px 8px #fff;
  color: #222f3e;
  text-align: center;
}

.tox .tox-comment__overlaytext div:nth-of-type(2) {
  font-size: 0.8em;
}

.tox .tox-comment__busy-spinner {
  align-items: center;
  background-color: #fff;
  bottom: 0;
  display: flex;
  justify-content: center;
  left: 0;
  position: absolute;
  right: 0;
  top: 0;
  z-index: 20;
}

.tox .tox-comment__scroll {
  display: flex;
  flex-direction: column;
  flex-shrink: 1;
  overflow: auto;
}

.tox .tox-conversations {
  margin: 8px;
}

.tox:not([dir=rtl]) .tox-comment__edit {
  margin-left: 8px;
}

.tox:not([dir=rtl]) .tox-comment__buttonspacing > *:last-child,
.tox:not([dir=rtl]) .tox-comment__edit > *:last-child,
.tox:not([dir=rtl]) .tox-comment__reply > *:last-child {
  margin-left: 8px;
}

.tox[dir=rtl] .tox-comment__edit {
  margin-right: 8px;
}

.tox[dir=rtl] .tox-comment__buttonspacing > *:last-child,
.tox[dir=rtl] .tox-comment__edit > *:last-child,
.tox[dir=rtl] .tox-comment__reply > *:last-child {
  margin-right: 8px;
}

.tox .tox-user {
  align-items: center;
  display: flex;
}

.tox .tox-user__avatar svg {
  fill: rgba(34, 47, 62, 0.7);
}

.tox .tox-user__name {
  color: rgba(34, 47, 62, 0.7);
  font-size: 12px;
  font-style: normal;
  font-weight: bold;
  text-transform: uppercase;
}

.tox:not([dir=rtl]) .tox-user__avatar svg {
  margin-right: 8px;
}

.tox:not([dir=rtl]) .tox-user__avatar + .tox-user__name {
  margin-left: 8px;
}

.tox[dir=rtl] .tox-user__avatar svg {
  margin-left: 8px;
}

.tox[dir=rtl] .tox-user__avatar + .tox-user__name {
  margin-right: 8px;
}

.tox .tox-dialog-wrap {
  align-items: center;
  bottom: 0;
  display: flex;
  justify-content: center;
  left: 0;
  position: fixed;
  right: 0;
  top: 0;
  z-index: 1100;
}

.tox .tox-dialog-wrap__backdrop {
  background-color: rgba(255, 255, 255, 0.75);
  bottom: 0;
  left: 0;
  position: absolute;
  right: 0;
  top: 0;
  z-index: 1;
}

.tox .tox-dialog-wrap__backdrop--opaque {
  background-color: #fff;
}

.tox .tox-dialog {
  background-color: #fff;
  border-color: #cccccc;
  border-radius: 3px;
  border-style: solid;
  border-width: 1px;
  box-shadow: 0 16px 16px -10px rgba(34, 47, 62, 0.15), 0 0 40px 1px rgba(34, 47, 62, 0.15);
  display: flex;
  flex-direction: column;
  max-height: 100%;
  max-width: 480px;
  overflow: hidden;
  position: relative;
  width: 95vw;
  z-index: 2;
}

@media only screen and (max-width:767px) {
  .amis-scope:not(.tox-force-desktop) .tox .tox-dialog {
    align-self: flex-start;
    margin: 8px auto;
    width: calc(100vw - 16px);
  }
}

.tox .tox-dialog-inline {
  z-index: 1100;
}

.tox .tox-dialog__header {
  align-items: center;
  background-color: #fff;
  border-bottom: none;
  color: #222f3e;
  display: flex;
  font-size: 16px;
  justify-content: space-between;
  padding: 8px 16px 0 16px;
  position: relative;
}

.tox .tox-dialog__header .tox-button {
  z-index: 1;
}

.tox .tox-dialog__draghandle {
  cursor: grab;
  height: 100%;
  left: 0;
  position: absolute;
  top: 0;
  width: 100%;
}

.tox .tox-dialog__draghandle:active {
  cursor: grabbing;
}

.tox .tox-dialog__dismiss {
  margin-left: auto;
}

.tox .tox-dialog__title {
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  font-size: 20px;
  font-style: normal;
  font-weight: normal;
  line-height: 1.3;
  margin: 0;
  text-transform: none;
}

.tox .tox-dialog__body {
  color: #222f3e;
  display: flex;
  flex: 1;
  -ms-flex-preferred-size: auto;
  font-size: 16px;
  font-style: normal;
  font-weight: normal;
  line-height: 1.3;
  min-width: 0;
  text-align: left;
  text-transform: none;
}

@media only screen and (max-width:767px) {
  .amis-scope:not(.tox-force-desktop) .tox .tox-dialog__body {
    flex-direction: column;
  }
}

.tox .tox-dialog__body-nav {
  align-items: flex-start;
  display: flex;
  flex-direction: column;
  padding: 16px 16px;
}

@media only screen and (max-width:767px) {
  .amis-scope:not(.tox-force-desktop) .tox .tox-dialog__body-nav {
    flex-direction: row;
    -webkit-overflow-scrolling: touch;
    overflow-x: auto;
    padding-bottom: 0;
  }
}

.tox .tox-dialog__body-nav-item {
  border-bottom: 2px solid transparent;
  color: rgba(34, 47, 62, 0.7);
  display: inline-block;
  font-size: 14px;
  line-height: 1.3;
  margin-bottom: 8px;
  text-decoration: none;
  white-space: nowrap;
}

.tox .tox-dialog__body-nav-item:focus {
  background-color: rgba(32, 122, 183, 0.1);
}

.tox .tox-dialog__body-nav-item--active {
  border-bottom: 2px solid #207ab7;
  color: #207ab7;
}

.tox .tox-dialog__body-content {
  box-sizing: border-box;
  display: flex;
  flex: 1;
  flex-direction: column;
  -ms-flex-preferred-size: auto;
  max-height: 650px;
  overflow: auto;
  -webkit-overflow-scrolling: touch;
  padding: 16px 16px;
}

.tox .tox-dialog__body-content > * {
  margin-bottom: 0;
  margin-top: 16px;
}

.tox .tox-dialog__body-content > *:first-child {
  margin-top: 0;
}

.tox .tox-dialog__body-content > *:last-child {
  margin-bottom: 0;
}

.tox .tox-dialog__body-content > *:only-child {
  margin-bottom: 0;
  margin-top: 0;
}

.tox .tox-dialog__body-content a {
  color: #207ab7;
  cursor: pointer;
  text-decoration: none;
}

.tox .tox-dialog__body-content a:hover,
.tox .tox-dialog__body-content a:focus {
  color: #185d8c;
  text-decoration: none;
}

.tox .tox-dialog__body-content a:active {
  color: #185d8c;
  text-decoration: none;
}

.tox .tox-dialog__body-content svg {
  fill: #222f3e;
}

.tox .tox-dialog__body-content ul {
  display: block;
  list-style-type: disc;
  margin-bottom: 16px;
  -webkit-margin-end: 0;
  margin-inline-end: 0;
  -webkit-margin-start: 0;
  margin-inline-start: 0;
  -webkit-padding-start: 2.5rem;
  padding-inline-start: 2.5rem;
}

.tox .tox-dialog__body-content .tox-form__group h1 {
  color: #222f3e;
  font-size: 20px;
  font-style: normal;
  font-weight: bold;
  letter-spacing: normal;
  margin-bottom: 16px;
  margin-top: 2rem;
  text-transform: none;
}

.tox .tox-dialog__body-content .tox-form__group h2 {
  color: #222f3e;
  font-size: 16px;
  font-style: normal;
  font-weight: bold;
  letter-spacing: normal;
  margin-bottom: 16px;
  margin-top: 2rem;
  text-transform: none;
}

.tox .tox-dialog__body-content .tox-form__group p {
  margin-bottom: 16px;
}

.tox .tox-dialog__body-content .tox-form__group h1:first-child,
.tox .tox-dialog__body-content .tox-form__group h2:first-child,
.tox .tox-dialog__body-content .tox-form__group p:first-child {
  margin-top: 0;
}

.tox .tox-dialog__body-content .tox-form__group h1:last-child,
.tox .tox-dialog__body-content .tox-form__group h2:last-child,
.tox .tox-dialog__body-content .tox-form__group p:last-child {
  margin-bottom: 0;
}

.tox .tox-dialog__body-content .tox-form__group h1:only-child,
.tox .tox-dialog__body-content .tox-form__group h2:only-child,
.tox .tox-dialog__body-content .tox-form__group p:only-child {
  margin-bottom: 0;
  margin-top: 0;
}

.tox .tox-dialog--width-lg {
  height: 650px;
  max-width: 1200px;
}

.tox .tox-dialog--width-md {
  max-width: 800px;
}

.tox .tox-dialog--width-md .tox-dialog__body-content {
  overflow: auto;
}

.tox .tox-dialog__body-content--centered {
  text-align: center;
}

.tox .tox-dialog__footer {
  align-items: center;
  background-color: #fff;
  border-top: 1px solid #cccccc;
  display: flex;
  justify-content: space-between;
  padding: 8px 16px;
}

.tox .tox-dialog__footer-start,
.tox .tox-dialog__footer-end {
  display: flex;
}

.tox .tox-dialog__busy-spinner {
  align-items: center;
  background-color: rgba(255, 255, 255, 0.75);
  bottom: 0;
  display: flex;
  justify-content: center;
  left: 0;
  position: absolute;
  right: 0;
  top: 0;
  z-index: 3;
}

.tox .tox-dialog__table {
  border-collapse: collapse;
  width: 100%;
}

.tox .tox-dialog__table thead th {
  font-weight: bold;
  padding-bottom: 8px;
}

.tox .tox-dialog__table tbody tr {
  border-bottom: 1px solid #cccccc;
}

.tox .tox-dialog__table tbody tr:last-child {
  border-bottom: none;
}

.tox .tox-dialog__table td {
  padding-bottom: 8px;
  padding-top: 8px;
}

.tox .tox-dialog__popups {
  position: absolute;
  width: 100%;
  z-index: 1100;
}

.tox .tox-dialog__body-iframe {
  display: flex;
  flex: 1;
  flex-direction: column;
  -ms-flex-preferred-size: auto;
}

.tox .tox-dialog__body-iframe .tox-navobj {
  display: flex;
  flex: 1;
  -ms-flex-preferred-size: auto;
}

.tox .tox-dialog__body-iframe .tox-navobj :nth-child(2) {
  flex: 1;
  -ms-flex-preferred-size: auto;
  height: 100%;
}

.tox .tox-dialog-dock-fadeout {
  opacity: 0;
  visibility: hidden;
}

.tox .tox-dialog-dock-fadein {
  opacity: 1;
  visibility: visible;
}

.tox .tox-dialog-dock-transition {
  transition: visibility 0s linear 0.3s, opacity 0.3s ease;
}

.tox .tox-dialog-dock-transition.tox-dialog-dock-fadein {
  transition-delay: 0s;
}

.tox.tox-platform-ie {
  /* IE11 CSS styles go here */
}

.tox.tox-platform-ie .tox-dialog-wrap {
  position: -ms-device-fixed;
}

@media only screen and (max-width:767px) {
  .amis-scope:not(.tox-force-desktop) .tox:not([dir=rtl]) .tox-dialog__body-nav {
    margin-right: 0;
  }
}

@media only screen and (max-width:767px) {
  .amis-scope:not(.tox-force-desktop) .tox:not([dir=rtl]) .tox-dialog__body-nav-item:not(:first-child) {
    margin-left: 8px;
  }
}

.tox:not([dir=rtl]) .tox-dialog__footer .tox-dialog__footer-start > *,
.tox:not([dir=rtl]) .tox-dialog__footer .tox-dialog__footer-end > * {
  margin-left: 8px;
}

.tox[dir=rtl] .tox-dialog__body {
  text-align: right;
}

@media only screen and (max-width:767px) {
  .amis-scope:not(.tox-force-desktop) .tox[dir=rtl] .tox-dialog__body-nav {
    margin-left: 0;
  }
}

@media only screen and (max-width:767px) {
  .amis-scope:not(.tox-force-desktop) .tox[dir=rtl] .tox-dialog__body-nav-item:not(:first-child) {
    margin-right: 8px;
  }
}

.tox[dir=rtl] .tox-dialog__footer .tox-dialog__footer-start > *,
.tox[dir=rtl] .tox-dialog__footer .tox-dialog__footer-end > * {
  margin-right: 8px;
}

.amis-scope.tox-dialog__disable-scroll {
  overflow: hidden;
}

.tox .tox-dropzone-container {
  display: flex;
  flex: 1;
  -ms-flex-preferred-size: auto;
}

.tox .tox-dropzone {
  align-items: center;
  background: #fff;
  border: 2px dashed #cccccc;
  box-sizing: border-box;
  display: flex;
  flex-direction: column;
  flex-grow: 1;
  justify-content: center;
  min-height: 100px;
  padding: 10px;
}

.tox .tox-dropzone p {
  color: rgba(34, 47, 62, 0.7);
  margin: 0 0 16px 0;
}

.tox .tox-edit-area {
  display: flex;
  flex: 1;
  -ms-flex-preferred-size: auto;
  overflow: hidden;
  position: relative;
}

.tox .tox-edit-area__iframe {
  background-color: #fff;
  border: 0;
  box-sizing: border-box;
  flex: 1;
  -ms-flex-preferred-size: auto;
  height: 100%;
  position: absolute;
  width: 100%;
}

.tox.tox-inline-edit-area {
  border: 1px dotted #cccccc;
}

.tox .tox-editor-container {
  display: flex;
  flex: 1 1 auto;
  flex-direction: column;
  overflow: hidden;
}

.tox .tox-editor-header {
  z-index: 1;
}

.tox:not(.tox-tinymce-inline) .tox-editor-header {
  box-shadow: none;
  transition: box-shadow 0.5s;
}

.tox.tox-tinymce--toolbar-bottom .tox-editor-header,
.tox.tox-tinymce-inline .tox-editor-header {
  margin-bottom: -1px;
}

.tox.tox-tinymce--toolbar-sticky-on .tox-editor-header {
  background-color: transparent;
  box-shadow: 0 4px 4px -3px rgba(0, 0, 0, 0.25);
}

.tox-editor-dock-fadeout {
  opacity: 0;
  visibility: hidden;
}

.tox-editor-dock-fadein {
  opacity: 1;
  visibility: visible;
}

.tox-editor-dock-transition {
  transition: visibility 0s linear 0.25s, opacity 0.25s ease;
}

.tox-editor-dock-transition.tox-editor-dock-fadein {
  transition-delay: 0s;
}

.tox .tox-control-wrap {
  flex: 1;
  position: relative;
}

.tox .tox-control-wrap:not(.tox-control-wrap--status-invalid) .tox-control-wrap__status-icon-invalid,
.tox .tox-control-wrap:not(.tox-control-wrap--status-unknown) .tox-control-wrap__status-icon-unknown,
.tox .tox-control-wrap:not(.tox-control-wrap--status-valid) .tox-control-wrap__status-icon-valid {
  display: none;
}

.tox .tox-control-wrap svg {
  display: block;
}

.tox .tox-control-wrap__status-icon-wrap {
  position: absolute;
  top: 50%;
  transform: translateY(-50%);
}

.tox .tox-control-wrap__status-icon-invalid svg {
  fill: #c00;
}

.tox .tox-control-wrap__status-icon-unknown svg {
  fill: orange;
}

.tox .tox-control-wrap__status-icon-valid svg {
  fill: green;
}

.tox:not([dir=rtl]) .tox-control-wrap--status-invalid .tox-textfield,
.tox:not([dir=rtl]) .tox-control-wrap--status-unknown .tox-textfield,
.tox:not([dir=rtl]) .tox-control-wrap--status-valid .tox-textfield {
  padding-right: 32px;
}

.tox:not([dir=rtl]) .tox-control-wrap__status-icon-wrap {
  right: 4px;
}

.tox[dir=rtl] .tox-control-wrap--status-invalid .tox-textfield,
.tox[dir=rtl] .tox-control-wrap--status-unknown .tox-textfield,
.tox[dir=rtl] .tox-control-wrap--status-valid .tox-textfield {
  padding-left: 32px;
}

.tox[dir=rtl] .tox-control-wrap__status-icon-wrap {
  left: 4px;
}

.tox .tox-autocompleter {
  max-width: 25em;
}

.tox .tox-autocompleter .tox-menu {
  max-width: 25em;
}

.tox .tox-autocompleter .tox-autocompleter-highlight {
  font-weight: bold;
}

.tox .tox-color-input {
  display: flex;
  position: relative;
  z-index: 1;
}

.tox .tox-color-input .tox-textfield {
  z-index: -1;
}

.tox .tox-color-input span {
  border-color: rgba(34, 47, 62, 0.2);
  border-radius: 3px;
  border-style: solid;
  border-width: 1px;
  box-shadow: none;
  box-sizing: border-box;
  height: 24px;
  position: absolute;
  top: 6px;
  width: 24px;
}

.tox .tox-color-input span:hover:not([aria-disabled=true]),
.tox .tox-color-input span:focus:not([aria-disabled=true]) {
  border-color: #207ab7;
  cursor: pointer;
}

.tox .tox-color-input span::before {
  background-image: linear-gradient(45deg, rgba(0, 0, 0, 0.25) 25%, transparent 25%), linear-gradient(-45deg, rgba(0, 0, 0, 0.25) 25%, transparent 25%), linear-gradient(45deg, transparent 75%, rgba(0, 0, 0, 0.25) 75%), linear-gradient(-45deg, transparent 75%, rgba(0, 0, 0, 0.25) 75%);
  background-position: 0 0, 0 6px, 6px -6px, -6px 0;
  background-size: 12px 12px;
  border: 1px solid #fff;
  border-radius: 3px;
  box-sizing: border-box;
  content: '';
  height: 24px;
  left: -1px;
  position: absolute;
  top: -1px;
  width: 24px;
  z-index: -1;
}

.tox .tox-color-input span[aria-disabled=true] {
  cursor: not-allowed;
}

.tox:not([dir=rtl]) .tox-color-input {
  /* stylelint-disable-next-line no-descending-specificity */
}

.tox:not([dir=rtl]) .tox-color-input .tox-textfield {
  padding-left: 36px;
}

.tox:not([dir=rtl]) .tox-color-input span {
  left: 6px;
}

.tox[dir="rtl"] .tox-color-input {
  /* stylelint-disable-next-line no-descending-specificity */
}

.tox[dir="rtl"] .tox-color-input .tox-textfield {
  padding-right: 36px;
}

.tox[dir="rtl"] .tox-color-input span {
  right: 6px;
}

.tox .tox-label,
.tox .tox-toolbar-label {
  color: rgba(34, 47, 62, 0.7);
  display: block;
  font-size: 14px;
  font-style: normal;
  font-weight: normal;
  line-height: 1.3;
  padding: 0 8px 0 0;
  text-transform: none;
  white-space: nowrap;
}

.tox .tox-toolbar-label {
  padding: 0 8px;
}

.tox[dir=rtl] .tox-label {
  padding: 0 0 0 8px;
}

.tox .tox-form {
  display: flex;
  flex: 1;
  flex-direction: column;
  -ms-flex-preferred-size: auto;
}

.tox .tox-form__group {
  box-sizing: border-box;
  margin-bottom: 4px;
}

.tox .tox-form-group--maximize {
  flex: 1;
}

.tox .tox-form__group--error {
  color: #c00;
}

.tox .tox-form__group--collection {
  display: flex;
}

.tox .tox-form__grid {
  display: flex;
  flex-direction: row;
  flex-wrap: wrap;
  justify-content: space-between;
}

.tox .tox-form__grid--2col > .tox-form__group {
  width: calc(50% - (8px / 2));
}

.tox .tox-form__grid--3col > .tox-form__group {
  width: calc(100% / 3 - (8px / 2));
}

.tox .tox-form__grid--4col > .tox-form__group {
  width: calc(25% - (8px / 2));
}

.tox .tox-form__controls-h-stack {
  align-items: center;
  display: flex;
}

.tox .tox-form__group--inline {
  align-items: center;
  display: flex;
}

.tox .tox-form__group--stretched {
  display: flex;
  flex: 1;
  flex-direction: column;
  -ms-flex-preferred-size: auto;
}

.tox .tox-form__group--stretched .tox-textarea {
  flex: 1;
  -ms-flex-preferred-size: auto;
}

.tox .tox-form__group--stretched .tox-navobj {
  display: flex;
  flex: 1;
  -ms-flex-preferred-size: auto;
}

.tox .tox-form__group--stretched .tox-navobj :nth-child(2) {
  flex: 1;
  -ms-flex-preferred-size: auto;
  height: 100%;
}

.tox:not([dir=rtl]) .tox-form__controls-h-stack > *:not(:first-child) {
  margin-left: 4px;
}

.tox[dir=rtl] .tox-form__controls-h-stack > *:not(:first-child) {
  margin-right: 4px;
}

.tox .tox-lock.tox-locked .tox-lock-icon__unlock,
.tox .tox-lock:not(.tox-locked) .tox-lock-icon__lock {
  display: none;
}

.tox .tox-textfield,
.tox .tox-toolbar-textfield,
.tox .tox-listboxfield .tox-listbox--select,
.tox .tox-textarea {
  -webkit-appearance: none;
  -moz-appearance: none;
  appearance: none;
  background-color: #fff;
  border-color: #cccccc;
  border-radius: 3px;
  border-style: solid;
  border-width: 1px;
  box-shadow: none;
  box-sizing: border-box;
  color: #222f3e;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  font-size: 16px;
  line-height: 24px;
  margin: 0;
  min-height: 34px;
  outline: none;
  padding: 5px 4.75px;
  resize: none;
  width: 100%;
}

.tox .tox-textfield[disabled],
.tox .tox-textarea[disabled] {
  background-color: #f2f2f2;
  color: rgba(34, 47, 62, 0.85);
  cursor: not-allowed;
}

.tox .tox-textfield:focus,
.tox .tox-listboxfield .tox-listbox--select:focus,
.tox .tox-textarea:focus {
  background-color: #fff;
  border-color: #207ab7;
  box-shadow: none;
  outline: none;
}

.tox .tox-toolbar-textfield {
  border-width: 0;
  margin-bottom: 3px;
  margin-top: 2px;
  max-width: 250px;
}

.tox .tox-naked-btn {
  background-color: transparent;
  border: 0;
  border-color: transparent;
  box-shadow: unset;
  color: #207ab7;
  cursor: pointer;
  display: block;
  margin: 0;
  padding: 0;
}

.tox .tox-naked-btn svg {
  display: block;
  fill: #222f3e;
}

.tox:not([dir=rtl]) .tox-toolbar-textfield + * {
  margin-left: 4px;
}

.tox[dir=rtl] .tox-toolbar-textfield + * {
  margin-right: 4px;
}

.tox .tox-listboxfield {
  cursor: pointer;
  position: relative;
}

.tox .tox-listboxfield .tox-listbox--select[disabled] {
  background-color: #f2f2f2;
  color: rgba(34, 47, 62, 0.85);
  cursor: not-allowed;
}

.tox .tox-listbox__select-label {
  cursor: default;
  flex: 1;
  margin: 0 4px;
}

.tox .tox-listbox__select-chevron {
  align-items: center;
  display: flex;
  justify-content: center;
  width: 16px;
}

.tox .tox-listbox__select-chevron svg {
  fill: #222f3e;
}

.tox .tox-listboxfield .tox-listbox--select {
  align-items: center;
  display: flex;
}

.tox:not([dir=rtl]) .tox-listboxfield svg {
  right: 8px;
}

.tox[dir=rtl] .tox-listboxfield svg {
  left: 8px;
}

.tox .tox-selectfield {
  cursor: pointer;
  position: relative;
}

.tox .tox-selectfield select {
  -webkit-appearance: none;
  -moz-appearance: none;
  appearance: none;
  background-color: #fff;
  border-color: #cccccc;
  border-radius: 3px;
  border-style: solid;
  border-width: 1px;
  box-shadow: none;
  box-sizing: border-box;
  color: #222f3e;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  font-size: 16px;
  line-height: 24px;
  margin: 0;
  min-height: 34px;
  outline: none;
  padding: 5px 4.75px;
  resize: none;
  width: 100%;
}

.tox .tox-selectfield select[disabled] {
  background-color: #f2f2f2;
  color: rgba(34, 47, 62, 0.85);
  cursor: not-allowed;
}

.tox .tox-selectfield select::-ms-expand {
  display: none;
}

.tox .tox-selectfield select:focus {
  background-color: #fff;
  border-color: #207ab7;
  box-shadow: none;
  outline: none;
}

.tox .tox-selectfield svg {
  pointer-events: none;
  position: absolute;
  top: 50%;
  transform: translateY(-50%);
}

.tox:not([dir=rtl]) .tox-selectfield select[size="0"],
.tox:not([dir=rtl]) .tox-selectfield select[size="1"] {
  padding-right: 24px;
}

.tox:not([dir=rtl]) .tox-selectfield svg {
  right: 8px;
}

.tox[dir=rtl] .tox-selectfield select[size="0"],
.tox[dir=rtl] .tox-selectfield select[size="1"] {
  padding-left: 24px;
}

.tox[dir=rtl] .tox-selectfield svg {
  left: 8px;
}

.tox .tox-textarea {
  -webkit-appearance: textarea;
  -moz-appearance: textarea;
  appearance: textarea;
  white-space: pre-wrap;
}

.tox-fullscreen {
  border: 0;
  height: 100%;
  left: 0;
  margin: 0;
  overflow: hidden;
  -ms-scroll-chaining: none;
  overscroll-behavior: none;
  padding: 0;
  position: fixed;
  top: 0;
  touch-action: pinch-zoom;
  width: 100%;
}

.tox.tox-tinymce.tox-fullscreen .tox-statusbar__resize-handle {
  display: none;
}

.tox.tox-tinymce.tox-fullscreen {
  background-color: transparent;
  z-index: 1200;
}

.tox-shadowhost.tox-fullscreen {
  z-index: 1200;
}

.tox-fullscreen .tox.tox-tinymce-aux,
.tox-fullscreen ~ .tox.tox-tinymce-aux {
  z-index: 1201;
}

.tox .tox-help__more-link {
  list-style: none;
  margin-top: 1em;
}

.tox .tox-image-tools {
  width: 100%;
}

.tox .tox-image-tools__toolbar {
  align-items: center;
  display: flex;
  justify-content: center;
}

.tox .tox-image-tools__image {
  background-color: #666;
  height: 380px;
  overflow: auto;
  position: relative;
  width: 100%;
}

.tox .tox-image-tools__image,
.tox .tox-image-tools__image + .tox-image-tools__toolbar {
  margin-top: 8px;
}

.tox .tox-image-tools__image-bg {
  background: url(data:image/gif;base64,R0lGODdhDAAMAIABAMzMzP///ywAAAAADAAMAAACFoQfqYeabNyDMkBQb81Uat85nxguUAEAOw==);
}

.tox .tox-image-tools__toolbar > .tox-spacer {
  flex: 1;
  -ms-flex-preferred-size: auto;
}

.tox .tox-croprect-block {
  background: black;
  filter: alpha(opacity=50);
  opacity: 0.5;
  position: absolute;
  zoom: 1;
}

.tox .tox-croprect-handle {
  border: 2px solid white;
  height: 20px;
  left: 0;
  position: absolute;
  top: 0;
  width: 20px;
}

.tox .tox-croprect-handle-move {
  border: 0;
  cursor: move;
  position: absolute;
}

.tox .tox-croprect-handle-nw {
  border-width: 2px 0 0 2px;
  cursor: nw-resize;
  left: 100px;
  margin: -2px 0 0 -2px;
  top: 100px;
}

.tox .tox-croprect-handle-ne {
  border-width: 2px 2px 0 0;
  cursor: ne-resize;
  left: 200px;
  margin: -2px 0 0 -20px;
  top: 100px;
}

.tox .tox-croprect-handle-sw {
  border-width: 0 0 2px 2px;
  cursor: sw-resize;
  left: 100px;
  margin: -20px 2px 0 -2px;
  top: 200px;
}

.tox .tox-croprect-handle-se {
  border-width: 0 2px 2px 0;
  cursor: se-resize;
  left: 200px;
  margin: -20px 0 0 -20px;
  top: 200px;
}

.tox:not([dir=rtl]) .tox-image-tools__toolbar > .tox-slider:not(:first-of-type) {
  margin-left: 8px;
}

.tox:not([dir=rtl]) .tox-image-tools__toolbar > .tox-button + .tox-slider {
  margin-left: 32px;
}

.tox:not([dir=rtl]) .tox-image-tools__toolbar > .tox-slider + .tox-button {
  margin-left: 32px;
}

.tox[dir=rtl] .tox-image-tools__toolbar > .tox-slider:not(:first-of-type) {
  margin-right: 8px;
}

.tox[dir=rtl] .tox-image-tools__toolbar > .tox-button + .tox-slider {
  margin-right: 32px;
}

.tox[dir=rtl] .tox-image-tools__toolbar > .tox-slider + .tox-button {
  margin-right: 32px;
}

.tox .tox-insert-table-picker {
  display: flex;
  flex-wrap: wrap;
  width: 170px;
}

.tox .tox-insert-table-picker > div {
  border-color: #cccccc;
  border-style: solid;
  border-width: 0 1px 1px 0;
  box-sizing: border-box;
  height: 17px;
  width: 17px;
}

.tox .tox-collection--list .tox-collection__group .tox-insert-table-picker {
  margin: -4px 0;
}

.tox .tox-insert-table-picker .tox-insert-table-picker__selected {
  background-color: rgba(32, 122, 183, 0.5);
  border-color: rgba(32, 122, 183, 0.5);
}

.tox .tox-insert-table-picker__label {
  color: rgba(34, 47, 62, 0.7);
  display: block;
  font-size: 14px;
  padding: 4px;
  text-align: center;
  width: 100%;
}

.tox:not([dir=rtl]) {
  /* stylelint-disable-next-line no-descending-specificity */
}

.tox:not([dir=rtl]) .tox-insert-table-picker > div:nth-child(10n) {
  border-right: 0;
}

.tox[dir=rtl] {
  /* stylelint-disable-next-line no-descending-specificity */
}

.tox[dir=rtl] .tox-insert-table-picker > div:nth-child(10n+1) {
  border-right: 0;
}

.tox {
  /* stylelint-disable */
  /* stylelint-enable */
}

.tox .tox-menu {
  background-color: #fff;
  border: 1px solid #cccccc;
  border-radius: 3px;
  box-shadow: 0 4px 8px 0 rgba(34, 47, 62, 0.1);
  display: inline-block;
  overflow: hidden;
  vertical-align: top;
  z-index: 1150;
}

.tox .tox-menu.tox-collection.tox-collection--list {
  padding: 0;
}

.tox .tox-menu.tox-collection.tox-collection--toolbar {
  padding: 4px;
}

.tox .tox-menu.tox-collection.tox-collection--grid {
  padding: 4px;
}

.tox .tox-menu__label h1,
.tox .tox-menu__label h2,
.tox .tox-menu__label h3,
.tox .tox-menu__label h4,
.tox .tox-menu__label h5,
.tox .tox-menu__label h6,
.tox .tox-menu__label p,
.tox .tox-menu__label blockquote,
.tox .tox-menu__label code {
  margin: 0;
}

.tox .tox-menubar {
  background: url("data:image/svg+xml;charset=utf8,%3Csvg height='39px' viewBox='0 0 40 39px' width='40' xmlns='http://www.w3.org/2000/svg'%3E%3Crect x='0' y='38px' width='100' height='1' fill='%23cccccc'/%3E%3C/svg%3E") left 0 top 0 #fff;
  background-color: #fff;
  display: flex;
  flex: 0 0 auto;
  flex-shrink: 0;
  flex-wrap: wrap;
  padding: 0 4px 0 4px;
}

.tox.tox-tinymce:not(.tox-tinymce-inline) .tox-editor-header:not(:first-child) .tox-menubar {
  border-top: 1px solid #cccccc;
}

/* Deprecated. Remove in next major release */

.tox .tox-mbtn {
  align-items: center;
  background: transparent;
  border: 0;
  border-radius: 3px;
  box-shadow: none;
  color: #222f3e;
  display: flex;
  flex: 0 0 auto;
  font-size: 14px;
  font-style: normal;
  font-weight: normal;
  height: 34px;
  justify-content: center;
  margin: 2px 0 3px 0;
  outline: none;
  overflow: hidden;
  padding: 0 4px;
  text-transform: none;
  width: auto;
}

.tox .tox-mbtn[disabled] {
  background-color: transparent;
  border: 0;
  box-shadow: none;
  color: rgba(34, 47, 62, 0.5);
  cursor: not-allowed;
}

.tox .tox-mbtn:focus:not(:disabled) {
  background: #dee0e2;
  border: 0;
  box-shadow: none;
  color: #222f3e;
}

.tox .tox-mbtn--active {
  background: #c8cbcf;
  border: 0;
  box-shadow: none;
  color: #222f3e;
}

.tox .tox-mbtn:hover:not(:disabled):not(.tox-mbtn--active) {
  background: #dee0e2;
  border: 0;
  box-shadow: none;
  color: #222f3e;
}

.tox .tox-mbtn__select-label {
  cursor: default;
  font-weight: normal;
  margin: 0 4px;
}

.tox .tox-mbtn[disabled] .tox-mbtn__select-label {
  cursor: not-allowed;
}

.tox .tox-mbtn__select-chevron {
  align-items: center;
  display: flex;
  justify-content: center;
  width: 16px;
  display: none;
}

.tox .tox-notification {
  border-radius: 3px;
  border-style: solid;
  border-width: 1px;
  box-shadow: none;
  box-sizing: border-box;
  display: -ms-grid;
  display: grid;
  font-size: 14px;
  font-weight: normal;
  -ms-grid-columns: minmax(40px, 1fr) auto minmax(40px, 1fr);
  grid-template-columns: minmax(40px, 1fr) auto minmax(40px, 1fr);
  margin-top: 4px;
  opacity: 0;
  padding: 4px;
  transition: transform 100ms ease-in, opacity 150ms ease-in;
}

.tox .tox-notification p {
  font-size: 14px;
  font-weight: normal;
}

.tox .tox-notification a {
  cursor: pointer;
  text-decoration: underline;
}

.tox .tox-notification--in {
  opacity: 1;
}

.tox .tox-notification--success {
  background-color: #e4eeda;
  border-color: #d7e6c8;
  color: #222f3e;
}

.tox .tox-notification--success p {
  color: #222f3e;
}

.tox .tox-notification--success a {
  color: #547831;
}

.tox .tox-notification--success svg {
  fill: #222f3e;
}

.tox .tox-notification--error {
  background-color: #f8dede;
  border-color: #f2bfbf;
  color: #222f3e;
}

.tox .tox-notification--error p {
  color: #222f3e;
}

.tox .tox-notification--error a {
  color: #c00;
}

.tox .tox-notification--error svg {
  fill: #222f3e;
}

.tox .tox-notification--warn,
.tox .tox-notification--warning {
  background-color: #fffaea;
  border-color: #ffe89d;
  color: #222f3e;
}

.tox .tox-notification--warn p,
.tox .tox-notification--warning p {
  color: #222f3e;
}

.tox .tox-notification--warn a,
.tox .tox-notification--warning a {
  color: #222f3e;
}

.tox .tox-notification--warn svg,
.tox .tox-notification--warning svg {
  fill: #222f3e;
}

.tox .tox-notification--info {
  background-color: #d9edf7;
  border-color: #779ecb;
  color: #222f3e;
}

.tox .tox-notification--info p {
  color: #222f3e;
}

.tox .tox-notification--info a {
  color: #222f3e;
}

.tox .tox-notification--info svg {
  fill: #222f3e;
}

.tox .tox-notification__body {
  -ms-grid-row-align: center;
  align-self: center;
  color: #222f3e;
  font-size: 14px;
  -ms-grid-column-span: 1;
  grid-column-end: 3;
  -ms-grid-column: 2;
  grid-column-start: 2;
  -ms-grid-row-span: 1;
  grid-row-end: 2;
  -ms-grid-row: 1;
  grid-row-start: 1;
  text-align: center;
  white-space: normal;
  word-break: break-all;
  word-break: break-word;
}

.tox .tox-notification__body > * {
  margin: 0;
}

.tox .tox-notification__body > * + * {
  margin-top: 1rem;
}

.tox .tox-notification__icon {
  -ms-grid-row-align: center;
  align-self: center;
  -ms-grid-column-span: 1;
  grid-column-end: 2;
  -ms-grid-column: 1;
  grid-column-start: 1;
  -ms-grid-row-span: 1;
  grid-row-end: 2;
  -ms-grid-row: 1;
  grid-row-start: 1;
  -ms-grid-column-align: end;
  justify-self: end;
}

.tox .tox-notification__icon svg {
  display: block;
}

.tox .tox-notification__dismiss {
  -ms-grid-row-align: start;
  align-self: start;
  -ms-grid-column-span: 1;
  grid-column-end: 4;
  -ms-grid-column: 3;
  grid-column-start: 3;
  -ms-grid-row-span: 1;
  grid-row-end: 2;
  -ms-grid-row: 1;
  grid-row-start: 1;
  -ms-grid-column-align: end;
  justify-self: end;
}

.tox .tox-notification .tox-progress-bar {
  -ms-grid-column-span: 3;
  grid-column-end: 4;
  -ms-grid-column: 1;
  grid-column-start: 1;
  -ms-grid-row-span: 1;
  grid-row-end: 3;
  -ms-grid-row: 2;
  grid-row-start: 2;
  -ms-grid-column-align: center;
  justify-self: center;
}

.tox .tox-pop {
  display: inline-block;
  position: relative;
}

.tox .tox-pop--resizing {
  transition: width 0.1s ease;
}

.tox .tox-pop--resizing .tox-toolbar,
.tox .tox-pop--resizing .tox-toolbar__group {
  flex-wrap: nowrap;
}

.tox .tox-pop--transition {
  transition: 0.15s ease;
  transition-property: left, right, top, bottom;
}

.tox .tox-pop--transition::before,
.tox .tox-pop--transition::after {
  transition: all 0.15s, visibility 0s, opacity 0.075s ease 0.075s;
}

.tox .tox-pop__dialog {
  background-color: #fff;
  border: 1px solid #cccccc;
  border-radius: 3px;
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.15);
  min-width: 0;
  overflow: hidden;
}

.tox .tox-pop__dialog > *:not(.tox-toolbar) {
  margin: 4px 4px 4px 8px;
}

.tox .tox-pop__dialog .tox-toolbar {
  background-color: transparent;
  margin-bottom: -1px;
}

.tox .tox-pop::before,
.tox .tox-pop::after {
  border-style: solid;
  content: '';
  display: block;
  height: 0;
  opacity: 1;
  position: absolute;
  width: 0;
}

.tox .tox-pop.tox-pop--inset::before,
.tox .tox-pop.tox-pop--inset::after {
  opacity: 0;
  transition: all 0s 0.15s, visibility 0s, opacity 0.075s ease;
}

.tox .tox-pop.tox-pop--bottom::before,
.tox .tox-pop.tox-pop--bottom::after {
  left: 50%;
  top: 100%;
}

.tox .tox-pop.tox-pop--bottom::after {
  border-color: #fff transparent transparent transparent;
  border-width: 8px;
  margin-left: -8px;
  margin-top: -1px;
}

.tox .tox-pop.tox-pop--bottom::before {
  border-color: #cccccc transparent transparent transparent;
  border-width: 9px;
  margin-left: -9px;
}

.tox .tox-pop.tox-pop--top::before,
.tox .tox-pop.tox-pop--top::after {
  left: 50%;
  top: 0;
  transform: translateY(-100%);
}

.tox .tox-pop.tox-pop--top::after {
  border-color: transparent transparent #fff transparent;
  border-width: 8px;
  margin-left: -8px;
  margin-top: 1px;
}

.tox .tox-pop.tox-pop--top::before {
  border-color: transparent transparent #cccccc transparent;
  border-width: 9px;
  margin-left: -9px;
}

.tox .tox-pop.tox-pop--left::before,
.tox .tox-pop.tox-pop--left::after {
  left: 0;
  top: calc(50% - 1px);
  transform: translateY(-50%);
}

.tox .tox-pop.tox-pop--left::after {
  border-color: transparent #fff transparent transparent;
  border-width: 8px;
  margin-left: -15px;
}

.tox .tox-pop.tox-pop--left::before {
  border-color: transparent #cccccc transparent transparent;
  border-width: 10px;
  margin-left: -19px;
}

.tox .tox-pop.tox-pop--right::before,
.tox .tox-pop.tox-pop--right::after {
  left: 100%;
  top: calc(50% + 1px);
  transform: translateY(-50%);
}

.tox .tox-pop.tox-pop--right::after {
  border-color: transparent transparent transparent #fff;
  border-width: 8px;
  margin-left: -1px;
}

.tox .tox-pop.tox-pop--right::before {
  border-color: transparent transparent transparent #cccccc;
  border-width: 10px;
  margin-left: -1px;
}

.tox .tox-pop.tox-pop--align-left::before,
.tox .tox-pop.tox-pop--align-left::after {
  left: 20px;
}

.tox .tox-pop.tox-pop--align-right::before,
.tox .tox-pop.tox-pop--align-right::after {
  left: calc(100% - 20px);
}

.tox .tox-sidebar-wrap {
  display: flex;
  flex-direction: row;
  flex-grow: 1;
  -ms-flex-preferred-size: 0;
  min-height: 0;
}

.tox .tox-sidebar {
  background-color: #fff;
  display: flex;
  flex-direction: row;
  justify-content: flex-end;
}

.tox .tox-sidebar__slider {
  display: flex;
  overflow: hidden;
}

.tox .tox-sidebar__pane-container {
  display: flex;
}

.tox .tox-sidebar__pane {
  display: flex;
}

.tox .tox-sidebar--sliding-closed {
  opacity: 0;
}

.tox .tox-sidebar--sliding-open {
  opacity: 1;
}

.tox .tox-sidebar--sliding-growing,
.tox .tox-sidebar--sliding-shrinking {
  transition: width 0.5s ease, opacity 0.5s ease;
}

.tox .tox-selector {
  background-color: #4099ff;
  border-color: #4099ff;
  border-style: solid;
  border-width: 1px;
  box-sizing: border-box;
  display: inline-block;
  height: 10px;
  position: absolute;
  width: 10px;
}

.tox.tox-platform-touch .tox-selector {
  height: 12px;
  width: 12px;
}

.tox .tox-slider {
  align-items: center;
  display: flex;
  flex: 1;
  -ms-flex-preferred-size: auto;
  height: 24px;
  justify-content: center;
  position: relative;
}

.tox .tox-slider__rail {
  background-color: transparent;
  border: 1px solid #cccccc;
  border-radius: 3px;
  height: 10px;
  min-width: 120px;
  width: 100%;
}

.tox .tox-slider__handle {
  background-color: #207ab7;
  border: 2px solid #185d8c;
  border-radius: 3px;
  box-shadow: none;
  height: 24px;
  left: 50%;
  position: absolute;
  top: 50%;
  transform: translateX(-50%) translateY(-50%);
  width: 14px;
}

.tox .tox-source-code {
  overflow: auto;
}

.tox .tox-spinner {
  display: flex;
}

.tox .tox-spinner > div {
  animation: tam-bouncing-dots 1.5s ease-in-out 0s infinite both;
  background-color: rgba(34, 47, 62, 0.7);
  border-radius: 100%;
  height: 8px;
  width: 8px;
}

.tox .tox-spinner > div:nth-child(1) {
  animation-delay: -0.32s;
}

.tox .tox-spinner > div:nth-child(2) {
  animation-delay: -0.16s;
}

@keyframes tam-bouncing-dots {
  0%, 80%, 100% {
    transform: scale(0);
  }

  40% {
    transform: scale(1);
  }
}

.tox:not([dir=rtl]) .tox-spinner > div:not(:first-child) {
  margin-left: 4px;
}

.tox[dir=rtl] .tox-spinner > div:not(:first-child) {
  margin-right: 4px;
}

.tox .tox-statusbar {
  align-items: center;
  background-color: #fff;
  border-top: 1px solid #cccccc;
  color: rgba(34, 47, 62, 0.7);
  display: flex;
  flex: 0 0 auto;
  font-size: 12px;
  font-weight: normal;
  height: 18px;
  overflow: hidden;
  padding: 0 8px;
  position: relative;
  text-transform: uppercase;
}

.tox .tox-statusbar__text-container {
  display: flex;
  flex: 1 1 auto;
  justify-content: flex-end;
  overflow: hidden;
}

.tox .tox-statusbar__path {
  display: flex;
  flex: 1 1 auto;
  margin-right: auto;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}

.tox .tox-statusbar__path > * {
  display: inline;
  white-space: nowrap;
}

.tox .tox-statusbar__wordcount {
  flex: 0 0 auto;
  margin-left: 1ch;
}

.tox .tox-statusbar a,
.tox .tox-statusbar__path-item,
.tox .tox-statusbar__wordcount {
  color: rgba(34, 47, 62, 0.7);
  text-decoration: none;
}

.tox .tox-statusbar a:hover:not(:disabled):not([aria-disabled=true]),
.tox .tox-statusbar__path-item:hover:not(:disabled):not([aria-disabled=true]),
.tox .tox-statusbar__wordcount:hover:not(:disabled):not([aria-disabled=true]),
.tox .tox-statusbar a:focus:not(:disabled):not([aria-disabled=true]),
.tox .tox-statusbar__path-item:focus:not(:disabled):not([aria-disabled=true]),
.tox .tox-statusbar__wordcount:focus:not(:disabled):not([aria-disabled=true]) {
  cursor: pointer;
  text-decoration: underline;
}

.tox .tox-statusbar__resize-handle {
  align-items: flex-end;
  align-self: stretch;
  cursor: nwse-resize;
  display: flex;
  flex: 0 0 auto;
  justify-content: flex-end;
  margin-left: auto;
  margin-right: -8px;
  padding-left: 1ch;
}

.tox .tox-statusbar__resize-handle svg {
  display: block;
  fill: rgba(34, 47, 62, 0.7);
}

.tox .tox-statusbar__resize-handle:focus svg {
  background-color: #dee0e2;
  border-radius: 1px;
  box-shadow: 0 0 0 2px #dee0e2;
}

.tox:not([dir=rtl]) .tox-statusbar__path > * {
  margin-right: 4px;
}

.tox:not([dir=rtl]) .tox-statusbar__branding {
  margin-left: 1ch;
}

.tox[dir=rtl] .tox-statusbar {
  flex-direction: row-reverse;
}

.tox[dir=rtl] .tox-statusbar__path > * {
  margin-left: 4px;
}

.tox .tox-throbber {
  z-index: 1299;
}

.tox .tox-throbber__busy-spinner {
  align-items: center;
  background-color: rgba(255, 255, 255, 0.6);
  bottom: 0;
  display: flex;
  justify-content: center;
  left: 0;
  position: absolute;
  right: 0;
  top: 0;
}

.tox .tox-tbtn {
  align-items: center;
  background: transparent;
  border: 0;
  border-radius: 3px;
  box-shadow: none;
  color: #222f3e;
  display: flex;
  flex: 0 0 auto;
  font-size: 14px;
  font-style: normal;
  font-weight: normal;
  height: 34px;
  justify-content: center;
  margin: 2px 0 3px 0;
  outline: none;
  overflow: hidden;
  padding: 0;
  text-transform: none;
  width: 34px;
}

.tox .tox-tbtn svg {
  display: block;
  fill: #222f3e;
}

.tox .tox-tbtn.tox-tbtn-more {
  padding-left: 5px;
  padding-right: 5px;
  width: inherit;
}

.tox .tox-tbtn:focus {
  background: #dee0e2;
  border: 0;
  box-shadow: none;
}

.tox .tox-tbtn:hover {
  background: #dee0e2;
  border: 0;
  box-shadow: none;
  color: #222f3e;
}

.tox .tox-tbtn:hover svg {
  fill: #222f3e;
}

.tox .tox-tbtn:active {
  background: #c8cbcf;
  border: 0;
  box-shadow: none;
  color: #222f3e;
}

.tox .tox-tbtn:active svg {
  fill: #222f3e;
}

.tox .tox-tbtn--disabled,
.tox .tox-tbtn--disabled:hover,
.tox .tox-tbtn:disabled,
.tox .tox-tbtn:disabled:hover {
  background: transparent;
  border: 0;
  box-shadow: none;
  color: rgba(34, 47, 62, 0.5);
  cursor: not-allowed;
}

.tox .tox-tbtn--disabled svg,
.tox .tox-tbtn--disabled:hover svg,
.tox .tox-tbtn:disabled svg,
.tox .tox-tbtn:disabled:hover svg {
  /* stylelint-disable-line no-descending-specificity */
  fill: rgba(34, 47, 62, 0.5);
}

.tox .tox-tbtn--enabled,
.tox .tox-tbtn--enabled:hover {
  background: #c8cbcf;
  border: 0;
  box-shadow: none;
  color: #222f3e;
}

.tox .tox-tbtn--enabled > *,
.tox .tox-tbtn--enabled:hover > * {
  transform: none;
}

.tox .tox-tbtn--enabled svg,
.tox .tox-tbtn--enabled:hover svg {
  /* stylelint-disable-line no-descending-specificity */
  fill: #222f3e;
}

.tox .tox-tbtn:focus:not(.tox-tbtn--disabled) {
  color: #222f3e;
}

.tox .tox-tbtn:focus:not(.tox-tbtn--disabled) svg {
  fill: #222f3e;
}

.tox .tox-tbtn:active > * {
  transform: none;
}

.tox .tox-tbtn--md {
  height: 51px;
  width: 51px;
}

.tox .tox-tbtn--lg {
  flex-direction: column;
  height: 68px;
  width: 68px;
}

.tox .tox-tbtn--return {
  -ms-grid-row-align: stretch;
  align-self: stretch;
  height: unset;
  width: 16px;
}

.tox .tox-tbtn--labeled {
  padding: 0 4px;
  width: unset;
}

.tox .tox-tbtn__vlabel {
  display: block;
  font-size: 10px;
  font-weight: normal;
  letter-spacing: -0.025em;
  margin-bottom: 4px;
  white-space: nowrap;
}

.tox .tox-tbtn--select {
  margin: 2px 0 3px 0;
  padding: 0 4px;
  width: auto;
}

.tox .tox-tbtn__select-label {
  cursor: default;
  font-weight: normal;
  margin: 0 4px;
}

.tox .tox-tbtn__select-chevron {
  align-items: center;
  display: flex;
  justify-content: center;
  width: 16px;
}

.tox .tox-tbtn__select-chevron svg {
  fill: rgba(34, 47, 62, 0.5);
}

.tox .tox-tbtn--bespoke .tox-tbtn__select-label {
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  width: 7em;
}

.tox .tox-split-button {
  border: 0;
  border-radius: 3px;
  box-sizing: border-box;
  display: flex;
  margin: 2px 0 3px 0;
  overflow: hidden;
}

.tox .tox-split-button:hover {
  box-shadow: 0 0 0 1px #dee0e2 inset;
}

.tox .tox-split-button:focus {
  background: #dee0e2;
  box-shadow: none;
  color: #222f3e;
}

.tox .tox-split-button > * {
  border-radius: 0;
}

.tox .tox-split-button__chevron {
  width: 16px;
}

.tox .tox-split-button__chevron svg {
  fill: rgba(34, 47, 62, 0.5);
}

.tox .tox-split-button .tox-tbtn {
  margin: 0;
}

.tox.tox-platform-touch .tox-split-button .tox-tbtn:first-child {
  width: 30px;
}

.tox.tox-platform-touch .tox-split-button__chevron {
  width: 20px;
}

.tox .tox-split-button.tox-tbtn--disabled:hover,
.tox .tox-split-button.tox-tbtn--disabled:focus,
.tox .tox-split-button.tox-tbtn--disabled .tox-tbtn:hover,
.tox .tox-split-button.tox-tbtn--disabled .tox-tbtn:focus {
  background: transparent;
  box-shadow: none;
  color: rgba(34, 47, 62, 0.5);
}

.tox .tox-toolbar-overlord {
  background-color: #fff;
}

.tox .tox-toolbar,
.tox .tox-toolbar__primary,
.tox .tox-toolbar__overflow {
  background: url("data:image/svg+xml;charset=utf8,%3Csvg height='39px' viewBox='0 0 40 39px' width='40' xmlns='http://www.w3.org/2000/svg'%3E%3Crect x='0' y='38px' width='100' height='1' fill='%23cccccc'/%3E%3C/svg%3E") left 0 top 0 #fff;
  background-color: #fff;
  display: flex;
  flex: 0 0 auto;
  flex-shrink: 0;
  flex-wrap: wrap;
  padding: 0 0;
}

.tox .tox-toolbar__overflow.tox-toolbar__overflow--closed {
  height: 0;
  opacity: 0;
  padding-bottom: 0;
  padding-top: 0;
  visibility: hidden;
}

.tox .tox-toolbar__overflow--growing {
  transition: height 0.3s ease, opacity 0.2s linear 0.1s;
}

.tox .tox-toolbar__overflow--shrinking {
  transition: opacity 0.3s ease, height 0.2s linear 0.1s, visibility 0s linear 0.3s;
}

.tox .tox-menubar + .tox-toolbar,
.tox .tox-menubar + .tox-toolbar-overlord .tox-toolbar__primary {
  border-top: 1px solid #cccccc;
  margin-top: -1px;
}

.tox .tox-toolbar--scrolling {
  flex-wrap: nowrap;
  overflow-x: auto;
}

.tox .tox-pop .tox-toolbar {
  border-width: 0;
}

.tox .tox-toolbar--no-divider {
  background-image: none;
}

.tox-tinymce:not(.tox-tinymce-inline) .tox-editor-header:not(:first-child) .tox-toolbar:first-child,
.tox-tinymce:not(.tox-tinymce-inline) .tox-editor-header:not(:first-child) .tox-toolbar-overlord:first-child .tox-toolbar__primary {
  border-top: 1px solid #cccccc;
}

.tox.tox-tinymce-aux .tox-toolbar__overflow {
  background-color: #fff;
  border: 1px solid #cccccc;
  border-radius: 3px;
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.15);
}

.tox .tox-toolbar__group {
  align-items: center;
  display: flex;
  flex-wrap: wrap;
  margin: 0 0;
  padding: 0 4px 0 4px;
}

.tox .tox-toolbar__group--pull-right {
  margin-left: auto;
}

.tox .tox-toolbar--scrolling .tox-toolbar__group {
  flex-shrink: 0;
  flex-wrap: nowrap;
}

.tox:not([dir=rtl]) .tox-toolbar__group:not(:last-of-type) {
  border-right: 1px solid #cccccc;
}

.tox[dir=rtl] .tox-toolbar__group:not(:last-of-type) {
  border-left: 1px solid #cccccc;
}

.tox .tox-tooltip {
  display: inline-block;
  padding: 8px;
  position: relative;
}

.tox .tox-tooltip__body {
  background-color: #222f3e;
  border-radius: 3px;
  box-shadow: 0 2px 4px rgba(34, 47, 62, 0.3);
  color: rgba(255, 255, 255, 0.75);
  font-size: 14px;
  font-style: normal;
  font-weight: normal;
  padding: 4px 8px;
  text-transform: none;
}

.tox .tox-tooltip__arrow {
  position: absolute;
}

.tox .tox-tooltip--down .tox-tooltip__arrow {
  border-left: 8px solid transparent;
  border-right: 8px solid transparent;
  border-top: 8px solid #222f3e;
  bottom: 0;
  left: 50%;
  position: absolute;
  transform: translateX(-50%);
}

.tox .tox-tooltip--up .tox-tooltip__arrow {
  border-bottom: 8px solid #222f3e;
  border-left: 8px solid transparent;
  border-right: 8px solid transparent;
  left: 50%;
  position: absolute;
  top: 0;
  transform: translateX(-50%);
}

.tox .tox-tooltip--right .tox-tooltip__arrow {
  border-bottom: 8px solid transparent;
  border-left: 8px solid #222f3e;
  border-top: 8px solid transparent;
  position: absolute;
  right: 0;
  top: 50%;
  transform: translateY(-50%);
}

.tox .tox-tooltip--left .tox-tooltip__arrow {
  border-bottom: 8px solid transparent;
  border-right: 8px solid #222f3e;
  border-top: 8px solid transparent;
  left: 0;
  position: absolute;
  top: 50%;
  transform: translateY(-50%);
}

.tox .tox-well {
  border: 1px solid #cccccc;
  border-radius: 3px;
  padding: 8px;
  width: 100%;
}

.tox .tox-well > *:first-child {
  margin-top: 0;
}

.tox .tox-well > *:last-child {
  margin-bottom: 0;
}

.tox .tox-well > *:only-child {
  margin: 0;
}

.tox .tox-custom-editor {
  border: 1px solid #cccccc;
  border-radius: 3px;
  display: flex;
  flex: 1;
  position: relative;
}

/* stylelint-disable */

.tox {
  /* stylelint-enable */
}

.tox .tox-dialog-loading::before {
  background-color: rgba(0, 0, 0, 0.5);
  content: "";
  height: 100%;
  position: absolute;
  width: 100%;
  z-index: 1000;
}

.tox .tox-tab {
  cursor: pointer;
}

.tox .tox-dialog__content-js {
  display: flex;
  flex: 1;
  -ms-flex-preferred-size: auto;
}

.tox .tox-dialog__body-content .tox-collection {
  display: flex;
  flex: 1;
  -ms-flex-preferred-size: auto;
}

.tox .tox-image-tools-edit-panel {
  height: 60px;
}

.tox .tox-image-tools__sidebar {
  height: 60px;
}

/*!
 * froala_editor v3.1.0 (https://www.froala.com/wysiwyg-editor)
 * License https://froala.com/wysiwyg-editor/terms/
 * Copyright 2014-2020 Froala Labs
 */

.amis-scope .clearfix::after {
  clear: both;
  display: block;
  content: "";
  height: 0;
}

.amis-scope .hide-by-clipping {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0;
}

.amis-scope img.fr-rounded,
.fr-img-caption.fr-rounded img {
  border-radius: 10px;
  -moz-border-radius: 10px;
  -webkit-border-radius: 10px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}

.amis-scope img.fr-bordered,
.fr-img-caption.fr-bordered img {
  border: solid 5px #CCC;
}

.amis-scope img.fr-bordered {
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  box-sizing: content-box;
}

.fr-img-caption.fr-bordered img {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}

.fr-view {
  word-wrap: break-word;
}

.fr-view span[style~="color:"] a {
  color: inherit;
}

.fr-view strong {
  font-weight: 700;
}

.fr-view table {
  border: none;
  border-collapse: collapse;
  empty-cells: show;
  max-width: 100%;
}

.fr-view table td {
  min-width: 5px;
}

.fr-view table.fr-dashed-borders td,
.fr-view table.fr-dashed-borders th {
  border-style: dashed;
}

.fr-view table.fr-alternate-rows tbody tr:nth-child(2n) {
  background: whitesmoke;
}

.fr-view table td,
.fr-view table th {
  border: 1px solid #DDD;
}

.fr-view table td:empty,
.fr-view table th:empty {
  height: 20px;
}

.fr-view table td.fr-highlighted,
.fr-view table th.fr-highlighted {
  border: 1px double red;
}

.fr-view table td.fr-thick,
.fr-view table th.fr-thick {
  border-width: 2px;
}

.fr-view table th {
  background: #ececec;
}

.fr-view hr {
  clear: both;
  user-select: none;
  -o-user-select: none;
  -moz-user-select: none;
  -khtml-user-select: none;
  -webkit-user-select: none;
  -ms-user-select: none;
  break-after: always;
  page-break-after: always;
}

.fr-view .fr-file {
  position: relative;
}

.fr-view .fr-file::after {
  position: relative;
  content: "\1F4CE";
  font-weight: normal;
}

.fr-view pre {
  white-space: pre-wrap;
  word-wrap: break-word;
  overflow: visible;
}

.fr-view[dir="rtl"] blockquote {
  border-left: none;
  border-right: solid 2px #5E35B1;
  margin-right: 0;
  padding-right: 5px;
  padding-left: 0;
}

.fr-view[dir="rtl"] blockquote blockquote {
  border-color: #00BCD4;
}

.fr-view[dir="rtl"] blockquote blockquote blockquote {
  border-color: #43A047;
}

.fr-view blockquote {
  border-left: solid 2px #5E35B1;
  margin-left: 0;
  padding-left: 5px;
  color: #5E35B1;
}

.fr-view blockquote blockquote {
  border-color: #00BCD4;
  color: #00BCD4;
}

.fr-view blockquote blockquote blockquote {
  border-color: #43A047;
  color: #43A047;
}

.fr-view span.fr-emoticon {
  font-weight: normal;
  font-family: "Apple Color Emoji","Segoe UI Emoji","NotoColorEmoji","Segoe UI Symbol","Android Emoji","EmojiSymbols";
  display: inline;
  line-height: 0;
}

.fr-view span.fr-emoticon.fr-emoticon-img {
  background-repeat: no-repeat !important;
  font-size: inherit;
  height: 1em;
  width: 1em;
  min-height: 20px;
  min-width: 20px;
  display: inline-block;
  margin: -.1em .1em .1em;
  line-height: 1;
  vertical-align: middle;
}

.fr-view .fr-text-gray {
  color: #AAA !important;
}

.fr-view .fr-text-bordered {
  border-top: solid 1px #222;
  border-bottom: solid 1px #222;
  padding: 10px 0;
}

.fr-view .fr-text-spaced {
  letter-spacing: 1px;
}

.fr-view .fr-text-uppercase {
  text-transform: uppercase;
}

.fr-view .fr-class-highlighted {
  background-color: #ffff00;
}

.fr-view .fr-class-code {
  border-color: #cccccc;
  border-radius: 2px;
  -moz-border-radius: 2px;
  -webkit-border-radius: 2px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  background: #f5f5f5;
  padding: 10px;
  font-family: "Courier New", Courier, monospace;
}

.fr-view .fr-class-transparency {
  opacity: 0.5;
}

.fr-view img {
  position: relative;
  max-width: 100%;
}

.fr-view img.fr-dib {
  margin: 5px auto;
  display: block;
  float: none;
  vertical-align: top;
}

.fr-view img.fr-dib.fr-fil {
  margin-left: 0;
  text-align: left;
}

.fr-view img.fr-dib.fr-fir {
  margin-right: 0;
  text-align: right;
}

.fr-view img.fr-dii {
  display: inline-block;
  float: none;
  vertical-align: bottom;
  margin-left: 5px;
  margin-right: 5px;
  max-width: calc(100% - (2 * 5px));
}

.fr-view img.fr-dii.fr-fil {
  float: left;
  margin: 5px 5px 5px 0;
  max-width: calc(100% - 5px);
}

.fr-view img.fr-dii.fr-fir {
  float: right;
  margin: 5px 0 5px 5px;
  max-width: calc(100% - 5px);
}

.fr-view span.fr-img-caption {
  position: relative;
  max-width: 100%;
}

.fr-view span.fr-img-caption.fr-dib {
  margin: 5px auto;
  display: block;
  float: none;
  vertical-align: top;
}

.fr-view span.fr-img-caption.fr-dib.fr-fil {
  margin-left: 0;
  text-align: left;
}

.fr-view span.fr-img-caption.fr-dib.fr-fir {
  margin-right: 0;
  text-align: right;
}

.fr-view span.fr-img-caption.fr-dii {
  display: inline-block;
  float: none;
  vertical-align: bottom;
  margin-left: 5px;
  margin-right: 5px;
  max-width: calc(100% - (2 * 5px));
}

.fr-view span.fr-img-caption.fr-dii.fr-fil {
  float: left;
  margin: 5px 5px 5px 0;
  max-width: calc(100% - 5px);
}

.fr-view span.fr-img-caption.fr-dii.fr-fir {
  float: right;
  margin: 5px 0 5px 5px;
  max-width: calc(100% - 5px);
}

.fr-view .fr-video {
  text-align: center;
  position: relative;
}

.fr-view .fr-video.fr-rv {
  padding-bottom: 56.25%;
  padding-top: 30px;
  height: 0;
  overflow: hidden;
}

.fr-view .fr-video.fr-rv>iframe,
.fr-view .fr-video.fr-rv object,
.fr-view .fr-video.fr-rv embed {
  position: absolute !important;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
}

.fr-view .fr-video>* {
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  box-sizing: content-box;
  max-width: 100%;
  border: none;
}

.fr-view .fr-video.fr-dvb {
  display: block;
  clear: both;
}

.fr-view .fr-video.fr-dvb.fr-fvl {
  text-align: left;
}

.fr-view .fr-video.fr-dvb.fr-fvr {
  text-align: right;
}

.fr-view .fr-video.fr-dvi {
  display: inline-block;
}

.fr-view .fr-video.fr-dvi.fr-fvl {
  float: left;
}

.fr-view .fr-video.fr-dvi.fr-fvr {
  float: right;
}

.fr-view a.fr-strong {
  font-weight: 700;
}

.fr-view a.fr-green {
  color: green;
}

.fr-view .fr-img-caption {
  text-align: center;
}

.fr-view .fr-img-caption .fr-img-wrap {
  padding: 0;
  margin: auto;
  text-align: center;
  width: 100%;
}

.fr-view .fr-img-caption .fr-img-wrap img {
  display: block;
  margin: auto;
  width: 100%;
}

.fr-view .fr-img-caption .fr-img-wrap>span {
  margin: auto;
  display: block;
  padding: 5px 5px 10px;
  font-size: 14px;
  font-weight: initial;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-opacity: 0.9;
  -moz-opacity: 0.9;
  opacity: 0.9;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
  width: 100%;
  text-align: center;
}

.fr-view button.fr-rounded,
.fr-view input.fr-rounded,
.fr-view textarea.fr-rounded {
  border-radius: 10px;
  -moz-border-radius: 10px;
  -webkit-border-radius: 10px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}

.fr-view button.fr-large,
.fr-view input.fr-large,
.fr-view textarea.fr-large {
  font-size: 24px;
}

.amis-scope a.fr-view.fr-strong {
  font-weight: 700;
}

.amis-scope a.fr-view.fr-green {
  color: green;
}

.amis-scope img.fr-view {
  position: relative;
  max-width: 100%;
}

.amis-scope img.fr-view.fr-dib {
  margin: 5px auto;
  display: block;
  float: none;
  vertical-align: top;
}

.amis-scope img.fr-view.fr-dib.fr-fil {
  margin-left: 0;
  text-align: left;
}

.amis-scope img.fr-view.fr-dib.fr-fir {
  margin-right: 0;
  text-align: right;
}

.amis-scope img.fr-view.fr-dii {
  display: inline-block;
  float: none;
  vertical-align: bottom;
  margin-left: 5px;
  margin-right: 5px;
  max-width: calc(100% - (2 * 5px));
}

.amis-scope img.fr-view.fr-dii.fr-fil {
  float: left;
  margin: 5px 5px 5px 0;
  max-width: calc(100% - 5px);
}

.amis-scope img.fr-view.fr-dii.fr-fir {
  float: right;
  margin: 5px 0 5px 5px;
  max-width: calc(100% - 5px);
}

.amis-scope span.fr-img-caption.fr-view {
  position: relative;
  max-width: 100%;
}

.amis-scope span.fr-img-caption.fr-view.fr-dib {
  margin: 5px auto;
  display: block;
  float: none;
  vertical-align: top;
}

.amis-scope span.fr-img-caption.fr-view.fr-dib.fr-fil {
  margin-left: 0;
  text-align: left;
}

.amis-scope span.fr-img-caption.fr-view.fr-dib.fr-fir {
  margin-right: 0;
  text-align: right;
}

.amis-scope span.fr-img-caption.fr-view.fr-dii {
  display: inline-block;
  float: none;
  vertical-align: bottom;
  margin-left: 5px;
  margin-right: 5px;
  max-width: calc(100% - (2 * 5px));
}

.amis-scope span.fr-img-caption.fr-view.fr-dii.fr-fil {
  float: left;
  margin: 5px 5px 5px 0;
  max-width: calc(100% - 5px);
}

.amis-scope span.fr-img-caption.fr-view.fr-dii.fr-fir {
  float: right;
  margin: 5px 0 5px 5px;
  max-width: calc(100% - 5px);
}

/*!
 * froala_editor v3.1.0 (https://www.froala.com/wysiwyg-editor)
 * License https://froala.com/wysiwyg-editor/terms/
 * Copyright 2014-2020 Froala Labs
 */

.amis-scope .clearfix::after {
  clear: both;
  display: block;
  content: "";
  height: 0;
}

.amis-scope .hide-by-clipping {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0;
}

.fr-element,
.fr-element:focus {
  outline: 0 solid transparent;
}

.fr-box.fr-basic {
  border-radius: 10px;
  -moz-border-radius: 10px;
  -webkit-border-radius: 10px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}

.fr-box.fr-basic .fr-element {
  font-family: sans-serif;
  color: #414141;
  font-size: 14px;
  line-height: 1.6;
  padding: 20px;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  overflow-x: auto;
  min-height: 60px;
  text-align: left;
}

.fr-box.fr-basic.fr-rtl .fr-element {
  text-align: right;
}

.fr-element {
  background: transparent;
  position: relative;
  z-index: 2;
  -webkit-user-select: auto;
}

.fr-element a {
  user-select: auto;
  -o-user-select: auto;
  -moz-user-select: auto;
  -khtml-user-select: auto;
  -webkit-user-select: auto;
  -ms-user-select: auto;
}

.fr-element.fr-disabled {
  user-select: none;
  -o-user-select: none;
  -moz-user-select: none;
  -khtml-user-select: none;
  -webkit-user-select: none;
  -ms-user-select: none;
}

.fr-element [contenteditable="true"] {
  outline: 0 solid transparent;
}

.fr-box a.fr-floating-btn {
  -webkit-box-shadow: 0 3px 1px -2px rgba(0,0,0,0.2),0 2px 2px 0 rgba(0,0,0,0.14),0 1px 5px 0 rgba(0,0,0,0.12);
  -moz-box-shadow: 0 3px 1px -2px rgba(0,0,0,0.2),0 2px 2px 0 rgba(0,0,0,0.14),0 1px 5px 0 rgba(0,0,0,0.12);
  box-shadow: 0 3px 1px -2px rgba(0,0,0,0.2),0 2px 2px 0 rgba(0,0,0,0.14),0 1px 5px 0 rgba(0,0,0,0.12);
  border-radius: 100%;
  -moz-border-radius: 100%;
  -webkit-border-radius: 100%;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  height: 40px;
  width: 40px;
  text-align: center;
  background: #FFF;
  color: #333333;
  -webkit-transition: background 0.2s ease 0s, color 0.2s ease 0s, transform 0.2s ease 0s;
  -moz-transition: background 0.2s ease 0s, color 0.2s ease 0s, transform 0.2s ease 0s;
  -ms-transition: background 0.2s ease 0s, color 0.2s ease 0s, transform 0.2s ease 0s;
  -o-transition: background 0.2s ease 0s, color 0.2s ease 0s, transform 0.2s ease 0s;
  outline: none;
  left: 0;
  top: 0;
  line-height: 40px;
  -webkit-transform: scale(0);
  -moz-transform: scale(0);
  -ms-transform: scale(0);
  -o-transform: scale(0);
  text-align: center;
  display: block;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  border: none;
}

.fr-box a.fr-floating-btn svg {
  -webkit-transition: transform 0.2s ease 0s;
  -moz-transition: transform 0.2s ease 0s;
  -ms-transition: transform 0.2s ease 0s;
  -o-transition: transform 0.2s ease 0s;
  fill: #333333;
}

.fr-box a.fr-floating-btn i,
.fr-box a.fr-floating-btn svg {
  font-size: 14px;
  line-height: 40px;
}

.fr-box a.fr-floating-btn.fr-btn+.fr-btn {
  margin-left: 10px;
}

.fr-box a.fr-floating-btn:hover {
  background: #ebebeb;
  cursor: pointer;
}

.fr-box a.fr-floating-btn:hover svg {
  fill: #333333;
}

.fr-box .fr-visible a.fr-floating-btn {
  -webkit-transform: scale(1);
  -moz-transform: scale(1);
  -ms-transform: scale(1);
  -o-transform: scale(1);
}

.amis-scope iframe.fr-iframe {
  width: 100%;
  border: none;
  position: relative;
  display: block;
  z-index: 2;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}

.fr-wrapper {
  position: relative;
  z-index: 1;
}

.fr-wrapper::after {
  clear: both;
  display: block;
  content: "";
  height: 0;
}

.fr-wrapper .fr-placeholder {
  position: absolute;
  font-size: 14px;
  color: #AAA;
  font-family: sans-serif;
  z-index: 1;
  display: none;
  top: 0;
  left: 0;
  right: 0;
  overflow: hidden;
}

.fr-wrapper.show-placeholder .fr-placeholder {
  display: block;
  white-space: nowrap;
  text-overflow: ellipsis;
}

.fr-wrapper ::-moz-selection {
  background: #b5d6fd;
  color: #000;
}

.fr-wrapper ::selection {
  background: #b5d6fd;
  color: #000;
}

.fr-box.fr-basic .fr-wrapper {
  background: #FFF;
  border: 1px solid #CCCCCC;
  border-bottom-color: #efefef;
  top: 0;
  left: 0;
}

.fr-box.fr-basic.fr-top .fr-wrapper {
  border-top: 0;
}

.fr-box.fr-basic.fr-bottom .fr-wrapper {
  border-bottom: 0;
  border-radius: 10px 10px 0 0;
  -moz-border-radius: 10px 10px 0 0;
  -webkit-border-radius: 10px 10px 0 0;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}

@media (min-width: 992px) {
  .fr-box.fr-document {
    min-width: 21cm;
  }

  .fr-box.fr-document .fr-wrapper {
    text-align: left;
    padding: 30px;
    min-width: 21cm;
    background: #efefef;
  }

  .fr-box.fr-document .fr-wrapper .fr-element {
    text-align: left;
    background: #FFF;
    width: 21cm;
    margin: auto;
    min-height: 26cm !important;
    padding: 1cm 2cm;
    overflow: visible;
    z-index: auto;
  }

  .fr-box.fr-document .fr-wrapper .fr-element hr {
    margin-left: -2cm;
    margin-right: -2cm;
    background: #efefef;
    height: 1cm;
    outline: none;
    border: none;
  }

  .fr-box.fr-document .fr-wrapper .fr-element img {
    z-index: 1;
  }
}

.fr-tooltip {
  position: absolute;
  top: 0;
  left: 0;
  padding: 0 8px;
  border-radius: 2px;
  -moz-border-radius: 2px;
  -webkit-border-radius: 2px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  background: #222222;
  color: #FFF;
  font-size: 11px;
  line-height: 22px;
  font-family: Arial, Helvetica, sans-serif;
  -webkit-transition: opacity 0.2s ease 0s;
  -moz-transition: opacity 0.2s ease 0s;
  -ms-transition: opacity 0.2s ease 0s;
  -o-transition: opacity 0.2s ease 0s;
  -webkit-opacity: 0;
  -moz-opacity: 0;
  opacity: 0;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
  left: -3000px;
  user-select: none;
  -o-user-select: none;
  -moz-user-select: none;
  -khtml-user-select: none;
  -webkit-user-select: none;
  -ms-user-select: none;
  z-index: 2147483647;
  text-rendering: optimizelegibility;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}

.fr-tooltip.fr-visible {
  -webkit-opacity: 1;
  -moz-opacity: 1;
  opacity: 1;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
}

.fr-toolbar .fr-btn-wrap,
.fr-popup .fr-btn-wrap,
.fr-modal .fr-btn-wrap {
  float: left;
  white-space: nowrap;
  position: relative;
}

.fr-toolbar .fr-btn-wrap.fr-hidden,
.fr-popup .fr-btn-wrap.fr-hidden,
.fr-modal .fr-btn-wrap.fr-hidden {
  display: none;
}

.fr-toolbar .fr-command.fr-btn,
.fr-popup .fr-command.fr-btn,
.fr-modal .fr-command.fr-btn {
  background: transparent;
  color: #333333;
  -moz-outline: 0;
  outline: none;
  border: 0;
  line-height: 1;
  cursor: pointer;
  text-align: left;
  margin: 4px 2px;
  padding: 0;
  -webkit-transition: all 0.5s;
  -moz-transition: all 0.5s;
  -ms-transition: all 0.5s;
  -o-transition: all 0.5s;
  border-radius: 4px;
  -moz-border-radius: 4px;
  -webkit-border-radius: 4px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  z-index: 2;
  position: relative;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  text-decoration: none;
  user-select: none;
  -o-user-select: none;
  -moz-user-select: none;
  -khtml-user-select: none;
  -webkit-user-select: none;
  -ms-user-select: none;
  float: left;
  height: 40px;
}

.fr-toolbar .fr-command.fr-btn.fr-dropdown.fr-options,
.fr-popup .fr-command.fr-btn.fr-dropdown.fr-options,
.fr-modal .fr-command.fr-btn.fr-dropdown.fr-options {
  border-radius: 0 4px 4px 0;
  -moz-border-radius: 0 4px 4px 0;
  -webkit-border-radius: 0 4px 4px 0;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}

.fr-toolbar .fr-command.fr-btn.fr-btn-hover,
.fr-popup .fr-command.fr-btn.fr-btn-hover,
.fr-modal .fr-command.fr-btn.fr-btn-hover {
  border-radius: 4px 0 0 4px;
  -moz-border-radius: 4px 0 0 4px;
  -webkit-border-radius: 4px 0 0 4px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}

.fr-toolbar .fr-command.fr-btn::-moz-focus-inner,
.fr-popup .fr-command.fr-btn::-moz-focus-inner,
.fr-modal .fr-command.fr-btn::-moz-focus-inner {
  border: 0;
  padding: 0;
}

.fr-toolbar .fr-command.fr-btn.fr-btn-text,
.fr-popup .fr-command.fr-btn.fr-btn-text,
.fr-modal .fr-command.fr-btn.fr-btn-text {
  width: auto;
}

.fr-toolbar .fr-command.fr-btn i,
.fr-toolbar .fr-command.fr-btn svg,
.fr-popup .fr-command.fr-btn i,
.fr-popup .fr-command.fr-btn svg,
.fr-modal .fr-command.fr-btn i,
.fr-modal .fr-command.fr-btn svg {
  display: block;
  text-align: center;
  float: none;
  margin: 8px 7px;
  width: 24px;
}

.fr-toolbar .fr-command.fr-btn svg.fr-svg,
.fr-popup .fr-command.fr-btn svg.fr-svg,
.fr-modal .fr-command.fr-btn svg.fr-svg {
  height: 24px;
}

.fr-toolbar .fr-command.fr-btn svg path,
.fr-popup .fr-command.fr-btn svg path,
.fr-modal .fr-command.fr-btn svg path {
  -webkit-transition: all 0.5s;
  -moz-transition: all 0.5s;
  -ms-transition: all 0.5s;
  -o-transition: all 0.5s;
  fill: #333333;
}

.fr-toolbar .fr-command.fr-btn span.fr-sr-only,
.fr-popup .fr-command.fr-btn span.fr-sr-only,
.fr-modal .fr-command.fr-btn span.fr-sr-only {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0;
}

.fr-toolbar .fr-command.fr-btn span,
.fr-popup .fr-command.fr-btn span,
.fr-modal .fr-command.fr-btn span {
  font-size: 14px;
  display: block;
  line-height: 17px;
  min-width: 30px;
  float: left;
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap;
  height: 17px;
  font-weight: bold;
  padding: 0 4px;
}

.fr-toolbar .fr-command.fr-btn img,
.fr-popup .fr-command.fr-btn img,
.fr-modal .fr-command.fr-btn img {
  margin: 8px 7px;
  width: 24px;
}

.fr-toolbar .fr-command.fr-btn.fr-btn-active-popup,
.fr-popup .fr-command.fr-btn.fr-btn-active-popup,
.fr-modal .fr-command.fr-btn.fr-btn-active-popup {
  background: #d6d6d6;
}

.fr-toolbar .fr-command.fr-btn.fr-dropdown.fr-selection span,
.fr-popup .fr-command.fr-btn.fr-dropdown.fr-selection span,
.fr-modal .fr-command.fr-btn.fr-dropdown.fr-selection span {
  font-weight: normal;
}

.fr-toolbar .fr-command.fr-btn.fr-dropdown i,
.fr-toolbar .fr-command.fr-btn.fr-dropdown span,
.fr-toolbar .fr-command.fr-btn.fr-dropdown img,
.fr-toolbar .fr-command.fr-btn.fr-dropdown svg,
.fr-popup .fr-command.fr-btn.fr-dropdown i,
.fr-popup .fr-command.fr-btn.fr-dropdown span,
.fr-popup .fr-command.fr-btn.fr-dropdown img,
.fr-popup .fr-command.fr-btn.fr-dropdown svg,
.fr-modal .fr-command.fr-btn.fr-dropdown i,
.fr-modal .fr-command.fr-btn.fr-dropdown span,
.fr-modal .fr-command.fr-btn.fr-dropdown img,
.fr-modal .fr-command.fr-btn.fr-dropdown svg {
  margin-left: 3px;
  margin-right: 11px;
}

.fr-toolbar .fr-command.fr-btn.fr-dropdown:after,
.fr-popup .fr-command.fr-btn.fr-dropdown:after,
.fr-modal .fr-command.fr-btn.fr-dropdown:after {
  position: absolute;
  width: 0;
  height: 0;
  border-left: 4px solid transparent;
  border-right: 4px solid transparent;
  border-top: 4px solid #333333;
  right: 2px;
  top: 18px;
  -webkit-transition: all 0.3s;
  -moz-transition: all 0.3s;
  -ms-transition: all 0.3s;
  -o-transition: all 0.3s;
  content: "";
}

.fr-toolbar .fr-command.fr-btn.fr-dropdown.fr-active,
.fr-popup .fr-command.fr-btn.fr-dropdown.fr-active,
.fr-modal .fr-command.fr-btn.fr-dropdown.fr-active {
  fill: #333333;
  background: #d6d6d6;
  -webkit-transition: 0.5s ease;
  -moz-transition: 0.5s ease;
  -ms-transition: 0.5s ease;
  -o-transition: 0.5s ease;
}

.fr-toolbar .fr-command.fr-btn.fr-dropdown.fr-active:hover,
.fr-popup .fr-command.fr-btn.fr-dropdown.fr-active:hover,
.fr-modal .fr-command.fr-btn.fr-dropdown.fr-active:hover {
  background: #ebebeb;
  fill: #333333;
}

.fr-toolbar .fr-command.fr-btn.fr-dropdown.fr-active:hover::after,
.fr-popup .fr-command.fr-btn.fr-dropdown.fr-active:hover::after,
.fr-modal .fr-command.fr-btn.fr-dropdown.fr-active:hover::after {
  border-top-color: #333333;
}

.fr-toolbar .fr-command.fr-btn.fr-dropdown.fr-active:after,
.fr-popup .fr-command.fr-btn.fr-dropdown.fr-active:after,
.fr-modal .fr-command.fr-btn.fr-dropdown.fr-active:after {
  border-top: 0;
  border-bottom: 4px solid #222222;
}

.fr-toolbar .fr-command.fr-btn.fr-disabled,
.fr-popup .fr-command.fr-btn.fr-disabled,
.fr-modal .fr-command.fr-btn.fr-disabled {
  color: #bdbdbd;
  cursor: default;
  -webkit-opacity: 0.3;
  -moz-opacity: 0.3;
  opacity: 0.3;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
}

.fr-toolbar .fr-command.fr-btn.fr-disabled::after,
.fr-popup .fr-command.fr-btn.fr-disabled::after,
.fr-modal .fr-command.fr-btn.fr-disabled::after {
  border-top-color: #bdbdbd;
}

.fr-toolbar .fr-command.fr-btn.fr-hidden,
.fr-popup .fr-command.fr-btn.fr-hidden,
.fr-modal .fr-command.fr-btn.fr-hidden {
  display: none;
}

.fr-toolbar .fr-tabs .fr-command.fr-btn,
.fr-popup .fr-tabs .fr-command.fr-btn,
.fr-modal .fr-tabs .fr-command.fr-btn {
  margin: 0;
  width: 46px;
  height: 40px;
  border-radius: 0;
  -moz-border-radius: 0;
  -webkit-border-radius: 0;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}

.fr-toolbar .fr-tabs .fr-command.fr-btn:not(:hover):not(:focus).fr-active,
.fr-toolbar .fr-tabs .fr-command.fr-btn:not(:hover):not(:focus).fr-active-tab,
.fr-popup .fr-tabs .fr-command.fr-btn:not(:hover):not(:focus).fr-active,
.fr-popup .fr-tabs .fr-command.fr-btn:not(:hover):not(:focus).fr-active-tab,
.fr-modal .fr-tabs .fr-command.fr-btn:not(:hover):not(:focus).fr-active,
.fr-modal .fr-tabs .fr-command.fr-btn:not(:hover):not(:focus).fr-active-tab {
  background: #FFF;
}

.fr-toolbar .fr-tabs .fr-command.fr-btn span,
.fr-popup .fr-tabs .fr-command.fr-btn span,
.fr-modal .fr-tabs .fr-command.fr-btn span {
  height: 27px;
}

.fr-toolbar .fr-tabs .fr-command.fr-btn img,
.fr-toolbar .fr-tabs .fr-command.fr-btn svg,
.fr-popup .fr-tabs .fr-command.fr-btn img,
.fr-popup .fr-tabs .fr-command.fr-btn svg,
.fr-modal .fr-tabs .fr-command.fr-btn img,
.fr-modal .fr-tabs .fr-command.fr-btn svg {
  margin: 8px 11px;
  width: 24px;
  height: 24px;
}

.fr-toolbar .fr-btn-grp .fr-command.fr-btn.fr-active:not(.fr-dropdown) svg path,
.fr-toolbar .fr-more-toolbar .fr-command.fr-btn.fr-active:not(.fr-dropdown) svg path,
.fr-toolbar .fr-buttons:not(.fr-tabs) .fr-command.fr-btn.fr-active:not(.fr-dropdown) svg path,
.fr-popup .fr-btn-grp .fr-command.fr-btn.fr-active:not(.fr-dropdown) svg path,
.fr-popup .fr-more-toolbar .fr-command.fr-btn.fr-active:not(.fr-dropdown) svg path,
.fr-popup .fr-buttons:not(.fr-tabs) .fr-command.fr-btn.fr-active:not(.fr-dropdown) svg path,
.fr-modal .fr-btn-grp .fr-command.fr-btn.fr-active:not(.fr-dropdown) svg path,
.fr-modal .fr-more-toolbar .fr-command.fr-btn.fr-active:not(.fr-dropdown) svg path,
.fr-modal .fr-buttons:not(.fr-tabs) .fr-command.fr-btn.fr-active:not(.fr-dropdown) svg path {
  fill: #0098f7;
}

.fr-toolbar.fr-disabled .fr-btn,
.fr-toolbar.fr-disabled .fr-btn.fr-active,
.fr-popup.fr-disabled .fr-btn,
.fr-popup.fr-disabled .fr-btn.fr-active,
.fr-modal.fr-disabled .fr-btn,
.fr-modal.fr-disabled .fr-btn.fr-active {
  color: #bdbdbd;
  -webkit-opacity: 0.3;
  -moz-opacity: 0.3;
  opacity: 0.3;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
}

.fr-toolbar.fr-disabled .fr-btn.fr-dropdown::after,
.fr-toolbar.fr-disabled .fr-btn.fr-active.fr-dropdown::after,
.fr-popup.fr-disabled .fr-btn.fr-dropdown::after,
.fr-popup.fr-disabled .fr-btn.fr-active.fr-dropdown::after,
.fr-modal.fr-disabled .fr-btn.fr-dropdown::after,
.fr-modal.fr-disabled .fr-btn.fr-active.fr-dropdown::after {
  border-top-color: #bdbdbd;
}

.fr-toolbar.fr-rtl .fr-btn-grp.fr-float-left,
.fr-popup.fr-rtl .fr-btn-grp.fr-float-left,
.fr-modal.fr-rtl .fr-btn-grp.fr-float-left {
  float: right;
}

.fr-toolbar.fr-rtl .fr-btn-grp.fr-float-right,
.fr-popup.fr-rtl .fr-btn-grp.fr-float-right,
.fr-modal.fr-rtl .fr-btn-grp.fr-float-right {
  float: left;
}

.fr-toolbar.fr-rtl .fr-command.fr-btn,
.fr-toolbar.fr-rtl .fr-btn-wrap,
.fr-popup.fr-rtl .fr-command.fr-btn,
.fr-popup.fr-rtl .fr-btn-wrap,
.fr-modal.fr-rtl .fr-command.fr-btn,
.fr-modal.fr-rtl .fr-btn-wrap {
  float: right;
}

.fr-toolbar.fr-rtl .fr-command.fr-btn.fr-dropdown.fr-options,
.fr-toolbar.fr-rtl .fr-btn-wrap.fr-dropdown.fr-options,
.fr-popup.fr-rtl .fr-command.fr-btn.fr-dropdown.fr-options,
.fr-popup.fr-rtl .fr-btn-wrap.fr-dropdown.fr-options,
.fr-modal.fr-rtl .fr-command.fr-btn.fr-dropdown.fr-options,
.fr-modal.fr-rtl .fr-btn-wrap.fr-dropdown.fr-options {
  border-radius: 4px 0 0 4px;
  -moz-border-radius: 4px 0 0 4px;
  -webkit-border-radius: 4px 0 0 4px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}

.fr-toolbar.fr-rtl .fr-command.fr-btn.fr-btn-hover,
.fr-toolbar.fr-rtl .fr-btn-wrap.fr-btn-hover,
.fr-popup.fr-rtl .fr-command.fr-btn.fr-btn-hover,
.fr-popup.fr-rtl .fr-btn-wrap.fr-btn-hover,
.fr-modal.fr-rtl .fr-command.fr-btn.fr-btn-hover,
.fr-modal.fr-rtl .fr-btn-wrap.fr-btn-hover {
  border-radius: 0 4px 4px 0;
  -moz-border-radius: 0 4px 4px 0;
  -webkit-border-radius: 0 4px 4px 0;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}

.fr-toolbar.fr-inline>.fr-command.fr-btn:not(.fr-hidden),
.fr-toolbar.fr-inline>.fr-btn-wrap:not(.fr-hidden) {
  display: -webkit-inline-flex;
  display: -ms-inline-flexbox;
  display: inline-flex;
  float: none;
}

.fr-desktop .fr-command:hover,
.fr-desktop .fr-command:focus,
.fr-desktop .fr-command.fr-btn-hover,
.fr-desktop .fr-command.fr-expanded {
  outline: 0;
  color: #333333;
}

.fr-desktop .fr-command:hover:not(.fr-table-cell),
.fr-desktop .fr-command:focus:not(.fr-table-cell),
.fr-desktop .fr-command.fr-btn-hover:not(.fr-table-cell),
.fr-desktop .fr-command.fr-expanded:not(.fr-table-cell) {
  background: #ebebeb;
}

.fr-desktop .fr-command:hover::after,
.fr-desktop .fr-command:focus::after,
.fr-desktop .fr-command.fr-btn-hover::after,
.fr-desktop .fr-command.fr-expanded::after {
  border-top-color: #333333;
}

.fr-desktop .fr-command.fr-selected:not(.fr-table-cell),
.fr-desktop .fr-command:active {
  color: #333333;
  background: #d6d6d6;
}

.fr-desktop .fr-command.fr-active:hover,
.fr-desktop .fr-command.fr-active:focus,
.fr-desktop .fr-command.fr-active.fr-btn-hover,
.fr-desktop .fr-command.fr-active.fr-expanded {
  background: #ebebeb;
}

.fr-desktop .fr-command.fr-active:active {
  background: #d6d6d6;
}

.fr-desktop .fr-command.fr-disabled:hover,
.fr-desktop .fr-command.fr-disabled:focus,
.fr-desktop .fr-command.fr-disabled.fr-selected {
  background: transparent;
}

.fr-desktop.fr-disabled .fr-command:hover,
.fr-desktop.fr-disabled .fr-command:focus,
.fr-desktop.fr-disabled .fr-command.fr-selected {
  background: transparent;
}

.fr-toolbar.fr-mobile .fr-command.fr-blink,
.fr-popup.fr-mobile .fr-command.fr-blink {
  background: #d6d6d6;
}

.fr-command.fr-btn.fr-options {
  width: 16px;
  margin-left: -5px;
}

.fr-command.fr-btn.fr-options.fr-btn-hover,
.fr-command.fr-btn.fr-options:hover,
.fr-command.fr-btn.fr-options:focus {
  border-left: solid 1px #FAFAFA;
  -webkit-transition: border-left 0s, background-color 0.5s;
  -moz-transition: border-left 0s, background-color 0.5s;
  -ms-transition: border-left 0s, background-color 0.5s;
  -o-transition: border-left 0s, background-color 0.5s;
}

.fr-command.fr-btn+.fr-dropdown-menu {
  background: #FFF;
  display: inline-block;
  position: absolute;
  right: auto;
  bottom: auto;
  height: auto;
  z-index: 4;
  border-radius: 4px;
  -moz-border-radius: 4px;
  -webkit-border-radius: 4px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  -webkit-overflow-scrolling: touch;
  overflow: hidden;
  zoom: 1;
  -webkit-box-shadow: 0 3px 1px -2px rgba(0,0,0,0.2),0 2px 2px 0 rgba(0,0,0,0.14),0 1px 5px 0 rgba(0,0,0,0.12);
  -moz-box-shadow: 0 3px 1px -2px rgba(0,0,0,0.2),0 2px 2px 0 rgba(0,0,0,0.14),0 1px 5px 0 rgba(0,0,0,0.12);
  box-shadow: 0 3px 1px -2px rgba(0,0,0,0.2),0 2px 2px 0 rgba(0,0,0,0.14),0 1px 5px 0 rgba(0,0,0,0.12);
}

.fr-command.fr-btn+.fr-dropdown-menu.test-height .fr-dropdown-wrapper {
  -webkit-transition: none;
  -moz-transition: none;
  -ms-transition: none;
  -o-transition: none;
  height: auto;
  max-height: 275px;
}

.fr-command.fr-btn+.fr-dropdown-menu .fr-dropdown-wrapper {
  padding: 0;
  margin: auto;
  display: inline-block;
  text-align: left;
  position: relative;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-transition: height 0.3s;
  -moz-transition: height 0.3s;
  -ms-transition: height 0.3s;
  -o-transition: height 0.3s;
  margin-top: 0;
  float: left;
  height: 0;
  margin-top: 0 !important;
}

.fr-command.fr-btn+.fr-dropdown-menu .fr-dropdown-wrapper .fr-dropdown-content {
  position: relative;
}

.fr-command.fr-btn+.fr-dropdown-menu .fr-dropdown-wrapper .fr-dropdown-content ul.fr-dropdown-list {
  list-style-type: none;
  margin: 0;
  padding: 8px 0;
  min-width: 72px;
}

.fr-command.fr-btn+.fr-dropdown-menu .fr-dropdown-wrapper .fr-dropdown-content ul.fr-dropdown-list li {
  padding: 0;
  margin: 0;
  font-size: 15px;
}

.fr-command.fr-btn+.fr-dropdown-menu .fr-dropdown-wrapper .fr-dropdown-content ul.fr-dropdown-list li a {
  padding: 0 20px;
  line-height: 200%;
  display: flex;
  cursor: pointer;
  white-space: nowrap;
  color: inherit;
  text-decoration: none;
  border-radius: 0;
  -moz-border-radius: 0;
  -webkit-border-radius: 0;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}

.fr-command.fr-btn+.fr-dropdown-menu .fr-dropdown-wrapper .fr-dropdown-content ul.fr-dropdown-list li a svg {
  width: 24px;
  height: 24px;
  margin: 3px 4px;
}

.fr-command.fr-btn+.fr-dropdown-menu .fr-dropdown-wrapper .fr-dropdown-content ul.fr-dropdown-list li a svg path {
  fill: #333333;
}

.fr-command.fr-btn+.fr-dropdown-menu .fr-dropdown-wrapper .fr-dropdown-content ul.fr-dropdown-list li a.fr-active {
  background: #d6d6d6;
}

.fr-command.fr-btn+.fr-dropdown-menu .fr-dropdown-wrapper .fr-dropdown-content ul.fr-dropdown-list li a.fr-disabled {
  color: #bdbdbd;
  cursor: default;
}

.fr-command.fr-btn+.fr-dropdown-menu .fr-dropdown-wrapper .fr-dropdown-content ul.fr-dropdown-list li a .fr-shortcut {
  margin-left: 20px;
  font-weight: bold;
  -webkit-opacity: 0.75;
  -moz-opacity: 0.75;
  opacity: 0.75;
}

.fr-command.fr-btn.fr-active+.fr-dropdown-menu {
  display: inline-block;
  -webkit-box-shadow: 0 3px 1px -2px rgba(0,0,0,0.2),0 2px 2px 0 rgba(0,0,0,0.14),0 1px 5px 0 rgba(0,0,0,0.12);
  -moz-box-shadow: 0 3px 1px -2px rgba(0,0,0,0.2),0 2px 2px 0 rgba(0,0,0,0.14),0 1px 5px 0 rgba(0,0,0,0.12);
  box-shadow: 0 3px 1px -2px rgba(0,0,0,0.2),0 2px 2px 0 rgba(0,0,0,0.14),0 1px 5px 0 rgba(0,0,0,0.12);
}

.fr-bottom>.fr-command.fr-btn+.fr-dropdown-menu {
  border-radius: 2px 2px 0 0;
  -moz-border-radius: 2px 2px 0 0;
  -webkit-border-radius: 2px 2px 0 0;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}

.fr-toolbar.fr-rtl .fr-dropdown-wrapper,
.fr-popup.fr-rtl .fr-dropdown-wrapper {
  text-align: right !important;
}

.amis-scope.prevent-scroll {
  overflow: hidden;
}

.amis-scope.prevent-scroll.fr-mobile {
  position: fixed;
  -webkit-overflow-scrolling: touch;
}

.fr-modal {
  color: #222222;
  font-family: Arial, Helvetica, sans-serif;
  position: fixed;
  overflow-x: auto;
  overflow-y: scroll;
  top: 0;
  left: 0;
  bottom: 0;
  right: 0;
  width: 100%;
  z-index: 2147483640;
  text-rendering: optimizelegibility;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  text-align: center;
  line-height: 1.2;
}

.fr-modal.fr-middle .fr-modal-wrapper {
  margin-top: 0;
  margin-bottom: 0;
  margin-left: auto;
  margin-right: auto;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -moz-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  -o-transform: translate(-50%, -50%);
  position: absolute;
}

.fr-modal .fr-modal-wrapper {
  border-radius: 10px;
  -moz-border-radius: 10px;
  -webkit-border-radius: 10px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  background-clip: padding-box;
  margin: 20px auto;
  display: inline-block;
  background: #FFF;
  min-width: 300px;
  -webkit-box-shadow: 0 3px 5px -1px rgba(0,0,0,0.2),0 6px 10px 0 rgba(0,0,0,0.14),0 1px 18px 0 rgba(0,0,0,0.12);
  -moz-box-shadow: 0 3px 5px -1px rgba(0,0,0,0.2),0 6px 10px 0 rgba(0,0,0,0.14),0 1px 18px 0 rgba(0,0,0,0.12);
  box-shadow: 0 3px 5px -1px rgba(0,0,0,0.2),0 6px 10px 0 rgba(0,0,0,0.14),0 1px 18px 0 rgba(0,0,0,0.12);
  border: 0;
  overflow: hidden;
  width: 90%;
  position: relative;
}

@media (min-width: 768px) and (max-width: 991px) {
  .fr-modal .fr-modal-wrapper {
    margin: 30px auto;
    width: 70%;
  }
}

@media (min-width: 992px) {
  .fr-modal .fr-modal-wrapper {
    margin: 50px auto;
    width: 960px;
  }
}

.fr-modal .fr-modal-wrapper .fr-modal-head {
  background: #FFF;
  overflow: hidden;
  position: absolute;
  width: 100%;
  min-height: 42px;
  z-index: 3;
  border-bottom: solid #efefef 1px;
  -webkit-transition: all 0.2s ease 0s;
  -moz-transition: all 0.2s ease 0s;
  -ms-transition: all 0.2s ease 0s;
  -o-transition: all 0.2s ease 0s;
}

.fr-modal .fr-modal-wrapper .fr-modal-head .fr-modal-head-line {
  height: 56px;
  padding: 0 10px;
}

.fr-modal .fr-modal-wrapper .fr-modal-head .fr-modal-close {
  margin: 10px;
  position: absolute;
  top: 0;
  right: 0;
}

.fr-modal .fr-modal-wrapper .fr-modal-head h4 {
  font-size: 20px;
  padding: 19px 10px;
  margin: 0;
  font-weight: 400;
  line-height: 18px;
  display: inline-block;
  float: left;
}

.fr-modal .fr-modal-wrapper div.fr-modal-body {
  height: 100%;
  min-height: 150px;
  overflow-y: auto;
  padding-bottom: 20px;
}

.fr-modal .fr-modal-wrapper div.fr-modal-body:focus {
  outline: 0;
}

.fr-modal .fr-modal-wrapper div.fr-modal-body button.fr-command {
  height: 36px;
  line-height: 1;
  color: #0098f7;
  padding: 10px;
  cursor: pointer;
  text-decoration: none;
  border: none;
  background: none;
  font-size: 16px;
  outline: none;
  -webkit-transition: background 0.2s ease 0s;
  -moz-transition: background 0.2s ease 0s;
  -ms-transition: background 0.2s ease 0s;
  -o-transition: background 0.2s ease 0s;
  border-radius: 2px;
  -moz-border-radius: 2px;
  -webkit-border-radius: 2px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}

.fr-modal .fr-modal-wrapper div.fr-modal-body button.fr-command+button {
  margin-left: 24px;
}

.fr-modal .fr-modal-wrapper div.fr-modal-body button.fr-command:hover,
.fr-modal .fr-modal-wrapper div.fr-modal-body button.fr-command:focus {
  background: #ebebeb;
  color: #0098f7;
}

.fr-modal .fr-modal-wrapper div.fr-modal-body button.fr-command:active {
  background: #d6d6d6;
  color: #0098f7;
}

.fr-modal .fr-modal-wrapper div.fr-modal-body button::-moz-focus-inner {
  border: 0;
}

.fr-desktop .fr-modal-wrapper .fr-modal-head i:hover {
  background: #ebebeb;
}

.fr-overlay {
  position: fixed;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
  background: #000;
  -webkit-opacity: 0.5;
  -moz-opacity: 0.5;
  opacity: 0.5;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
  z-index: 2147483639;
}

.amis-scope ol.decimal_type {
  counter-reset: item;
}

.amis-scope ol.decimal_type>li {
  display: block;
}

.amis-scope ol.decimal_type>li:before {
  content: counters(item,".") ". ";
  counter-increment: item;
}

.fr-popup {
  position: absolute;
  display: none;
  color: #222222;
  background: #FFF;
  -webkit-box-shadow: 0 3px 5px -1px rgba(0,0,0,0.2),0 6px 10px 0 rgba(0,0,0,0.14),0 1px 18px 0 rgba(0,0,0,0.12);
  -moz-box-shadow: 0 3px 5px -1px rgba(0,0,0,0.2),0 6px 10px 0 rgba(0,0,0,0.14),0 1px 18px 0 rgba(0,0,0,0.12);
  box-shadow: 0 3px 5px -1px rgba(0,0,0,0.2),0 6px 10px 0 rgba(0,0,0,0.14),0 1px 18px 0 rgba(0,0,0,0.12);
  font-family: Arial, Helvetica, sans-serif;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  user-select: none;
  -o-user-select: none;
  -moz-user-select: none;
  -khtml-user-select: none;
  -webkit-user-select: none;
  -ms-user-select: none;
  margin-top: 10px;
  z-index: 2147483635;
  text-align: left;
  border-radius: 6px;
  -moz-border-radius: 6px;
  -webkit-border-radius: 6px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  text-rendering: optimizelegibility;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  line-height: 1.2;
}

.fr-popup .fr-icon {
  text-align: center;
  vertical-align: middle;
  font-size: 20px;
  line-height: 1;
  cursor: pointer;
  font-weight: 400;
  box-sizing: content-box;
  padding: 6px;
}

.fr-popup .fr-icon-container {
  padding: 20px;
  max-height: 200px;
  overflow: auto;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}

@supports not (-ms-high-contrast: none) {
  .fr-popup .fr-icon-container {
    grid-template-columns: repeat(auto-fill, minmax(36px, 36px));
    display: grid;
  }
}

@media (min-width: 768px) {
  .fr-popup .fr-icon-container {
    min-width: 276px;
  }
}

@media screen and (-ms-high-contrast: active), (-ms-high-contrast: none) {
  .fr-popup .fr-icon-container {
    display: inline-flex;
    -ms-flex-flow: row wrap;
  }
}

@media screen and (-ms-high-contrast: active) and (max-width: 768px), (-ms-high-contrast: none) and (max-width: 768px) {
  .fr-popup .fr-icon-container {
    width: 236px;
  }
}

.fr-popup .fr-input-focus {
  background: whitesmoke;
}

.fr-popup.fr-above {
  margin-top: -10px;
  border-top: 0;
}

.fr-popup.fr-active {
  display: block;
}

.fr-popup.fr-hidden {
  -webkit-opacity: 0;
  -moz-opacity: 0;
  opacity: 0;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
}

.fr-popup.fr-empty {
  display: none !important;
}

.fr-popup .fr-hs {
  display: block !important;
}

.fr-popup .fr-hs.fr-hidden {
  display: none !important;
}

.fr-popup .fr-input-line {
  position: relative;
  padding: 15px 0;
}

.fr-popup .fr-input-line input[type="text"],
.fr-popup .fr-input-line textarea {
  width: 100%;
  margin-bottom: 1px;
  border-radius: 2px;
  -moz-border-radius: 2px;
  -webkit-border-radius: 2px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  border: solid 1px #999999;
  color: #222222;
  font-size: 14px;
  background: #FFF;
  position: relative;
  z-index: 2;
  padding: 4px 12px;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-transition: border 0.5s, padding 0.5s;
  -moz-transition: border 0.5s, padding 0.5s;
  -ms-transition: border 0.5s, padding 0.5s;
  -o-transition: border 0.5s, padding 0.5s;
}

.fr-popup .fr-input-line input[type="text"]:hover,
.fr-popup .fr-input-line textarea:hover {
  border: solid 1px #515151;
}

.fr-popup .fr-input-line input[type="text"]:focus,
.fr-popup .fr-input-line textarea:focus {
  border: solid 2px #0098f7;
  padding: 3px 11px;
}

.fr-popup .fr-input-line input[type="text"] {
  height: 46px;
}

.fr-popup .fr-input-line input+label,
.fr-popup .fr-input-line textarea+label {
  position: absolute;
  top: 29px;
  left: 12px;
  font-size: 14px;
  color: grey;
  -webkit-transition: all 0.5s ease;
  -moz-transition: all 0.5s ease;
  -ms-transition: all 0.5s ease;
  -o-transition: all 0.5s ease;
  z-index: 3;
  display: block;
  background: #FFF;
  padding: 0;
  cursor: text;
}

.fr-popup .fr-input-line input.fr-not-empty+label,
.fr-popup .fr-input-line textarea.fr-not-empty+label {
  color: gray;
  width: auto;
  left: 4px;
  padding: 0 4px;
  font-size: 11px;
  top: 9px;
}

.fr-popup input,
.fr-popup textarea {
  user-select: text;
  -o-user-select: text;
  -moz-user-select: text;
  -khtml-user-select: text;
  -webkit-user-select: text;
  -ms-user-select: text;
  border-radius: 0;
  -moz-border-radius: 0;
  -webkit-border-radius: 0;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  outline: none;
}

.fr-popup textarea {
  resize: none;
}

.fr-popup .fr-buttons {
  white-space: nowrap;
  line-height: 0;
}

.fr-popup .fr-buttons .fr-btn {
  margin-left: 4px;
  margin-right: 4px;
  display: inline-block;
  float: none;
}

.fr-popup .fr-buttons .fr-btn i {
  float: left;
}

.fr-popup .fr-buttons .fr-separator {
  display: inline-block;
  float: none;
}

.fr-popup .fr-buttons.fr-tabs {
  border-radius: 6px 6px 0 0;
  -moz-border-radius: 6px 6px 0 0;
  -webkit-border-radius: 6px 6px 0 0;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  background-color: #f5f5f5;
  overflow: hidden;
}

@media (max-width: 768px) {
  .fr-popup .fr-buttons.fr-tabs.fr-tabs-scroll {
    overflow: scroll;
    overflow-y: hidden;
    width: 276px;
  }
}

.fr-popup .fr-buttons:not(.fr-tabs) {
  padding: 5px;
}

.fr-popup .fr-layer {
  border-radius: 6px;
  -moz-border-radius: 6px;
  -webkit-border-radius: 6px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  width: 195px;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  margin: 20px;
  display: none;
}

@media (min-width: 768px) {
  .fr-popup .fr-layer {
    width: 260px;
  }
}

.fr-popup .fr-layer.fr-active {
  display: inline-block;
}

.fr-popup .fr-action-buttons {
  z-index: 7;
  height: 36px;
  text-align: right;
}

.fr-popup .fr-action-buttons button.fr-command {
  height: 36px;
  line-height: 1;
  color: #0098f7;
  padding: 10px;
  cursor: pointer;
  text-decoration: none;
  border: none;
  background: none;
  font-size: 16px;
  outline: none;
  -webkit-transition: background 0.2s ease 0s;
  -moz-transition: background 0.2s ease 0s;
  -ms-transition: background 0.2s ease 0s;
  -o-transition: background 0.2s ease 0s;
  border-radius: 2px;
  -moz-border-radius: 2px;
  -webkit-border-radius: 2px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}

.fr-popup .fr-action-buttons button.fr-command+button {
  margin-left: 24px;
}

.fr-popup .fr-action-buttons button.fr-command:hover,
.fr-popup .fr-action-buttons button.fr-command:focus {
  background: #ebebeb;
  color: #0098f7;
}

.fr-popup .fr-action-buttons button.fr-command:active {
  background: #d6d6d6;
  color: #0098f7;
}

.fr-popup .fr-action-buttons button::-moz-focus-inner {
  border: 0;
}

.fr-popup .fr-checkbox {
  position: relative;
  display: inline-block;
  width: 18px;
  height: 18px;
  padding: 10px;
  border-radius: 100%;
  line-height: 1;
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  box-sizing: content-box;
  vertical-align: middle;
}

.fr-popup .fr-checkbox svg {
  margin-left: 2px;
  margin-top: 2px;
  display: none;
  width: 10px;
  height: 10px;
}

.fr-popup .fr-checkbox span {
  border-radius: 2px;
  -moz-border-radius: 2px;
  -webkit-border-radius: 2px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  width: 18px;
  height: 18px;
  display: inline-block;
  position: relative;
  z-index: 1;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-transition: background 0.2s ease 0s, border-color 0.2s ease 0s;
  -moz-transition: background 0.2s ease 0s, border-color 0.2s ease 0s;
  -ms-transition: background 0.2s ease 0s, border-color 0.2s ease 0s;
  -o-transition: background 0.2s ease 0s, border-color 0.2s ease 0s;
}

.fr-popup .fr-checkbox input {
  position: absolute;
  z-index: 2;
  -webkit-opacity: 0;
  -moz-opacity: 0;
  opacity: 0;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
  border: 0 none;
  cursor: pointer;
  height: 18px;
  margin: 0;
  padding: 0;
  width: 18px;
  top: 7px;
  left: 7px;
}

.fr-popup .fr-checkbox input:not(:checked)+span {
  border: solid 2px #999999;
}

.fr-popup .fr-checkbox input:not(:checked):active+span {
  background-color: #f5f5f5;
}

.fr-popup .fr-checkbox input:not(:checked):focus+span,
.fr-popup .fr-checkbox input:not(:checked):hover+span {
  border-color: #515151;
}

.fr-popup .fr-checkbox input:checked+span {
  background: #0098f7;
  border: solid 2px #0098f7;
}

.fr-popup .fr-checkbox input:checked+span svg {
  display: block;
}

.fr-popup .fr-checkbox input:checked:active+span {
  background-color: #EcF5Ff;
}

.fr-popup .fr-checkbox input:checked:focus+span,
.fr-popup .fr-checkbox input:checked:hover+span {
  -webkit-opacity: 0.8;
  -moz-opacity: 0.8;
  opacity: 0.8;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
}

.fr-popup .fr-checkbox-line {
  font-size: 14px;
  line-height: 1.4px;
  margin-top: 10px;
}

.fr-popup .fr-checkbox-line label {
  cursor: pointer;
  margin: 0 5px;
  vertical-align: middle;
}

.fr-popup.fr-rtl {
  direction: rtl;
  text-align: right;
}

.fr-popup.fr-rtl .fr-action-buttons {
  text-align: left;
}

.fr-popup.fr-rtl .fr-input-line input+label,
.fr-popup.fr-rtl .fr-input-line textarea+label {
  left: auto;
  right: 0;
}

.fr-popup.fr-rtl .fr-buttons .fr-separator.fr-vs {
  float: right;
}

.fr-text-edit-layer {
  width: 250px;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  display: block !important;
}

.fr-toolbar {
  color: #222222;
  background: #FFF;
  position: relative;
  font-family: Arial, Helvetica, sans-serif;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  user-select: none;
  -o-user-select: none;
  -moz-user-select: none;
  -khtml-user-select: none;
  -webkit-user-select: none;
  -ms-user-select: none;
  border-radius: 2px;
  -moz-border-radius: 2px;
  -webkit-border-radius: 2px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  text-align: left;
  border: 1px solid #CCCCCC;
  text-rendering: optimizelegibility;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  line-height: 1.2;
  padding-bottom: 0;
  -webkit-transition: padding-bottom 0.5s;
  -moz-transition: padding-bottom 0.5s;
  -ms-transition: padding-bottom 0.5s;
  -o-transition: padding-bottom 0.5s;
}

.fr-toolbar::after {
  clear: both;
  display: block;
  content: "";
  height: 0;
}

.fr-toolbar::after {
  height: 0;
}

.fr-toolbar .fr-newline {
  clear: both;
  display: block;
  content: "";
  margin-left: 9px;
  margin-right: 9px;
  background: #efefef;
  height: 1px;
  -webkit-transition: height 0.5s;
  -moz-transition: height 0.5s;
  -ms-transition: height 0.5s;
  -o-transition: height 0.5s;
}

.fr-toolbar.fr-toolbar-open {
  padding-bottom: 48px;
}

.fr-toolbar.fr-toolbar-open .fr-newline {
  height: 0;
}

.fr-toolbar .fr-float-right {
  float: right;
}

.fr-toolbar .fr-float-left {
  float: left;
}

.fr-toolbar .fr-more-toolbar {
  float: left;
  border-radius: 0;
  -moz-border-radius: 0;
  -webkit-border-radius: 0;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  background-color: #f5f5f5;
  -webkit-transition: height 0.5s;
  -moz-transition: height 0.5s;
  -ms-transition: height 0.5s;
  -o-transition: height 0.5s;
  height: 0;
  z-index: 2;
  overflow: hidden;
  position: absolute;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  width: 100%;
}

.fr-toolbar .fr-more-toolbar.fr-expanded {
  height: 48px;
}

.fr-toolbar .fr-more-toolbar.fr-overflow-visible {
  overflow: visible;
}

.fr-toolbar .fr-more-toolbar>.fr-command.fr-btn {
  margin-left: 4px;
  margin-right: 4px;
}

.fr-toolbar .fr-btn-grp {
  display: inline-block;
  margin: 0 17px 0 12px;
}

@media (max-width: 768px) {
  .fr-toolbar .fr-btn-grp {
    margin: 0 7px 0 6px;
  }
}

.fr-toolbar .fr-command.fr-btn.fr-open {
  margin-top: 10px;
  margin-bottom: -1px;
  border-radius: 4px 4px 0 0;
  -moz-border-radius: 4px 4px 0 0;
  -webkit-border-radius: 4px 4px 0 0;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}

.fr-toolbar .fr-command.fr-btn.fr-open:not(:hover):not(:focus):not(:active) {
  background: #f5f5f5;
}

.fr-toolbar.fr-rtl {
  text-align: right;
}

.fr-toolbar.fr-inline {
  display: none;
  -webkit-box-shadow: 0 3px 5px -1px rgba(0,0,0,0.2),0 6px 10px 0 rgba(0,0,0,0.14),0 1px 18px 0 rgba(0,0,0,0.12);
  -moz-box-shadow: 0 3px 5px -1px rgba(0,0,0,0.2),0 6px 10px 0 rgba(0,0,0,0.14),0 1px 18px 0 rgba(0,0,0,0.12);
  box-shadow: 0 3px 5px -1px rgba(0,0,0,0.2),0 6px 10px 0 rgba(0,0,0,0.14),0 1px 18px 0 rgba(0,0,0,0.12);
  border: 0;
  white-space: nowrap;
  position: absolute;
  margin-top: 5px;
  z-index: 2147483630;
}

.fr-toolbar.fr-inline.fr-above {
  margin-top: -10px;
  border-top: 0;
}

.fr-toolbar.fr-inline .fr-newline {
  height: 0;
}

.fr-toolbar.fr-top {
  top: 0;
  border-bottom: 0;
  border-radius: 10px 10px 0 0;
  -moz-border-radius: 10px 10px 0 0;
  -webkit-border-radius: 10px 10px 0 0;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}

.fr-toolbar.fr-bottom {
  bottom: 0;
  border-top: 0;
  padding-bottom: 0;
  border-radius: 0 0 10px 10px;
  -moz-border-radius: 0 0 10px 10px;
  -webkit-border-radius: 0 0 10px 10px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}

.fr-toolbar.fr-bottom .fr-newline {
  padding-top: 0;
  -webkit-transition: padding-top 0.5s;
  -moz-transition: padding-top 0.5s;
  -ms-transition: padding-top 0.5s;
  -o-transition: padding-top 0.5s;
}

.fr-toolbar.fr-bottom.fr-toolbar-open .fr-newline {
  padding-top: 48px;
  background: #FFF;
}

.fr-toolbar.fr-bottom .fr-command.fr-btn.fr-open {
  margin-top: -1px;
  margin-bottom: 10px;
  border-radius: 0 0 4px 4px;
  -moz-border-radius: 0 0 4px 4px;
  -webkit-border-radius: 0 0 4px 4px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}

.fr-toolbar.fr-sticky-on {
  border-radius: 0;
  -moz-border-radius: 0;
  -webkit-border-radius: 0;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}

.fr-separator {
  background: #ebebeb;
  display: block;
  vertical-align: top;
  float: left;
}

.fr-separator+.fr-separator {
  display: none;
}

.fr-separator.fr-vs {
  height: 32px;
  width: 1px;
  margin: 8px 4px;
}

.fr-separator.fr-hs {
  clear: both;
  width: calc(100% - (2 * 4px));
  margin: 0 4px;
  height: 1px;
}

.fr-separator.fr-hidden {
  display: none !important;
}

.fr-rtl .fr-separator {
  float: right;
}

.fr-toolbar.fr-inline .fr-separator.fr-hs {
  float: none;
}

.fr-toolbar.fr-inline .fr-separator.fr-vs {
  float: none;
  display: inline-block;
}

.amis-scope .second-toolbar {
  border: 1px solid #CCCCCC;
  border-top: 0;
  background: #FFF;
  line-height: 1.4;
  border-radius: 0 0 10px 10px;
  -moz-border-radius: 0 0 10px 10px;
  -webkit-border-radius: 0 0 10px 10px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}

.amis-scope .second-toolbar::after {
  clear: both;
  display: block;
  content: "";
  height: 0;
}

.amis-scope #logo {
  float: left;
  outline: none;
}

.amis-scope #logo>span {
  display: inline-block;
  float: left;
  font-family: sans-serif;
  padding: 11px 5px 10px 15px;
  font-size: 12px;
  font-weight: 500;
  color: #b1b2b7;
  -webkit-transition: color 0.3s;
  -moz-transition: color 0.3s;
  -ms-transition: color 0.3s;
  -o-transition: color 0.3s;
}

.amis-scope #logo>svg {
  height: 20px;
  width: 47px;
  margin: 7px 0;
  cursor: pointer;
}

.amis-scope #logo>svg * {
  -webkit-transition: fill 0.3s;
  -moz-transition: fill 0.3s;
  -ms-transition: fill 0.3s;
  -o-transition: fill 0.3s;
}

.amis-scope #logo:hover>span,
.amis-scope #logo:focus>span {
  color: #0098f7;
}

.amis-scope #logo:hover>svg .fr-logo,
.amis-scope #logo:focus>svg .fr-logo {
  fill: #0098f7;
}

.fr-visibility-helper {
  display: none;
  margin-left: 0 !important;
}

@media (min-width: 768px) {
  .fr-visibility-helper {
    margin-left: 1px !important;
  }
}

@media (min-width: 992px) {
  .fr-visibility-helper {
    margin-left: 2px !important;
  }
}

@media (min-width: 1200px) {
  .fr-visibility-helper {
    margin-left: 3px !important;
  }
}

.fr-opacity-0 {
  -webkit-opacity: 0;
  -moz-opacity: 0;
  opacity: 0;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
}

.fr-box {
  position: relative;
}

.fr-sticky {
  position: -webkit-sticky;
  position: -moz-sticky;
  position: -ms-sticky;
  position: -o-sticky;
  position: sticky;
}

.fr-sticky-off {
  position: relative;
}

.fr-sticky-on {
  position: fixed;
  z-index: 10;
}

.fr-sticky-on.fr-sticky-ios {
  position: absolute;
  left: 0;
  right: 0;
  width: auto !important;
}

.fr-sticky-dummy {
  display: none;
}

.fr-sticky-on+.fr-sticky-dummy,
.fr-sticky-box>.fr-sticky-dummy {
  display: block;
}

.amis-scope span.fr-sr-only {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0;
}

.amis-scope .clearfix::after {
  clear: both;
  display: block;
  content: "";
  height: 0;
}

.amis-scope .hide-by-clipping {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0;
}

.fr-box .fr-counter {
  padding: 10px;
  float: right;
  color: #999999;
  content: attr(data-chars);
  font-size: 14px;
  font-family: sans-serif;
  z-index: 1;
  border-radius: 2px 0 0 0;
  -moz-border-radius: 2px 0 0 0;
  -webkit-border-radius: 2px 0 0 0;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}

.fr-box.fr-rtl .fr-counter {
  left: 0;
  right: auto;
  border-left: none;
  border-radius: 0 2px 0 0;
  -moz-border-radius: 0 2px 0 0;
  -webkit-border-radius: 0 2px 0 0;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}

.fr-box.fr-code-view .fr-counter {
  display: none;
}

.amis-scope .clearfix::after {
  clear: both;
  display: block;
  content: "";
  height: 0;
}

.amis-scope .hide-by-clipping {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0;
}

.amis-scope textarea.fr-code {
  display: none;
  width: 100%;
  resize: none;
  -moz-resize: none;
  -webkit-resize: none;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  border: none;
  padding: 10px;
  margin: 0;
  font-family: "Courier New",monospace;
  font-size: 14px;
  background: #FFF;
  color: #000;
  outline: none;
}

.fr-box.fr-rtl textarea.fr-code {
  direction: rtl;
}

.fr-box .CodeMirror {
  display: none;
}

.fr-box.fr-code-view textarea.fr-code {
  display: block;
}

.fr-box.fr-code-view .fr-element,
.fr-box.fr-code-view .fr-placeholder,
.fr-box.fr-code-view .fr-iframe {
  display: none;
}

.fr-box.fr-code-view .CodeMirror {
  display: block;
}

.fr-box.fr-inline.fr-code-view .fr-command.fr-btn.html-switch {
  display: block;
}

.fr-box.fr-inline .fr-command.fr-btn.html-switch {
  display: none;
  position: absolute;
  top: 0;
  right: 0;
  display: none;
  background: #FFF;
  color: #333333;
  -moz-outline: 0;
  outline: 0;
  border: 0;
  line-height: 1;
  cursor: pointer;
  text-align: left;
  padding: 8px 7px;
  -webkit-transition: background 0.2s ease 0s;
  -moz-transition: background 0.2s ease 0s;
  -ms-transition: background 0.2s ease 0s;
  -o-transition: background 0.2s ease 0s;
  border-radius: 0;
  -moz-border-radius: 0;
  -webkit-border-radius: 0;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  z-index: 2;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  text-decoration: none;
  user-select: none;
  -o-user-select: none;
  -moz-user-select: none;
  -khtml-user-select: none;
  -webkit-user-select: none;
  -ms-user-select: none;
}

.fr-box.fr-inline .fr-command.fr-btn.html-switch i {
  font-size: 24px;
  width: 24px;
  text-align: center;
}

.fr-box.fr-inline .fr-command.fr-btn.html-switch.fr-desktop:hover {
  background: #ebebeb;
}

.amis-scope .clearfix::after {
  clear: both;
  display: block;
  content: "";
  height: 0;
}

.amis-scope .hide-by-clipping {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0;
}

.fr-popup .fr-layer.fr-color-hex-layer {
  margin: 0;
  padding: 20px;
  padding-top: 0;
  float: left;
}

.fr-popup .fr-layer.fr-color-hex-layer .fr-input-line {
  float: left;
  width: calc(100% - 50px);
  padding: 15px 0 0;
}

.fr-popup .fr-layer.fr-color-hex-layer .fr-action-buttons {
  float: right;
  width: 38px;
  height: 40px;
  padding: 17px 0 0;
  margin: 0;
}

.fr-popup .fr-layer.fr-color-hex-layer .fr-action-buttons button.fr-command {
  border-radius: 2px;
  -moz-border-radius: 2px;
  -webkit-border-radius: 2px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  font-size: 13px;
  height: 40px;
  width: 38px;
}

.fr-popup .fr-separator+.fr-colors-tabs {
  margin-left: 2px;
  margin-right: 2px;
}

.fr-popup .fr-color-set {
  line-height: 0;
  display: none;
}

.fr-popup .fr-color-set.fr-selected-set {
  display: block;
  padding: 20px;
  padding-bottom: 0;
}

.fr-popup .fr-color-set>span {
  display: inline-block;
  width: 32px;
  height: 32px;
  position: relative;
  z-index: 1;
}

.fr-popup .fr-color-set>span>i,
.fr-popup .fr-color-set>span>svg {
  text-align: center;
  line-height: 32px;
  height: 24px;
  width: 24px;
  margin: 4px;
  font-size: 13px;
  position: absolute;
  bottom: 0;
  cursor: default;
  left: 0;
}

.fr-popup .fr-color-set>span>i path,
.fr-popup .fr-color-set>span>svg path {
  fill: #222222;
}

.fr-popup .fr-color-set>span .fr-selected-color {
  color: #FFF;
  font-family: FontAwesome;
  font-size: 13px;
  font-weight: 400;
  line-height: 32px;
  position: absolute;
  top: 0;
  bottom: 0;
  right: 0;
  left: 0;
  text-align: center;
  cursor: default;
}

.fr-popup .fr-color-set>span:hover,
.fr-popup .fr-color-set>span:focus {
  outline: 1px solid #222222;
  z-index: 2;
}

.fr-rtl .fr-popup .fr-colors-tabs .fr-colors-tab.fr-selected-tab[data-param1="text"] ~ [data-param1="background"]::after {
  -webkit-transform: translate3d(100%, 0, 0);
  -moz-transform: translate3d(100%, 0, 0);
  -ms-transform: translate3d(100%, 0, 0);
  -o-transform: translate3d(100%, 0, 0);
}

.amis-scope .clearfix::after {
  clear: both;
  display: block;
  content: "";
  height: 0;
}

.amis-scope .hide-by-clipping {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0;
}

.fr-drag-helper {
  background: #0098f7;
  height: 2px;
  margin-top: -1px;
  -webkit-opacity: 0.2;
  -moz-opacity: 0.2;
  opacity: 0.2;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
  position: absolute;
  z-index: 2147483640;
  display: none;
}

.fr-drag-helper.fr-visible {
  display: block;
}

.fr-dragging {
  -webkit-opacity: 0.4;
  -moz-opacity: 0.4;
  opacity: 0.4;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
}

.amis-scope .clearfix::after {
  clear: both;
  display: block;
  content: "";
  height: 0;
}

.amis-scope .hide-by-clipping {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0;
}

.fr-popup .fr-emoticon {
  width: 24px;
  height: 24px;
  font-family: "Apple Color Emoji", "Segoe UI Emoji", NotoColorEmoji, "Segoe UI Symbol", "Android Emoji", EmojiSymbols;
}

.fr-popup .fr-emoticon img {
  height: 24px;
  width: 24px;
}

.fr-popup .fr-command.fr-btn.fr-tabs-unicode {
  padding: 0 0 0 14px;
}

@media screen and (-ms-high-contrast: active) and (min-width: 768px), (-ms-high-contrast: none) and (min-width: 768px) {
  .fr-popup .fr-icon-container.fr-emoticon-container {
    width: 368px;
  }
}

.amis-scope .clearfix::after {
  clear: both;
  display: block;
  content: "";
  height: 0;
}

.amis-scope .hide-by-clipping {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0;
}

.fr-popup .fr-file-upload-layer {
  border: dashed 2px #bdbdbd;
  padding: 25px 0;
  margin: 20px;
  position: relative;
  font-size: 14px;
  letter-spacing: 1px;
  line-height: 140%;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  text-align: center;
}

.fr-popup .fr-file-upload-layer:hover {
  background: #ebebeb;
}

.fr-popup .fr-file-upload-layer.fr-drop {
  background: #ebebeb;
  border-color: #0098f7;
}

.fr-popup .fr-file-upload-layer .fr-form {
  -webkit-opacity: 0;
  -moz-opacity: 0;
  opacity: 0;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
  z-index: 2147483640;
  overflow: hidden;
  margin: 0 !important;
  padding: 0 !important;
  width: 100% !important;
}

.fr-popup .fr-file-upload-layer .fr-form input {
  cursor: pointer;
  position: absolute;
  right: 0;
  top: 0;
  bottom: 0;
  width: 500%;
  height: 100%;
  margin: 0;
  font-size: 400px;
}

.fr-popup .fr-file-progress-bar-layer {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}

.fr-popup .fr-file-progress-bar-layer>h3 {
  font-size: 16px;
  margin: 10px 0;
  font-weight: normal;
}

.fr-popup .fr-file-progress-bar-layer>div.fr-action-buttons {
  display: none;
}

.fr-popup .fr-file-progress-bar-layer>div.fr-loader {
  background: #b3e0fd;
  height: 10px;
  width: 100%;
  margin-top: 20px;
  overflow: hidden;
  position: relative;
}

.fr-popup .fr-file-progress-bar-layer>div.fr-loader span {
  display: block;
  height: 100%;
  width: 0%;
  background: #0098f7;
  -webkit-transition: width 0.2s ease 0s;
  -moz-transition: width 0.2s ease 0s;
  -ms-transition: width 0.2s ease 0s;
  -o-transition: width 0.2s ease 0s;
}

.fr-popup .fr-file-progress-bar-layer>div.fr-loader.fr-indeterminate span {
  width: 30% !important;
  position: absolute;
  top: 0;
  -webkit-animation: loading 2s linear infinite;
  -moz-animation: loading 2s linear infinite;
  -o-animation: loading 2s linear infinite;
  animation: loading 2s linear infinite;
}

.fr-popup .fr-file-progress-bar-layer.fr-error>div.fr-loader {
  display: none;
}

.fr-popup .fr-file-progress-bar-layer.fr-error>div.fr-action-buttons {
  display: block;
}

@keyframes loading {
  from {
    left: -25%;
  }

  to {
    left: 100%;
  }
}

@-webkit-keyframes loading {
  from {
    left: -25%;
  }

  to {
    left: 100%;
  }
}

@-moz-keyframes loading {
  from {
    left: -25%;
  }

  to {
    left: 100%;
  }
}

@-o-keyframes loading {
  from {
    left: -25%;
  }

  to {
    left: 100%;
  }
}

@keyframes loading {
  from {
    left: -25%;
  }

  to {
    left: 100%;
  }
}

.amis-scope .clearfix::after {
  clear: both;
  display: block;
  content: "";
  height: 0;
}

.amis-scope .hide-by-clipping {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0;
}

.amis-scope.fr-fullscreen {
  overflow: hidden;
  height: 100%;
  width: 100%;
  position: fixed;
}

.fr-box.fr-fullscreen {
  margin: 0 !important;
  position: fixed;
  top: 0;
  left: 0;
  bottom: 0;
  right: 0;
  z-index: 2147483630 !important;
  width: auto !important;
}

.fr-box.fr-fullscreen.fr-basic.fr-top .fr-wrapper {
  border-radius: 0;
  -moz-border-radius: 0;
  -webkit-border-radius: 0;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}

.fr-box.fr-fullscreen.fr-basic.fr-bottom .fr-wrapper {
  border-radius: 0;
  -moz-border-radius: 0;
  -webkit-border-radius: 0;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}

.fr-box.fr-fullscreen .fr-toolbar {
  border-radius: 0;
  -moz-border-radius: 0;
  -webkit-border-radius: 0;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}

.fr-box.fr-fullscreen .fr-toolbar.fr-top {
  top: 0 !important;
}

.fr-box.fr-fullscreen .fr-toolbar.fr-bottom {
  bottom: 0 !important;
}

.fr-box.fr-fullscreen .second-toolbar {
  margin-top: 0;
  border-radius: 0;
  -moz-border-radius: 0;
  -webkit-border-radius: 0;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}

.fr-fullscreen-wrapper {
  z-index: 2147483640 !important;
  width: 100% !important;
  margin: 0 !important;
  padding: 0 !important;
  overflow: visible !important;
}

.amis-scope .clearfix::after {
  clear: both;
  display: block;
  content: "";
  height: 0;
}

.amis-scope .hide-by-clipping {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0;
}

.fr-modal .fr-modal-wrapper .fr-modal-body .fr-help-modal {
  text-align: left;
  padding: 20px 20px 10px;
}

.fr-modal .fr-modal-wrapper .fr-modal-body .fr-help-modal table {
  border-collapse: collapse;
  font-size: 14px;
  line-height: 1.5;
  width: 100%;
}

.fr-modal .fr-modal-wrapper .fr-modal-body .fr-help-modal table+table {
  margin-top: 20px;
}

.fr-modal .fr-modal-wrapper .fr-modal-body .fr-help-modal table tr {
  border: 0;
}

.fr-modal .fr-modal-wrapper .fr-modal-body .fr-help-modal table th {
  text-align: left;
}

.fr-modal .fr-modal-wrapper .fr-modal-body .fr-help-modal table th,
.fr-modal .fr-modal-wrapper .fr-modal-body .fr-help-modal table td {
  padding: 6px 0 4px;
}

.fr-modal .fr-modal-wrapper .fr-modal-body .fr-help-modal table tbody tr {
  border-bottom: solid 1px #ebebeb;
}

.fr-modal .fr-modal-wrapper .fr-modal-body .fr-help-modal table tbody td:first-child {
  width: 60%;
  color: #646464;
}

.fr-modal .fr-modal-wrapper .fr-modal-body .fr-help-modal table tbody td:nth-child(n+2) {
  letter-spacing: 0.5px;
}

.amis-scope .clearfix::after {
  clear: both;
  display: block;
  content: "";
  height: 0;
}

.amis-scope .hide-by-clipping {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0;
}

.fr-element img {
  cursor: pointer;
  padding: 0 1px;
}

.fr-image-resizer {
  position: absolute;
  border: solid 1px #0098f7;
  display: none;
  user-select: none;
  -o-user-select: none;
  -moz-user-select: none;
  -khtml-user-select: none;
  -webkit-user-select: none;
  -ms-user-select: none;
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  box-sizing: content-box;
}

.fr-image-resizer.fr-active {
  display: block;
}

.fr-image-resizer .fr-handler {
  display: block;
  position: absolute;
  background: #0098f7;
  border: solid 1px #FFF;
  border-radius: 2px;
  -moz-border-radius: 2px;
  -webkit-border-radius: 2px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  z-index: 4;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}

.fr-image-resizer .fr-handler.fr-hnw {
  cursor: nw-resize;
}

.fr-image-resizer .fr-handler.fr-hne {
  cursor: ne-resize;
}

.fr-image-resizer .fr-handler.fr-hsw {
  cursor: sw-resize;
}

.fr-image-resizer .fr-handler.fr-hse {
  cursor: se-resize;
}

.fr-image-resizer .fr-handler {
  width: 12px;
  height: 12px;
}

.fr-image-resizer .fr-handler.fr-hnw {
  left: -6px;
  top: -6px;
}

.fr-image-resizer .fr-handler.fr-hne {
  right: -6px;
  top: -6px;
}

.fr-image-resizer .fr-handler.fr-hsw {
  left: -6px;
  bottom: -6px;
}

.fr-image-resizer .fr-handler.fr-hse {
  right: -6px;
  bottom: -6px;
}

@media (min-width: 1200px) {
  .fr-image-resizer .fr-handler {
    width: 10px;
    height: 10px;
  }

  .fr-image-resizer .fr-handler.fr-hnw {
    left: -5px;
    top: -5px;
  }

  .fr-image-resizer .fr-handler.fr-hne {
    right: -5px;
    top: -5px;
  }

  .fr-image-resizer .fr-handler.fr-hsw {
    left: -5px;
    bottom: -5px;
  }

  .fr-image-resizer .fr-handler.fr-hse {
    right: -5px;
    bottom: -5px;
  }
}

.fr-image-overlay {
  position: fixed;
  top: 0;
  left: 0;
  bottom: 0;
  right: 0;
  z-index: 2147483640;
  display: none;
}

.fr-popup .fr-image-upload-layer {
  border: dashed 2px #bdbdbd;
  padding: 25px 0;
  margin: 20px;
  position: relative;
  font-size: 14px;
  letter-spacing: 1px;
  line-height: 140%;
  text-align: center;
}

.fr-popup .fr-image-upload-layer:hover {
  background: #ebebeb;
}

.fr-popup .fr-image-upload-layer.fr-drop {
  background: #ebebeb;
  border-color: #0098f7;
}

.fr-popup .fr-image-upload-layer .fr-form {
  -webkit-opacity: 0;
  -moz-opacity: 0;
  opacity: 0;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
  z-index: 2147483640;
  overflow: hidden;
  margin: 0 !important;
  padding: 0 !important;
  width: 100% !important;
}

.fr-popup .fr-image-upload-layer .fr-form input {
  cursor: pointer;
  position: absolute;
  right: 0;
  top: 0;
  bottom: 0;
  width: 500%;
  height: 100%;
  margin: 0;
  font-size: 400px;
}

.fr-popup .fr-image-progress-bar-layer>h3 {
  font-size: 16px;
  margin: 10px 0;
  font-weight: normal;
}

.fr-popup .fr-image-progress-bar-layer>div.fr-action-buttons {
  display: none;
}

.fr-popup .fr-image-progress-bar-layer>div.fr-loader {
  background: #b3e0fd;
  height: 10px;
  width: 100%;
  margin-top: 20px;
  overflow: hidden;
  position: relative;
}

.fr-popup .fr-image-progress-bar-layer>div.fr-loader span {
  display: block;
  height: 100%;
  width: 0%;
  background: #0098f7;
  -webkit-transition: width 0.2s ease 0s;
  -moz-transition: width 0.2s ease 0s;
  -ms-transition: width 0.2s ease 0s;
  -o-transition: width 0.2s ease 0s;
}

.fr-popup .fr-image-progress-bar-layer>div.fr-loader.fr-indeterminate span {
  width: 30% !important;
  position: absolute;
  top: 0;
  -webkit-animation: loading 2s linear infinite;
  -moz-animation: loading 2s linear infinite;
  -o-animation: loading 2s linear infinite;
  animation: loading 2s linear infinite;
}

.fr-popup .fr-image-progress-bar-layer.fr-error>div.fr-loader {
  display: none;
}

.fr-popup .fr-image-progress-bar-layer.fr-error>div.fr-action-buttons {
  display: block;
}

.fr-image-size-layer .fr-image-group .fr-input-line {
  width: calc(50% - 5px);
  display: inline-block;
}

.fr-image-size-layer .fr-image-group .fr-input-line+.fr-input-line {
  margin-left: 10px;
}

.fr-uploading {
  -webkit-opacity: 0.4;
  -moz-opacity: 0.4;
  opacity: 0.4;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
}

@-webkit-keyframes loading {
  from {
    left: -25%;
  }

  to {
    left: 100%;
  }
}

@-moz-keyframes loading {
  from {
    left: -25%;
  }

  to {
    left: 100%;
  }
}

@-o-keyframes loading {
  from {
    left: -25%;
  }

  to {
    left: 100%;
  }
}

@keyframes loading {
  from {
    left: -25%;
  }

  to {
    left: 100%;
  }
}

.amis-scope .clearfix::after {
  clear: both;
  display: block;
  content: "";
  height: 0;
}

.amis-scope .hide-by-clipping {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0;
}

.fr-modal .fr-modal-head .fr-modal-head-line::after {
  clear: both;
  display: block;
  content: "";
  height: 0;
}

.fr-modal .fr-modal-head .fr-modal-head-line .fr-modal-more {
  margin-top: 10px;
}

.fr-modal .fr-modal-head .fr-modal-head-line .fr-modal-more.fr-not-available {
  opacity: 0;
  width: 0;
  padding: 12px 0;
}

.fr-modal .fr-modal-head .fr-modal-tags {
  padding: 0 20px;
  display: none;
  text-align: left;
}

.fr-modal .fr-modal-head .fr-modal-tags a {
  display: inline-block;
  opacity: 0;
  padding: 6px 12px;
  margin: 8px 0 8px 8px;
  text-decoration: none;
  border-radius: 32px;
  -moz-border-radius: 32px;
  -webkit-border-radius: 32px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  -webkit-transition: opacity 0.2s ease 0s, background 0.2s ease 0s;
  -moz-transition: opacity 0.2s ease 0s, background 0.2s ease 0s;
  -ms-transition: opacity 0.2s ease 0s, background 0.2s ease 0s;
  -o-transition: opacity 0.2s ease 0s, background 0.2s ease 0s;
  cursor: pointer;
  background-color: #f5f5f5;
}

.fr-modal .fr-modal-head .fr-modal-tags a:focus {
  outline: none;
  background-color: #ebebeb;
}

.fr-modal .fr-modal-head .fr-modal-tags a:hover {
  background-color: #ebebeb;
}

.fr-modal .fr-modal-head .fr-modal-tags a:active {
  background-color: #d6d6d6;
}

.fr-modal .fr-modal-head .fr-modal-tags a.fr-selected-tag {
  background-color: #EcF5Ff;
  color: #0098f7;
}

.fr-modal .fr-modal-head .fr-modal-tags a.fr-selected-tag:focus {
  outline: none;
  background-color: #ebebeb;
}

.fr-modal .fr-modal-head .fr-modal-tags a.fr-selected-tag:hover {
  background-color: #ebebeb;
}

.fr-modal .fr-modal-head .fr-modal-tags a.fr-selected-tag:active {
  background-color: #d6d6d6;
}

.fr-show-tags .fr-modal-more svg path {
  fill: #0098f7;
}

.amis-scope div.fr-modal-body {
  -webkit-transition: background 0.2s ease 0s;
  -moz-transition: background 0.2s ease 0s;
  -ms-transition: background 0.2s ease 0s;
  -o-transition: background 0.2s ease 0s;
}

.amis-scope div.fr-modal-body .fr-preloader {
  display: block;
  margin: 50px auto;
}

.amis-scope div.fr-modal-body div.fr-image-list {
  text-align: center;
  margin: 0 20px;
  padding: 0;
}

.amis-scope div.fr-modal-body div.fr-image-list .fr-list-column {
  float: left;
  width: calc((100% - 20px) / 2);
}

@media (min-width: 768px) and (max-width: 1199px) {
  .amis-scope div.fr-modal-body div.fr-image-list .fr-list-column {
    width: calc((100% - 40px) / 3);
  }
}

@media (min-width: 1200px) {
  .amis-scope div.fr-modal-body div.fr-image-list .fr-list-column {
    width: calc((100% - 60px) / 4);
  }
}

.amis-scope div.fr-modal-body div.fr-image-list .fr-list-column+.fr-list-column {
  margin-left: 20px;
}

.amis-scope div.fr-modal-body div.fr-image-list div.fr-image-container {
  position: relative;
  width: 100%;
  display: block;
  border-radius: 2px;
  -moz-border-radius: 2px;
  -webkit-border-radius: 2px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  overflow: hidden;
}

.amis-scope div.fr-modal-body div.fr-image-list div.fr-image-container:first-child {
  margin-top: 20px;
}

.amis-scope div.fr-modal-body div.fr-image-list div.fr-image-container+div {
  margin-top: 20px;
}

.amis-scope div.fr-modal-body div.fr-image-list div.fr-image-container.fr-image-deleting::after {
  position: absolute;
  -webkit-opacity: 0.5;
  -moz-opacity: 0.5;
  opacity: 0.5;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
  -webkit-transition: opacity 0.2s ease 0s;
  -moz-transition: opacity 0.2s ease 0s;
  -ms-transition: opacity 0.2s ease 0s;
  -o-transition: opacity 0.2s ease 0s;
  background: #000;
  content: "";
  top: 0;
  left: 0;
  bottom: 0;
  right: 0;
  z-index: 2;
}

.amis-scope div.fr-modal-body div.fr-image-list div.fr-image-container.fr-image-deleting::before {
  content: attr(data-deleting);
  color: #FFF;
  top: 0;
  left: 0;
  bottom: 0;
  right: 0;
  margin: auto;
  position: absolute;
  z-index: 3;
  font-size: 15px;
  height: 20px;
}

.amis-scope div.fr-modal-body div.fr-image-list div.fr-image-container.fr-empty {
  height: 95px;
  background: #CCCCCC;
  z-index: 1;
}

.amis-scope div.fr-modal-body div.fr-image-list div.fr-image-container.fr-empty::after {
  position: absolute;
  margin: auto;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
  content: attr(data-loading);
  display: inline-block;
  height: 20px;
}

.amis-scope div.fr-modal-body div.fr-image-list div.fr-image-container img {
  width: 100%;
  vertical-align: middle;
  position: relative;
  z-index: 2;
  -webkit-opacity: 1;
  -moz-opacity: 1;
  opacity: 1;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
  -webkit-transition: opacity 0.2s ease 0s, filter 0.2s ease 0s;
  -moz-transition: opacity 0.2s ease 0s, filter 0.2s ease 0s;
  -ms-transition: opacity 0.2s ease 0s, filter 0.2s ease 0s;
  -o-transition: opacity 0.2s ease 0s, filter 0.2s ease 0s;
  -webkit-transform: translateZ(0);
  -moz-transform: translateZ(0);
  -ms-transform: translateZ(0);
  -o-transform: translateZ(0);
}

.amis-scope div.fr-modal-body div.fr-image-list div.fr-image-container.fr-mobile-selected img {
  -webkit-opacity: 0.75;
  -moz-opacity: 0.75;
  opacity: 0.75;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
}

.amis-scope div.fr-modal-body div.fr-image-list div.fr-image-container.fr-mobile-selected .fr-delete-img,
.amis-scope div.fr-modal-body div.fr-image-list div.fr-image-container.fr-mobile-selected .fr-insert-img {
  display: inline-block;
}

.amis-scope div.fr-modal-body div.fr-image-list div.fr-image-container .fr-delete-img,
.amis-scope div.fr-modal-body div.fr-image-list div.fr-image-container .fr-insert-img {
  display: none;
  top: 50%;
  border-radius: 100%;
  -moz-border-radius: 100%;
  -webkit-border-radius: 100%;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  -webkit-transition: background 0.2s ease 0s, color 0.2s ease 0s;
  -moz-transition: background 0.2s ease 0s, color 0.2s ease 0s;
  -ms-transition: background 0.2s ease 0s, color 0.2s ease 0s;
  -o-transition: background 0.2s ease 0s, color 0.2s ease 0s;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  position: absolute;
  cursor: pointer;
  margin: 0;
  line-height: 40px;
  text-decoration: none;
  z-index: 3;
}

.amis-scope div.fr-modal-body div.fr-image-list div.fr-image-container .fr-delete-img {
  background: #B8312F;
  fill: #FFF;
  padding: 8px;
  left: 50%;
  -webkit-transform: translateY(-50%) translateX(25%);
  -moz-transform: translateY(-50%) translateX(25%);
  -ms-transform: translateY(-50%) translateX(25%);
  -o-transform: translateY(-50%) translateX(25%);
}

.amis-scope div.fr-modal-body div.fr-image-list div.fr-image-container .fr-insert-img {
  background: #FFF;
  fill: #0098f7;
  padding: 8px;
  left: 50%;
  -webkit-transform: translateY(-50%) translateX(-125%);
  -moz-transform: translateY(-50%) translateX(-125%);
  -ms-transform: translateY(-50%) translateX(-125%);
  -o-transform: translateY(-50%) translateX(-125%);
}

.fr-desktop .fr-modal-wrapper div.fr-modal-body div.fr-image-list div.fr-image-container:hover img {
  -webkit-opacity: 0.75;
  -moz-opacity: 0.75;
  opacity: 0.75;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
}

.fr-desktop .fr-modal-wrapper div.fr-modal-body div.fr-image-list div.fr-image-container:hover .fr-delete-img,
.fr-desktop .fr-modal-wrapper div.fr-modal-body div.fr-image-list div.fr-image-container:hover .fr-insert-img {
  display: inline-block;
  width: 40px;
  height: 40px;
}

.fr-desktop .fr-modal-wrapper div.fr-modal-body div.fr-image-list div.fr-image-container .fr-delete-img:hover {
  background: #bf4644;
  color: #FFF;
}

.fr-desktop .fr-modal-wrapper div.fr-modal-body div.fr-image-list div.fr-image-container .fr-insert-img:hover {
  background: #ebebeb;
}

.amis-scope .clearfix::after {
  clear: both;
  display: block;
  content: "";
  height: 0;
}

.amis-scope .hide-by-clipping {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0;
}

.fr-line-breaker {
  cursor: text;
  border-top: 1px solid #0098f7;
  position: fixed;
  z-index: 2;
  display: none;
}

.fr-line-breaker.fr-visible {
  display: block;
}

.fr-line-breaker a.fr-floating-btn {
  position: absolute;
  left: calc(50% - (40px / 2));
  top: -20px;
}

.fr-line-breaker a.fr-floating-btn svg {
  margin: 8px;
  height: 24px;
  width: 24px;
}

.amis-scope .clearfix::after {
  clear: both;
  display: block;
  content: "";
  height: 0;
}

.amis-scope .hide-by-clipping {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0;
}

.fr-quick-insert {
  position: absolute;
  z-index: 2147483639;
  white-space: nowrap;
  padding-right: 10px;
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  box-sizing: content-box;
}

.fr-quick-insert a.fr-floating-btn svg {
  margin: 8px;
  width: 24px;
  height: 24px;
}

.fr-quick-insert.fr-on a.fr-floating-btn svg {
  -webkit-transform: rotate(135deg);
  -moz-transform: rotate(135deg);
  -ms-transform: rotate(135deg);
  -o-transform: rotate(135deg);
}

.fr-quick-insert.fr-hidden {
  display: none;
}

.fr-qi-helper {
  position: absolute;
  z-index: 3;
  padding-left: 20px;
  white-space: nowrap;
}

.fr-qi-helper a.fr-btn.fr-floating-btn {
  text-align: center;
  padding: 6px 10px 10px 10px;
  display: inline-block;
  color: #222222;
  background: #FFF;
  -webkit-opacity: 0;
  -moz-opacity: 0;
  opacity: 0;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
  -webkit-transform: scale(0);
  -moz-transform: scale(0);
  -ms-transform: scale(0);
  -o-transform: scale(0);
}

.fr-qi-helper a.fr-btn.fr-floating-btn svg {
  fill: #222222;
}

.fr-qi-helper a.fr-btn.fr-floating-btn.fr-size-1 {
  -webkit-opacity: 1;
  -moz-opacity: 1;
  opacity: 1;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
  -webkit-transform: scale(1);
  -moz-transform: scale(1);
  -ms-transform: scale(1);
  -o-transform: scale(1);
}

.amis-scope .clearfix::after {
  clear: both;
  display: block;
  content: "";
  height: 0;
}

.amis-scope .hide-by-clipping {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0;
}

.fr-popup .fr-buttons.fr-tabs .fr-special-character-category {
  padding: 10px 15px;
}

.fr-popup .fr-buttons.fr-tabs .fr-special-character-category span {
  font-weight: normal;
  font-size: 16px;
}

.fr-popup .fr-special-character {
  width: 24px;
  height: 24px;
}

@media screen and (-ms-high-contrast: active) and (min-width: 768px), (-ms-high-contrast: none) and (min-width: 768px) {
  .fr-popup .fr-icon-container.fr-sc-container {
    width: 368px;
  }
}

.amis-scope .clearfix::after {
  clear: both;
  display: block;
  content: "";
  height: 0;
}

.amis-scope .hide-by-clipping {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0;
}

.fr-element table td.fr-selected-cell,
.fr-element table th.fr-selected-cell {
  border: 1px double #0098f7;
}

.fr-element table tr {
  user-select: none;
  -o-user-select: none;
  -moz-user-select: none;
  -khtml-user-select: none;
  -webkit-user-select: none;
  -ms-user-select: none;
}

.fr-element table td,
.fr-element table th {
  user-select: text;
  -o-user-select: text;
  -moz-user-select: text;
  -khtml-user-select: text;
  -webkit-user-select: text;
  -ms-user-select: text;
}

.fr-element .fr-no-selection table td,
.fr-element .fr-no-selection table th {
  user-select: none;
  -o-user-select: none;
  -moz-user-select: none;
  -khtml-user-select: none;
  -webkit-user-select: none;
  -ms-user-select: none;
}

.fr-table-resizer {
  cursor: col-resize;
  position: absolute;
  z-index: 3;
  display: none;
}

.fr-table-resizer.fr-moving {
  z-index: 2;
}

.fr-table-resizer div {
  -webkit-opacity: 0;
  -moz-opacity: 0;
  opacity: 0;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
  border-right: 1px solid #0098f7;
}

.fr-no-selection {
  user-select: none;
  -o-user-select: none;
  -moz-user-select: none;
  -khtml-user-select: none;
  -webkit-user-select: none;
  -ms-user-select: none;
}

.fr-popup .fr-table-size {
  margin: 20px;
}

.fr-popup .fr-table-size .fr-table-size-info {
  text-align: center;
  font-size: 14px;
}

.fr-popup .fr-table-size .fr-select-table-size {
  line-height: 0;
  padding: 5px;
  white-space: nowrap;
}

.fr-popup .fr-table-size .fr-select-table-size>span {
  display: inline-block;
  padding: 0 4px 4px 0;
  background: transparent;
}

.fr-popup .fr-table-size .fr-select-table-size>span>span {
  display: inline-block;
  width: 18px;
  height: 18px;
  border: 1px solid #DDD;
}

.fr-popup .fr-table-size .fr-select-table-size>span.hover {
  background: transparent;
}

.fr-popup .fr-table-size .fr-select-table-size>span.hover>span {
  background: rgba(0,152,247,0.3);
  border: solid 1px #0098f7;
}

.fr-popup .fr-table-size .fr-select-table-size .new-line::after {
  clear: both;
  display: block;
  content: "";
  height: 0;
}

.fr-popup.fr-above .fr-table-size .fr-select-table-size>span {
  display: inline-block !important;
}

.fr-popup .fr-table-colors {
  display: block;
  padding: 20px;
  padding-bottom: 0;
}

.fr-popup.fr-desktop .fr-table-size .fr-select-table-size>span>span {
  width: 12px;
  height: 12px;
}

.fr-insert-helper {
  position: absolute;
  z-index: 9999;
  white-space: nowrap;
}

.amis-scope .clearfix::after {
  clear: both;
  display: block;
  content: "";
  height: 0;
}

.amis-scope .hide-by-clipping {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0;
}

.fr-element .fr-video {
  user-select: none;
  -o-user-select: none;
  -moz-user-select: none;
  -khtml-user-select: none;
  -webkit-user-select: none;
  -ms-user-select: none;
}

.fr-element .fr-video::after {
  position: absolute;
  content: '';
  z-index: 1;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  cursor: pointer;
  display: block;
  background: transparent;
}

.fr-element .fr-video.fr-active>* {
  z-index: 2;
  position: relative;
}

.fr-element .fr-video>* {
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  box-sizing: content-box;
  max-width: 100%;
  border: none;
}

.fr-box .fr-video-resizer {
  position: absolute;
  border: solid 1px #0098f7;
  display: none;
  user-select: none;
  -o-user-select: none;
  -moz-user-select: none;
  -khtml-user-select: none;
  -webkit-user-select: none;
  -ms-user-select: none;
}

.fr-box .fr-video-resizer.fr-active {
  display: block;
}

.fr-box .fr-video-resizer .fr-handler {
  display: block;
  position: absolute;
  background: #0098f7;
  border: solid 1px #FFF;
  z-index: 4;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}

.fr-box .fr-video-resizer .fr-handler.fr-hnw {
  cursor: nw-resize;
}

.fr-box .fr-video-resizer .fr-handler.fr-hne {
  cursor: ne-resize;
}

.fr-box .fr-video-resizer .fr-handler.fr-hsw {
  cursor: sw-resize;
}

.fr-box .fr-video-resizer .fr-handler.fr-hse {
  cursor: se-resize;
}

.fr-box .fr-video-resizer .fr-handler {
  width: 12px;
  height: 12px;
}

.fr-box .fr-video-resizer .fr-handler.fr-hnw {
  left: -6px;
  top: -6px;
}

.fr-box .fr-video-resizer .fr-handler.fr-hne {
  right: -6px;
  top: -6px;
}

.fr-box .fr-video-resizer .fr-handler.fr-hsw {
  left: -6px;
  bottom: -6px;
}

.fr-box .fr-video-resizer .fr-handler.fr-hse {
  right: -6px;
  bottom: -6px;
}

@media (min-width: 1200px) {
  .fr-box .fr-video-resizer .fr-handler {
    width: 10px;
    height: 10px;
  }

  .fr-box .fr-video-resizer .fr-handler.fr-hnw {
    left: -5px;
    top: -5px;
  }

  .fr-box .fr-video-resizer .fr-handler.fr-hne {
    right: -5px;
    top: -5px;
  }

  .fr-box .fr-video-resizer .fr-handler.fr-hsw {
    left: -5px;
    bottom: -5px;
  }

  .fr-box .fr-video-resizer .fr-handler.fr-hse {
    right: -5px;
    bottom: -5px;
  }
}

.fr-popup .fr-video-size-layer .fr-video-group .fr-input-line {
  width: calc(50% - 5px);
  display: inline-block;
}

.fr-popup .fr-video-size-layer .fr-video-group .fr-input-line+.fr-input-line {
  margin-left: 10px;
}

.fr-popup .fr-video-upload-layer {
  border: dashed 2px #bdbdbd;
  padding: 25px 0;
  margin: 20px;
  position: relative;
  font-size: 14px;
  letter-spacing: 1px;
  line-height: 140%;
  text-align: center;
}

.fr-popup .fr-video-upload-layer:hover {
  background: #ebebeb;
}

.fr-popup .fr-video-upload-layer.fr-drop {
  background: #ebebeb;
  border-color: #0098f7;
}

.fr-popup .fr-video-upload-layer .fr-form {
  -webkit-opacity: 0;
  -moz-opacity: 0;
  opacity: 0;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
  z-index: 2147483640;
  overflow: hidden;
  margin: 0 !important;
  padding: 0 !important;
  width: 100% !important;
}

.fr-popup .fr-video-upload-layer .fr-form input {
  cursor: pointer;
  position: absolute;
  right: 0;
  top: 0;
  bottom: 0;
  width: 500%;
  height: 100%;
  margin: 0;
  font-size: 400px;
}

.fr-popup .fr-video-progress-bar-layer>h3 {
  font-size: 16px;
  margin: 10px 0;
  font-weight: normal;
}

.fr-popup .fr-video-progress-bar-layer>div.fr-action-buttons {
  display: none;
}

.fr-popup .fr-video-progress-bar-layer>div.fr-loader {
  background: #b3e0fd;
  height: 10px;
  width: 100%;
  margin-top: 20px;
  overflow: hidden;
  position: relative;
}

.fr-popup .fr-video-progress-bar-layer>div.fr-loader span {
  display: block;
  height: 100%;
  width: 0%;
  background: #0098f7;
  -webkit-transition: width 0.2s ease 0s;
  -moz-transition: width 0.2s ease 0s;
  -ms-transition: width 0.2s ease 0s;
  -o-transition: width 0.2s ease 0s;
}

.fr-popup .fr-video-progress-bar-layer>div.fr-loader.fr-indeterminate span {
  width: 30% !important;
  position: absolute;
  top: 0;
  -webkit-animation: loading 2s linear infinite;
  -moz-animation: loading 2s linear infinite;
  -o-animation: loading 2s linear infinite;
  animation: loading 2s linear infinite;
}

.fr-popup .fr-video-progress-bar-layer.fr-error>div.fr-loader {
  display: none;
}

.fr-popup .fr-video-progress-bar-layer.fr-error>div.fr-action-buttons {
  display: block;
}

.fr-video-overlay {
  position: fixed;
  top: 0;
  left: 0;
  bottom: 0;
  right: 0;
  z-index: 2147483640;
  display: none;
}

.amis-scope .clearfix::after {
  clear: both;
  display: block;
  content: "";
  height: 0;
}

.amis-scope .hide-by-clipping {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0;
}

.amis-scope img.fr-rounded,
.fr-img-caption.fr-rounded img {
  border-radius: 10px;
  -moz-border-radius: 10px;
  -webkit-border-radius: 10px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}

.amis-scope img.fr-bordered,
.fr-img-caption.fr-bordered img {
  border: solid 5px #CCC;
}

.amis-scope img.fr-bordered {
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  box-sizing: content-box;
}

.fr-img-caption.fr-bordered img {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}

.fr-view {
  word-wrap: break-word;
}

.fr-view span[style~="color:"] a {
  color: inherit;
}

.fr-view strong {
  font-weight: 700;
}

.fr-view table {
  border: none;
  border-collapse: collapse;
  empty-cells: show;
  max-width: 100%;
}

.fr-view table td {
  min-width: 5px;
}

.fr-view table.fr-dashed-borders td,
.fr-view table.fr-dashed-borders th {
  border-style: dashed;
}

.fr-view table.fr-alternate-rows tbody tr:nth-child(2n) {
  background: whitesmoke;
}

.fr-view table td,
.fr-view table th {
  border: 1px solid #DDD;
}

.fr-view table td:empty,
.fr-view table th:empty {
  height: 20px;
}

.fr-view table td.fr-highlighted,
.fr-view table th.fr-highlighted {
  border: 1px double red;
}

.fr-view table td.fr-thick,
.fr-view table th.fr-thick {
  border-width: 2px;
}

.fr-view table th {
  background: #ececec;
}

.fr-view hr {
  clear: both;
  user-select: none;
  -o-user-select: none;
  -moz-user-select: none;
  -khtml-user-select: none;
  -webkit-user-select: none;
  -ms-user-select: none;
  break-after: always;
  page-break-after: always;
}

.fr-view .fr-file {
  position: relative;
}

.fr-view .fr-file::after {
  position: relative;
  content: "\1F4CE";
  font-weight: normal;
}

.fr-view pre {
  white-space: pre-wrap;
  word-wrap: break-word;
  overflow: visible;
}

.fr-view[dir="rtl"] blockquote {
  border-left: none;
  border-right: solid 2px #5E35B1;
  margin-right: 0;
  padding-right: 5px;
  padding-left: 0;
}

.fr-view[dir="rtl"] blockquote blockquote {
  border-color: #00BCD4;
}

.fr-view[dir="rtl"] blockquote blockquote blockquote {
  border-color: #43A047;
}

.fr-view blockquote {
  border-left: solid 2px #5E35B1;
  margin-left: 0;
  padding-left: 5px;
  color: #5E35B1;
}

.fr-view blockquote blockquote {
  border-color: #00BCD4;
  color: #00BCD4;
}

.fr-view blockquote blockquote blockquote {
  border-color: #43A047;
  color: #43A047;
}

.fr-view span.fr-emoticon {
  font-weight: normal;
  font-family: "Apple Color Emoji","Segoe UI Emoji","NotoColorEmoji","Segoe UI Symbol","Android Emoji","EmojiSymbols";
  display: inline;
  line-height: 0;
}

.fr-view span.fr-emoticon.fr-emoticon-img {
  background-repeat: no-repeat !important;
  font-size: inherit;
  height: 1em;
  width: 1em;
  min-height: 20px;
  min-width: 20px;
  display: inline-block;
  margin: -.1em .1em .1em;
  line-height: 1;
  vertical-align: middle;
}

.fr-view .fr-text-gray {
  color: #AAA !important;
}

.fr-view .fr-text-bordered {
  border-top: solid 1px #222;
  border-bottom: solid 1px #222;
  padding: 10px 0;
}

.fr-view .fr-text-spaced {
  letter-spacing: 1px;
}

.fr-view .fr-text-uppercase {
  text-transform: uppercase;
}

.fr-view .fr-class-highlighted {
  background-color: #ffff00;
}

.fr-view .fr-class-code {
  border-color: #cccccc;
  border-radius: 2px;
  -moz-border-radius: 2px;
  -webkit-border-radius: 2px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  background: #f5f5f5;
  padding: 10px;
  font-family: "Courier New", Courier, monospace;
}

.fr-view .fr-class-transparency {
  opacity: 0.5;
}

.fr-view img {
  position: relative;
  max-width: 100%;
}

.fr-view img.fr-dib {
  margin: 5px auto;
  display: block;
  float: none;
  vertical-align: top;
}

.fr-view img.fr-dib.fr-fil {
  margin-left: 0;
  text-align: left;
}

.fr-view img.fr-dib.fr-fir {
  margin-right: 0;
  text-align: right;
}

.fr-view img.fr-dii {
  display: inline-block;
  float: none;
  vertical-align: bottom;
  margin-left: 5px;
  margin-right: 5px;
  max-width: calc(100% - (2 * 5px));
}

.fr-view img.fr-dii.fr-fil {
  float: left;
  margin: 5px 5px 5px 0;
  max-width: calc(100% - 5px);
}

.fr-view img.fr-dii.fr-fir {
  float: right;
  margin: 5px 0 5px 5px;
  max-width: calc(100% - 5px);
}

.fr-view span.fr-img-caption {
  position: relative;
  max-width: 100%;
}

.fr-view span.fr-img-caption.fr-dib {
  margin: 5px auto;
  display: block;
  float: none;
  vertical-align: top;
}

.fr-view span.fr-img-caption.fr-dib.fr-fil {
  margin-left: 0;
  text-align: left;
}

.fr-view span.fr-img-caption.fr-dib.fr-fir {
  margin-right: 0;
  text-align: right;
}

.fr-view span.fr-img-caption.fr-dii {
  display: inline-block;
  float: none;
  vertical-align: bottom;
  margin-left: 5px;
  margin-right: 5px;
  max-width: calc(100% - (2 * 5px));
}

.fr-view span.fr-img-caption.fr-dii.fr-fil {
  float: left;
  margin: 5px 5px 5px 0;
  max-width: calc(100% - 5px);
}

.fr-view span.fr-img-caption.fr-dii.fr-fir {
  float: right;
  margin: 5px 0 5px 5px;
  max-width: calc(100% - 5px);
}

.fr-view .fr-video {
  text-align: center;
  position: relative;
}

.fr-view .fr-video.fr-rv {
  padding-bottom: 56.25%;
  padding-top: 30px;
  height: 0;
  overflow: hidden;
}

.fr-view .fr-video.fr-rv>iframe,
.fr-view .fr-video.fr-rv object,
.fr-view .fr-video.fr-rv embed {
  position: absolute !important;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
}

.fr-view .fr-video>* {
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  box-sizing: content-box;
  max-width: 100%;
  border: none;
}

.fr-view .fr-video.fr-dvb {
  display: block;
  clear: both;
}

.fr-view .fr-video.fr-dvb.fr-fvl {
  text-align: left;
}

.fr-view .fr-video.fr-dvb.fr-fvr {
  text-align: right;
}

.fr-view .fr-video.fr-dvi {
  display: inline-block;
}

.fr-view .fr-video.fr-dvi.fr-fvl {
  float: left;
}

.fr-view .fr-video.fr-dvi.fr-fvr {
  float: right;
}

.fr-view a.fr-strong {
  font-weight: 700;
}

.fr-view a.fr-green {
  color: green;
}

.fr-view .fr-img-caption {
  text-align: center;
}

.fr-view .fr-img-caption .fr-img-wrap {
  padding: 0;
  margin: auto;
  text-align: center;
  width: 100%;
}

.fr-view .fr-img-caption .fr-img-wrap img {
  display: block;
  margin: auto;
  width: 100%;
}

.fr-view .fr-img-caption .fr-img-wrap>span {
  margin: auto;
  display: block;
  padding: 5px 5px 10px;
  font-size: 14px;
  font-weight: initial;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-opacity: 0.9;
  -moz-opacity: 0.9;
  opacity: 0.9;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
  width: 100%;
  text-align: center;
}

.fr-view button.fr-rounded,
.fr-view input.fr-rounded,
.fr-view textarea.fr-rounded {
  border-radius: 10px;
  -moz-border-radius: 10px;
  -webkit-border-radius: 10px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}

.fr-view button.fr-large,
.fr-view input.fr-large,
.fr-view textarea.fr-large {
  font-size: 24px;
}

.amis-scope a.fr-view.fr-strong {
  font-weight: 700;
}

.amis-scope a.fr-view.fr-green {
  color: green;
}

.amis-scope img.fr-view {
  position: relative;
  max-width: 100%;
}

.amis-scope img.fr-view.fr-dib {
  margin: 5px auto;
  display: block;
  float: none;
  vertical-align: top;
}

.amis-scope img.fr-view.fr-dib.fr-fil {
  margin-left: 0;
  text-align: left;
}

.amis-scope img.fr-view.fr-dib.fr-fir {
  margin-right: 0;
  text-align: right;
}

.amis-scope img.fr-view.fr-dii {
  display: inline-block;
  float: none;
  vertical-align: bottom;
  margin-left: 5px;
  margin-right: 5px;
  max-width: calc(100% - (2 * 5px));
}

.amis-scope img.fr-view.fr-dii.fr-fil {
  float: left;
  margin: 5px 5px 5px 0;
  max-width: calc(100% - 5px);
}

.amis-scope img.fr-view.fr-dii.fr-fir {
  float: right;
  margin: 5px 0 5px 5px;
  max-width: calc(100% - 5px);
}

.amis-scope span.fr-img-caption.fr-view {
  position: relative;
  max-width: 100%;
}

.amis-scope span.fr-img-caption.fr-view.fr-dib {
  margin: 5px auto;
  display: block;
  float: none;
  vertical-align: top;
}

.amis-scope span.fr-img-caption.fr-view.fr-dib.fr-fil {
  margin-left: 0;
  text-align: left;
}

.amis-scope span.fr-img-caption.fr-view.fr-dib.fr-fir {
  margin-right: 0;
  text-align: right;
}

.amis-scope span.fr-img-caption.fr-view.fr-dii {
  display: inline-block;
  float: none;
  vertical-align: bottom;
  margin-left: 5px;
  margin-right: 5px;
  max-width: calc(100% - (2 * 5px));
}

.amis-scope span.fr-img-caption.fr-view.fr-dii.fr-fil {
  float: left;
  margin: 5px 5px 5px 0;
  max-width: calc(100% - 5px);
}

.amis-scope span.fr-img-caption.fr-view.fr-dii.fr-fir {
  float: right;
  margin: 5px 0 5px 5px;
  max-width: calc(100% - 5px);
}

@charset "UTF-8";

:root {
  --black: #1c2b36;
  --white: #fff;
  --primary: #7266ba;
  --primary-onHover: #5b4eac;
  --primary-onActive: #564aa3;
  --secondary: #6c757d;
  --secondary-onHover: #5a6268;
  --secondary-onActive: #545b62;
  --success: #27c24c;
  --success-onHover: #21a240;
  --success-onActive: #1e983b;
  --info: #23b7e5;
  --info-onHover: #18a0ca;
  --info-onActive: #1797be;
  --warning: #fad733;
  --warning-onHover: #f9d00e;
  --warning-onActive: #f4ca06;
  --danger: #f05050;
  --danger-onHover: #ed2d2d;
  --danger-onActive: #ec2121;
  --light: #edf1f2;
  --dark: #3a3f51;
  --fontFamilyMonospace: SFMono-Regular, Menlo, Monaco, Consolas,
    "Liberation Mono", "Courier New", monospace;
  --fontFamilyBase: -apple-system, BlinkMacSystemFont, "SF Pro SC",
    "SF Pro Text", "Helvetica Neue", Helvetica, "PingFang SC", "Segoe UI",
    Roboto, "Hiragino Sans GB", "Arial", "microsoft yahei ui", "Microsoft YaHei",
    SimSun, sans-serif;
  --fontSizeBase: 0.875rem;
  --fontSizeMd: 0.875rem;
  --fontSizeLg: 1rem;
  --fontSizeXl: 1.25rem;
  --fontSizeSm: 0.75rem;
  --fontSizeXs: 0.6875rem;
  --text-color: #58666e;
  --button-color: #fff;
  --animation-duration: 0.2s;
  --text--muted-color: #99a6ad;
  --text--loud-color: #414c52;
  --pre-color: var(--text-color);
  --borderColor: #d1d5db;
  --borderColorLight: #dfe2e6;
  --borderColorDarken: #b4bbc5;
  --borderRadius: 0.142rem;
  --borderRadiusMd: 0.285rem;
  --borderRadiusLg: 0.428rem;
  --boxShadow: 0 0.5rem 1rem rgba(0, 0, 0, 0.15);
  --boxShadowSm: 0 0.125rem 0.25rem rgba(0, 0, 0, 0.075);
  --lineHeightBase: 1.5;
  --body-lineHeight: var(--lineHeightBase);
  --borderWidth: 0.0625rem;
  --fontWeightNormal: 400;
  --fontWeightBase: var(--fontWeightNormal);
  --fontWeightBold: 700;
  --background: var(--white);
  --code-color: var(--danger);
  --code-background: var(--background);
  --pre-background: var(--background);
  --link-color: var(--info);
  --link-decoration: none;
  --link-onHover-color: var(--info-onHover);
  --link-onHover-decoration: underline;
  --body-bg: var(--light);
  --body-size: var(--fontSizeBase);
  --body-color: var(--text-color);
  --body-weight: var(--fontWeightBase);
  --gap-xs: 0.25rem;
  --gap-sm: 0.5rem;
  --gap-base: 0.75rem;
  --gap-md: 1rem;
  --gap-lg: 1.25rem;
  --gap-xl: 1.5rem;
  --icon-color: #4b5563;
  --icon-onHover-color: #111827;
  --icon-onDisabled-color: #6b7280;
  --label--default-bg: #374151;
  --label--primary-bg: var(--primary);
  --label--success-bg: var(--success);
  --label--info-bg: var(--info);
  --label--warning-bg: var(--warning);
  --label--danger-bg: var(--danger);
  --label-color: #fff;
  --label-link--hover-color: #fff;
  --scrollbar-width: 1.0625rem;
  --Alert--danger-bg: #f2dede;
  --Alert--danger-borderColor: #ebccd1;
  --Alert--danger-color: #a94442;
  --Alert--info-bg: #d9edf7;
  --Alert--info-borderColor: #19c8d5;
  --Alert--info-color: #31708f;
  --Alert--success-bg: #dff0d8;
  --Alert--success-borderColor: #d6e9c6;
  --Alert--success-color: #3c763d;
  --Alert--warning-bg: #fcf8e3;
  --Alert--warning-borderColor: #faebcc;
  --Alert--warning-color: #8a6d3b;
  --Alert-borderColor: transparent;
  --Alert-borderRadius: var(--borderRadiusMd);
  --Alert-borderWidth: var(--borderWidth);
  --Alert-boxShadow: none;
  --Alert-fontSize: var(--fontSizeBase);
  --Alert-marginBottom: var(--gap-md);
  --Alert-paddingX: var(--gap-sm);
  --Alert-paddingY: var(--gap-sm);
  --Audio-border: 0.0625rem solid #dee2e6;
  --Audio-height: 3.125rem;
  --Audio-input-width: 5rem;
  --Audio-item-margin: 0.625rem;
  --Audio-lineHeight: 3.125rem;
  --Audio-play-top: var(--gap-xs);
  --Audio-play-width: var(--gap-md);
  --Audio-process-minWidth: 5rem;
  --Audio-rate-bg: #dee2e6;
  --Audio-rate-height: 3.125rem;
  --Audio-rate-lineHeight: 3.125rem;
  --Audio-rate-width: 2.5rem;
  --Audio-rateControlItem-bg: #dee2e6;
  --Audio-rateControlItem-borderRight: 0.0625rem solid #d3dae0;
  --Audio-svg-height: var(--gap-md);
  --Audio-svg-top: 0.375rem;
  --Audio-svg-width: var(--gap-md);
  --Audio-thumb-bg: #606670;
  --Audio-thumb-height: 0.875rem;
  --Audio-thumb-marginTop: -0.3125rem;
  --Audio-thumb-width: 0.875rem;
  --Audio-times-margin: 0 var(--gap-xs);
  --Audio-times-width: 4.6875rem;
  --Audio-track-bg: #d7dbdd;
  --Audio-track-border: 0.0625rem solid transparent;
  --Audio-track-borderRadius: 0.1875rem;
  --Audio-track-height: 0.375rem;
  --Audio-volume-height: 3.125rem;
  --Audio-volume-lineHeight: 3.125rem;
  --Audio-volume-width: var(--gap-md);
  --Audio-volumeControl-width: 6.875rem;
  --Avatar-bg: #d1d5db;
  --Avatar-width: 2.5rem;
  --Badge-size: var(--gap-md);
  --Badge-color: var(--white);
  --Button--danger-bg: var(--danger);
  --Button--danger-border: var(--Button--danger-bg);
  --Button--danger-color: var(--button-color);
  --Button--danger-onActive-bg: var(--danger-onActive);
  --Button--danger-onActive-border: #eb1515;
  --Button--danger-onActive-color: var(--Button--danger-color);
  --Button--danger-onHover-bg: var(--danger-onHover);
  --Button--danger-onHover-border: var(--danger-onActive);
  --Button--danger-onHover-color: var(--Button--danger-color);
  --Button--dark-bg: var(--dark);
  --Button--dark-border: var(--Button--dark-bg);
  --Button--dark-color: var(--button-color);
  --Button--dark-onActive-bg: #252833;
  --Button--dark-onActive-border: #1f222c;
  --Button--dark-onActive-color: var(--Button--dark-color);
  --Button--dark-onHover-bg: #2a2e3b;
  --Button--dark-onHover-border: #252833;
  --Button--dark-onHover-color: var(--Button--dark-color);
  --Button--default-bg: var(--white);
  --Button--default-border: var(--borderColor);
  --Button--default-color: var(--text-color);
  --Button--default-onActive-bg: #e6e6e6;
  --Button--default-onActive-border: #adb4bf;
  --Button--default-onActive-color: var(--Button--default-color);
  --Button--default-onHover-bg: #ececec;
  --Button--default-onHover-border: #b4bbc5;
  --Button--default-onHover-color: var(--Button--default-color);
  --Button--iconOnly-minWidthRate: 4 / 3;
  --Button--info-bg: var(--info);
  --Button--info-border: var(--Button--info-bg);
  --Button--info-color: var(--button-color);
  --Button--info-onActive-bg: var(--info-onActive);
  --Button--info-onActive-border: #158eb3;
  --Button--info-onActive-color: var(--Button--info-color);
  --Button--info-onHover-bg: var(--info-onHover);
  --Button--info-onHover-border: var(--info-onActive);
  --Button--info-onHover-color: var(--Button--info-color);
  --Button--lg-borderRadius: var(--borderRadius);
  --Button--lg-fontSize: var(--fontSizeLg);
  --Button--lg-height: 2.875rem;
  --Button--lg-lineHeight: 24 / 20;
  --Button--lg-paddingX: 1rem;
  --Button--lg-paddingY: calc(
    (
        var(--Button--lg-height) - var(--Button-borderWidth) * 2 -
          var(--Button--lg-lineHeight) * var(--Button--lg-fontSize)
      ) / 2
  );
  --Button--light-bg: var(--light);
  --Button--light-border: var(--borderColor);
  --Button--light-color: var(--text-color);
  --Button--light-onActive-bg: #cfdadd;
  --Button--light-onActive-border: #c8d4d7;
  --Button--light-onActive-color: var(--Button--light-color);
  --Button--light-onHover-bg: #d7e0e2;
  --Button--light-onHover-border: #cfdadd;
  --Button--light-onHover-color: var(--Button--light-color);
  --Button--link-color: var(--primary);
  --Button--link-onDisabled-color: #4b5563;
  --Button--link-onHover-color: var(--text--loud-color);
  --Button--md-fontSize: var(--Button-fontSize);
  --Button--md-height: var(--Button-height);
  --Button--md-lineHeight: var(--Button-lineHeight);
  --Button--md-paddingX: var(--Button-paddingX);
  --Button--md-paddingY: calc(
    (
        var(--Button--md-height) - var(--Button-borderWidth) * 2 -
          var(--Button--md-lineHeight) * var(--Button--md-fontSize)
      ) / 2
  );
  --Button--primary-bg: var(--primary);
  --Button--primary-border: var(--Button--primary-bg);
  --Button--primary-color: var(--button-color);
  --Button--primary-onActive-bg: var(--primary-onActive);
  --Button--primary-onActive-border: #52469b;
  --Button--primary-onActive-color: var(--Button--primary-color);
  --Button--primary-onHover-bg: var(--primary-onHover);
  --Button--primary-onHover-border: var(--primary-onActive);
  --Button--primary-onHover-color: var(--Button--primary-color);
  --Button--secondary-bg: var(--secondary);
  --Button--secondary-border: var(--Button--secondary-bg);
  --Button--secondary-color: var(--button-color);
  --Button--secondary-onActive-bg: var(--secondary-onActive);
  --Button--secondary-onActive-border: #4e555b;
  --Button--secondary-onActive-color: var(--Button--secondary-color);
  --Button--secondary-onHover-bg: var(--secondary-onHover);
  --Button--secondary-onHover-border: var(--secondary-onActive);
  --Button--secondary-onHover-color: var(--Button--secondary-color);
  --Button--sm-borderRadius: var(--borderRadius);
  --Button--sm-fontSize: var(--fontSizeSm);
  --Button--sm-height: 1.875rem;
  --Button--sm-lineHeight: 18 / 12;
  --Button--sm-paddingX: 0.5rem;
  --Button--sm-paddingY: calc(
    (
        var(--Button--sm-height) - var(--Button-borderWidth) * 2 -
          var(--Button--sm-lineHeight) * var(--Button--sm-fontSize)
      ) / 2
  );
  --Button--success-bg: var(--success);
  --Button--success-border: var(--Button--success-bg);
  --Button--success-color: var(--button-color);
  --Button--success-onActive-bg: var(--success-onActive);
  --Button--success-onActive-border: #1c8d37;
  --Button--success-onActive-color: var(--Button--success-color);
  --Button--success-onHover-bg: var(--success-onHover);
  --Button--success-onHover-border: var(--success-onActive);
  --Button--success-onHover-color: var(--Button--success-color);
  --Button--warning-bg: var(--warning);
  --Button--warning-border: var(--Button--warning-bg);
  --Button--warning-color: var(--button-color);
  --Button--warning-onActive-bg: var(--warning-onActive);
  --Button--warning-onActive-border: #e8c006;
  --Button--warning-onActive-color: var(--Button--warning-color);
  --Button--warning-onHover-bg: var(--warning-onHover);
  --Button--warning-onHover-border: var(--warning-onActive);
  --Button--warning-onHover-color: var(--Button--warning-color);
  --Button--xs-fontSize: var(--fontSizeXs);
  --Button--xs-height: 1.375rem;
  --Button--xs-lineHeight: 18 / 11;
  --Button--xs-paddingX: var(--gap-xs);
  --Button--xs-paddingY: calc(
    (
        var(--Button--xs-height) - var(--Button-borderWidth) * 2 -
          var(--Button--xs-lineHeight) * var(--Button--xs-fontSize)
      ) / 2
  );
  --Button-borderRadius: var(--borderRadius);
  --Button-borderWidth: var(--Form-input-borderWidth);
  --Button-boxShadow: inset 0 1px 0 rgba(255, 255, 255, 0.15),
    0 1px 1px rgba(0, 0, 0, 0.075);
  --Button-textShadow: none;
  --Button-fontSize: var(--Form-input-fontSize);
  --Button-fontWeight: var(--fontWeightNormal);
  --Button-height: var(--Form-input-height);
  --Button-lineHeight: var(--Form-input-lineHeight);
  --Button-mimWidth: auto;
  --Button-onActive-boxShadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
  --Button-onActive-color: var(--primary);
  --Button-onActive-border: var(--primary);
  --Button-onDisabled-borderColor: #dee2e6;
  --Button-onDisabled-opacity: 0.65;
  --Button-onFocus-boxShadow: none;
  --Button-paddingX: 0.75rem;
  --Button-paddingY: calc(
    (
        var(--Button-height) - var(--Button-borderWidth) * 2 -
          var(--Button-lineHeight) * var(--Button-fontSize)
      ) / 2
  );
  --Button-transition: color var(--animation-duration) ease-in-out,
    background-color var(--animation-duration) ease-in-out,
    border-color var(--animation-duration) ease-in-out,
    box-shadow var(--animation-duration) ease-in-out;
  --ButtonGroup--primary-isActive-color: var(--white);
  --ButtonGroup--primary-isActive-bg: var(--primary);
  --Calendar-btn-bg: var(--info);
  --Calendar-btn-border: var(--Calendar-btn-bg);
  --Calendar-btn-borderRadius: var(--Button-borderRadius);
  --Calendar-btn-color: var(--white);
  --Calendar-btn-fontSize: var(--fontSizeSm);
  --Calendar-btn-height: 1.875rem;
  --Calendar-btn-lineHeight: var(--lineHeightBase);
  --Calendar-btn-onActive-bg: #1797be;
  --Calendar-btn-onActive-border: #158eb3;
  --Calendar-btn-onActive-color: var(--Calendar-btn-color);
  --Calendar-btn-onHover-bg: #18a0ca;
  --Calendar-btn-onHover-border: #1797be;
  --Calendar-btn-onHover-color: var(--Calendar-btn-color);
  --Calendar-btn-paddingX: 0.625rem;
  --Calendar-btn-paddingY: calc(
    (
        var(--Calendar-btn-height) - var(--Calendar-btn-lineHeight) *
          var(--Calendar-btn-fontSize)
      ) / 2
  );
  --Calendar-btnCancel-bg: var(--light);
  --Calendar-btnCancel-border: var(--Button--default-border);
  --Calendar-btnCancel-borderRadius: var(--Button-borderRadius);
  --Calendar-btnCancel-color: var(--text-color);
  --Calendar-btnCancel-onActive-bg: var(--Button--default-onActive-bg);
  --Calendar-btnCancel-onActive-border: var(--Button--default-onActive-border);
  --Calendar-btnCancel-onActive-color: var(--Button--default-onActive-color);
  --Calendar-btnCancel-onHover-bg: var(--Button--default-onHover-bg);
  --Calendar-btnCancel-onHover-border: var(--Button--default-onHover-border);
  --Calendar-btnCancel-onHover-color: var(--Button--default-onHover-color);
  --Calendar-cell-bg: var(--white);
  --Calendar-cell-onActive-bg: var(--info);
  --Calendar-cell-onBetween-bg: rgba(35, 183, 229, 0.1);
  --Calendar-cell-onDisabled-bg: var(--light);
  --Calendar-cell-onHover-bg: #ededed;
  --Calendar-color: var(--text-color);
  --Calendar-fontSize: var(--fontSizeBase);
  --Calendar-input-borderColor: var(--borderColor);
  --Calendar-input-borderRadius: var(--borderRadius);
  --Calendar-input-color: var(--info);
  --Calendar-input-fontSize: var(--fontSizeBase);
  --Calendar-input-height: 1.875rem;
  --Calendar-input-lineHeight: var(--lineHeightBase);
  --Calendar-input-onFocused-borderColor: var(--info);
  --Calendar-input-paddingX: 0.625rem;
  --Calendar-input-paddingY: calc(
    (
        var(--Calendar-input-height) - var(--Calendar-input-lineHeight) *
          var(--Calendar-input-fontSize)
      ) / 2
  );
  --Calendar-shortcut-color: var(--info);
  --Calendar-shortcut-decoration: none;
  --Calendar-shortcut-onHover-color: #1485a8;
  --Calendar-shortcut-onHover-decoration: none;
  --Calendar-shortcuts-bg: transparent;
  --Calendar-shortcuts-height: 1.875rem;
  --Calendar-wLabel-color: #999;
  --Card-actions-borderColor: #dfe2e6;
  --Card-actions-fontSize: var(--fontSizeBase);
  --Card-actions-onChecked-onHover-bg: #c2ecf9;
  --Card-actions-onChecked-onHover-color: #1498c1;
  --Card-actions-onHover-bg: #f2f2f2;
  --Card-actions-onHover-color: #090d15;
  --Card-bg: var(--white);
  --Card-borderColor: var(--borderColor);
  --Card-borderRadius: var(--borderRadius);
  --Card-borderWidth: var(--borderWidth);
  --Card-onChecked-bg: #d9f3fb;
  --Card-onChecked-borderColor: #abe4f6;
  --Card-onChecked-color: #20b9e8;
  --Card-onChecked-fieldLabel-color: #7dd6f1;
  --Card-onDragging-opacity: 0.1;
  --Card-onModified-bg: #e8f0fe;
  --Card-onModified-borderColor: #b7d0fc;
  --Card-onModified-color: #4285f4;
  --Card-onModified-fieldLabel-color: #a2c3fa;
  --Card-onModified-onHover-bg: #d0e0fd;
  --Card-onModified-onHover-color: #1266f1;
  --Cards--unsaved-heading-bg: #e8f0fe;
  --Cards--unsaved-heading-color: #4285f4;
  --Cards-fixedTop-boxShadow: var(--boxShadow);
  --Cards-placeholder-height: 6.25rem;
  --Cards-toolbar-marginX: 0;
  --Cards-toolbar-marginY: var(--gap-base);
  --Carousel--dark-control: black;
  --Carousel--light-control: white;
  --Carousel-arrowControl-height: var(--gap-lg);
  --Carousel-arrowControl-width: var(--gap-lg);
  --Carousel-bg: #f6f8f8;
  --Carousel-dot-borderRadius: 0.25rem;
  --Carousel-dot-height: 0.5rem;
  --Carousel-dot-margin: 0.4375rem var(--gap-xs);
  --Carousel-dot-width: 0.5rem;
  --Carousel-height: 12.5rem;
  --Carousel-imageDescription-bottom: 1.5625rem;
  --Carousel-imageTitle-bottom: 2.8125rem;
  --Carousel-minWidth: 6.25rem;
  --Carousel-svg-height: var(--gap-lg);
  --Carousel-svg-width: var(--gap-lg);
  --Carousel-transitionDuration: var(--animation-duration);
  --Checkbox--full-inner-size: 0.75rem;
  --Checkbox--sm--full-inner-size: 0.625rem;
  --Checkbox--sm-inner-size: calc(var(--Checkbox--sm-size) / 2);
  --Checkbox--sm-size: 1rem;
  --Checkbox-borderRadius: var(--borderRadius);
  --Checkbox-color: var(--Form-input-borderColor);
  --Checkbox-gap: var(--gap-xs);
  --Checkbox-gb: #fff;
  --Checkbox-size: var(--Form-fontSize);
  --Checkbox-inner-size: calc(var(--Checkbox-size) / 2);
  --Checkbox-onHover-color: var(--info);
  --Checkbox-onDisabled-bg: #e5e7eb;
  --Checkbox-onDisabled-color: var(--text--muted-color);
  --ColorPicker-bg: var(--white);
  --ColorPicker-borderColor: var(--Form-input-borderColor);
  --ColorPicker-borderRadius: var(--Form-input-borderRadius);
  --ColorPicker-borderWidth: var(--Form-input-borderWidth);
  --ColorPicker-color: var(--Form-input-color);
  --ColorPicker-fontSize: var(--Form-input-fontSize);
  --ColorPicker-height: var(--Form-input-height);
  --ColorPicker-lineHeight: var(--Form-input-lineHeight);
  --ColorPicker-onDisabled-bg: #e5e7eb;
  --ColorPicker-onDisabled-color: var(--text--muted-color);
  --ColorPicker-onFocused-borderColor: var(--Form-input-onFocused-borderColor);
  --ColorPicker-onHover-bg: #f2f2f2;
  --ColorPicker-onHover-borderColor: var(--borderColor);
  --ColorPicker-paddingX: 0.75rem;
  --ColorPicker-paddingY: calc(
    (
        var(--ColorPicker-height) - var(--ColorPicker-lineHeight) *
          var(--ColorPicker-fontSize)
      ) / 2 - var(--ColorPicker-borderWidth)
  );
  --ColorPicker-placeholderColor: var(--Form-input-placeholderColor);
  --Combo--horizontal-dragger-top: var(--Form-label-paddingTop);
  --Combo--horizontal-item-gap: var(--gap-xs);
  --Combo--vertical-item-borderColor: var(--borderColor);
  --Combo--vertical-item-borderRadius: var(--borderRadius);
  --Combo--vertical-item-borderWidth: var(--borderWidth);
  --Combo--vertical-item-gap: var(--gap-xs);
  --Combo--vertical-item-onHover-borderColor: var(--info);
  --Combo--vertical-item-paddingX: 0.625rem;
  --Combo--vertical-item-paddingY: 0.625rem;
  --Combo-addBtn-bg: var(--Button--info-bg);
  --Combo-addBtn-border: var(--Button--info-border);
  --Combo-addBtn-borderRadius: var(--Button-borderRadius);
  --Combo-addBtn-color: var(--Button--info-color);
  --Combo-addBtn-fontSize: var(--Button--sm-fontSize);
  --Combo-addBtn-height: 1.625rem;
  --Combo-addBtn-lineHeight: var(--Button--sm-lineHeight);
  --Combo-addBtn-onActive-bg: #1797be;
  --Combo-addBtn-onActive-border: #adb4bf;
  --Combo-addBtn-onActive-color: var(--Combo-addBtn-color);
  --Combo-addBtn-onHover-bg: #18a0ca;
  --Combo-addBtn-onHover-border: #b4bbc5;
  --Combo-addBtn-onHover-color: var(--Combo-addBtn-color);
  --Combo-addBtn-paddingX: var(--Button--sm-paddingX);
  --Combo-addBtn-paddingY: calc(
    (
        var(--Combo-addBtn-height) - var(--Button-borderWidth) * 2 -
          var(--Combo-addBtn-lineHeight) * var(--Combo-addBtn-fontSize)
      ) / 2
  );
  --Combo-items-marginBottom: var(--gap-sm);
  --Combo-toolbarBtn-color: var(--icon-color);
  --Combo-toolbarBtn-height: var(--gap-md);
  --Combo-toolbarBtn-lineHeight: 1;
  --Combo-toolbarBtn-onHover-color: #353c46;
  --Combo-toolbarBtn-paddingX: var(--gap-xs);
  --Combo-toolbarBtn-paddingY: 0.125rem;
  --Copyable-iconColor: var(--icon-color);
  --Copyable-onHover-iconColor: var(--icon-onHover-color);
  --Crud-toolbar-gap: var(--gap-xs);
  --Crud-toolbar-height: 1.875rem;
  --Crud-toolbar-lineHeight: var(--lineHeightBase);
  --DatePicker-bg: var(--white);
  --DatePicker-borderColor: var(--Form-input-borderColor);
  --DatePicker-borderRadius: var(--Form-input-borderRadius);
  --DatePicker-borderWidth: var(--Form-input-borderWidth);
  --DatePicker-color: var(--Form-input-color);
  --DatePicker-fontSize: var(--Form-input-fontSize);
  --DatePicker-header-select-borderColor: #fff;
  --DatePicker-height: var(--Form-input-height);
  --DatePicker-iconColor: var(--icon-color);
  --DatePicker-lineHeight: var(--Form-input-lineHeight);
  --DatePicker-onFocused-borderColor: var(--Form-input-onFocused-borderColor);
  --DatePicker-onHover-bg: var(--DatePicker-bg);
  --DatePicker-onHover-borderColor: var(--Form-input-onFocused-borderColor);
  --DatePicker-onHover-iconColor: var(--icon-onHover-color);
  --DatePicker-paddingX: 0.75rem;
  --DatePicker-paddingY: calc(
    (
        var(--DatePicker-height) - var(--DatePicker-lineHeight) *
          var(--DatePicker-fontSize)
      ) / 2 - var(--DatePicker-borderWidth)
  );
  --DatePicker-placeholderColor: var(--Form-input-placeholderColor);
  --Divider-borderStyle: dashed;
  --Drawer-bg: var(--background);
  --Drawer-body-padding: var(--gap-base);
  --Drawer-close-color: rgba(255, 255, 255, 0.8);
  --Drawer-close-onHover-color: rgba(255, 255, 255, 1);
  --Drawer-content-borderColor: var(--borderColor);
  --Drawer-content-borderRadius: 0;
  --Drawer-content-borderWidth: var(--borderWidth);
  --Drawer-footer-borderColor: #dfe2e6;
  --Drawer-footer-padding: var(--gap-base);
  --Drawer-header-bg: #f9f9f9;
  --Drawer-header-borderColor: #dfe2e6;
  --Drawer-header-padding: var(--gap-base);
  --Drawer-overlay-bg: rgba(0, 0, 0, 0.6);
  --Drawer-title-fontColor: var(--text--loud-color);
  --Drawer-title-fontSize: var(--fontSizeMd);
  --Drawer-widthBase: 80%;
  --Drawer-widthLg: 50rem;
  --Drawer-widthMd: 31.25rem;
  --Drawer-widthSm: 18.75rem;
  --Drawer-widthXl: 90%;
  --Drawer-widthXs: 12.5rem;
  --DropDown-caret-marginLeft: var(--gap-sm);
  --DropDown-menu-bg: var(--white);
  --DropDown-menu-borderColor: var(--borderColor);
  --DropDown-menu-borderRadius: var(--borderRadius);
  --DropDown-menu-borderWidth: var(--borderWidth);
  --DropDown-menu-boxShadow: var(--boxShadow);
  --DropDown-menu-height: 2.125rem;
  --DropDown-menu-minWidth: 10rem;
  --DropDown-menu-paddingX: 0;
  --DropDown-menu-paddingY: var(--gap-xs);
  --DropDown-menuItem-onHover-bg: var(--ListMenu-item--onHover-bg);
  --DropDown-menuItem-onHover-color: inherit;
  --DropDown-menuItem-onActive-color: var(--info);
  --DropDown-menuItem-onDisabled-color: var(--text--muted-color);
  --DropDown-menuItem-paddingX: var(--gap-sm);
  --DropDown-menuItem-paddingY: calc(
    (var(--DropDown-menu-height) - var(--fontSizeBase) * var(--lineHeightBase)) /
      2
  );
  --Fieldset-legend-bgColor: var(--white);
  --Form--horizontal-gutterWidth: var(--gap-md);
  --Form--horizontal-label-align: right;
  --Form--horizontal-label-whiteSpace: "normal";
  --Form--horizontal-label-widthBase: 7.5rem;
  --Form--horizontal-label-widthLg: 12.5rem;
  --Form--horizontal-label-widthMd: 10rem;
  --Form--horizontal-label-widthSm: 5.625rem;
  --Form--horizontal-label-widthXs: 3.75rem;
  --Form-control-widthBase: 12.5rem;
  --Form-control-widthLg: 20rem;
  --Form-control-widthMd: 15rem;
  --Form-control-widthSm: 10rem;
  --Form-control-widthXs: 5rem;
  --Form-description-color: #6f808a;
  --Form-description-fontSize: var(--fontSizeSm);
  --Form-fontSize: var(--fontSizeBase);
  --Form-group--lg-gutterWidth: 2.5rem;
  --Form-group--md-gutterWidth: 1.875rem;
  --Form-group--sm-gutterWidth: var(--gap-md);
  --Form-group--xs-gutterWidth: 0.625rem;
  --Form-group-gutterWidth: var(--Form--horizontal-gutterWidth);
  --Form-input-addOnBg: #edf1f2;
  --Form-input-addOnColor: var(--text-color);
  --Form-input-addOnDividerBorderWidth: var(--borderWidth);
  --Form-input-bg: var(--white);
  --Form-input-borderColor: var(--borderColor);
  --Form-input-borderRadius: var(--borderRadius);
  --Form-input-borderWidth: 0.0625rem;
  --Form-input-boxShadow: none;
  --Form-input-color: var(--text-color);
  --Form-input-fontSize: var(--Form-fontSize);
  --Form-input-height: 1.875rem;
  --Form-input-iconColor: var(--icon-color);
  --Form-input-lineHeight: 1.4285714286;
  --Form-input-marginBottom: 0.375rem;
  --Form-input-onActive-color: var(--info);
  --Form-input-onDisabled-bg: #e5e7eb;
  --Form-input-onDisabled-borderColor: var(--Form-input-borderColor);
  --Form-input-onError-bg: var(--Form-input-bg);
  --Form-input-onError-borderColor: var(--danger);
  --Form-input-onFocus-addOnColor: var(--primary);
  --Form-input-onFocused-bg: var(--Form-input-bg);
  --Form-input-onFocused-borderColor: var(--info);
  --Form-input-onHover-iconColor: #1f2329;
  --Form-input-onHover-bg: rgba(255, 255, 255, 0.6);
  --Form-input-onHover-borderColor: var(--Form-input-onFocused-borderColor);
  --Form-input-paddingX: 0.5rem;
  --Form-input-paddingY: calc(
    (
        var(--Form-input-height) - var(--Form-input-lineHeight) *
          var(--Form-input-fontSize) - 0.125rem
      ) / 2
  );
  --Form-input-placeholderColor: var(--text--muted-color);
  --Form-item-gap: var(--gap-base);
  --Form-label-paddingTop: calc(
    (
        var(--Form-input-height) - var(--Form-input-lineHeight) *
          var(--Form-input-fontSize)
      ) / 2
  );
  --Form-row-gutterWidth: 0.625rem;
  --Form-select-bg: var(--white);
  --Form-select-borderColor: var(--Form-input-borderColor);
  --Form-select-borderRadius: var(--Form-input-borderRadius);
  --Form-select-borderWidth: var(--Form-input-borderWidth);
  --Form-select-caret-iconColor: var(--icon-color);
  --Form-select-caret-onHover-iconColor: var(--icon-onHover-color);
  --Form-select-checkall-bottomBorder: #eceff8;
  --Form-select-color: var(--text-color);
  --Form-select-input-fontSize: var(--fontSizeSm);
  --Form-select-menu-bg: var(--white);
  --Form-select-menu-color: var(--Form-select-color);
  --Form-select-menu-height: var(--Form-input-height);
  --Form-select-menu-onActive-bg: transparent;
  --Form-select-menu-onActive-color: var(--info);
  --Form-select-menu-onDisabled-bg: transparent;
  --Form-select-menu-onDisabled-color: var(--text--muted-color);
  --Form-select-menu-onHover-bg: rgba(0, 126, 255, 0.08);
  --Form-select-menu-onHover-color: var(--info);
  --Form-select-onError-borderColor: var(--Form-input-onError-borderColor);
  --Form-select-onFocused-borderColor: var(--Form-input-onFocused-borderColor);
  --Form-select-onFocused-color: var(--Form-select-color);
  --Form-select-onHover-bg: #f2f2f2;
  --Form-select-onHover-borderColor: var(--Form-input-borderColor);
  --Form-select-outer-borderWidth: 0.0625rem;
  --Form-select-outer-boxShadow: none;
  --Form-select-paddingX: var(--Form-input-paddingX);
  --Form-select-placeholderColor: var(--Form-input-placeholderColor);
  --Form-select-popoverGap: 0;
  --Form-select-search-height: var(--Form-select-menu-height);
  --Form-selectOption-height: var(--Form-input-height);
  --Form-selectValue-bg: #d9f3fb;
  --Form-selectValue-borderColor: #abe4f6;
  --Form-selectValue-color: var(--info);
  --Form-selectValue-fontSize: var(--fontSizeSm);
  --Form-selectValue-onDisable-bg: #f0fafd;
  --Form-selectValue-onHover-bg: #c2ecf9;
  --Form-select-onFocus-boxShadow: none;
  --IconPicker-content-maxHeight: 21.875rem;
  --IconPicker-padding: var(--gap-xs);
  --IconPicker-selectedIcon-marginRight: var(--gap-xs);
  --IconPicker-sugItem-height: 1.75rem;
  --IconPicker-sugItem-lineHeight: 1.75rem;
  --IconPicker-sugItem-width: 1.75rem;
  --IconPicker-tab-height: 1.875rem;
  --IconPicker-tab-lineHeight: 1.875rem;
  --IconPicker-tab-onActive-bg: var(--white);
  --IconPicker-tab-padding: 0 0.625rem;
  --IconPicker-tabs-bg: #f0f3f4;
  --ImageControl-addBtn-bg: var(--Button--default-bg);
  --ImageControl-addBtn-border: var(--Button--default-border);
  --ImageControl-addBtn-color: var(--Button--default-color);
  --ImageControl-addBtn-onActive-bg: #e6e6e6;
  --ImageControl-addBtn-onActive-border: #adb4bf;
  --ImageControl-addBtn-onActive-color: var(--ImageControl-addBtn-color);
  --ImageControl-addBtn-onDisabled-bg: var(--Form-input-onDisabled-bg);
  --ImageControl-addBtn-onDisabled-border: var(
    --Form-input-onDisabled-borderColor
  );
  --ImageControl-addBtn-onDisabled-color: var(--text--muted-color);
  --ImageControl-addBtn-onHover-bg: #ececec;
  --ImageControl-addBtn-onHover-border: #b4bbc5;
  --ImageControl-addBtn-onHover-color: var(--Button--default-color);
  --InputGroup-addOn-bg: var(--Form-input-addOnBg);
  --InputGroup-addOn-borderColor: var(--Form-input-borderColor);
  --InputGroup-addOn-borderRadius: var(--Form-input-borderRadius);
  --InputGroup-addOn-borderWidth: var(--Form-input-borderWidth);
  --InputGroup-addOn-onFocused-borderColor: var(
    --Form-input-onFocused-borderColor
  );
  --InputGroup-button-borderColor: var(--Form-input-borderColor);
  --InputGroup-button-borderRadius: var(--borderRadius);
  --InputGroup-button-borderWidth: var(--borderWidth);
  --InputGroup-height: var(--Form-input-height);
  --InputGroup-paddingX: 0.625rem;
  --InputGroup-paddingY: calc(
    (
        var(--InputGroup-height) - var(--Form-input-lineHeight) *
          var(--Form-input-fontSize) - 0.125rem
      ) / 2
  );
  --InputGroup-select-arrowColor: var(--icon-color);
  --InputGroup-select-bg: var(--white);
  --InputGroup-select-borderColor: var(--Form-select-borderColor);
  --InputGroup-select-borderRadius: var(--Form-select-borderRadius);
  --InputGroup-select-borderWidth: var(--Form-select-borderWidth);
  --InputGroup-select-color: var(--Form-select-color);
  --InputGroup-select-onFocused-arrowColor: var(--icon-onHover-color);
  --InputGroup-select-onFocused-bg: var(--white);
  --InputGroup-select-onFocused-color: var(--Form-select-onFocused-color);
  --InputRange-label--value-display: block;
  --InputRange-label--value-positionTop: -2.25rem;
  --InputRange-label--value-positionLeft: -0.375rem;
  --InputRange-label-color: var(--InputRange-neutralColor);
  --InputRange-label-fontSize: 0.8rem;
  --InputRange-label-positionBottom: -1.4rem;
  --InputRange-neutralColor: #aaaaaa;
  --InputRange-neutralLightColor: #eeeeee;
  --InputRange-onDisabled-color: #cccccc;
  --InputRange-primaryColor: var(--info);
  --InputRange-slider-bg: var(--InputRange-primaryColor);
  --InputRange-slider-border: 0.0625rem solid var(--InputRange-primaryColor);
  --InputRange-slider-height: 1.5rem;
  --InputRange-slider-onActive-transform: scale(1.3);
  --InputRange-slider-onDisabled-bg: var(--InputRange-onDisabled-color);
  --InputRange-slider-onDisabled-border: 0.0625rem solid var(--InputRange-onDisabled-color);
  --InputRange-slider-onFocus-borderRadius: var(--borderRadiusMd);
  --InputRange-slider-onFocus-boxShadow: 0 0 0
    var(--InputRange-slider-onFocus-borderRadius) rgba(35, 183, 229, 0.2);
  --InputRange-slider-transition: transform var(--animation-duration) ease-out,
    box-shadow var(--animation-duration) ease-out;
  --InputRange-slider-width: 1.125rem;
  --InputRange-sliderContainer-transition: left var(--animation-duration)
    ease-out;
  --InputRange-track-bg: var(--InputRange-neutralLightColor);
  --InputRange-track-height: 0.75rem;
  --InputRange-track-onActive-bg: var(--InputRange-primaryColor);
  --InputRange-track-onDisabled-bg: var(--InputRange-neutralLightColor);
  --InputRange-track-transition: left var(--animation-duration) ease-out,
    width var(--animation-duration) ease-out;
  --Layout--offscreen-width: 75%;
  --Layout-aside--folded-width: 3.75rem;
  --Layout-aside--lg-width: 18.75rem;
  --Layout-aside--md-width: 15.625rem;
  --Layout-aside--sm-width: 9.375rem;
  --Layout-aside-bg: #3a3f51;
  --Layout-aside-color: #a6a8b1;
  --Layout-aside-onAcitve-bg: #2e3344;
  --Layout-aside-onHover-bg: #32374a;
  --Layout-aside-subList-bg: #242734;
  --Layout-aside-onAcitve-onHover-bg: var(--Layout-aside-onAcitve-bg);
  --Layout-aside-width: 12.5rem;
  --Layout-asideDivider-bg: #2e3344;
  --Layout-asideDivider-margin: var(--gap-sm) 0;
  --Layout-asideLabel-color: #8b8e99;
  --Layout-asideLink-arrowColor: var(--Layout-asideLink-color);
  --Layout-asideLink-color: #b4b6bd;
  --Layout-asideLink-fontSize: var(--fontSizeBase);
  --Layout-asideLink-fontSize: var(--fontSizeBase);
  --Layout-asideLink-iconColor: inherit;
  --Layout-asideLink-onActive-arrowColor: var(
    --Layout-asideLink-onActive-color
  );
  --Layout-asideLink-onActive-color: #fff;
  --Layout-asideLink-onHover-color: #fff;
  --Layout-asideLink-onHover-iconColor: inherit;
  --Layout-asideLink-onHover-iconSize: inherit;
  --Layout-brand-bg: var(--dark);
  --Layout-brand-color: #eaebed;
  --Layout-brandBar-color: #a6a8b1;
  --Layout-header-bg: var(--white);
  --Layout-header-boxShadow: 0 0.125rem 0.125rem rgba(0, 0, 0, 0.05),
    0 1px 0 rgba(0, 0, 0, 0.05);
  --Layout-header-height: 3.125rem;
  --Layout-headerBar-borderBottom: none;
  --Layout-footer-height: 3.125rem;
  --Layout-nav--folded-height: 3.125rem;
  --Layout-nav--folded-height: 3.125rem;
  --Layout-nav-height: 2.5rem;
  --Layout-nav-height: 2.5rem;
  --Layout-nav-lgHeight: 3.125rem;
  --Layout-nav-lgHeight: 3.125rem;
  --Layout-body-bg: var(--body-bg);
  --List--unsaved-heading-bg: #e8f0fe;
  --List--unsaved-heading-color: #4285f4;
  --List-bg: var(--white);
  --List-borderColor: var(--borderColor);
  --List-borderRadius: var(--borderRadius);
  --List-borderWidth: var(--borderWidth);
  --List-fixedTop-boxShadow: var(--boxShadow);
  --List-placeholder-height: 1.875rem;
  --List-toolbar-marginX: 0;
  --List-toolbar-marginY: var(--gap-base);
  --ListControl-fontSize: var(--Form-fontSize);
  --ListControl-gutterWidth: 0.625rem;
  --ListControl-item-bg: var(--white);
  --ListControl-item-borderColor: var(--borderColor);
  --ListControl-item-borderWidth: var(--borderWidth);
  --ListControl-item-color: var(--text-color);
  --ListControl-item-onActive-after-borderColor: var(--primary);
  --ListControl-item-onActive-before-bg: var(--white);
  --ListControl-item-onActive-bg: var(--primary);
  --ListControl-item-onActive-borderColor: #564aa3;
  --ListControl-item-onActive-color: var(--white);
  --ListControl-item-onActive-onHover-bg: var(--primary);
  --ListControl-item-onDisabled-bg: var(--ListControl-item-bg);
  --ListControl-item-onDisabled-borderColor: #dfe2e6;
  --ListControl-item-onDisabled-color: var(--ListControl-item-color);
  --ListControl-item-onDisabled-opacity: 0.6;
  --ListControl-item-onHover-bg: #ececec;
  --ListControl-item-onHover-borderColor: #b4bbc5;
  --ListControl-item-onHover-color: var(--ListControl-item-color);
  --ListControl-item-paddingX: 0.75rem;
  --ListControl-item-paddingY: 0.375rem;
  --ListControl-item-transition: none;
  --ListItem--strip-bg: #f6f8f8;
  --ListItem-borderColor: #dfe2e6;
  --ListItem-borderWidth: var(--List-borderWidth);
  --ListItem-onChecked-bg: #d9f3fb;
  --ListItem-onChecked-borderColor: #abe4f6;
  --ListItem-onChecked-color: #20b9e8;
  --ListItem-onChecked-fieldLabel-color: #7dd6f1;
  --ListItem-onDragging-opacity: 0.1;
  --ListItem-onModified-bg: #e8f0fe;
  --ListItem-onModified-borderColor: #b7d0fc;
  --ListItem-onModified-color: #4285f4;
  --ListItem-onModified-fieldLabel-color: #a2c3fa;
  --ListItem-paddingX: var(--gap-base);
  --ListItem-paddingY: var(--gap-sm);
  --listMenu--onActive-borderColor: var(--info);
  --ListMenu-borderRadius: 0.125rem;
  --ListMenu-borderWidth: 0.0625rem;
  --ListMenu-bordrColor: var(--borderColor);
  --ListMenu-divider-color: var(--borderColorLight);
  --ListMenu-item--onActive-bg: transparent;
  --ListMenu-item--onActive-color: var(--info);
  --ListMenu-item--onDisabled-bg: transparent;
  --ListMenu-item--onDisabled-color: var(--text--muted-color);
  --ListMenu-item--onHover-bg: rgba(0, 126, 255, 0.08);
  --ListMenu-item--onHover-color: var(--info);
  --ListMenu-item-bg: var(--white);
  --ListMenu-item-color: var(--text-color);
  --ListMenu-item-height: 2.125rem;
  --Log-bg: #222;
  --Log-padding: var(--gap-xs) 0;
  --Log-line-padding: 0 var(--gap-xs);
  --Log-color: #f1f1f1;
  --Log-line--onHover-bg: #444;
  --Modal-bg: var(--background);
  --Modal-body--noHeader-paddingTop: var(--gap-base);
  --Modal-body-borderBottom: var(--Modal-content-borderWidth) solid #dfe2e6;
  --Modal-body-borderTop: var(--Modal-content-borderWidth) solid #dfe2e6;
  --Modal-body-paddingX: var(--gap-md);
  --Modal-body-paddingY: var(--gap-md);
  --Modal-close-color: var(--text--muted-color);
  --Modal-close-width: 0.75rem;
  --Modal-content-borderColor: var(--borderColor);
  --Modal-content-borderRadius: var(--borderRadius);
  --Modal-content-borderWidth: var(--borderWidth);
  --Modal-content-minHeight: unset;
  --Modal-content-startMarginTop: 3.75rem;
  --Modal-content-stepMarginTop: 1.875rem;
  --Modal-footer-marginX: 0;
  --Modal-footer-marginY: 0;
  --Modal-footer-padding: var(--gap-sm);
  --Modal-header-bg: #f9f9f9;
  --Modal-header-height: 2.5rem;
  --Modal-header-paddingX: var(--gap-md);
  --Modal-header-paddingY: calc(
    (
        var(--Modal-header-height) - var(--Modal-title-lineHeight) *
          var(--Modal-title-fontSize)
      ) / 2
  );
  --Modal-overlay-bg: rgba(0, 0, 0, 0.6);
  --Modal-title-color: var(--text--loud-color);
  --Modal-title-fontSize: var(--fontSizeBase);
  --Modal-title-fontWeight: normal;
  --Modal-title-lineHeight: var(--lineHeightBase);
  --Modal-widthBase: 31.25rem;
  --Modal-widthLg: 68.75rem;
  --Modal-widthMd: 50rem;
  --Modal-widthSm: 21.875rem;
  --Modal-widthXl: 90%;
  --Model-close-onHover-color: var(--text-color);
  --Nav-item-bg: transparent;
  --Nav-item-borderRadius: 0;
  --Nav-item-color: var(--text-color);
  --Nav-item-fontSize: var(--fontSizeBase);
  --Nav-item-onActive-bg: var(--info);
  --Nav-item-onActive-borderLeft: 3px solid transparent;
  --Nav-item-onActive-color: var(--white);
  --Nav-item-onDisabled-color: var(--text--muted-color);
  --Nav-item-onHover-bg: rgba(0, 0, 0, 0.05);
  --Nav-item-onHover-color: var(--text--loud-color);
  --Nav-subItem-fontSize: var(--fontSizeBase);
  --Nav-subItem-onActiveBeforeBg: #e5eaeb;
  --Number-bg: var(--Form-input-bg);
  --Number-borderColor: var(--Form-input-borderColor);
  --Number-borderRadius: var(--Form-input-borderRadius);
  --Number-borderWidth: var(--Form-input-borderWidth);
  --Number-handler--down-content: "-";
  --Number-handler--up-content: "+";
  --Number-handler--up-transform: none;
  --Number-handler-bg: var(--white);
  --Number-handler-borderBottom: 0.0625rem solid var(--Form-input-borderColor);
  --Number-handler-color: var(--Form-input-color);
  --Number-handler-fontFamily: inherit;
  --Number-handler-fontSize: var(--fontSizeBase);
  --Number-handler-onActive-bg: var(--Number-handler-onHover-bg);
  --Number-handler-onDisabled-bg: var(--Form-input-onDisabled-bg);
  --Number-handler-onDisabled-color: var(--text--muted-color);
  --Number-handler-onHover-bg: #f2f2f2;
  --Number-handler-onHover-color: var(--text-color);
  --Number-handler-width: var(--gap-lg);
  --Number-onDisabled-bg: var(--Form-input-bg);
  --Page-aside-bg: #e5eaeb;
  --Page-aside-maxWidth: 18.75rem;
  --Page-aside-width: 12.5rem;
  --Page-body-padding: var(--gap-base);
  --Page-content-paddingX: 0;
  --Page-content-paddingY: 0;
  --Page-header-paddingX: var(--gap-base);
  --Page-header-paddingY: var(--gap-base);
  --Page-header-bg: transparent;
  --Page-main-bg: transparent;
  --Page-title-color: var(--text--loud-color);
  --Page-title-fontSize: var(--fontSizeLg);
  --Page-title-fontWeight: var(--fontWeightNormal);
  --Page-title-lineHeight: 1.5;
  --Pagination-fontSize: var(--fontSizeBase);
  --Pagination-height: 1.875rem;
  --Pagination-minWidth: 1.875rem;
  --Pagination-onActive-backgroundColor: var(--primary);
  --Pagination-onActive-border: 0;
  --Pagination-onActive-color: var(--white);
  --Pagination-padding: 0 0.5rem;
  --Panel--default-badgeBg: #333;
  --Panel--default-badgeColor: #f5f5f5;
  --Panel--default-bg: #f6f8f8;
  --Panel--default-color: var(--text-color);
  --Panel--default-headingBorderColor: var(--borderColor);
  --Panel-bg: var(--white);
  --Panel-bodyPadding: var(--gap-base);
  --Panel-border: var(--borderWidth) solid transparent;
  --Panel-borderRadius: var(--borderRadius);
  --Panel-borderWidth: 0.0625rem;
  --Panel-boxShadow: 0 0.0625rem 0.0625rem rgba(0, 0, 0, 0.05);
  --Panel-btnToolbarTextAlign: right;
  --Panel-fixedBottom-borderTop: none;
  --Panel-fixedBottom-boxShadow: 0 -0.5rem 1rem rgba(0, 0, 0, 0.15);
  --Panel-footerBg: transparent;
  --Panel-footerBorderColor: var(--borderColorLight);
  --Panel-footerBorderRadius: 0 0 0.125rem 0.125rem;
  --Panel-footerButtonMarginLeft: var(--gap-sm);
  --Panel-footerPadding: var(--gap-sm) var(--gap-base);
  --Panel-headingBorderBottom: var(--borderWidth) solid transparent;
  --Panel-headingBorderRadius: var(--borderRadius) var(--borderRadius) 0 0;
  --Panel-headingPadding: var(--gap-sm) var(--gap-base);
  --Panel-marginBottom: var(--gap-lg);
  --Panel-titleColor: inherit;
  --Panel-titleFontSize: var(--fontSizeMd);
  --Panel-titleMarginBottom: 0;
  --Panel-titleMarginTop: 0;
  --Picker-iconColor: var(--icon-color);
  --Picker-onHover-iconColor: var(--icon-onHover-color);
  --PopOver-bg: white;
  --PopOverAble-iconColor: inherit;
  --PopOverAble-onHover-iconColor: inherit;
  --Property-title-bg: #f2f2f2;
  --Property-label-bg: #f7f7f7;
  --QuickEdit-iconColor: inherit;
  --QuickEdit-onFocus-borderColor: var(--info);
  --QuickEdit-onFocus-borderWidth: var(--borderWidth);
  --QuickEdit-onHover-iconColor: inherit;
  --Radio--sm-size: var(--Checkbox--sm-size);
  --Radio-color: var(--Checkbox-color);
  --Radio-inner-size: calc(var(--Radio-size) / 2);
  --Radio-onHover-color: var(--Checkbox-onHover-color);
  --Radio-size: var(--Checkbox-size);
  --Radio-onDisabled-bg: #e5e7eb;
  --Radio-onDisabled-color: var(--text--muted-color);
  --Radio-onFocus-boxShadow: none;
  --Remark-bg: #fff;
  --Remark-borderColor: var(--borderColor);
  --Remark-borderWidth: 0.0625rem;
  --Remark-icon-fontSize: var(--fontSizeBase);
  --Remark-iconColor: var(--icon-color);
  --Remark-marginLeft: var(--gap-sm);
  --Remark-onHover-bg: var(--primary);
  --Remark-onHover-borderColor: var(--primary);
  --Remark-onHover-iconColor: #fff;
  --Remark-width: 1rem;
  --ResultBox-icon--onDisabled-color: #ebebeb;
  --ResultBox-icon--onHover-color: #666666;
  --ResultBox-icon-color: #999;
  --ResultBox-value--onDisabled-color: #cccccc;
  --ResultBox-value--onHover-bg: rgba(0, 145, 255, 0.1);
  --ResultBox-value-bg: #f5f5f5;
  --ResultBox-value-color: #000;
  --Rating-onActive-color: var(--info);
  --Satus-icon-width: var(--gap-lg);
  --Satus-icon-height: var(--Satus-icon-width);
  --Sparkline-line-color: var(--info);
  --Sparkline-area-color: rgba(35, 183, 229, 0.1);
  --Spinner--lg-height: 3.125rem;
  --Spinner--lg-width: 3.125rem;
  --Spinner--sm-height: 1rem;
  --Spinner--sm-width: 1rem;
  --Spinner-bg: url("data:image/svg+xml,%0A%3Csvg width='38' height='38' viewBox='0 0 38 38' xmlns='http://www.w3.org/2000/svg'%3E%3Cdefs%3E%3ClinearGradient x1='8.042%25' y1='0%25' x2='65.682%25' y2='23.865%25' id='a'%3E%3Cstop stop-color='%23eee' stop-opacity='0' offset='0%25'/%3E%3Cstop stop-color='%23999' stop-opacity='.631' offset='63.146%25'/%3E%3Cstop stop-color='%23666' offset='100%25'/%3E%3C/linearGradient%3E%3C/defs%3E%3Cg fill='none' fill-rule='evenodd'%3E%3Cg transform='translate(1 1)'%3E%3Cpath d='M36 18c0-9.94-8.06-18-18-18' id='Oval-2' stroke='url(%23a)' stroke-width='2'%3E%3CanimateTransform attributeName='transform' type='rotate' from='0 18 18' to='360 18 18' dur='0.9s' repeatCount='indefinite' /%3E%3C/path%3E%3Ccircle fill='%23eee' cx='36' cy='18' r='1'%3E%3CanimateTransform attributeName='transform' type='rotate' from='0 18 18' to='360 18 18' dur='0.9s' repeatCount='indefinite' /%3E%3C/circle%3E%3C/g%3E%3C/g%3E%3C/svg%3E%0A");
  --Spinner-height: 1.625rem;
  --Spinner-overlay-bg: rgba(255, 255, 255, 0.4);
  --Spinner-width: 1.625rem;
  --Switch-bgColor: #4b5563;
  --Switch-borderColor: #353c46;
  --Switch-gap: var(--gap-sm);
  --Switch-height: 1.375rem;
  --Switch-onActive-bgColor: var(--info);
  --Switch-onDisabled-bgColor: #ccc;
  --Switch-onDisabled-circle-BackgroundColor: var(--white);
  --Switch-onDisabled-color: #fff;
  --Switch-valueColor: var(--white);
  --Switch-width: 3.125rem;
  --Table--unsaved-heading-bg: #e8f0fe;
  --Table--unsaved-heading-color: #4285f4;
  --Table-bg: var(--background);
  --Table-borderColor: var(--borderColor);
  --Table-borderRadius: var(--borderRadius);
  --Table-borderWidth: var(--borderWidth);
  --Table-color: var(--text-color);
  --Table-expandBtn-color: var(--info);
  --Table-fixed-zIndex: 5;
  --Table-fixedLeft-boxShadow: 0.42rem 0 0.42rem -0.28rem rgba(0, 0, 0, 0.15);
  --Table-fixedRight-boxShadow: -0.42rem 0 0.42rem -0.28rem rgba(0, 0, 0, 0.15);
  --Table-fixedTop-boxShadow: var(--boxShadow);
  --Table-fontSize: var(--fontSizeBase);
  --Table-heading-bg: var(--white);
  --Table-heading-height: 2.5rem;
  --Table-lineHeight: var(--lineHeightBase);
  --Table-onChecked-bg: #d9f3fb;
  --Table-onChecked-borderColor: #abe4f6;
  --Table-onChecked-color: #20b9e8;
  --Table-onDragging-opacity: 0.1;
  --Table-onHover-bg-rgb: 243, 246, 246;
  --Table-onHover-bg: #f3f6f6;
  --Table-onHover-borderColor: #d6dfdf;
  --Table-onHover-boxShadow: var(--boxShadow);
  --Table-onHover-color: var(--text-color);
  --Table-onModified-bg: #e8f0fe;
  --Table-onModified-borderColor: #d0e0fd;
  --Table-onModified-color: #4285f4;
  --Table-placeholder-height: 6.25rem;
  --Table-strip-bg: #f9fafa;
  --Table-tbody-borderTopColor: #d8dce1;
  --Table-thead-bg: #f6f8f8;
  --Table-thead-borderColor: var(--Table-borderColor);
  --Table-thead-borderWidth: var(--Table-borderWidth);
  --Table-thead-color: var(--text--loud-color);
  --Table-thead-fontSize: var(--fontSizeBase);
  --Table-thead-iconColor: var(--icon-color);
  --Table-toolbar-marginX: 0;
  --Table-toolbar-marginY: var(--gap-base);
  --Table-tree-borderColor: var(--Table-borderColor);
  --TableCell--edge-paddingX: var(--gap-md);
  --TableCell-filterBtn--onActive-color: var(--primary);
  --TableCell-filterBtn-width: 1rem;
  --TableCell-filterPopOver-dropDownItem-height: 2.125rem;
  --TableCell-filterPopOver-dropDownItem-padding: 0 0.75rem;
  --TableCell-height: 2.5rem;
  --TableCell-paddingX: var(--gap-sm);
  --TableCell-paddingY: calc(
    (var(--TableCell-height) - var(--Table-fontSize) * var(--Table-lineHeight)) /
      2
  );
  --TableCell-searchBtn--onActive-color: var(--primary);
  --TableCell-searchBtn-width: 1rem;
  --TableCell-sortBtn--default-onActive-opacity: 1;
  --TableCell-sortBtn--default-opacity: 0;
  --TableCell-sortBtn--onActive-color: var(--primary);
  --TableCell-sortBtn-width: 0.5rem;
  --Tabs--card-bg: #f6f8f8;
  --Tabs--card-borderTopColor: var(--borderColor);
  --Tabs--card-linkMargin: 0 10px 0 0;
  --Tabs--card-linkPadding: 0.625rem 0.625rem;
  --Tabs--card-onActive-bg: var(--background);
  --Tabs--card-onActive-borderColor: var(--borderColor);
  --Tabs--card-padding: 0.375rem 0 0 0.625rem;
  --Tabs--line-borderColor: var(--borderColor);
  --Tabs--line-borderWidth: 0.125rem;
  --Tabs--line-content-bg: transparent;
  --Tabs--line-content-padding: var(--gap-base) 0;
  --Tabs--line-linkMargin: 0 40px 0 0;
  --Tabs--line-linkPadding: 0 0 8px;
  --Tabs--line-onHover-borderColor: var(--primary);
  --Tabs--line-onHover-color: var(--primary);
  --Tabs--radio-bg: #eaf6fe;
  --Tabs--vertical-onActive-borderColor: var(--primary);
  --Tabs-borderColor: var(--borderColor);
  --Tabs-borderRadius: var(--borderRadius);
  --Tabs-borderWidth: var(--borderWidth);
  --Tabs-color: var(--text-color);
  --Tabs-content-bg: var(--background);
  --Tabs-linkFontSize: var(--fontSizeBase);
  --Tabs-linkMargin: 0 0.1875rem 0 0;
  --Tabs-linkPadding: var(--gap-sm) var(--gap-base);
  --Tabs-onActive-bg: var(--background);
  --Tabs-onActive-borderColor: var(--borderColor);
  --Tabs-onActive-color: #374151;
  --Tabs-onDisabled-color: #4b5563;
  --Tabs-onHover-borderColor: #e5e7eb;
  --Tabs--vertical-bg: var(--Table-thead-bg);
  --Tabs--vertical-width: 8.75rem;
  --Tabs--vertical-onActive-color: var(--primary);
  --Tabs--vertical-onActive-border: var(--primary);
  --Tabs--vertical-onActive-bg: var(--Tabs--vertical-bg);
  --Tabs--vertical-onActive-borderWidth: 0 0 0 0.25rem;
  --Tabs--vertical-onActive-container-borderRight: none;
  --Tabs--vertical-onActive-container-bg: var(--Tabs--vertical-bg);
  --Tabs--chrome-onHover-bg: #f6f7f8;
  --Tabs--chrome-bg: #e7eaed;
  --Tabs--chrome-radius-size: 0.5rem;
  --Tabs--chrome-right-boder-color: var(--borderColorDarken);
  --TagControl-sugBtn-bg: var(--Button--default-bg);
  --TagControl-sugBtn-border: var(--Button--default-border);
  --TagControl-sugBtn-borderRadius: var(--Button-borderRadius);
  --TagControl-sugBtn-borderWidth: var(--Button-borderWidth);
  --TagControl-sugBtn-color: var(--Button--default-color);
  --TagControl-sugBtn-fontSize: var(--Button--sm-fontSize);
  --TagControl-sugBtn-height: var(--Button--sm-height);
  --TagControl-sugBtn-lineHeight: var(--Button--sm-lineHeight);
  --TagControl-sugBtn-onActive-bg: #e6e6e6;
  --TagControl-sugBtn-onActive-border: #adb4bf;
  --TagControl-sugBtn-onActive-color: var(--TagControl-sugBtn-color);
  --TagControl-sugBtn-onHover-bg: #ececec;
  --TagControl-sugBtn-onHover-border: #b4bbc5;
  --TagControl-sugBtn-onHover-color: var(--Button--default-color);
  --TagControl-sugBtn-paddingX: var(--Button--sm-paddingX);
  --TagControl-sugBtn-paddingY: calc(
    (
        var(--TagControl-sugBtn-height) - var(--Button-borderWidth) * 2 -
          var(--TagControl-sugBtn-lineHeight) *
          var(--TagControl-sugBtn-fontSize)
      ) / 2
  );
  --TagControl-sugTip-color: var(--info);
  --Toast--danger-bgColor: var(--danger);
  --Toast--danger-borderColor: var(--danger);
  --Toast--danger-color: var(--Toast-color);
  --Toast--info-bgColor: var(--info);
  --Toast--info-borderColor: var(--info);
  --Toast--info-color: var(--Toast-color);
  --Toast--success-bgColor: var(--success);
  --Toast--success-borderColor: var(--success);
  --Toast--success-color: var(--Toast-color);
  --Toast--warning-bgColor: var(--warning);
  --Toast--warning-borderColor: var(--warning);
  --Toast--warning-color: var(--Toast-color);
  --Toast-border-width: 0;
  --Toast-borderRadius: var(--borderRadiusLg);
  --Toast-box-shadow: var(--boxShadow);
  --Toast-close--onHover-color: var(--Toast-close-color);
  --Toast-close-color: var(--white);
  --Toast-color: var(--white);
  --Toast-icon-width: 1rem;
  --Toast-icon-height: var(--Toast-icon-width);
  --Toast-opacity: 0.8;
  --Toast-paddingL: 2.5rem;
  --Toast-paddingX: var(--gap-sm);
  --Toast-paddingY: var(--gap-xs);
  --Toast-title-display: block;
  --Toast-width: 18.75rem;
  --Tooltip--attr-bg: rgba(0, 0, 0, 0.7);
  --Tooltip--attr-borderColor: var(--borderColor);
  --Tooltip--attr-borderRadius: var(--borderRadius);
  --Tooltip--attr-borderWidth: 0;
  --Tooltip--attr-boxShadow: var(--boxShadow);
  --Tooltip--attr-color: var(--background);
  --Tooltip--attr-fontSize: var(--fontSizeSm);
  --Tooltip--attr-gap: var(--gap-sm);
  --Tooltip--attr-lineHeigt: var(--lineHeightBase);
  --Tooltip--attr-paddingX: 0.625rem;
  --Tooltip--attr-paddingY: 0.125rem;
  --Tooltip--attr-transition: all var(--animation-duration) ease-in-out;
  --Tooltip-arrow-color: var(--Tooltip-bg);
  --Tooltip-arrow-color: var(--Tooltip-bg);
  --Tooltip-arrow-height: 0.5rem;
  --Tooltip-arrow-height: 0.5rem;
  --Tooltip-arrow-outerColor: #d1d5db;
  --Tooltip-arrow-width: 1rem;
  --Tooltip-arrow-width: 1rem;
  --Tooltip-bg: var(--background);
  --Tooltip-body-color: var(--text-color);
  --Tooltip-body-paddingX: var(--gap-sm);
  --Tooltip-body-paddingY: var(--gap-sm);
  --Tooltip-borderColor: var(--borderColor);
  --Tooltip-borderRadius: var(--borderRadiusLg);
  --Tooltip-borderWidth: var(--borderWidth);
  --Tooltip-boxShadow: var(--boxShadow);
  --Tooltip-fontSize: var(--fontSizeSm);
  --Tooltip-maxWidth: 15rem;
  --Tooltip-minWidth: auto;
  --Tooltip-title-bg: #f7f7f7;
  --Tooltip-title-borderBottom-color: #ebebeb;
  --Tooltip-title-color: var(--text--loud-color);
  --Tooltip-title-paddingX: var(--gap-sm);
  --Tooltip-title-paddingY: var(--gap-xs);
  --Transfer-title-bg: #f6f8f8;
  --Tree-indent: var(--gap-md);
  --Tree-inputHeight: calc(var(--Form-input-height) * 0.85);
  --Tree-item-onHover-bg: rgba(0, 126, 255, 0.08);
  --Tree-itemArrowWidth: 0.75rem;
  --Tree-itemHeight: 1.875rem;
  --Tree-itemLabel--onChecked-color: var(--Form-selectValue-color);
  --TreeSelect-popover-bg: #fff;
  --Wizard-badge-bg: #9ca3af;
  --Wizard-badge-border: 0;
  --Wizard-badge-borderRadius: 0.625rem;
  --Wizard-badge-color: var(--white);
  --Wizard-badge-fontSize: var(--fontSizeSm);
  --Wizard-badge-marginRight: 0.25rem;
  --Wizard-badge-onActive-backgroundColor: var(--info);
  --Wizard-badge-onComplete-backgroundColor: var(--info);
  --Wizard-badge-size: var(--gap-md);
  --Wizard-steps-bg--isComplete: #f1f5f9;
  --Wizard-steps-bg: #f3f4f6;
  --Wizard-steps-borderWidth: 0.0625rem;
  --Wizard-steps-height: 2.5rem;
  --Wizard-steps-li-onActive-arrow-bg: #fff;
  --Wizard-steps-li-onActive-bg: #fff;
  --Wizard-steps-li-onActive-color: var(--info);
  --Wizard-steps-liAfterContent: "";
  --Wizard-steps-liVender: "";
  --Wizard-steps-padding: 0;
  --Wizard-steps-textAlign: left;
  --Wizard-steps-ulDisplay: block;
  --Wizard-stepsContent-padding: var(--gap-base);
  --AnchorNav-links-container-borderRight: 0.0625rem solid #d3dae0;
  --AnchorNav-onActive-borderWidth: 0 0.125rem 0 0;
  --Steps-bg: var(--borderColorDarken);
  --Steps-status-success: var(--info);
  --Steps-status-error: var(--danger);
  --Steps-icon-fontsize: var(--fontSizeLg);
  --Steps-title-fontsize: var(--fontSizeLg);
  --Steps-title-color: var(--text--loud-color);
  --Steps-sub-title-fontsize: var(--fontSizeBase);
  --Steps-sub-title-color: var(--text-color);
  --Steps-line-bg: var(--Steps-bg);
  --Steps-line-success-bg: var(--Steps-status-success);
}

/* Reset
  =============== */

.amis-scope {
  box-sizing: border-box;
}

.amis-scope *,
.amis-scope *::before,
.amis-scope *::after {
  box-sizing: inherit;
}

.amis-scope figure {
  margin: 0;
}

/*! normalize.css v8.0.0 | MIT License | github.com/necolas/normalize.css */

/* Document
   ========================================================================== */

/**
 * 1. Correct the line height in all browsers.
 * 2. Prevent adjustments of font size after orientation changes in iOS.
 */

.amis-scope {
  line-height: 1.15;
  -webkit-text-size-adjust: 100%;
}

/* Sections
     ========================================================================== */

/**
   * Remove the margin in all browsers.
   */

.amis-scope {
  margin: 0;
}

/**
   * Correct the font size and margin on `h1` elements within `section` and
   * `article` contexts in Chrome, Firefox, and Safari.
   */

.amis-scope h1 {
  font-size: 2em;
  margin: 0.67em 0;
}

/* Grouping content
     ========================================================================== */

/**
   * 1. Add the correct box sizing in Firefox.
   * 2. Show the overflow in Edge and IE.
   */

.amis-scope hr {
  box-sizing: content-box;
  height: 0;
  overflow: visible;
}

/**
   * 1. Correct the inheritance and scaling of font size in all browsers.
   * 2. Correct the odd `em` font sizing in all browsers.
   */

.amis-scope pre {
  font-family: monospace, monospace;
  font-size: 1em;
}

/* Text-level semantics
     ========================================================================== */

/**
   * Remove the gray background on active links in IE 10.
   */

.amis-scope a {
  background: transparent;
}

/**
   * 1. Remove the bottom border in Chrome 57-
   * 2. Add the correct text decoration in Chrome, Edge, IE, Opera, and Safari.
   */

.amis-scope abbr[title] {
  border-bottom: none;
  text-decoration: underline;
  text-decoration: underline dotted;
}

/**
   * Add the correct font weight in Chrome, Edge, and Safari.
   */

.amis-scope b,
.amis-scope strong {
  font-weight: bolder;
}

/**
   * 1. Correct the inheritance and scaling of font size in all browsers.
   * 2. Correct the odd `em` font sizing in all browsers.
   */

.amis-scope code,
.amis-scope kbd,
.amis-scope samp {
  font-family: monospace, monospace;
  font-size: 1em;
}

/**
   * Add the correct font size in all browsers.
   */

.amis-scope small {
  font-size: 80%;
}

/**
   * Prevent `sub` and `sup` elements from affecting the line height in
   * all browsers.
   */

.amis-scope sub,
.amis-scope sup {
  font-size: 75%;
  line-height: 0;
  position: relative;
  vertical-align: baseline;
}

.amis-scope sub {
  bottom: -0.25em;
}

.amis-scope sup {
  top: -0.5em;
}

/* Embedded content
     ========================================================================== */

/**
   * Remove the border on images inside links in IE 10.
   */

.amis-scope img {
  border-style: none;
}

/* Forms
     ========================================================================== */

/**
   * 1. Change the font styles in all browsers.
   * 2. Remove the margin in Firefox and Safari.
   */

.amis-scope button,
.amis-scope input,
.amis-scope optgroup,
.amis-scope select,
.amis-scope textarea {
  font-family: inherit;
  font-size: 100%;
  line-height: 1.15;
  margin: 0;
}

/**
   * Show the overflow in IE.
   * 1. Show the overflow in Edge.
   */

.amis-scope button,
.amis-scope input {
  overflow: visible;
}

/**
   * Remove the inheritance of text transform in Edge, Firefox, and IE.
   * 1. Remove the inheritance of text transform in Firefox.
   */

.amis-scope button,
.amis-scope select {
  text-transform: none;
}

/**
   * Correct the inability to style clickable types in iOS and Safari.
   */

.amis-scope button,
.amis-scope [type=button],
.amis-scope [type=reset],
.amis-scope [type=submit] {
  -webkit-appearance: button;
}

/**
   * Remove the inner border and padding in Firefox.
   */

.amis-scope button::-moz-focus-inner,
.amis-scope [type=button]::-moz-focus-inner,
.amis-scope [type=reset]::-moz-focus-inner,
.amis-scope [type=submit]::-moz-focus-inner {
  border-style: none;
  padding: 0;
}

/**
   * Restore the focus styles unset by the previous rule.
   */

.amis-scope button:-moz-focusring,
.amis-scope [type=button]:-moz-focusring,
.amis-scope [type=reset]:-moz-focusring,
.amis-scope [type=submit]:-moz-focusring {
  outline: 1px dotted ButtonText;
}

/**
   * Correct the padding in Firefox.
   */

.amis-scope fieldset {
  padding: 0.35em 0.75em 0.625em;
}

/**
   * 1. Correct the text wrapping in Edge and IE.
   * 2. Correct the color inheritance from `fieldset` elements in IE.
   * 3. Remove the padding so developers are not caught out when they zero out
   *    `fieldset` elements in all browsers.
   */

.amis-scope legend {
  box-sizing: border-box;
  color: inherit;
  display: table;
  max-width: 100%;
  padding: 0;
  white-space: normal;
}

/**
   * Add the correct vertical alignment in Chrome, Firefox, and Opera.
   */

.amis-scope progress {
  vertical-align: baseline;
}

/**
   * Remove the default vertical scrollbar in IE 10+.
   */

.amis-scope textarea {
  overflow: auto;
}

/**
   * 1. Add the correct box sizing in IE 10.
   * 2. Remove the padding in IE 10.
   */

.amis-scope [type=checkbox],
.amis-scope [type=radio] {
  box-sizing: border-box;
  padding: 0;
}

/**
   * Correct the cursor style of increment and decrement buttons in Chrome.
   */

.amis-scope [type=number]::-webkit-inner-spin-button,
.amis-scope [type=number]::-webkit-outer-spin-button {
  height: auto;
}

/**
   * 1. Correct the odd appearance in Chrome and Safari.
   * 2. Correct the outline style in Safari.
   */

.amis-scope [type=search] {
  -webkit-appearance: textfield;
  outline-offset: -2px;
}

/**
   * Remove the inner padding in Chrome and Safari on macOS.
   */

.amis-scope [type=search]::-webkit-search-decoration {
  -webkit-appearance: none;
}

/**
   * 1. Correct the inability to style clickable types in iOS and Safari.
   * 2. Change font properties to `inherit` in Safari.
   */

::-webkit-file-upload-button {
  -webkit-appearance: button;
  font: inherit;
}

/* Interactive
     ========================================================================== */

/*
   * Add the correct display in Edge, IE 10+, and Firefox.
   */

.amis-scope details {
  display: block;
}

/*
   * Add the correct display in all browsers.
   */

.amis-scope summary {
  display: list-item;
}

/* Misc
     ========================================================================== */

/**
   * Add the correct display in IE 10+.
   */

.amis-scope template {
  display: none;
}

/**
   * Add the correct display in IE 10.
   */

.amis-scope [hidden] {
  display: none;
}

.amis-scope svg.icon {
  width: 1em;
  height: 1em;
  fill: currentColor;
}

.amis-scope svg.r90 {
  transform: rotate(90deg);
}

.amis-scope svg.icon-success {
  color: #27c24c;
}

.amis-scope svg.icon-fail {
  color: #f05050;
}

/**
 * Basic typography style for copy text
 */

.amis-scope {
  font-size: 16px;
}

.amis-scope {
  color: var(--body-color);
  background: var(--body-bg);
  font-size: var(--body-size);
  font-weight: var(--body-weight);
  font-family: var(--fontFamilyBase);
  line-height: var(--body-lineHeight);
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}

.amis-scope a {
  color: var(--link-color);
  text-decoration: var(--link-decoration);
}

.amis-scope a:hover {
  color: var(--link-onHover-color);
  text-decoration: var(--link-onHover-decoration);
}

.amis-scope label {
  font-weight: var(--fontWeightNormal);
}

.amis-scope h1,
.amis-scope h2,
.amis-scope h3,
.amis-scope h4,
.amis-scope h5,
.amis-scope h6 {
  font-weight: var(--fontWeightNormal);
  color: var(--text--loud-color);
  line-height: 1.1;
}

.amis-scope .is-matched {
  color: var(--danger);
}

.amis-scope pre,
.amis-scope code,
.amis-scope kbd,
.amis-scope samp {
  font-family: var(--fontFamilyMonospace);
}

.amis-scope .amis-routes-wrapper {
  width: 100%;
  height: 100%;
}

.amis-scope,
.amis-scope {
  width: 100%;
  height: 100%;
}

.amis-scope {
  overflow-x: hidden;
}

.amis-scope .a-Layout {
  min-height: 100%;
  width: 100%;
  position: relative;
}

.amis-scope .a-Layout:before {
  content: "";
  position: absolute;
  width: inherit;
  top: 0;
  bottom: 0;
  z-index: -1;
  background: var(--body-bg);
  border: inherit;
  display: block;
}

.amis-scope .a-Layout--boxed {
  margin-right: auto;
  margin-left: auto;
}

.amis-scope .a-Layout .a-Layout-header {
  background: var(--Layout-header-bg);
  box-shadow: var(--Layout-header-boxShadow);
  height: var(--Layout-header-height);
}

.amis-scope .a-Layout--headerFixed {
  padding-top: var(--Layout-header-height);
}

.amis-scope .a-Layout--headerFixed .a-Layout-header {
  position: fixed;
  top: 0;
  width: 100%;
  z-index: 1200;
}

.amis-scope .a-Layout-brandBar {
  background: var(--Layout-brand-bg);
  color: var(--Layout-brandBar-color);
}

.amis-scope .a-Layout-brandBar > button {
  padding: 0.625rem 1.0625rem;
  font-size: 1rem;
  line-height: calc(var(--Layout-header-height) - var(--gap-md));
  text-decoration: none;
  background: transparent;
  border: none;
}

.amis-scope .a-Layout-brand {
  color: var(--Layout-brand-color);
  text-align: left;
  font-size: var(--fontSizeMd);
  font-weight: var(--fontWeightNormal);
  max-width: 100%;
  height: auto;
  line-height: var(--Layout-header-height);
  display: inline-block;
  vertical-align: middle;
  padding: 0 var(--gap-base);
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
}

.amis-scope .a-Layout-brand:hover {
  text-decoration: none;
}

.amis-scope .a-Layout-brand img {
  max-height: calc(var(--Layout-header-height) / 2);
  vertical-align: middle;
  display: inline;
}

.amis-scope .a-Layout-headerBar {
  border-bottom: var(--Layout-headerBar-borderBottom);
  min-height: var(--Layout-header-height);
  padding: 0 var(--gap-sm);
  display: flex;
  flex-direction: row;
  align-items: center;
}

.amis-scope .a-Layout-offScreenBtn {
  display: none;
  float: right;
  padding: 13px var(--gap-md);
}

.amis-scope .a-Layout-aside {
  position: relative;
  background: var(--Layout-aside-bg);
  color: var(--Layout-aside-color);
}

.amis-scope .a-Layout-aside:before {
  content: "";
  position: absolute;
  width: inherit;
  top: 0;
  bottom: 0;
  z-index: -1;
  background: inherit;
  border: inherit;
}

.amis-scope .a-Layout-asideFooter {
  position: absolute;
  bottom: 0;
  width: 100%;
  z-index: 1200;
  max-width: var(--Layout-aside-width);
}

.amis-scope .a-Layout-asideFooter ~ div {
  padding-bottom: 3.125rem;
}

.amis-scope .a-Layout-body {
  padding-bottom: var(--Layout-footer-height);
  width: 100%;
  height: 100%;
}

.amis-scope .a-Layout--noFooter .a-Layout-body {
  padding-bottom: 0;
}

.amis-scope .a-Layout-footer {
  position: absolute;
  bottom: 0;
  left: 0;
  right: 0;
  z-index: 0;
}

.amis-scope .a-Layout--sm .a-Layout-asideFooter {
  max-width: var(--Layout-aside--sm-width);
}

.amis-scope .a-Layout--sm .a-AsideNav-item a {
  font-size: var(--fontSizeSm);
}

.amis-scope .a-Layout--md .a-Layout-asideFooter {
  max-width: var(--Layout-aside--md-width);
}

.amis-scope .a-Layout--lg .a-Layout-asideFooter {
  max-width: var(--Layout-aside--lg-width);
}

@media (max-width: 767px) {
  .amis-scope .a-Layout-content {
    transition: transform var(--animation-duration) ease;
  }

  .amis-scope .a-Layout-aside {
    display: none;
  }

  .amis-scope .a-Layout--offScreen .a-Layout-aside {
    position: fixed;
    top: 3.125rem;
    bottom: 0;
    width: var(--Layout--offscreen-width);
    display: block !important;
    visibility: visible;
    overflow-x: hidden;
    overflow-y: auto;
    -webkit-overflow-scrolling: touch;
    z-index: 1010;
  }

  .amis-scope .a-Layout-headerBar {
    display: none;
  }

  .amis-scope .a-Layout--offScreen .a-Layout-body,
  .amis-scope .a-Layout--offScreen .a-Layout-footer {
    background: var(--body-bg);
    transition: transform var(--animation-duration) ease;
    backface-visibility: hidden;
    transform: translate3d(var(--Layout--offscreen-width), 0px, 0px);
    overflow: hidden;
    position: fixed;
    width: 100%;
    top: 0;
    bottom: 0;
    left: 0;
    right: 0;
    z-index: 1015;
    padding-top: 3.125rem;
  }

  .amis-scope .a-Layout-offScreenBtn {
    display: block;
  }
}

@media (min-width: 768px) {
  .amis-scope .a-Layout {
    display: flex;
    flex-direction: column;
  }

  .amis-scope .a-Layout-header {
    width: 100%;
  }

  .amis-scope .a-Layout > .a-Layout-body {
    flex-grow: 1;
    position: relative;
  }

  .amis-scope .a-Layout--boxed {
    width: 47.5rem;
  }

  .amis-scope .a-Layout--boxed.a-Layout--headerFixed .a-Layout-header {
    width: 47.5rem;
  }

  .amis-scope .a-Layout-brand,
  .amis-scope .a-Layout-brandBar,
  .amis-scope .a-Layout-aside {
    width: var(--Layout-aside-width);
    transition: width var(--animation-duration) ease;
  }

  .amis-scope .a-Layout-brandBar {
    float: left;
  }

  .amis-scope .a-Layout--withAside {
    flex-direction: row;
    flex-wrap: wrap;
    justify-content: stretch;
  }

  .amis-scope .a-Layout--withAside > .a-Layout-content {
    flex-grow: 1;
    width: 0;
    position: relative;
  }

  .amis-scope .a-Layout--withAside .a-Layout-headerBar,
  .amis-scope .a-Layout--withAside .a-Layout-footer {
    margin-left: var(--Layout-aside-width);
    transition: margin var(--animation-duration) ease;
  }

  .amis-scope .a-Layout .visible-folded {
    display: none;
  }

  .amis-scope .a-Layout--folded .visible-folded {
    display: inherit;
  }

  .amis-scope .a-Layout--folded .hidden-folded {
    display: none !important;
  }

  .amis-scope .a-Layout--folded .text-center-folded {
    text-align: center;
  }

  .amis-scope .a-Layout--folded .pull-none-folded {
    float: none !important;
  }

  .amis-scope .a-Layout--folded .w-auto-folded {
    width: auto;
  }

  .amis-scope .a-Layout--folded .a-Layout-aside,
  .amis-scope .a-Layout--folded .a-Layout-brandBar {
    width: var(--Layout-aside--folded-width);
  }

  .amis-scope .a-Layout--folded.a-Layout--withAside .a-Layout-headerBar,
  .amis-scope .a-Layout--folded.a-Layout--withAside .a-Layout-footer {
    margin-left: var(--Layout-aside--folded-width);
  }

  .amis-scope .a-Layout--folded .a-Layout-brand {
    display: block;
    padding: 0;
    font-size: var(--fontSizeLg);
    text-align: center;
  }

  .amis-scope .a-Layout--asideFixed .a-Layout-aside {
    height: 100%;
  }

  .amis-scope .a-Layout--asideFixed .a-Layout-aside:before {
    position: fixed;
    z-index: 15;
  }

  .amis-scope .a-Layout--asideFixed .a-Layout-brandBar {
    position: fixed;
  }

  .amis-scope .a-Layout--asideFixed .a-Layout-asideWrap {
    position: fixed;
    overflow: hidden;
    top: var(--Layout-header-height);
    bottom: 0;
    left: 0;
    width: inherit;
    z-index: 1200;
  }

  .amis-scope .a-Layout--asideFixed .a-Layout-asideInner {
    width: calc(100% + 17px);
    position: relative;
    height: 100%;
    overflow-x: hidden;
    overflow-y: scroll;
    -webkit-overflow-scrolling: touch;
  }

  .amis-scope .a-Layout--asideFixed .a-Layout-asideInner::-webkit-scrollbar {
    -webkit-appearance: none;
  }

  .amis-scope .a-Layout--asideFixed .a-Layout-asideInner::-webkit-scrollbar:vertical {
    width: 17px;
  }

  .amis-scope .a-Layout--asideFixed.a-Layout--folded .a-Layout-aside {
    position: static;
  }

  .amis-scope .a-Layout--asideFixed.a-Layout--folded .a-Layout-brandBar {
    position: static;
  }

  .amis-scope .a-Layout--asideFixed.a-Layout--folded .a-Layout-asideWrap {
    overflow: visible;
    z-index: 15;
  }

  .amis-scope .a-Layout--asideFixed.a-Layout--folded .a-Layout-asideInner {
    overflow: visible;
    padding-right: 17px;
  }

  .amis-scope .a-Layout--sm:not(.a-Layout--folded) .a-Layout-brand,
  .amis-scope .a-Layout--sm:not(.a-Layout--folded) .a-Layout-brandBar,
  .amis-scope .a-Layout--sm:not(.a-Layout--folded) .a-Layout-aside {
    width: var(--Layout-aside--sm-width);
  }

  .amis-scope .a-Layout--md:not(.a-Layout--folded) .a-Layout-brand,
  .amis-scope .a-Layout--md:not(.a-Layout--folded) .a-Layout-brandBar,
  .amis-scope .a-Layout--md:not(.a-Layout--folded) .a-Layout-aside {
    width: var(--Layout-aside--md-width);
  }

  .amis-scope .a-Layout--lg:not(.a-Layout--folded) .a-Layout-brand,
  .amis-scope .a-Layout--lg:not(.a-Layout--folded) .a-Layout-brandBar,
  .amis-scope .a-Layout--lg:not(.a-Layout--folded) .a-Layout-aside {
    width: var(--Layout-aside--lg-width);
  }
}

@media (min-width: 992px) {
  .amis-scope .a-Layout--boxed {
    width: 61.25rem;
  }

  .amis-scope .a-Layout--boxed.a-Layout--headerFixed .a-Layout-header {
    width: 61.25rem;
  }
}

@media (min-width: 1200px) {
  .amis-scope .a-Layout--boxed {
    width: 73.75rem;
  }

  .amis-scope .a-Layout--boxed.a-Layout--headerFixed .a-Layout-header {
    width: 73.75rem;
  }
}

.amis-scope .a-Grid-col--xs1 {
  flex: 0 0 8.3333333333%;
  max-width: 8.3333333333%;
  min-height: 1px;
  padding-left: 0.5rem;
  padding-right: 0.5rem;
}

.amis-scope .a-Grid-col--xs2 {
  flex: 0 0 16.6666666667%;
  max-width: 16.6666666667%;
  min-height: 1px;
  padding-left: 0.5rem;
  padding-right: 0.5rem;
}

.amis-scope .a-Grid-col--xs3 {
  flex: 0 0 25%;
  max-width: 25%;
  min-height: 1px;
  padding-left: 0.5rem;
  padding-right: 0.5rem;
}

.amis-scope .a-Grid-col--xs4 {
  flex: 0 0 33.3333333333%;
  max-width: 33.3333333333%;
  min-height: 1px;
  padding-left: 0.5rem;
  padding-right: 0.5rem;
}

.amis-scope .a-Grid-col--xs5 {
  flex: 0 0 41.6666666667%;
  max-width: 41.6666666667%;
  min-height: 1px;
  padding-left: 0.5rem;
  padding-right: 0.5rem;
}

.amis-scope .a-Grid-col--xs6 {
  flex: 0 0 50%;
  max-width: 50%;
  min-height: 1px;
  padding-left: 0.5rem;
  padding-right: 0.5rem;
}

.amis-scope .a-Grid-col--xs7 {
  flex: 0 0 58.3333333333%;
  max-width: 58.3333333333%;
  min-height: 1px;
  padding-left: 0.5rem;
  padding-right: 0.5rem;
}

.amis-scope .a-Grid-col--xs8 {
  flex: 0 0 66.6666666667%;
  max-width: 66.6666666667%;
  min-height: 1px;
  padding-left: 0.5rem;
  padding-right: 0.5rem;
}

.amis-scope .a-Grid-col--xs9 {
  flex: 0 0 75%;
  max-width: 75%;
  min-height: 1px;
  padding-left: 0.5rem;
  padding-right: 0.5rem;
}

.amis-scope .a-Grid-col--xs10 {
  flex: 0 0 83.3333333333%;
  max-width: 83.3333333333%;
  min-height: 1px;
  padding-left: 0.5rem;
  padding-right: 0.5rem;
}

.amis-scope .a-Grid-col--xs11 {
  flex: 0 0 91.6666666667%;
  max-width: 91.6666666667%;
  min-height: 1px;
  padding-left: 0.5rem;
  padding-right: 0.5rem;
}

.amis-scope .a-Grid-col--xs12 {
  flex: 0 0 100%;
  max-width: 100%;
  min-height: 1px;
  padding-left: 0.5rem;
  padding-right: 0.5rem;
}

.amis-scope .a-Grid-col--xs {
  flex-basis: 0;
  flex-grow: 1;
  min-height: 1px;
  max-width: 100%;
  width: 100%;
  padding-left: 0.5rem;
  padding-right: 0.5rem;
}

.amis-scope .a-Grid-col--xsAuto {
  flex: 0 0 auto;
  width: auto;
  max-width: 100%;
  padding-left: 0.5rem;
  padding-right: 0.5rem;
}

@media (min-width: 576px) {
  .amis-scope .a-Grid {
    margin-left: -0.5rem;
    margin-right: -0.5rem;
    display: flex;
    flex-wrap: wrap;
    flex: 1;
  }

  .amis-scope .a-Grid--hRight {
    justify-content: flex-end;
  }

  .amis-scope .a-Grid--hCenter {
    justify-content: center;
  }

  .amis-scope .a-Grid--hBetween {
    justify-content: space-between;
  }

  .amis-scope .a-Grid--vMiddle > div {
    display: flex;
    flex-direction: column;
    justify-content: center;
  }

  .amis-scope .a-Grid--vBottom > div {
    display: flex;
    flex-direction: column;
    justify-content: flex-end;
  }

  .amis-scope .a-Grid--vBetween > div {
    display: flex;
    flex-direction: column;
    justify-content: space-between;
  }

  .amis-scope .a-Grid > .a-Grid-col--vTop {
    display: flex;
    flex-direction: column;
    justify-content: flex-start;
  }

  .amis-scope .a-Grid > .a-Grid-col--vMiddle {
    display: flex;
    flex-direction: column;
    justify-content: center;
  }

  .amis-scope .a-Grid > .a-Grid-col--vBottom {
    display: flex;
    flex-direction: column;
    justify-content: flex-end;
  }

  .amis-scope .a-Grid > .a-Grid-col--vBetween {
    display: flex;
    flex-direction: column;
    justify-content: space-between;
  }

  .amis-scope .a-Grid-col--sm1 {
    flex: 0 0 8.3333333333%;
    max-width: 8.3333333333%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--sm2 {
    flex: 0 0 16.6666666667%;
    max-width: 16.6666666667%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--sm3 {
    flex: 0 0 25%;
    max-width: 25%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--sm4 {
    flex: 0 0 33.3333333333%;
    max-width: 33.3333333333%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--sm5 {
    flex: 0 0 41.6666666667%;
    max-width: 41.6666666667%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--sm6 {
    flex: 0 0 50%;
    max-width: 50%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--sm7 {
    flex: 0 0 58.3333333333%;
    max-width: 58.3333333333%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--sm8 {
    flex: 0 0 66.6666666667%;
    max-width: 66.6666666667%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--sm9 {
    flex: 0 0 75%;
    max-width: 75%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--sm10 {
    flex: 0 0 83.3333333333%;
    max-width: 83.3333333333%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--sm11 {
    flex: 0 0 91.6666666667%;
    max-width: 91.6666666667%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--sm12 {
    flex: 0 0 100%;
    max-width: 100%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--sm {
    flex-basis: 0;
    flex-grow: 1;
    min-height: 1px;
    max-width: 100%;
    width: 100%;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--smAuto {
    flex: 0 0 auto;
    width: auto;
    max-width: 100%;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }
}

@media (min-width: 768px) {
  .amis-scope .a-Grid-col--md1 {
    flex: 0 0 8.3333333333%;
    max-width: 8.3333333333%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--md2 {
    flex: 0 0 16.6666666667%;
    max-width: 16.6666666667%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--md3 {
    flex: 0 0 25%;
    max-width: 25%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--md4 {
    flex: 0 0 33.3333333333%;
    max-width: 33.3333333333%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--md5 {
    flex: 0 0 41.6666666667%;
    max-width: 41.6666666667%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--md6 {
    flex: 0 0 50%;
    max-width: 50%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--md7 {
    flex: 0 0 58.3333333333%;
    max-width: 58.3333333333%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--md8 {
    flex: 0 0 66.6666666667%;
    max-width: 66.6666666667%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--md9 {
    flex: 0 0 75%;
    max-width: 75%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--md10 {
    flex: 0 0 83.3333333333%;
    max-width: 83.3333333333%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--md11 {
    flex: 0 0 91.6666666667%;
    max-width: 91.6666666667%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--md12 {
    flex: 0 0 100%;
    max-width: 100%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--md {
    flex-basis: 0;
    flex-grow: 1;
    min-height: 1px;
    max-width: 100%;
    width: 100%;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--mdAuto {
    flex: 0 0 auto;
    width: auto;
    max-width: 100%;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }
}

@media (min-width: 992px) {
  .amis-scope .a-Grid-col--lg1 {
    flex: 0 0 8.3333333333%;
    max-width: 8.3333333333%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--lg2 {
    flex: 0 0 16.6666666667%;
    max-width: 16.6666666667%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--lg3 {
    flex: 0 0 25%;
    max-width: 25%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--lg4 {
    flex: 0 0 33.3333333333%;
    max-width: 33.3333333333%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--lg5 {
    flex: 0 0 41.6666666667%;
    max-width: 41.6666666667%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--lg6 {
    flex: 0 0 50%;
    max-width: 50%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--lg7 {
    flex: 0 0 58.3333333333%;
    max-width: 58.3333333333%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--lg8 {
    flex: 0 0 66.6666666667%;
    max-width: 66.6666666667%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--lg9 {
    flex: 0 0 75%;
    max-width: 75%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--lg10 {
    flex: 0 0 83.3333333333%;
    max-width: 83.3333333333%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--lg11 {
    flex: 0 0 91.6666666667%;
    max-width: 91.6666666667%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--lg12 {
    flex: 0 0 100%;
    max-width: 100%;
    min-height: 1px;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--lg {
    flex-basis: 0;
    flex-grow: 1;
    min-height: 1px;
    max-width: 100%;
    width: 100%;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .amis-scope .a-Grid-col--lgAuto {
    flex: 0 0 auto;
    width: auto;
    max-width: 100%;
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }
}

.amis-scope .a-Grid--none {
  margin-left: 0;
  margin-right: 0;
}

.amis-scope .a-Grid--none > div {
  padding-left: 0;
  padding-right: 0;
}

.amis-scope .a-Grid--xs {
  margin-left: calc(var(--gap-xs) * -0.5);
  margin-right: calc(var(--gap-xs) * -0.5);
}

.amis-scope .a-Grid--xs > div {
  padding-left: calc(var(--gap-xs) * 0.5);
  padding-right: calc(var(--gap-xs) * 0.5);
}

.amis-scope .a-Grid--sm {
  margin-left: calc(var(--gap-sm) * -0.5);
  margin-right: calc(var(--gap-sm) * -0.5);
}

.amis-scope .a-Grid--sm > div {
  padding-left: calc(var(--gap-sm) * 0.5);
  padding-right: calc(var(--gap-sm) * 0.5);
}

.amis-scope .a-Grid--base {
  margin-left: calc(var(--gap-base) * -0.5);
  margin-right: calc(var(--gap-base) * -0.5);
}

.amis-scope .a-Grid--base > div {
  padding-left: calc(var(--gap-base) * 0.5);
  padding-right: calc(var(--gap-base) * 0.5);
}

.amis-scope .a-Grid--md {
  margin-left: calc(var(--gap-md) * -0.5);
  margin-right: calc(var(--gap-md) * -0.5);
}

.amis-scope .a-Grid--md > div {
  padding-left: calc(var(--gap-md) * 0.5);
  padding-right: calc(var(--gap-md) * 0.5);
}

.amis-scope .a-Grid--lg {
  margin-left: calc(var(--gap-lg) * -0.5);
  margin-right: calc(var(--gap-lg) * -0.5);
}

.amis-scope .a-Grid--lg > div {
  padding-left: calc(var(--gap-lg) * 0.5);
  padding-right: calc(var(--gap-lg) * 0.5);
}

.amis-scope .a-AsideNav::before,
.amis-scope .a-AsideNav::after {
  display: table;
  content: "";
}

.amis-scope .a-AsideNav::after {
  clear: both;
}

.amis-scope .a-AsideNav-label {
  color: var(--Layout-asideLabel-color);
  margin-top: var(--gap-base);
  margin-bottom: var(--gap-sm);
  font-size: var(--fontSizeXs);
  padding-left: var(--gap-base);
  padding-right: var(--gap-base);
}

.amis-scope .a-AsideNav-list {
  list-style: none;
  padding: 0;
  margin: 0;
}

.amis-scope .a-AsideNav-itemArrow {
  float: right;
  display: block;
  width: var(--gap-md);
  text-align: center;
  line-height: 1.0625rem;
  margin-top: 0.125rem;
}

.amis-scope .a-AsideNav-itemArrow:empty:before {
  content: "";
  display: inline-block;
  transform-origin: center;
  transition: transform var(--animation-duration) ease;
  background: url(data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4KPHN2ZyB2aWV3Qm94PSIwIDAgNTEzIDEwMjEiIHZlcnNpb249IjEuMSIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIiB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGluayI+Cgk8ZyBpZD0icmlnaHQtYXJyb3ciIGZpbGw9IiNmZmZmZmYiIGZpbGwtcnVsZT0ibm9uemVybyI+CgkJPHBhdGggZD0iTTU2LjU1OTA1NCwxMDEzLjc3MzY5IEw1MTIuOTA4MTE2LDUxMi42ODQ1MjQgTDU2LjU1OTA1NCwxMi4yMzQ1MDEgQzQ5LjQxMTQ2NzgsMi45MzQ1NTkxMiAzNy42NjY0MjM4LC0xLjU5MTg4MTc2IDI2LjEyNjIzMjQsMC41MDU5NDgyNDYgQzE0LjU4NjA0MSwyLjYwMzc3ODI1IDUuMTg1NDQ0MDksMTAuOTc0MTcyNyAxLjc2ODE1NTE2LDIyLjE5NDY0NzEgQy0xLjY0OTEzMzc3LDMzLjQxNTEyMTQgMS40ODk4MDIyOCw0NS42MDQ1MzUxIDkuOTAxNTE2LDUzLjc3ODg4NCBMNDI0LjcwNjE5Nyw1MTIuNjg0NTI0IEwxMi40NTgwOTQsOTY5LjY3MjczMSBDMi40NTgyMDU5Niw5ODIuNTUxNDk4IDQuMDEyOTc3MzcsMTAwMC45NDgzIDE2LjAzMjQ0MjIsMTAxMS45NjYxNSBDMjguMDUxOTA3MSwxMDIyLjk4Mzk5IDQ2LjUxNDIzNDYsMTAyMi45MzYxOSA1OC40NzY0ODcsMTAxMS44NTYyNiBMNTYuNTU5MDU0LDEwMTMuNzczNjkgWiIgaWQ9Iui3r+W+hCI+CgkJPC9wYXRoPgoJPC9nPgo8L3N2Zz4K);
  width: 0.625rem;
  height: 0.625rem;
  background-position: center center;
  background-repeat: no-repeat;
}

.amis-scope .a-AsideNav-item.is-open > a > .a-AsideNav-itemArrow:empty:before {
  transform: rotate(90deg);
  color: var(--Layout-asideLink-onActive-arrowColor);
}

.amis-scope .a-AsideNav-itemArrow > svg {
  color: var(--Layout-asideLink-color);
  width: 0.625rem;
  height: 0.625rem;
  transform-origin: center;
  transition: transform var(--animation-duration) ease;
}

.amis-scope .a-AsideNav-item.is-open > a > .a-AsideNav-itemArrow > svg {
  transform: rotate(90deg);
}

.amis-scope .a-AsideNav-itemBadge {
  padding: 0.125rem var(--gap-xs);
  margin-top: 0.125rem;
  font-size: var(--fontSizeXs);
  text-shadow: 0 0.0625rem 0 rgba(0, 0, 0, 0.2);
  float: right;
  min-width: 0.0625rem;
  line-height: 1;
  font-weight: var(--fontWeightBold);
  text-align: center;
  white-space: nowrap;
  vertical-align: baseline;
  border-radius: 0.625rem;
}

.amis-scope .a-AsideNav-itemIcon {
  margin: calc( ( var(--Layout-nav-height) - var(--lineHeightBase) * var(--Layout-asideLink-fontSize) ) / -2 ) -0.625rem;
  line-height: var(--Layout-nav-height);
  width: var(--Layout-nav-height);
  vertical-align: middle;
  float: left;
  margin-right: 0;
  text-align: center;
  position: relative;
  overflow: hidden;
  color: var(--Layout-asideLink-iconColor);
  font-size: var(--Layout-asideLink-onHover-iconSize);
}

.amis-scope .a-AsideNav-itemIcon:before {
  position: relative;
  z-index: 2;
}

.amis-scope .a-AsideNav-subList {
  margin: 0;
  padding: 0;
  opacity: 0;
  height: 0;
  overflow: hidden;
  margin-left: calc(var(--gap-md) * -1);
  transition: all var(--animation-duration) ease-in-out 0s;
  background: var(--Layout-aside-subList-bg);
}

.amis-scope .a-Layout--folded .a-AsideNav-item > .a-AsideNav-subList {
  display: block;
  overflow: hidden;
}

.amis-scope .is-open > .a-AsideNav-subList,
.amis-scope .a-Layout--folded .a-AsideNav-item .a-AsideNav-item.is-open > .a-AsideNav-subList,
.amis-scope .a-Layout--folded .a-AsideNav-item:hover > .a-AsideNav-subList,
.amis-scope .a-Layout--folded .a-AsideNav-item:focus > .a-AsideNav-subList,
.amis-scope .a-Layout--folded .a-AsideNav-item:active > .a-AsideNav-subList {
  opacity: 1;
  margin-left: 0;
  height: auto !important;
  overflow: visible;
}

.amis-scope .a-AsideNav-item {
  position: relative;
  display: block;
}

.amis-scope .a-AsideNav-item a {
  font-weight: normal;
  cursor: pointer;
  text-transform: none;
  display: block;
  font-size: var(--Layout-asideLink-fontSize);
  padding: calc( ( var(--Layout-nav-height) - var(--lineHeightBase) * var(--Layout-asideLink-fontSize) ) / 2 ) var(--gap-base);
  position: relative;
  transition: background-color var(--animation-duration) ease-in-out 0s;
  color: var(--Layout-asideLink-color);
  text-decoration: none;
  user-select: none;
}

.amis-scope .a-AsideNav-item a:hover {
  color: var(--Layout-asideLink-onHover-color);
  text-decoration: none;
  background: var(--Layout-aside-onHover-bg);
}

.amis-scope .a-AsideNav-item a:hover .a-AsideNav-itemIcon {
  color: var(--Layout-asideLink-onHover-iconColor);
}

.amis-scope .a-AsideNav-item.is-active > a {
  background: var(--Layout-aside-onAcitve-bg);
  color: var(--Layout-asideLink-onActive-color);
}

.amis-scope .a-AsideNav-item.is-active > a:hover {
  background: var(--Layout-aside-onAcitve-onHover-bg);
}

.amis-scope .a-AsideNav-item.is-lg > a {
  padding: calc( ( var(--Layout-nav-lgHeight) - var(--lineHeightBase) * var(--Layout-asideLink-fontSize) ) / 2 ) var(--gap-md);
}

.amis-scope .a-AsideNav-item .a-AsideNav-item a {
  padding-left: calc(var(--Layout-nav-height) + 0.3125rem);
}

.amis-scope .a-AsideNav-item .a-AsideNav-item .a-AsideNav-item a {
  padding-left: calc(var(--Layout-nav-height) + 0.9375rem);
}

.amis-scope .a-AsideNav-item .a-AsideNav-item .a-AsideNav-item .a-AsideNav-item a {
  padding-left: calc(var(--Layout-nav-height) + 1.875rem);
}

.amis-scope .a-AsideNav-item .a-AsideNav-item .a-AsideNav-item .a-AsideNav-item .a-AsideNav-item a {
  padding-left: calc(var(--Layout-nav-height) + 2.8125rem);
}

.amis-scope .a-AsideNav-item .a-AsideNav-item .a-AsideNav-subList {
  display: none;
}

.amis-scope .a-AsideNav-item .a-AsideNav-item.is-open .a-AsideNav-subList {
  display: block;
}

.amis-scope .a-AsideNav-subHeader {
  display: none;
}

.amis-scope .a-AsideNav-subHeader a {
  cursor: default;
  background: transparent;
  color: var(--Layout-asideLink-color);
  padding: calc( ( var(--Layout-nav--folded-height) - var(--lineHeightBase) * var(--Layout-asideLink-fontSize) ) / 2 ) var(--gap-md);
}

.amis-scope .a-AsideNav-subHeader a:hover {
  color: var(--Layout-asideLink-onHover-color);
  background: transparent;
}

.amis-scope .a-AsideNav-tooltip {
  pointer-events: none;
  left: 0;
  top: 50%;
  transform: translateY(-50%);
  position: absolute;
  font-size: var(--Tooltip--attr-fontSize);
  line-height: var(--Tooltip--attr-lineHeigt);
  text-align: left;
  white-space: nowrap;
  background: var(--Tooltip--attr-bg);
  border: var(--Tooltip--attr-borderWidth) solid var(--Tooltip--attr-borderColor);
  border-radius: var(--Tooltip--attr-borderRadius);
  box-shadow: var(--Tooltip--attr-boxShadow);
  left: 100%;
  color: var(--Tooltip--attr-color);
  padding: var(--Tooltip--attr-paddingY) var(--Tooltip--attr-paddingX);
  opacity: 0;
  transition: var(--Tooltip--attr-transition);
}

.amis-scope .a-AsideNav-divider {
  width: auto;
  height: 0.0625rem;
  margin: var(--Layout-asideDivider-margin);
  overflow: hidden;
  font-size: 0;
  background: var(--Layout-asideDivider-bg);
}

.amis-scope img.a-AsideNav-itemIcon {
  float: none;
  height: var(--Layout-asideLink-fontSize);
  width: auto;
  margin-right: var(--gap-xs);
  vertical-align: middle;
}

@media (min-width: 768px) {
  .amis-scope .a-Layout--folded .a-AsideNav-label {
    display: none;
  }

  .amis-scope .a-Layout--folded .a-AsideNav-subHeader {
    display: block;
  }

  .amis-scope .a-Layout--folded .a-AsideNav-item:hover > .a-AsideNav-tooltip {
    opacity: 1;
    z-index: 1600;
    margin: 0 0 0 var(--Tooltip--attr-gap);
    opacity: 1;
  }

  .amis-scope .a-Layout--folded .a-AsideNav-list > .a-AsideNav-item > a {
    text-align: center;
    position: relative;
    padding: 0;
    text-align: center;
    height: var(--Layout-nav--folded-height);
    border: none;
  }

  .amis-scope .a-Layout--folded .a-AsideNav-list > .a-AsideNav-item > a .a-AsideNav-itemArrow,
  .amis-scope .a-Layout--folded .a-AsideNav-list > .a-AsideNav-item > a .a-AsideNav-itemLabel {
    display: none;
  }

  .amis-scope .a-Layout--folded .a-AsideNav-list > .a-AsideNav-item > a .a-AsideNav-itemIcon {
    width: auto;
    float: none !important;
    display: block;
    font-size: 1rem;
    margin: 0;
    line-height: var(--Layout-nav--folded-height);
    border: none !important;
  }

  .amis-scope .a-Layout--folded .a-AsideNav-list > .a-AsideNav-item > a .a-AsideNav-itemBadge {
    position: absolute;
    right: 0.75rem;
    top: 0.5rem;
    z-index: 3;
  }

  .amis-scope .a-Layout--folded .a-AsideNav-list > .a-AsideNav-item.is-lg > a {
    height: var(--Layout-nav-lgHeight);
  }

  .amis-scope .a-Layout--folded .a-AsideNav-list > .a-AsideNav-item.is-lg > a .a-AsideNav-itemIcon {
    line-height: var(--Layout-nav-lgHeight);
  }

  .amis-scope .a-Layout--folded .a-AsideNav-item .a-AsideNav-item a {
    padding-left: var(--gap-md) !important;
  }

  .amis-scope .a-Layout--folded .a-AsideNav-subList {
    height: 0 !important;
    position: absolute;
    left: 100%;
    top: 0 !important;
    z-index: 1050;
    width: var(--Layout-aside-width);
    box-shadow: 0 0.125rem 0.375rem rgba(0, 0, 0, 0.1);
  }

  .amis-scope .a-Layout--folded.a-Layout--sm .a-AsideNav-subList {
    width: var(--Layout-aside--sm-width);
  }

  .amis-scope .a-Layout--folded.a-Layout--md .a-AsideNav-subList {
    width: var(--Layout-aside--md-width);
  }

  .amis-scope .a-Layout--folded.a-Layout--lg .a-AsideNav-subList {
    width: var(--Layout-aside--lg-width);
  }
}

.amis-scope .a-Hbox {
  display: flex;
  flex-direction: row;
  flex-wrap: nowrap;
}

.amis-scope .a-Hbox-col {
  flex-basis: 0;
  flex-grow: 1;
  min-height: 1px;
  max-width: 100%;
  width: 100%;
}

.amis-scope .a-Hbox-col--customWidth {
  flex-grow: unset;
  flex-basis: unset;
}

.amis-scope .a-Hbox-col--auto {
  flex: 0 0 auto;
  width: auto;
  max-width: 100%;
}

.amis-scope .a-Hbox--hRight {
  justify-content: flex-end;
}

.amis-scope .a-Hbox--hCenter {
  justify-content: center;
}

.amis-scope .a-Hbox--hBetween {
  justify-content: space-between;
}

.amis-scope .a-Hbox--vMiddle > .a-Hbox-col {
  display: flex;
  flex-direction: column;
  justify-content: center;
}

.amis-scope .a-Hbox--vBottom > .a-Hbox-col {
  display: flex;
  flex-direction: column;
  justify-content: flex-end;
}

.amis-scope .a-Hbox--vBetween > .a-Hbox-col {
  display: flex;
  flex-direction: column;
  justify-content: space-between;
}

.amis-scope .a-Hbox > .a-Hbox-col--vTop {
  display: flex;
  flex-direction: column;
  justify-content: flex-start;
}

.amis-scope .a-Hbox > .a-Hbox-col--vMiddle {
  display: flex;
  flex-direction: column;
  justify-content: center;
}

.amis-scope .a-Hbox > .a-Hbox-col--vBottom {
  display: flex;
  flex-direction: column;
  justify-content: flex-end;
}

.amis-scope .a-Hbox > .a-Hbox-col--vBetween {
  display: flex;
  flex-direction: column;
  justify-content: space-between;
}

.amis-scope .a-Hbox--xs {
  margin-left: calc(var(--gap-xs) * -0.5);
  margin-right: calc(var(--gap-xs) * -0.5);
}

.amis-scope .a-Hbox--xs > .a-Hbox-col {
  padding-left: calc(var(--gap-xs) * 0.5);
  padding-right: calc(var(--gap-xs) * 0.5);
}

.amis-scope .a-Hbox--sm {
  margin-left: calc(var(--gap-sm) * -0.5);
  margin-right: calc(var(--gap-sm) * -0.5);
}

.amis-scope .a-Hbox--sm > .a-Hbox-col {
  padding-left: calc(var(--gap-sm) * 0.5);
  padding-right: calc(var(--gap-sm) * 0.5);
}

.amis-scope .a-Hbox--base {
  margin-left: calc(var(--gap-base) * -0.5);
  margin-right: calc(var(--gap-base) * -0.5);
}

.amis-scope .a-Hbox--base > .a-Hbox-col {
  padding-left: calc(var(--gap-base) * 0.5);
  padding-right: calc(var(--gap-base) * 0.5);
}

.amis-scope .a-Hbox--md {
  margin-left: calc(var(--gap-md) * -0.5);
  margin-right: calc(var(--gap-md) * -0.5);
}

.amis-scope .a-Hbox--md > .a-Hbox-col {
  padding-left: calc(var(--gap-md) * 0.5);
  padding-right: calc(var(--gap-md) * 0.5);
}

.amis-scope .a-Hbox--lg {
  margin-left: calc(var(--gap-lg) * -0.5);
  margin-right: calc(var(--gap-lg) * -0.5);
}

.amis-scope .a-Hbox--lg > .a-Hbox-col {
  padding-left: calc(var(--gap-lg) * 0.5);
  padding-right: calc(var(--gap-lg) * 0.5);
}

.amis-scope .a-Vbox {
  display: table;
  border-spacing: 0;
  position: relative;
  width: 100%;
  height: 100%;
  min-height: 240px;
}

.amis-scope .a-Vbox .row-row {
  display: table-row;
  height: 100%;
}

.amis-scope .a-Vbox .row-row .a-Vbox-cell {
  position: relative;
  height: 100%;
  width: 100%;
}

.amis-scope .ie .a-Vbox .row-row .a-Vbox-cell {
  display: table-cell;
  overflow: auto;
}

.amis-scope .ie .a-Vbox .row-row .a-Vbox-cell .cell-inner {
  overflow: visible !important;
}

.amis-scope .a-Vbox .row-row .a-Vbox-cell .cell-inner {
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
  -webkit-overflow-scrolling: touch;
  overflow: auto;
}

.amis-scope .a-Button {
  display: inline-block;
  font-weight: var(--Button-fontWeight);
  text-align: center;
  vertical-align: middle;
  user-select: none;
  background: transparent;
  border: var(--Button-borderWidth) solid transparent;
  transition: var(--Button-transition);
  white-space: nowrap;
  min-width: var(--Button-mimWidth);
  padding: var(--Button-paddingY) var(--Button-paddingX);
  font-size: var(--Button-fontSize);
  line-height: var(--Button-lineHeight);
  border-radius: var(--Button-borderRadius);
  height: var(--Button-height);
}

.amis-scope .a-Button:active,
.amis-scope .a-Button.is-active {
  color: var(--Button-onActive-color);
  box-shadow: var(--Button-onActive-boxShadow);
  border-color: var(--Button-onActive-border);
}

.amis-scope .a-Button:active:focus,
.amis-scope .a-Button.is-active:focus {
  box-shadow: var(--Button-onActive-boxShadow);
}

.amis-scope .a-Button .a-Button-icon:first-child:not(:last-child):not(.pull-right),
.amis-scope .a-Button > svg.icon:not(:last-child):not(.pull-right),
.amis-scope .a-Button > .pull-left {
  margin-right: var(--Button-paddingX);
}

.amis-scope .a-Button .a-Button-icon:last-child:not(:first-child):not(.pull-left),
.amis-scope .a-Button > .pull-right {
  margin-left: var(--Button-paddingX);
}

.amis-scope .a-Button img.a-Button-icon {
  height: var(--Button-fontSize);
  vertical-align: middle;
}

.amis-scope .a-Button:hover:focus {
  text-decoration: none;
}

.amis-scope .a-Button:focus,
.amis-scope .a-Button.focus {
  outline: 0;
  box-shadow: var(--Button-onFocus-boxShadow);
}

.amis-scope .a-Button.is-disabled,
.amis-scope .a-Button:disabled {
  opacity: var(--Button-onDisabled-opacity);
  filter: grayscale(100%);
  box-shadow: none;
  cursor: not-allowed;
}

.amis-scope .a-Button:not(:disabled):not(.is-disabled) {
  cursor: pointer;
}

.amis-scope .a-Button > .pull-left,
.amis-scope .a-Button > .pull-right {
  line-height: inherit;
}

.amis-scope .a-Button > .fa,
.amis-scope .a-Button > .iconfont,
.amis-scope .a-Button > .glyphicon {
  font-size: inherit;
}

.amis-scope a.a-Button.is-disabled,
.amis-scope fieldset:disabled a.a-Button {
  pointer-events: none;
}

.amis-scope .a-Button--primary {
  color: var(--Button--primary-color);
  background: var(--Button--primary-bg);
  border-color: var(--Button--primary-border);
  box-shadow: var(--Button-boxShadow);
  text-shadow: var(--Button-textShadow);
}

.amis-scope .a-Button--primary:not(:disabled):not(.is-disabled):hover {
  color: var(--Button--primary-onHover-color);
  background: var(--Button--primary-onHover-bg);
  border-color: var(--Button--primary-onHover-border);
}

.amis-scope .a-Button--primary:hover:focus {
  box-shadow: var(--Button-boxShadow);
}

.amis-scope .a-Button--secondary {
  color: var(--Button--secondary-color);
  background: var(--Button--secondary-bg);
  border-color: var(--Button--secondary-border);
  box-shadow: var(--Button-boxShadow);
  text-shadow: var(--Button-textShadow);
}

.amis-scope .a-Button--secondary:not(:disabled):not(.is-disabled):hover {
  color: var(--Button--secondary-onHover-color);
  background: var(--Button--secondary-onHover-bg);
  border-color: var(--Button--secondary-onHover-border);
}

.amis-scope .a-Button--secondary:hover:focus {
  box-shadow: var(--Button-boxShadow);
}

.amis-scope .a-Button--success {
  color: var(--Button--success-color);
  background: var(--Button--success-bg);
  border-color: var(--Button--success-border);
  box-shadow: var(--Button-boxShadow);
  text-shadow: var(--Button-textShadow);
}

.amis-scope .a-Button--success:not(:disabled):not(.is-disabled):hover {
  color: var(--Button--success-onHover-color);
  background: var(--Button--success-onHover-bg);
  border-color: var(--Button--success-onHover-border);
}

.amis-scope .a-Button--success:hover:focus {
  box-shadow: var(--Button-boxShadow);
}

.amis-scope .a-Button--info {
  color: var(--Button--info-color);
  background: var(--Button--info-bg);
  border-color: var(--Button--info-border);
  box-shadow: var(--Button-boxShadow);
  text-shadow: var(--Button-textShadow);
}

.amis-scope .a-Button--info:not(:disabled):not(.is-disabled):hover {
  color: var(--Button--info-onHover-color);
  background: var(--Button--info-onHover-bg);
  border-color: var(--Button--info-onHover-border);
}

.amis-scope .a-Button--info:hover:focus {
  box-shadow: var(--Button-boxShadow);
}

.amis-scope .a-Button--warning {
  color: var(--Button--warning-color);
  background: var(--Button--warning-bg);
  border-color: var(--Button--warning-border);
  box-shadow: var(--Button-boxShadow);
  text-shadow: var(--Button-textShadow);
}

.amis-scope .a-Button--warning:not(:disabled):not(.is-disabled):hover {
  color: var(--Button--warning-onHover-color);
  background: var(--Button--warning-onHover-bg);
  border-color: var(--Button--warning-onHover-border);
}

.amis-scope .a-Button--warning:hover:focus {
  box-shadow: var(--Button-boxShadow);
}

.amis-scope .a-Button--danger {
  color: var(--Button--danger-color);
  background: var(--Button--danger-bg);
  border-color: var(--Button--danger-border);
  box-shadow: var(--Button-boxShadow);
  text-shadow: var(--Button-textShadow);
}

.amis-scope .a-Button--danger:not(:disabled):not(.is-disabled):hover {
  color: var(--Button--danger-onHover-color);
  background: var(--Button--danger-onHover-bg);
  border-color: var(--Button--danger-onHover-border);
}

.amis-scope .a-Button--danger:hover:focus {
  box-shadow: var(--Button-boxShadow);
}

.amis-scope .a-Button--light {
  color: var(--Button--light-color);
  background: var(--Button--light-bg);
  border-color: var(--Button--light-border);
  box-shadow: var(--Button-boxShadow);
  text-shadow: var(--Button-textShadow);
}

.amis-scope .a-Button--light:not(:disabled):not(.is-disabled):hover {
  color: var(--Button--light-onHover-color);
  background: var(--Button--light-onHover-bg);
  border-color: var(--Button--light-onHover-border);
}

.amis-scope .a-Button--light:hover:focus {
  box-shadow: var(--Button-boxShadow);
}

.amis-scope .a-Button--dark {
  color: var(--Button--dark-color);
  background: var(--Button--dark-bg);
  border-color: var(--Button--dark-border);
  box-shadow: var(--Button-boxShadow);
  text-shadow: var(--Button-textShadow);
}

.amis-scope .a-Button--dark:not(:disabled):not(.is-disabled):hover {
  color: var(--Button--dark-onHover-color);
  background: var(--Button--dark-onHover-bg);
  border-color: var(--Button--dark-onHover-border);
}

.amis-scope .a-Button--dark:hover:focus {
  box-shadow: var(--Button-boxShadow);
}

.amis-scope .a-Button--default {
  color: var(--Button--default-color);
  background: var(--Button--default-bg);
  border-color: var(--Button--default-border);
  box-shadow: var(--Button-boxShadow);
  text-shadow: var(--Button-textShadow);
}

.amis-scope .a-Button--default:not(:disabled):not(.is-disabled):hover {
  color: var(--Button--default-onHover-color);
  background: var(--Button--default-onHover-bg);
  border-color: var(--Button--default-onHover-border);
}

.amis-scope .a-Button--default:hover:focus {
  box-shadow: var(--Button-boxShadow);
}

.amis-scope .a-Button--xs {
  padding: var(--Button--xs-paddingY) var(--Button--xs-paddingX);
  font-size: var(--Button--xs-fontSize);
  line-height: var(--Button--xs-lineHeight);
  border-radius: var(--Button--sm-borderRadius);
  height: var(--Button--xs-height);
}

.amis-scope .a-Button--xs .a-Button-icon:first-child:not(:last-child):not(.pull-right),
.amis-scope .a-Button--xs > svg.icon:not(:last-child):not(.pull-right),
.amis-scope .a-Button--xs > .pull-left {
  margin-right: var(--Button--xs-paddingX);
}

.amis-scope .a-Button--xs .a-Button-icon:last-child:not(:first-child):not(.pull-left),
.amis-scope .a-Button--xs > .pull-right {
  margin-left: var(--Button--xs-paddingX);
}

.amis-scope .a-Button--xs img.a-Button-icon {
  height: var(--Button-fontSize);
  vertical-align: middle;
}

.amis-scope .a-Button--xs.a-Button--iconOnly {
  min-width: calc( var(--Button--xs-height) * var(--Button--iconOnly-minWidthRate) );
}

.amis-scope .a-Button--sm {
  padding: var(--Button--sm-paddingY) var(--Button--sm-paddingX);
  font-size: var(--Button--sm-fontSize);
  line-height: var(--Button--sm-lineHeight);
  border-radius: var(--Button--sm-borderRadius);
  height: var(--Button--sm-height);
}

.amis-scope .a-Button--sm .a-Button-icon:first-child:not(:last-child):not(.pull-right),
.amis-scope .a-Button--sm > svg.icon:not(:last-child):not(.pull-right),
.amis-scope .a-Button--sm > .pull-left {
  margin-right: var(--Button--sm-paddingX);
}

.amis-scope .a-Button--sm .a-Button-icon:last-child:not(:first-child):not(.pull-left),
.amis-scope .a-Button--sm > .pull-right {
  margin-left: var(--Button--sm-paddingX);
}

.amis-scope .a-Button--sm img.a-Button-icon {
  height: var(--Button-fontSize);
  vertical-align: middle;
}

.amis-scope .a-Button--sm.a-Button--iconOnly {
  min-width: calc( var(--Button--sm-height) * var(--Button--iconOnly-minWidthRate) );
}

.amis-scope .a-Button--md {
  padding: var(--Button--md-paddingY) var(--Button--md-paddingX);
  font-size: var(--Button--md-fontSize);
  line-height: var(--Button--md-lineHeight);
  border-radius: var(--Button-borderRadius);
  height: var(--Button--md-height);
}

.amis-scope .a-Button--md .a-Button-icon:first-child:not(:last-child):not(.pull-right),
.amis-scope .a-Button--md > svg.icon:not(:last-child):not(.pull-right),
.amis-scope .a-Button--md > .pull-left {
  margin-right: var(--Button--md-paddingX);
}

.amis-scope .a-Button--md .a-Button-icon:last-child:not(:first-child):not(.pull-left),
.amis-scope .a-Button--md > .pull-right {
  margin-left: var(--Button--md-paddingX);
}

.amis-scope .a-Button--md img.a-Button-icon {
  height: var(--Button-fontSize);
  vertical-align: middle;
}

.amis-scope .a-Button--md.a-Button--iconOnly {
  min-width: calc( var(--Button--md-height) * var(--Button--iconOnly-minWidthRate) );
}

.amis-scope .a-Button--lg {
  padding: var(--Button--lg-paddingY) var(--Button--lg-paddingX);
  font-size: var(--Button--lg-fontSize);
  line-height: var(--Button--lg-lineHeight);
  border-radius: var(--Button--lg-borderRadius);
  height: var(--Button--lg-height);
}

.amis-scope .a-Button--lg .a-Button-icon:first-child:not(:last-child):not(.pull-right),
.amis-scope .a-Button--lg > svg.icon:not(:last-child):not(.pull-right),
.amis-scope .a-Button--lg > .pull-left {
  margin-right: var(--Button--lg-paddingX);
}

.amis-scope .a-Button--lg .a-Button-icon:last-child:not(:first-child):not(.pull-left),
.amis-scope .a-Button--lg > .pull-right {
  margin-left: var(--Button--lg-paddingX);
}

.amis-scope .a-Button--lg img.a-Button-icon {
  height: var(--Button-fontSize);
  vertical-align: middle;
}

.amis-scope .a-Button--lg.a-Button--iconOnly {
  min-width: calc( var(--Button--lg-height) * var(--Button--iconOnly-minWidthRate) );
}

.amis-scope .a-Button--iconOnly {
  min-width: calc(var(--Button-height) * var(--Button--iconOnly-minWidthRate));
}

.amis-scope .a-Button--iconOnly:not(.a-Button--link) > svg.icon {
  width: 0.875rem;
  height: 0.875rem;
  top: 0.125rem;
}

.amis-scope .a-Button--iconOnly:not(.a-Button--link) > .fa,
.amis-scope .a-Button--iconOnly:not(.a-Button--link) > .iconfont {
  font-size: var(--fontSizeMd);
}

.amis-scope .a-Button--iconOnly:not(.a-Button--link) > .iconfont {
  line-height: 1;
}

.amis-scope .a-Button--link {
  width: auto;
  min-width: auto;
  font-weight: var(--fontWeightNormal);
  color: var(--Button--link-color);
  text-decoration: var(--link-decoration);
  border: none;
  height: auto;
}

.amis-scope .a-Button--link:hover:focus {
  color: var(--Button--link-onHover-color);
  text-decoration: var(--link-onHover-decoration);
  box-shadow: none;
}

.amis-scope .a-Button--link:disabled,
.amis-scope .a-Button--link.is-disabled {
  color: var(--text--muted-color);
  pointer-events: none;
  background: transparent;
}

.amis-scope .a-Button--block {
  display: block;
  width: 100%;
}

.amis-scope .a-Button--block + .a-Button--block {
  margin-top: var(--gap-base);
}

.amis-scope input[type=submit].a-Button--block,
.amis-scope input[type=reset].a-Button--block,
.amis-scope input[type=button].a-Button--block {
  width: 100%;
}

.amis-scope .a-ButtonToolbar {
  margin-left: calc(var(--gap-xs) * -1);
  margin-top: calc(var(--gap-xs) * -1);
}

.amis-scope .a-ButtonToolbar > .a-Button {
  margin-left: var(--gap-xs);
  margin-top: var(--gap-xs);
}

.amis-scope .a-Avatar {
  background: var(--Avatar-bg);
  width: var(--Avatar-width);
  height: var(--Avatar-width);
  line-height: var(--Avatar-width);
  display: inline-block;
  overflow: hidden;
  flex-shrink: 0;
  border-radius: 50%;
  text-align: center;
}

.amis-scope .a-Avatar--square {
  border-radius: 0%;
}

.amis-scope .a-Avatar--rounded {
  border-radius: 10%;
}

.amis-scope .a-Avatar i {
  font-size: var(--fontSizeLg);
}

.amis-scope .a-Avatar img {
  color: transparent;
  width: 100%;
  height: 100%;
  object-fit: cover;
}

.amis-scope .a-Avatar:hover img,
.amis-scope .a-Avatar:hover i {
  transform: scale(1.1);
}

.amis-scope .a-Breadcrumb-icon {
  margin-right: 0.125rem;
}

.amis-scope .a-Breadcrumb-separator {
  user-select: none;
  margin: 0 var(--gap-xs);
}

.amis-scope .a-Badge {
  display: inline-block;
  position: relative;
}

.amis-scope .a-Badge-text,
.amis-scope .a-Badge-dot {
  background: var(--danger);
  position: absolute;
  top: 0;
  right: 0;
  transform: translate(50%, -50%);
  transform-origin: 100% 0;
  z-index: auto;
  border-radius: calc(var(--Badge-size) / 2);
  box-shadow: 0 0 0 1px #fff;
}

.amis-scope .a-Badge--top-left {
  top: 0;
  left: 0;
  right: auto;
  transform: translate(-50%, -50%);
}

.amis-scope .a-Badge--bottom-left {
  top: auto;
  bottom: 0;
  left: 0;
  right: auto;
  transform: translate(-50%, 50%);
}

.amis-scope .a-Badge--bottom-right {
  top: auto;
  bottom: 0;
  left: auto;
  right: 0;
  transform: translate(50%, 50%);
}

.amis-scope .a-Badge-text {
  color: var(--Badge-color);
  height: var(--Badge-size);
  line-height: var(--Badge-size);
  white-space: nowrap;
  text-align: center;
  padding: 0 6px;
}

.amis-scope .a-Badge-dot {
  z-index: auto;
  width: var(--Badge-size);
  height: var(--Badge-size);
  border-radius: 50%;
}

@keyframes badgeDotAnimation {
  0% {
    transform: scale(0.8);
    opacity: 0.4;
  }

  to {
    transform: scale(3.2);
    opacity: 0;
  }
}

.is-modalOpened {
  overflow: hidden;
}

.is-modalOpened .amis-scope .a-Modal {
  overflow-x: hidden;
  overflow-y: auto;
}

@keyframes modalIn {
  from {
    opacity: 0;
    transform: translate3d(0, -300px, 0) scale(0.2);
  }
}

@keyframes modalOut {
  to {
    opacity: 0;
    transform: translate3d(0, -300px, 0) scale(0.2);
  }
}

.amis-scope .a-Modal {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 1400;
  overflow: hidden;
  outline: 0;
}

.amis-scope .a-Modal-content {
  position: relative;
  display: flex;
  flex-direction: column;
  width: 100%;
  pointer-events: auto;
  background: var(--Modal-bg);
  background-clip: padding-box;
  outline: 0;
  z-index: 2;
  margin-left: auto;
  margin-right: auto;
  margin-top: var(--Modal-content-startMarginTop);
  margin-bottom: var(--gap-md);
  border: var(--Modal-content-borderWidth) solid var(--Modal-content-borderColor);
  border-radius: var(--Modal-content-borderRadius);
}

.amis-scope .a-Modal-content.in,
.amis-scope .a-Modal-content.out {
  animation-duration: var(--animation-duration);
  animation-fill-mode: both;
}

.amis-scope .a-Modal-content.in {
  animation-name: modalIn;
}

.amis-scope .a-Modal-content.out {
  animation-name: modalOut;
}

.amis-scope .a-Modal-overlay {
  transition: ease-in-out opacity var(--animation-duration);
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 1;
  background: var(--Modal-overlay-bg);
  pointer-events: none;
  opacity: 0;
}

.amis-scope .a-Modal-overlay.in {
  opacity: 1;
}

.amis-scope .a-Modal-overlay.out {
  opacity: 0;
}

.amis-scope .a-Modal-header {
  padding: var(--Modal-header-paddingY) var(--Modal-header-paddingX);
  background: var(--Modal-header-bg);
  border-bottom: var(--Modal-body-borderTop);
  border-top-left-radius: var(--Modal-content-borderRadius);
  border-top-right-radius: var(--Modal-content-borderRadius);
}

.amis-scope .a-Modal-header::before,
.amis-scope .a-Modal-header::after {
  display: table;
  content: "";
}

.amis-scope .a-Modal-header::after {
  clear: both;
}

.amis-scope .a-Modal-title {
  font-size: var(--Modal-title-fontSize);
  color: var(--Modal-title-color);
  font-weight: var(--Modal-title-fontWeight);
}

.amis-scope .a-Modal-close {
  float: right;
  color: var(--Modal-close-color);
  line-height: inherit;
  text-decoration: none;
  vertical-align: middle;
}

.amis-scope .a-Modal-close svg {
  width: var(--Modal-close-width);
  height: var(--Modal-close-width);
  fill: var(--Modal-close-color);
}

.amis-scope .a-Modal-close:not(.is-disabled) {
  cursor: pointer;
}

.amis-scope .a-Modal-close:not(.is-disabled):hover {
  text-decoration: none;
  color: var(--Model-close-onHover-color);
}

.amis-scope .a-Modal-close:not(.is-disabled):hover svg {
  fill: var(--Model-close-onHover-color);
}

.amis-scope .a-Modal-content > .a-Modal-close {
  position: absolute;
  right: var(--gap-md);
  top: var(--gap-sm);
  z-index: 10;
}

.amis-scope .a-Modal-body {
  padding: var(--Modal-body--noHeader-paddingTop) var(--Modal-body-paddingX) var(--Modal-body-paddingY);
  flex-grow: 1;
}

.amis-scope .a-Modal-header + .a-Modal-body {
  padding-top: var(--Modal-body-paddingY);
}

.amis-scope .a-Modal-footer {
  display: flex;
  align-items: center;
  justify-content: flex-end;
  padding: var(--Modal-footer-padding);
  border-top: var(--Modal-body-borderBottom);
  margin: var(--Modal-footer-marginY) var(--Modal-footer-marginX);
  border-bottom-left-radius: var(--Modal-content-borderRadius);
  border-bottom-right-radius: var(--Modal-content-borderRadius);
}

.amis-scope .a-Modal-footer .a-Button {
  margin-left: var(--gap-sm);
}

.amis-scope .a-Modal--2th .a-Modal-content {
  margin-top: calc( var(--Modal-content-startMarginTop) + 1 * var(--Modal-content-stepMarginTop) );
}

.amis-scope .a-Modal--3th .a-Modal-content {
  margin-top: calc( var(--Modal-content-startMarginTop) + 2 * var(--Modal-content-stepMarginTop) );
}

.amis-scope .a-Modal--4th .a-Modal-content {
  margin-top: calc( var(--Modal-content-startMarginTop) + 3 * var(--Modal-content-stepMarginTop) );
}

.amis-scope .a-Modal--5th .a-Modal-content {
  margin-top: calc( var(--Modal-content-startMarginTop) + 4 * var(--Modal-content-stepMarginTop) );
}

.amis-scope .a-Modal--6th .a-Modal-content {
  margin-top: calc( var(--Modal-content-startMarginTop) + 5 * var(--Modal-content-stepMarginTop) );
}

.amis-scope .a-Modal--7th .a-Modal-content {
  margin-top: calc( var(--Modal-content-startMarginTop) + 6 * var(--Modal-content-stepMarginTop) );
}

.amis-scope .a-Modal--8th .a-Modal-content {
  margin-top: calc( var(--Modal-content-startMarginTop) + 7 * var(--Modal-content-stepMarginTop) );
}

.amis-scope .a-Modal--9th .a-Modal-content {
  margin-top: calc( var(--Modal-content-startMarginTop) + 8 * var(--Modal-content-stepMarginTop) );
}

.amis-scope .a-Modal--10th .a-Modal-content {
  margin-top: calc( var(--Modal-content-startMarginTop) + 9 * var(--Modal-content-stepMarginTop) );
}

@media (min-width: 576px) {
  .amis-scope .a-Modal-content {
    max-width: var(--Modal-widthBase);
  }

  .amis-scope .a-Modal--sm .a-Modal-content {
    max-width: var(--Modal-widthSm);
  }

  .amis-scope .a-Modal--base .a-Modal-content {
    max-width: var(--Modal-widthBase);
  }

  .amis-scope .a-Modal--md .a-Modal-content {
    max-width: var(--Modal-widthMd);
  }

  .amis-scope .a-Modal--lg .a-Modal-content {
    max-width: var(--Modal-widthLg);
  }

  .amis-scope .a-Modal--xl .a-Modal-content {
    max-width: var(--Modal-widthXl);
  }
}

.amis-scope .a-Dialog-info {
  flex-basis: 0;
  flex-grow: 1;
  text-align: left;
}

.amis-scope .a-Dialog-error {
  color: var(--danger);
  white-space: pre-wrap;
}

.amis-scope .a-Modal--full {
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
}

.amis-scope .a-Modal--full > .a-Modal-content {
  flex-basis: 0;
  flex-grow: 1;
  margin: 30px;
  width: calc(100% - 60px);
  max-width: unset;
}

.amis-scope .a-Modal--full > .a-Modal-content > .a-Modal-body {
  height: 0;
  overflow: auto;
}

.amis-scope .a-Drawer {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 1400;
  overflow: hidden;
  outline: 0;
}

.amis-scope .a-Drawer-content {
  position: absolute;
  display: flex;
  flex-direction: column;
  width: 100%;
  height: 100%;
  pointer-events: auto;
  background: var(--Drawer-bg);
  background-clip: padding-box;
  outline: 0;
  z-index: 2;
  border: var(--Drawer-content-borderWidth) solid var(--Drawer-content-borderColor);
  border-radius: var(--Drawer-content-borderRadius);
  transition: transform ease-in-out var(--animation-duration);
}

.amis-scope .a-Drawer-overlay {
  transition: ease-out opacity var(--animation-duration);
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 1;
  background: var(--Drawer-overlay-bg);
  opacity: 0;
}

.amis-scope .a-Drawer-overlay.in {
  opacity: 1;
}

.amis-scope .a-Drawer-header {
  padding: var(--Drawer-header-padding);
  background: var(--Drawer-header-bg);
  border-bottom: var(--Drawer-content-borderWidth) solid var(--Drawer-header-borderColor);
  border-top-left-radius: var(--Drawer-content-borderRadius);
  border-top-right-radius: var(--Drawer-content-borderRadius);
}

.amis-scope .a-Drawer-header::before,
.amis-scope .a-Drawer-header::after {
  display: table;
  content: "";
}

.amis-scope .a-Drawer-header::after {
  clear: both;
}

.amis-scope .a-Drawer-title {
  font-size: var(--Drawer-title-fontSize);
  color: var(--Drawer-title-fontColor);
}

.amis-scope .a-Drawer-close {
  position: absolute;
  color: var(--Drawer-close-color);
  line-height: 1;
  text-decoration: none;
}

.amis-scope .a-Drawer-close svg {
  width: 30px;
  height: 30px;
  fill: var(--Drawer-close-color);
}

.amis-scope .a-Drawer-close:not(.is-disabled) {
  cursor: pointer;
}

.amis-scope .a-Drawer-close:not(.is-disabled):hover {
  text-decoration: none;
  color: var(--Drawer-close-onHover-color);
}

.amis-scope .a-Drawer-close:not(.is-disabled):hover svg {
  fill: var(--Drawer-close-onHover-color);
}

.amis-scope .a-Drawer-body {
  padding: var(--Drawer-body-padding);
  flex-basis: 0;
  flex-grow: 1;
  overflow: auto;
}

.amis-scope .a-Drawer-footer {
  display: flex;
  align-items: flex-end;
  justify-content: flex-end;
  padding: var(--Drawer-footer-padding);
  border-top: var(--Drawer-content-borderWidth) solid var(--Drawer-footer-borderColor);
  border-bottom-left-radius: var(--Drawer-content-borderRadius);
  border-bottom-right-radius: var(--Drawer-content-borderRadius);
}

.amis-scope .a-Drawer-footer .a-Button {
  margin-left: var(--gap-xs);
}

.amis-scope .a-Drawer-footer .a-Drawer-info {
  flex-basis: 0;
  flex-grow: 1;
  text-align: left;
  align-self: center;
}

.amis-scope .a-Drawer-footer .a-Drawer-error {
  color: var(--danger);
  white-space: pre-wrap;
}

.amis-scope .a-Drawer.a-Drawer--noOverlay {
  pointer-events: none;
}

.amis-scope .a-Drawer.a-Drawer--noOverlay .a-Drawer-close svg {
  margin-top: 0.125rem;
  width: var(--gap-md);
  height: var(--gap-md);
  fill: #99a6ad;
}

.amis-scope .a-Drawer .a-Drawer-resizeCtrl {
  position: absolute;
  border: var(--borderWidth) solid var(--borderColor);
  background: var(--white);
  border-radius: var(--borderRadius);
  font-size: var(--fontSizeSm);
  line-height: 0.625rem;
  text-align: center;
  user-select: none;
}

@media (min-width: 576px) {
  .amis-scope .a-Drawer .a-Drawer-content {
    width: var(--Drawer-widthBase);
    height: var(--Drawer-widthBase);
  }

  .amis-scope .a-Drawer--xs .a-Drawer-content {
    width: var(--Drawer-widthXs);
    height: var(--Drawer-widthXs);
  }

  .amis-scope .a-Drawer--sm .a-Drawer-content {
    width: var(--Drawer-widthSm);
    height: var(--Drawer-widthSm);
  }

  .amis-scope .a-Drawer--md .a-Drawer-content {
    width: var(--Drawer-widthMd);
    height: var(--Drawer-widthMd);
  }

  .amis-scope .a-Drawer--lg .a-Drawer-content {
    width: var(--Drawer-widthLg);
    height: var(--Drawer-widthLg);
  }

  .amis-scope .a-Drawer--xl .a-Drawer-content {
    width: var(--Drawer-widthXl);
    height: var(--Drawer-widthXl);
  }
}

.amis-scope .a-Drawer--top .a-Drawer-content.in,
.amis-scope .a-Drawer--right .a-Drawer-content.in,
.amis-scope .a-Drawer--bottom .a-Drawer-content.in,
.amis-scope .a-Drawer--left .a-Drawer-content.in {
  transform: translate3d(0, 0, 0);
}

.amis-scope .a-Drawer--top .a-Drawer-close {
  top: 100%;
  margin-top: var(--gap-sm);
  left: var(--gap-sm);
}

.amis-scope .a-Drawer--top.a-Drawer--noOverlay .a-Drawer-close {
  top: var(--gap-base);
  right: var(--gap-base);
  left: auto;
  margin-top: 0;
}

.amis-scope .a-Drawer--top .a-Drawer-content {
  top: 0;
  bottom: auto;
  left: 0;
  right: 0;
  width: 100%;
  transform: translate3d(0, -100%, 0);
  box-shadow: 0 10px 10px -10px rgba(0, 0, 0, 0.2);
  min-height: 120px;
}

.amis-scope .a-Drawer--top .a-Drawer-resizeCtrl {
  bottom: -0.375rem;
  left: 50%;
  cursor: ns-resize;
  width: 1.5rem;
  height: 0.75rem;
}

.amis-scope .a-Drawer--right .a-Drawer-close {
  right: 100%;
  margin-right: var(--gap-sm);
  top: var(--gap-sm);
}

.amis-scope .a-Drawer--right.a-Drawer--noOverlay .a-Drawer-close {
  top: var(--gap-base);
  right: var(--gap-base);
  margin-right: 0;
}

.amis-scope .a-Drawer--right .a-Drawer-content {
  top: 0;
  bottom: 0;
  left: auto;
  right: 0;
  height: 100%;
  transform: translate3d(100%, 0, 0);
  box-shadow: -10px 0 10px -10px rgba(0, 0, 0, 0.2);
  min-width: 120px;
}

.amis-scope .a-Drawer--right .a-Drawer-footer {
  justify-content: flex-start;
}

.amis-scope .a-Drawer--right .a-Drawer-footer .a-Button {
  margin-left: 0;
  margin-right: var(--gap-xs);
}

.amis-scope .a-Drawer--right .a-Drawer-footer .a-Drawer-info {
  flex-basis: 0;
  flex-grow: 1;
  order: 10;
  align-self: center;
  text-align: right;
}

.amis-scope .a-Drawer--right .a-Drawer-footer .a-Drawer-error {
  color: var(--danger);
}

.amis-scope .a-Drawer--right .a-Drawer-resizeCtrl {
  left: -0.375rem;
  top: 50%;
  cursor: ew-resize;
  writing-mode: vertical-lr;
  width: 0.75rem;
  height: 1.5rem;
}

.amis-scope .a-Drawer--bottom .a-Drawer-close {
  bottom: 100%;
  margin-bottom: var(--gap-sm);
  left: var(--gap-sm);
}

.amis-scope .a-Drawer--bottom.a-Drawer--noOverlay .a-Drawer-close {
  top: var(--gap-base);
  right: var(--gap-base);
  left: auto;
  margin-bottom: 0;
}

.amis-scope .a-Drawer--bottom .a-Drawer-content {
  top: auto;
  bottom: 0;
  left: 0;
  right: 0;
  width: 100%;
  transform: translate3d(0, 100%, 0);
  box-shadow: 0 -10px 10px -10px rgba(0, 0, 0, 0.2);
  min-height: 120px;
}

.amis-scope .a-Drawer--bottom .a-Drawer-resizeCtrl {
  top: -0.375rem;
  left: 50%;
  cursor: ns-resize;
  width: 1.5rem;
  height: 0.75rem;
}

.amis-scope .a-Drawer--left .a-Drawer-close {
  left: 100%;
  margin-left: var(--gap-sm);
  top: var(--gap-sm);
}

.amis-scope .a-Drawer--left.a-Drawer--noOverlay .a-Drawer-close {
  left: auto;
  right: var(--gap-base);
  top: var(--gap-base);
}

.amis-scope .a-Drawer--left .a-Drawer-content {
  top: 0;
  bottom: 0;
  right: auto;
  left: 0;
  height: 100%;
  transform: translate3d(-100%, 0, 0);
  box-shadow: 10px 0 10px -10px rgba(0, 0, 0, 0.2);
  border-width: 0 var(--Drawer-content-borderWidth) 0 0;
  min-width: 120px;
}

.amis-scope .a-Drawer--left .a-Drawer-resizeCtrl {
  right: -0.375rem;
  top: 50%;
  cursor: ew-resize;
  writing-mode: vertical-lr;
  width: 0.75rem;
  height: 1.5rem;
}

.amis-scope .a-Tooltip {
  position: absolute;
  top: 0;
  left: 0;
  font-family: inherit;
  border-radius: var(--borderRadius);
  min-width: var(--Tooltip-minWidth);
  max-width: var(--Tooltip-maxWidth);
  text-align: left;
  white-space: normal;
  z-index: 1600;
  word-wrap: break-word;
  background: var(--Tooltip-bg);
  border: var(--Tooltip-borderWidth) solid var(--Tooltip-borderColor);
  box-shadow: var(--Tooltip-boxShadow);
}

.amis-scope .a-Tooltip-arrow {
  position: absolute;
  display: block;
  width: var(--Tooltip-arrow-width);
  height: var(--Tooltip-arrow-height);
  margin-left: calc(var(--Tooltip-arrow-width) * -1 / 2);
  left: 50%;
}

.amis-scope .a-Tooltip-arrow::before,
.amis-scope .a-Tooltip-arrow::after {
  position: absolute;
  display: block;
  content: "";
  border-color: transparent;
  border-style: solid;
}

.amis-scope .a-Tooltip--top {
  margin-top: calc(var(--Tooltip-arrow-height) * -1 - 0.125rem);
}

.amis-scope .a-Tooltip--top .a-Tooltip-arrow {
  bottom: calc( (var(--Tooltip-arrow-height) + var(--Tooltip-borderWidth)) * -1 );
}

.amis-scope .a-Tooltip--top .a-Tooltip-arrow::before,
.amis-scope .a-Tooltip--top .a-Tooltip-arrow::after {
  border-width: var(--Tooltip-arrow-height) calc(var(--Tooltip-arrow-width) / 2) 0;
}

.amis-scope .a-Tooltip--top .a-Tooltip-arrow::before {
  bottom: 0;
  border-top-color: var(--Tooltip-arrow-outerColor);
}

.amis-scope .a-Tooltip--top .a-Tooltip-arrow::after {
  bottom: var(--Tooltip-borderWidth);
  border-top-color: var(--Tooltip-arrow-color);
}

.amis-scope .a-Tooltip--right {
  margin-left: calc(var(--Tooltip-arrow-height) + 0.125rem);
}

.amis-scope .a-Tooltip--right .a-Tooltip-arrow {
  left: calc(var(--Tooltip-borderWidth) * -1);
  width: var(--Tooltip-arrow-height);
  height: var(--Tooltip-arrow-width);
  margin-top: calc(var(--Tooltip-arrow-width) / -2);
  top: 50%;
}

.amis-scope .a-Tooltip--right .a-Tooltip-arrow::before,
.amis-scope .a-Tooltip--right .a-Tooltip-arrow::after {
  border-width: calc(var(--Tooltip-arrow-width) / 2) var(--Tooltip-arrow-height) calc(var(--Tooltip-arrow-width) / 2) 0;
}

.amis-scope .a-Tooltip--right .a-Tooltip-arrow::before {
  left: 0;
  border-right-color: var(--Tooltip-arrow-outerColor);
}

.amis-scope .a-Tooltip--right .a-Tooltip-arrow::after {
  left: var(--Tooltip-borderWidth);
  border-right-color: var(--Tooltip-arrow-color);
}

.amis-scope .a-Tooltip--bottom {
  margin-top: calc(var(--Tooltip-arrow-height) + 0.125rem);
}

.amis-scope .a-Tooltip--bottom .a-Tooltip-arrow {
  top: calc( (var(--Tooltip-arrow-height) + var(--Tooltip-borderWidth)) * -1 );
}

.amis-scope .a-Tooltip--bottom .a-Tooltip-arrow::before,
.amis-scope .a-Tooltip--bottom .a-Tooltip-arrow::after {
  border-width: 0 calc(var(--Tooltip-arrow-width) / 2) var(--Tooltip-arrow-height) calc(var(--Tooltip-arrow-width) / 2);
}

.amis-scope .a-Tooltip--bottom .a-Tooltip-arrow::before {
  top: 0;
  border-bottom-color: var(--Tooltip-arrow-outerColor);
}

.amis-scope .a-Tooltip--bottom .a-Tooltip-arrow::after {
  top: var(--Tooltip-borderWidth);
  border-bottom-color: var(--Tooltip-arrow-color);
}

.amis-scope .a-Tooltip--bottom .a-Tooltip-title::before {
  position: absolute;
  top: 0;
  left: 50%;
  display: block;
  width: var(--Tooltip-arrow-width);
  margin-left: calc(var(--Tooltip-arrow-width) / -2);
  content: "";
  border-bottom: var(--Tooltip-borderWidth) solid var(--Tooltip-title-bg);
}

.amis-scope .a-Tooltip--left {
  margin-left: calc(var(--Tooltip-arrow-height) * -1 - 0.125rem);
}

.amis-scope .a-Tooltip--left .a-Tooltip-arrow {
  left: auto;
  right: calc( (var(--Tooltip-arrow-height) + var(--Tooltip-borderWidth)) * -1 );
  width: var(--Tooltip-arrow-height);
  height: var(--Tooltip-arrow-width);
  margin-top: calc(var(--Tooltip-arrow-width) * -1 / 2);
  top: 50%;
}

.amis-scope .a-Tooltip--left .a-Tooltip-arrow::before,
.amis-scope .a-Tooltip--left .a-Tooltip-arrow::after {
  border-width: calc(var(--Tooltip-arrow-width) / 2) 0 calc(var(--Tooltip-arrow-width) / 2) var(--Tooltip-arrow-height);
}

.amis-scope .a-Tooltip--left .a-Tooltip-arrow::before {
  right: 0;
  border-left-color: var(--Tooltip-arrow-outerColor);
}

.amis-scope .a-Tooltip--left .a-Tooltip-arrow::after {
  right: var(--Tooltip-borderWidth);
  border-left-color: var(--Tooltip-arrow-color);
}

.amis-scope .a-Tooltip-title {
  padding: var(--Tooltip-title-paddingY) var(--Tooltip-title-paddingX);
  margin-bottom: 0;
  font-size: var(--fontSizeBase);
  color: var(--Tooltip-title-color);
  background: var(--Tooltip-title-bg);
  border-bottom: var(--Tooltip-borderWidth) solid var(--Tooltip-title-borderBottom-color);
  border-top-left-radius: calc( var(--Tooltip-borderRadius) - var(--Tooltip-borderWidth) );
  border-top-right-radius: calc( var(--Tooltip-borderRadius) - var(--Tooltip-borderWidth) );
}

.amis-scope .a-Tooltip-title:empty {
  display: none;
}

.amis-scope .a-Tooltip-body {
  color: var(--Tooltip-body-color);
  padding: var(--Tooltip-body-paddingY) var(--Tooltip-body-paddingX);
}

@keyframes tooltipIn {
  from {
    opacity: 0;
    margin: 0;
  }
}

.amis-scope [data-tooltip] {
  position: relative;
}

.amis-scope [data-tooltip]:after {
  pointer-events: none;
  left: 0;
  top: 50%;
  transform: translateY(-50%);
  position: absolute;
  content: attr(data-tooltip);
  font-size: var(--Tooltip--attr-fontSize);
  line-height: var(--Tooltip--attr-lineHeigt);
  text-align: left;
  white-space: normal;
  width: max-content;
  box-sizing: content-box;
  max-width: 300px;
  background: var(--Tooltip--attr-bg);
  border: var(--Tooltip--attr-borderWidth) solid var(--Tooltip--attr-borderColor);
  border-radius: var(--Tooltip--attr-borderRadius);
  box-shadow: var(--Tooltip--attr-boxShadow);
  left: 100%;
  color: var(--Tooltip--attr-color);
  padding: var(--Tooltip--attr-paddingY) var(--Tooltip--attr-paddingX);
  display: none;
  animation-duration: var(--animation-duration);
  animation-fill-mode: both;
}

@media screen and (min-width: 0\0 ) {
  .amis-scope [data-tooltip]:after {
    white-space: nowrap;
    max-width: unset;
  }
}

.amis-scope [data-tooltip]:not(.is-disabled):hover:after {
  display: inline-block;
  animation-name: tooltipIn;
  opacity: 1;
  z-index: 1600;
  margin: 0 0 0 var(--Tooltip--attr-gap);
  opacity: 1;
}

.amis-scope [data-tooltip][data-position=bottom]:after {
  left: 50%;
  top: 100%;
  transform: translateX(-50%);
}

.amis-scope [data-tooltip][data-position=bottom]:hover:after {
  margin: var(--Tooltip--attr-gap) 0 0 0;
}

.amis-scope [data-tooltip][data-position=left]:after {
  top: 50%;
  right: 100%;
  left: auto;
  transform: translateY(-50%);
}

.amis-scope [data-tooltip][data-position=left]:hover:after {
  margin: 0 var(--Tooltip--attr-gap) 0 0;
}

.amis-scope [data-tooltip][data-position=top]:after {
  left: 50%;
  top: auto;
  bottom: 100%;
  transform: translateX(-50%);
}

.amis-scope [data-tooltip][data-position=top]:hover:after {
  margin: calc(var(--Tooltip--attr-gap) * -1) 0 0 0;
}

.amis-scope [data-tooltip]:hover:active:after {
  content: "";
  display: none !important;
}

.amis-scope .a-TplField.is-inline {
  display: inline;
}

.amis-scope .a-PopOver {
  position: absolute;
  background: var(--PopOver-bg);
  top: 0;
  left: 0;
  z-index: 1300;
  display: none;
  padding: 0;
  margin: 0;
  font-weight: var(--fontWeightNormal);
  letter-spacing: normal;
  line-height: var(--lineHeightBase);
  text-align: left;
  text-align: start;
  text-decoration: none;
  text-shadow: none;
  text-transform: none;
  white-space: normal;
  word-break: normal;
  word-spacing: normal;
  word-wrap: normal;
  font-size: var(--fontSizeBase);
  box-shadow: var(--boxShadow);
  border: var(--borderWidth) solid var(--borderColor);
  border-radius: var(--borderRadius);
}

.amis-scope .a-PopOver > * {
  position: relative;
  z-index: 2;
}

.amis-scope .a-PopOver-overlay {
  position: fixed !important;
  top: 0;
  left: 0;
  right: 0;
  z-index: 1;
  bottom: 0;
  background: transparent;
}

@keyframes bounceIn {
  from, 20%, 40%, 60%, 80%, to {
    animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
  }

  0% {
    opacity: 0;
    transform: scale3d(0.3, 0.3, 0.3);
  }

  20% {
    transform: scale3d(1.1, 1.1, 1.1);
  }

  40% {
    transform: scale3d(0.9, 0.9, 0.9);
  }

  60% {
    opacity: 1;
    transform: scale3d(1.03, 1.03, 1.03);
  }

  80% {
    transform: scale3d(0.97, 0.97, 0.97);
  }

  to {
    opacity: 1;
    transform: scale3d(1, 1, 1);
  }
}

@keyframes bounceOut {
  20% {
    transform: scale3d(0.9, 0.9, 0.9);
  }

  50%, 55% {
    opacity: 1;
    transform: scale3d(1.1, 1.1, 1.1);
  }

  to {
    opacity: 0;
    transform: scale3d(0.3, 0.3, 0.3);
  }
}

.amis-scope .a-Toast {
  display: flex;
  align-items: center;
  max-width: var(--Toast-width);
  pointer-events: auto;
  margin-bottom: var(--gap-xs);
  padding: var(--Toast-paddingY) var(--Toast-paddingX);
  box-shadow: var(--Toast-box-shadow);
  border-radius: var(--Toast-borderRadius);
  border: var(--Toast-border-width) solid;
  color: var(--Toast-color);
  position: relative;
  opacity: var(--Toast-opacity);
  cursor: pointer;
  opacity: 0;
  transform: translateZ(0);
}

.amis-scope .a-Toast-wrap {
  pointer-events: none;
  position: fixed;
  z-index: 2000;
}

.amis-scope .a-Toast.in,
.amis-scope .a-Toast.out {
  animation-fill-mode: both;
  animation-duration: var(--animation-duration);
  opacity: 1;
}

.amis-scope .a-Toast.in {
  animation-name: bounceIn;
}

.amis-scope .a-Toast.out {
  animation-name: bounceOut;
}

.amis-scope .a-Toast-close {
  color: var(--Toast-close-color);
  display: inline-flex;
  margin-left: var(--gap-xs);
  opacity: 0.8;
}

.amis-scope .a-Toast-close:hover {
  color: var(--Toast-close--onHover-color);
  opacity: 1;
}

.amis-scope .a-Toast-body {
  display: inline-block;
  vertical-align: middle;
  white-space: pre-wrap;
  flex-grow: 1;
}

.amis-scope .a-Toast-icon {
  display: inline-flex;
  text-rendering: auto;
  -webkit-font-smoothing: antialiased;
  vertical-align: middle;
  margin-right: var(--gap-xs);
}

.amis-scope .a-Toast-icon > svg {
  top: 0;
  width: var(--Toast-icon-width);
  height: var(--Toast-icon-height);
  color: inherit;
}

.amis-scope .a-Toast--error {
  color: var(--Toast--danger-color);
  border-color: var(--Toast--danger-borderColor);
  background: var(--Toast--danger-bgColor);
}

.amis-scope .a-Toast--warning {
  color: var(--Toast--warning-color);
  border-color: var(--Toast--warning-borderColor);
  background: var(--Toast--warning-bgColor);
}

.amis-scope .a-Toast--info {
  color: var(--Toast--info-color);
  border-color: var(--Toast--info-borderColor);
  background: var(--Toast--info-bgColor);
}

.amis-scope .a-Toast--success {
  color: var(--Toast--success-color);
  border-color: var(--Toast--success-borderColor);
  background: var(--Toast--success-bgColor);
}

.amis-scope .a-Toast-wrap--topRight {
  top: var(--gap-base);
  right: var(--gap-base);
}

.amis-scope .a-Toast-wrap--topCenter {
  top: var(--gap-base);
  left: 50%;
  margin-left: calc(var(--Toast-width) / -2);
}

.amis-scope .a-Toast-wrap--topLeft {
  top: var(--gap-base);
  left: var(--gap-base);
}

.amis-scope .a-Toast-wrap--bottomLeft {
  left: var(--gap-base);
  bottom: var(--gap-base);
}

.amis-scope .a-Toast-wrap--bottomCenter {
  left: 50%;
  margin-left: calc(var(--Toast-width) / -2);
  bottom: var(--gap-base);
}

.amis-scope .a-Toast-wrap--bottomRight {
  bottom: var(--gap-base);
  right: var(--gap-base);
}

.amis-scope .a-Alert {
  font-size: var(--Alert-fontSize);
  box-shadow: var(--Alert-boxShadow);
  padding: var(--Alert-paddingY) var(--Alert-paddingX);
  border: var(--Alert-borderWidth) solid var(--Alert-borderColor);
  border-radius: var(--Alert-borderRadius);
  margin-bottom: var(--Alert-marginBottom);
  position: relative;
}

.amis-scope .a-Alert-close {
  position: absolute;
  outline: none;
  padding: 0;
  cursor: pointer;
  background: transparent;
  border: 0;
  float: right;
  line-height: 1;
  color: #000;
  text-shadow: 0 1px 0 #fff;
  filter: alpha(opacity=20);
  opacity: 0.2;
  right: var(--Alert-paddingX);
  top: 50%;
  transform: translateY(-50%);
}

.amis-scope .a-Alert-close:hover {
  color: #000;
  text-decoration: none;
  cursor: pointer;
  filter: alpha(opacity=50);
  opacity: 0.5;
}

.amis-scope .a-Alert--danger {
  color: var(--Alert--danger-color);
  background: var(--Alert--danger-bg);
  border-color: var(--Alert--danger-borderColor);
}

.amis-scope .a-Alert--info {
  color: var(--Alert--info-color);
  background: var(--Alert--info-bg);
  border-color: var(--Alert--info-borderColor);
}

.amis-scope .a-Alert--success {
  color: var(--Alert--success-color);
  background: var(--Alert--success-bg);
  border-color: var(--Alert--success-borderColor);
}

.amis-scope .a-Alert--warning {
  color: var(--Alert--warning-color);
  background: var(--Alert--warning-bg);
  border-color: var(--Alert--warning-borderColor);
}

.amis-scope .a-AppBcn {
  height: 1.875rem;
  line-height: 1.875rem;
  font-size: 0.75rem;
  list-style: none;
  margin: 0;
  padding: 0 0 0 var(--gap-md);
  border-bottom: var(--borderWidth) solid var(--borderColor);
}

.amis-scope .a-AppBcn-item {
  display: inline-block;
}

.amis-scope .a-AppBcn-item + .a-AppBcn-item:before {
  padding: 0 5px;
  color: #ccc;
  content: "/ ";
}

.amis-scope .a-AppFoldBtn {
  color: var(--icon-color);
  padding: 0.625rem;
  margin-left: -0.625rem;
  cursor: pointer;
}

.amis-scope .a-AppFoldBtn:hover {
  color: var(--icon-onHover-color);
}

.amis-scope .a-AppLogo-html {
  display: inline-flex;
  vertical-align: middle;
}

.amis-scope .a-ArrayInput-placeholder {
  color: var(--text--muted-color);
  padding-top: var(--Form-label-paddingTop);
}

.amis-scope .a-ArrayInput-addBtn {
  font-size: var(--Combo-addBtn-fontSize);
  padding: var(--Combo-addBtn-paddingY) var(--Combo-addBtn-paddingX);
  font-size: var(--Combo-addBtn-fontSize);
  line-height: var(--Combo-addBtn-lineHeight);
  border-radius: var(--Combo-addBtn-borderRadius);
  height: var(--Combo-addBtn-height);
  color: var(--Combo-addBtn-color);
  background: var(--Combo-addBtn-bg);
  border-color: var(--Combo-addBtn-border);
  box-shadow: var(--Button-boxShadow);
  text-shadow: var(--Button-textShadow);
}

.amis-scope .a-ArrayInput-addBtn > svg {
  width: var(--Combo-addBtn-fontSize);
  height: var(--Combo-addBtn-fontSize);
}

.amis-scope .a-ArrayInput-addBtn .a-Button-icon:first-child:not(:last-child):not(.pull-right),
.amis-scope .a-ArrayInput-addBtn > svg.icon:not(:last-child):not(.pull-right),
.amis-scope .a-ArrayInput-addBtn > .pull-left {
  margin-right: var(--Combo-addBtn-paddingX);
}

.amis-scope .a-ArrayInput-addBtn .a-Button-icon:last-child:not(:first-child):not(.pull-left),
.amis-scope .a-ArrayInput-addBtn > .pull-right {
  margin-left: var(--Combo-addBtn-paddingX);
}

.amis-scope .a-ArrayInput-addBtn img.a-Button-icon {
  height: var(--Button-fontSize);
  vertical-align: middle;
}

.amis-scope .a-ArrayInput-addBtn:not(:disabled):not(.is-disabled):hover {
  color: var(--Combo-addBtn-onHover-color);
  background: var(--Combo-addBtn-onHover-bg);
  border-color: var(--Combo-addBtn-onHover-border);
}

.amis-scope .a-ArrayInput-addBtn:hover:focus {
  box-shadow: var(--Button-boxShadow);
}

.amis-scope .a-ArrayInput-addBtn.is-disabled {
  pointer-events: none;
  opacity: var(--Button-onDisabled-opacity);
}

.amis-scope .a-ArrayInput-toolbar {
  margin-top: var(--gap-sm);
  display: flex;
  flex-direction: row;
  justify-content: space-between;
}

.amis-scope .a-ArrayInput-toolbar--dnd {
  padding-left: 29px;
}

.amis-scope .a-ArrayInput-sortTip {
  color: var(--text--muted-color);
}

.amis-scope .a-ArrayInput-item {
  display: flex;
  flex-direction: row;
  align-items: flex-start;
  margin-bottom: var(--gap-xs);
}

.amis-scope .a-ArrayInput-item > div {
  flex-grow: 1;
  width: 0;
  min-width: 120px;
  margin-right: var(--gap-xs);
}

.amis-scope .a-ArrayInput-item > div:not(:first-child) {
  margin-left: var(--gap-xs);
}

.amis-scope .a-ArrayInput-item--dragging {
  position: relative;
  opacity: 0.4;
}

.amis-scope .a-ArrayInput-itemRemove,
.amis-scope .a-ArrayInput-itemDrager {
  margin: 0;
  flex-grow: unset;
  display: inline-block;
  padding: var(--Form-label-paddingTop) var(--gap-xs);
  cursor: pointer;
}

.amis-scope .a-ArrayInput-itemRemove > svg,
.amis-scope .a-ArrayInput-itemDrager > svg {
  color: var(--icon-color);
}

.amis-scope .a-ArrayInput-itemRemove:hover > svg,
.amis-scope .a-ArrayInput-itemDrager:hover > svg {
  color: var(--icon-onHover-color);
}

.amis-scope .a-ArrayInput-itemDrager {
  cursor: move;
}

.amis-scope .a-Tabs-linksContainer {
  position: relative;
}

.amis-scope .a-Tabs-linksContainer-arrow {
  height: 100%;
  display: flex;
  align-items: center;
  top: 0;
  cursor: pointer;
  position: absolute;
}

.amis-scope .a-Tabs-linksContainer-arrow .iconfont {
  font-size: var(--Remark-icon-fontSize);
}

.amis-scope .a-Tabs-linksContainer-arrow:hover {
  color: var(--icon-onHover-color);
}

.amis-scope .a-Tabs-linksContainer-arrow--left {
  left: 4px;
}

.amis-scope .a-Tabs-linksContainer-arrow--right {
  right: 4px;
}

.amis-scope .a-Tabs-linksContainer-arrow--disabled .iconfont {
  cursor: not-allowed;
  color: var(--Number-handler-onDisabled-color);
}

.amis-scope .a-Tabs-linksContainer-arrow--disabled:hover {
  color: var(--Number-handler-onDisabled-color);
}

.amis-scope .a-Tabs-linksContainer-main {
  overflow-y: auto;
  scrollbar-width: none;
  width: 100%;
}

.amis-scope .a-Tabs-linksContainer-main::-webkit-scrollbar {
  display: none;
}

.amis-scope .a-Tabs-linksContainer-main > .a-Tabs-links {
  white-space: nowrap;
  min-width: 100%;
  display: inline-block;
}

.amis-scope .a-Tabs .a-Tabs-linksContainer--overflow {
  padding: 0 20px;
}

.amis-scope .a-Tabs-links {
  margin: 0;
  padding: 0;
  border-bottom: var(--Tabs-borderWidth) solid var(--Tabs-borderColor);
  list-style: none;
  user-select: none;
}

.amis-scope .a-Tabs-links::before,
.amis-scope .a-Tabs-links::after {
  display: table;
  content: "";
}

.amis-scope .a-Tabs-links::after {
  clear: both;
}

.amis-scope .a-Tabs-links > .a-Tabs-link {
  margin-bottom: calc(var(--Tabs-borderWidth) * -1);
  display: inline-block;
  position: relative;
}

.amis-scope .a-Tabs-links > .a-Tabs-link > a:first-child {
  font-size: var(--Tabs-linkFontSize);
  outline: none;
  border: var(--Tabs-borderWidth) solid transparent;
  border-top-left-radius: var(--Tabs-borderRadius);
  border-top-right-radius: var(--Tabs-borderRadius);
  color: var(--Tabs-color);
  margin: var(--Tabs-linkMargin);
  padding: var(--Tabs-linkPadding);
  text-decoration: none;
  cursor: pointer;
  display: block;
}

.amis-scope .a-Tabs-links > .a-Tabs-link > .a-Combo-toolbarBtn {
  position: absolute;
  right: -10px;
  top: -10px;
  z-index: 10;
  display: none;
}

.amis-scope .a-Tabs-links > .a-Tabs-link:hover > .a-Combo-toolbarBtn {
  display: block;
}

.amis-scope .a-Tabs-links > .a-Tabs-link:hover > a:first-child,
.amis-scope .a-Tabs-links > .a-Tabs-link > a:first-child:focus {
  border-color: var(--Tabs-onHover-borderColor);
  text-decoration: none;
}

.amis-scope .a-Tabs-links > .a-Tabs-link.disabled,
.amis-scope .a-Tabs-links > .a-Tabs-link.is-disabled {
  cursor: not-allowed;
}

.amis-scope .a-Tabs-links > .a-Tabs-link.disabled > a:first-child,
.amis-scope .a-Tabs-links > .a-Tabs-link.is-disabled > a:first-child {
  color: var(--Tabs-onDisabled-color);
  background: transparent;
  border-color: transparent;
  pointer-events: none;
}

.amis-scope .a-Tabs-links > .a-Tabs-link.active > a:first-child,
.amis-scope .a-Tabs-links > .a-Tabs-link.is-active > a:first-child {
  color: var(--Tabs-onActive-color);
  background: var(--Tabs-onActive-bg);
  border-color: var(--Tabs-onActive-borderColor);
  border-bottom-color: transparent;
}

.amis-scope .a-Tabs-content {
  background: var(--Tabs-content-bg);
  border-style: solid;
  border-width: 0 var(--Tabs-borderWidth) var(--Tabs-borderWidth);
  border-color: var(--Tabs-borderColor);
}

.amis-scope .a-Tabs-pane {
  display: none;
  padding: var(--gap-base);
  opacity: 0;
  transition: opacity var(--animation-duration) linear;
}

.amis-scope .a-Tabs-pane.is-active {
  display: block;
}

.amis-scope .a-Tabs-pane.in {
  opacity: 1;
}

.amis-scope .a-Tabs--line > .a-Tabs-linksContainer > .a-Tabs-linksContainer-arrow {
  top: -4px;
}

.amis-scope .a-Tabs--line > .a-Tabs-links,
.amis-scope .a-Tabs--line > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links {
  border-bottom-color: var(--Tabs--line-borderColor);
}

.amis-scope .a-Tabs--line > .a-Tabs-links > li > a:first-child,
.amis-scope .a-Tabs--line > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links > li > a:first-child {
  border-width: 0 0 var(--Tabs--line-borderWidth) 0;
  padding: var(--Tabs--line-linkPadding);
  margin: var(--Tabs--line-linkMargin);
}

.amis-scope .a-Tabs--line > .a-Tabs-links > li > a:first-child:hover,
.amis-scope .a-Tabs--line > .a-Tabs-links > li > a:first-child:focus,
.amis-scope .a-Tabs--line > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links > li > a:first-child:hover,
.amis-scope .a-Tabs--line > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links > li > a:first-child:focus {
  color: var(--primary);
  background: transparent;
  border-color: transparent;
}

.amis-scope .a-Tabs--line > .a-Tabs-links > li:last-child > a,
.amis-scope .a-Tabs--line > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links > li:last-child > a {
  margin: 0;
}

.amis-scope .a-Tabs--line > .a-Tabs-links > li.is-active > a:first-child,
.amis-scope .a-Tabs--line > .a-Tabs-links > li.is-active > a:first-child:hover,
.amis-scope .a-Tabs--line > .a-Tabs-links > li.is-active > a:first-child:focus,
.amis-scope .a-Tabs--line > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links > li.is-active > a:first-child,
.amis-scope .a-Tabs--line > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links > li.is-active > a:first-child:hover,
.amis-scope .a-Tabs--line > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links > li.is-active > a:first-child:focus {
  border-color: var(--Tabs--line-onHover-borderColor);
  color: var(--Tabs--line-onHover-color);
  background: transparent;
}

.amis-scope .a-Tabs--line > .a-Tabs-content {
  border-width: 0;
  padding: var(--Tabs--line-content-padding);
  background: var(--Tabs--line-content-bg);
}

.amis-scope .a-Tabs--card > .a-Tabs-linksContainer {
  background: var(--Tabs--card-bg);
}

.amis-scope .a-Tabs--card > .a-Tabs-links,
.amis-scope .a-Tabs--card > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links {
  padding: var(--Tabs--card-padding);
  background: var(--Tabs--card-bg);
  border-top: 0.0625rem solid var(--Tabs--card-borderTopColor);
}

.amis-scope .a-Tabs--card > .a-Tabs-links > li.is-active > a:first-child,
.amis-scope .a-Tabs--card > .a-Tabs-links > li.is-active > a:first-child:hover,
.amis-scope .a-Tabs--card > .a-Tabs-links > li.is-active > a:first-child:focus,
.amis-scope .a-Tabs--card > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links > li.is-active > a:first-child,
.amis-scope .a-Tabs--card > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links > li.is-active > a:first-child:hover,
.amis-scope .a-Tabs--card > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links > li.is-active > a:first-child:focus {
  border-color: var(--Tabs--card-onActive-borderColor);
  color: var(--primary);
  border-bottom-color: var(--Tabs--card-onActive-bg);
  background: var(--Tabs--card-onActive-bg);
}

.amis-scope .a-Tabs--card > .a-Tabs-links > li > a:first-child,
.amis-scope .a-Tabs--card > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links > li > a:first-child {
  padding: var(--Tabs--card-linkPadding);
  margin: var(--Tabs--card-linkMargin);
}

.amis-scope .a-Tabs--card > .a-Tabs-links > li > a:first-child:hover,
.amis-scope .a-Tabs--card > .a-Tabs-links > li > a:first-child:focus,
.amis-scope .a-Tabs--card > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links > li > a:first-child:hover,
.amis-scope .a-Tabs--card > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links > li > a:first-child:focus {
  color: #666;
  background: var(--Tabs--card-onActive-bg);
  border-bottom-color: transparent;
}

.amis-scope .a-Tabs--card > .a-Tabs-content {
  border-width: 0;
}

.amis-scope .a-Tabs--radio > .a-Tabs-linksContainer > .a-Tabs-linksContainer-arrow {
  top: -4px;
}

.amis-scope .a-Tabs--radio > .a-Tabs-links,
.amis-scope .a-Tabs--radio > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links {
  border: 0;
  margin-bottom: 0.625rem;
}

.amis-scope .a-Tabs--radio > .a-Tabs-links > li,
.amis-scope .a-Tabs--radio > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links > li {
  margin: 0;
}

.amis-scope .a-Tabs--radio > .a-Tabs-links > li > a:first-child,
.amis-scope .a-Tabs--radio > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links > li > a:first-child {
  border-width: 0.0625rem;
  border-color: var(--Tabs-borderColor);
  font-size: var(--fontSizeSm);
  text-align: center;
  margin: 0;
  padding: 0 0.625rem;
  min-width: 68px;
  height: 1.875rem;
  line-height: 1.875rem;
  border-radius: 0;
  background: var(--Tabs--radio-bg);
}

.amis-scope .a-Tabs--radio > .a-Tabs-links > li > a:first-child:hover,
.amis-scope .a-Tabs--radio > .a-Tabs-links > li > a:first-child:focus,
.amis-scope .a-Tabs--radio > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links > li > a:first-child:hover,
.amis-scope .a-Tabs--radio > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links > li > a:first-child:focus {
  color: var(--primary);
}

.amis-scope .a-Tabs--radio > .a-Tabs-links > li.is-active > a:first-child,
.amis-scope .a-Tabs--radio > .a-Tabs-links > li.is-active > a:first-child:hover,
.amis-scope .a-Tabs--radio > .a-Tabs-links > li.is-active > a:first-child:focus,
.amis-scope .a-Tabs--radio > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links > li.is-active > a:first-child,
.amis-scope .a-Tabs--radio > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links > li.is-active > a:first-child:hover,
.amis-scope .a-Tabs--radio > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links > li.is-active > a:first-child:focus {
  color: var(--Tabs--radio-bg);
  background: var(--primary);
  border-color: var(--primary);
  position: relative;
  z-index: 1;
}

.amis-scope .a-Tabs--radio > .a-Tabs-links > li + li,
.amis-scope .a-Tabs--radio > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links > li + li {
  margin-left: -1px;
}

.amis-scope .a-Tabs--radio > .a-Tabs-content {
  border-top: var(--Tabs-borderWidth) solid var(--Tabs-borderColor);
}

.amis-scope .a-Tabs--tiled > .a-Tabs-links,
.amis-scope .a-Tabs--tiled > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links {
  width: 100%;
  display: flex;
  flex-direction: row;
  padding-left: var(--Tabs-borderWidth);
  border-bottom: 0;
}

.amis-scope .a-Tabs--tiled > .a-Tabs-links > li,
.amis-scope .a-Tabs--tiled > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links > li {
  flex-grow: 1;
  text-align: center;
  margin: 0 0 0 calc(var(--Tabs-borderWidth) * -1);
}

.amis-scope .a-Tabs--tiled > .a-Tabs-links > li > a:first-child,
.amis-scope .a-Tabs--tiled > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links > li > a:first-child {
  margin: 0;
  border-radius: 0;
  border-style: solid;
  border-color: var(--Tabs-borderColor);
  border-width: var(--Tabs-borderWidth);
}

.amis-scope .a-Tabs--tiled > .a-Tabs-links > li > a:first-child:hover,
.amis-scope .a-Tabs--tiled > .a-Tabs-links > li > a:first-child:focus,
.amis-scope .a-Tabs--tiled > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links > li > a:first-child:hover,
.amis-scope .a-Tabs--tiled > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links > li > a:first-child:focus {
  position: relative;
  z-index: 1;
  border-color: var(--Tabs-onActive-borderColor);
  color: var(--primary);
}

.amis-scope .a-Tabs--tiled > .a-Tabs-links > li.is-active > a:first-child,
.amis-scope .a-Tabs--tiled > .a-Tabs-links > li.is-active > a:first-child:hover,
.amis-scope .a-Tabs--tiled > .a-Tabs-links > li.is-active > a:first-child:focus,
.amis-scope .a-Tabs--tiled > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links > li.is-active > a:first-child,
.amis-scope .a-Tabs--tiled > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links > li.is-active > a:first-child:hover,
.amis-scope .a-Tabs--tiled > .a-Tabs-linksContainer > .a-Tabs-linksContainer-main > .a-Tabs-links > li.is-active > a:first-child:focus {
  cursor: default;
  color: var(--primary);
  border-color: var(--Tabs-borderColor);
  border-top-color: var(--primary);
  border-bottom-color: transparent;
}

.amis-scope .a-Tabs--vertical {
  display: flex;
  min-height: 12.5rem;
  border: var(--Tabs-borderWidth) solid var(--Tabs-borderColor);
  border-radius: 0;
}

.amis-scope .a-Tabs--vertical > .a-Tabs-links {
  width: var(--Tabs--vertical-width);
  background: var(--Tabs--vertical-onActive-container-bg);
  border: none;
  border-right: var(--Tabs--vertical-onActive-container-borderRight);
  padding-bottom: 3.75rem;
}

.amis-scope .a-Tabs--vertical > .a-Tabs-links > li {
  margin: 0 0 0 -1px;
  display: block;
}

.amis-scope .a-Tabs--vertical > .a-Tabs-links > li > a:first-child {
  border-color: transparent;
  border-radius: 0;
  border-width: var(--Tabs--vertical-onActive-borderWidth);
  margin: 0;
}

.amis-scope .a-Tabs--vertical > .a-Tabs-links > li > a:first-child:hover,
.amis-scope .a-Tabs--vertical > .a-Tabs-links > li > a:first-child:focus {
  color: var(--primary);
  border-color: transparent;
}

.amis-scope .a-Tabs--vertical > .a-Tabs-links > li.is-active > a:first-child,
.amis-scope .a-Tabs--vertical > .a-Tabs-links > li.is-active > a:first-child:hover,
.amis-scope .a-Tabs--vertical > .a-Tabs-links > li.is-active > a:first-child:focus {
  color: var(--Tabs--vertical-onActive-color);
  background: var(--Tabs--vertical-onActive-bg);
  border-color: var(--Tabs--vertical-onActive-border);
}

.amis-scope .a-Tabs--vertical > .a-Tabs-content {
  border: none;
  flex-grow: 1;
}

.amis-scope .a-Tabs--vertical > .a-Tabs-content > .a-Tabs-pane {
  height: 100%;
}

.amis-scope .a-Tabs--chrome > .a-Tabs-links {
  background: var(--Tabs--chrome-bg);
  border-bottom: 0;
  padding: 0 0.625rem;
  padding-top: 0.5rem;
  display: flex;
}

.amis-scope .a-Tabs--chrome > .a-Tabs-links > li {
  position: relative;
  margin-bottom: 0;
  white-space: nowrap;
  min-width: 0;
  max-width: 15.625rem;
  padding: 0.4375rem 1.25rem 0.375rem;
  cursor: pointer;
  flex: 1;
}

.amis-scope .a-Tabs--chrome > .a-Tabs-links > li > a:first-child {
  background: none;
  border: none;
  position: relative;
  z-index: 5;
  overflow: hidden;
  padding: 0;
}

.amis-scope .a-Tabs--chrome > .a-Tabs-links > li.is-active > a:first-child,
.amis-scope .a-Tabs--chrome > .a-Tabs-links > li.is-active > a:first-child:hover,
.amis-scope .a-Tabs--chrome > .a-Tabs-links > li.is-active > a:first-child:focus {
  background: none;
  border: none;
}

.amis-scope .a-Tabs--chrome > .a-Tabs-links > li.is-active:after {
  display: none;
}

.amis-scope .a-Tabs--chrome > .a-Tabs-links > li:after {
  content: "";
  width: 1px;
  height: calc(100% - var(--Tabs--chrome-radius-size) * 2);
  position: absolute;
  right: -2px;
  background: var(--Tabs--chrome-right-boder-color);
  top: var(--Tabs--chrome-radius-size);
}

.amis-scope .a-Tabs--chrome > .a-Tabs-links > li:hover .chrome-tab-background {
  z-index: 3;
  display: block;
  background-color: var(--Tabs--chrome-onHover-bg);
}

.amis-scope .a-Tabs--chrome > .a-Tabs-links > li:hover .chrome-tab-background > svg {
  fill: var(--Tabs--chrome-onHover-bg);
}

.amis-scope .a-Tabs--chrome > .a-Tabs-links > li:hover:after {
  display: none;
}

.amis-scope .a-Tabs--chrome > .a-Tabs-links > li.is-active .chrome-tab-background {
  display: block;
  background-color: var(--Tabs-onActive-bg);
}

.amis-scope .a-Tabs--chrome > .a-Tabs-links > li.is-active .chrome-tab-background > svg {
  fill: var(--Tabs-onActive-bg);
}

.amis-scope .a-Tabs--chrome .chrome-tab-background {
  display: none;
  position: absolute;
  z-index: 4;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  pointer-events: none;
  border-radius: var(--Tabs--chrome-radius-size) var(--Tabs--chrome-radius-size) 0 0;
}

.amis-scope .a-Tabs--chrome .chrome-tab-background > svg {
  width: var(--Tabs--chrome-radius-size);
  height: var(--Tabs--chrome-radius-size);
  bottom: 0;
  position: absolute;
}

.amis-scope .a-Tabs--chrome .chrome-tab-background > .chrome-tab-background--right {
  right: calc(var(--Tabs--chrome-radius-size) * -1);
}

.amis-scope .a-Tabs--chrome .chrome-tab-background > .chrome-tab-background--left {
  left: calc(var(--Tabs--chrome-radius-size) * -1);
}

.amis-scope .a-Tabs-toolbar {
  display: inline-block;
  float: right;
  padding-top: var(--gap-xs);
}

.amis-scope .a-Nav {
  list-style: none;
  user-select: none;
  margin: 0;
  padding: 0;
  position: relative;
}

.amis-scope .a-Nav .a-Nav-itemIcon {
  margin-right: var(--gap-sm);
}

.amis-scope .a-Nav img.a-Nav-itemIcon {
  height: var(--Tabs-linkFontSize);
  vertical-align: middle;
}

.amis-scope .a-Nav--tabs {
  border-bottom: var(--Tabs-borderWidth) solid var(--Tabs-borderColor);
}

.amis-scope .a-Nav--tabs .a-Nav-item {
  margin-bottom: calc(var(--Tabs-borderWidth) * -1);
  display: inline-block;
}

.amis-scope .a-Nav--tabs .a-Nav-item > a {
  font-size: var(--Tabs-linkFontSize);
  display: block;
  outline: none;
  border: var(--Tabs-borderWidth) solid transparent;
  border-top-left-radius: var(--Tabs-borderRadius);
  border-top-right-radius: var(--Tabs-borderRadius);
  color: var(--Tabs-color);
  text-decoration: none;
  margin-right: 0.125rem;
  padding: var(--gap-sm) var(--gap-base);
  cursor: pointer;
}

.amis-scope .a-Nav--tabs .a-Nav-item:hover > a,
.amis-scope .a-Nav--tabs .a-Nav-item > a:focus {
  border-color: var(--Tabs-onHover-borderColor);
  text-decoration: none;
}

.amis-scope .a-Nav--tabs .a-Nav-item.disabled > a,
.amis-scope .a-Nav--tabs .a-Nav-item.is-disabled > a {
  color: var(--Tabs-onDisabled-color);
  background: transparent;
  border-color: transparent;
  pointer-events: none;
}

.amis-scope .a-Nav--tabs .a-Nav-item.active > a,
.amis-scope .a-Nav--tabs .a-Nav-item.is-active > a {
  color: var(--Tabs-onActive-color);
  background: var(--Tabs-onActive-bg);
  border-color: var(--Tabs-onActive-borderColor);
  border-bottom-color: var(--Tabs-content-bg);
}

.amis-scope .a-Nav--stacked {
  min-height: 3.125rem;
}

.amis-scope .a-Nav--stacked .a-Nav-item {
  position: relative;
}

.amis-scope .a-Nav--stacked .a-Nav-item > a {
  display: block;
  outline: none;
  color: var(--Nav-item-color);
  text-decoration: none;
  padding: var(--gap-sm) var(--gap-base);
  cursor: pointer;
  background: var(--Nav-item-bg);
  border-radius: var(--Nav-item-borderRadius);
  text-overflow: ellipsis;
}

.amis-scope .a-Nav--stacked .a-Nav-item > a::after {
  border-left: var(--Nav-item-onActive-borderLeft);
  position: absolute;
  left: 0;
  top: 0;
  content: "";
  width: 1px;
  height: 100%;
  transform: scaleY(0.0001);
  transition: transform 0.15s cubic-bezier(0.215, 0.61, 0.355, 1), opacity 0.15s cubic-bezier(0.215, 0.61, 0.355, 1);
}

.amis-scope .a-Nav--stacked .a-Nav-item.has-sub > a {
  padding-right: calc(var(--gap-base) + var(--gap-sm));
}

.amis-scope .a-Nav--stacked .a-Nav-item > a:hover,
.amis-scope .a-Nav--stacked .a-Nav-item > a:focus {
  border-color: var(--Nav-item-onHover-color);
  text-decoration: none;
  background: var(--Nav-item-onHover-bg);
}

.amis-scope .a-Nav--stacked .a-Nav-item.disabled > a,
.amis-scope .a-Nav--stacked .a-Nav-item.is-disabled > a {
  color: var(--Nav-item-onDisabled-color);
  background: transparent;
  pointer-events: none;
}

.amis-scope .a-Nav--stacked .a-Nav-item.active > a,
.amis-scope .a-Nav--stacked .a-Nav-item.is-active > a {
  color: var(--Nav-item-onActive-color);
  background: var(--Nav-item-onActive-bg);
  padding-left: 0.75rem;
  position: relative;
}

.amis-scope .a-Nav--stacked .a-Nav-item.active > a::after,
.amis-scope .a-Nav--stacked .a-Nav-item.is-active > a::after {
  transform: scaleY(1);
}

.amis-scope .a-Nav--stacked .a-Nav-item.is-unfolded > .a-Nav-itemToggler {
  transform: rotate(180deg) scale(0.8);
}

.amis-scope .a-Nav--stacked .a-Nav-item.is-unfolded > .a-Nav-subItems {
  display: block;
}

.amis-scope .a-Nav--stacked .a-Nav-item .a-Nav-spinner {
  position: absolute;
  right: 0.625rem;
  top: 0.5rem;
}

.amis-scope .a-Nav--stacked .a-Nav-item .a-Nav-itemToggler {
  position: absolute;
  right: 0;
  top: 0.1875rem;
  width: 1.875rem;
  height: 1.875rem;
  text-align: center;
  line-height: 1.875rem;
  vertical-align: middle;
  cursor: pointer;
  transform: scale(0.8);
  transition: transform var(--animation-duration);
}

.amis-scope .a-Nav--stacked .a-Nav-item .a-Nav-itemToggler > svg {
  width: 10px;
  height: 10px;
  top: 0;
}

.amis-scope .a-Nav--stacked .a-Nav-item .a-Nav-subItems {
  display: none;
  padding-left: 0;
  list-style: none;
}

.amis-scope .a-Nav--stacked .a-Nav-item .a-Nav-item {
  font-size: var(--Nav-subItem-fontSize);
}

.amis-scope .a-Page {
  width: 100%;
  height: 100%;
}

.amis-scope .a-Page-header {
  padding: var(--Page-header-paddingY) var(--Page-header-paddingX);
}

.amis-scope .a-Page-main {
  background: var(--Page-main-bg);
  height: 100%;
  display: flex;
  flex-direction: column;
}

.amis-scope .a-Page-content {
  padding: var(--Page-content-paddingY) var(--Page-content-paddingX);
  position: relative;
  height: 100%;
  width: 100%;
}

.amis-scope .a-Page-main > .a-Page-header {
  border-bottom: var(--borderWidth) solid var(--borderColor);
  background: var(--Page-header-bg);
}

.amis-scope .a-Page-headerRow {
  background: var(--Page-header-bg);
  border-bottom: var(--borderWidth) solid var(--borderColor);
  display: flex;
  flex-direction: row;
  align-items: center;
}

.amis-scope .a-Page-headerRow .a-Page-header,
.amis-scope .a-Page-headerRow .a-Page-toolbar {
  flex-grow: 1;
  min-height: 100%;
}

.amis-scope .a-Page-headerRow .a-Page-toolbar {
  text-align: right;
  padding-right: var(--gap-base);
  display: flex;
  flex-direction: row;
  justify-content: flex-end;
  align-items: center;
  flex-wrap: wrap;
}

.amis-scope .a-Page-title {
  margin: 0;
  padding: 0;
  color: var(--Page-title-color);
  line-height: var(--Page-title-lineHeight);
  font-size: var(--Page-title-fontSize);
  font-weight: var(--Page-title-fontWeight);
}

.amis-scope .a-Page-body {
  padding: var(--Page-body-padding);
  flex: 1 auto;
}

.amis-scope .a-Page-asideTplWrapper {
  padding: var(--gap-xs);
}

.amis-scope .a-Page-toolbar > * + * {
  margin-left: var(--gap-xs);
}

.amis-scope .a-Page-aside {
  background: var(--Page-aside-bg);
}

@media (min-width: 768px) {
  .amis-scope .a-Page-aside {
    min-width: var(--Page-aside-width);
    max-width: var(--Page-aside-maxWidth);
    border-right: var(--borderWidth) solid var(--borderColor);
  }

  .amis-scope .a-Page-aside::before {
    content: "";
    position: absolute;
    width: inherit;
    top: 0;
    bottom: 0;
    z-index: -1;
    background: inherit;
    border: inherit;
  }

  .amis-scope .a-Page--withSidebar {
    display: flex;
    flex-direction: row;
    align-items: stretch;
  }

  .amis-scope .a-Page--withSidebar > .a-Page-content {
    width: 0;
    flex-grow: 1;
  }
}

.amis-scope .a-Remark {
  display: inline-block;
  vertical-align: middle;
  margin-left: var(--Remark-marginLeft);
  cursor: pointer;
  text-align: center;
}

.amis-scope .a-Remark > span {
  color: var(--Remark-iconColor);
  font-size: var(--fontSizeSm);
}

.amis-scope .a-Remark-icon {
  color: var(--Remark-iconColor);
  font-size: var(--Remark-icon-fontSize);
  background: var(--Remark-bg);
  border: var(--Remark-borderWidth) solid var(--Remark-borderColor);
  width: var(--Remark-width);
  height: var(--Remark-width);
  line-height: 1;
  display: inline-flex;
  vertical-align: baseline;
  align-self: center;
  align-items: center;
  justify-content: center;
  font-size: var(--fontSizeSm);
  user-select: none;
}

.amis-scope .a-Remark-icon > svg {
  width: 100%;
  height: 100%;
  display: block;
}

.amis-scope .a-Remark > span + .a-Remark-icon {
  margin-left: var(--gap-xs);
}

.amis-scope .a-Remark:hover > .a-Remark-icon {
  color: var(--Remark-onHover-iconColor);
  background: var(--Remark-onHover-bg);
  border-color: var(--Remark-onHover-borderColor);
}

.amis-scope .a-Remark > svg {
  width: calc(var(--Remark-width) - 0.125rem);
  height: calc(var(--Remark-width) - 0.125rem);
  color: var(--Remark-iconColor);
}

.amis-scope .a-Remark:hover > svg {
  color: var(--Remark-onHover-iconColor);
}

.amis-scope .a-Chart {
  min-width: 300px;
  min-height: 300px;
  position: relative;
}

.amis-scope .a-Chart-placeholder {
  position: absolute;
  top: 50%;
  left: 50%;
  transform: translate(-50%, -50%);
}

.amis-scope .a-Chart-content {
  position: absolute;
  left: 0;
  top: 0;
  width: 100%;
  height: 100%;
}

.amis-scope .a-Video {
  min-width: 200px;
}

.amis-scope .a-Video-cursor {
  position: absolute;
  border: 2px solid var(--info);
  transition: all var(--animation-duration) ease-out;
}

.amis-scope .a-Video-frameList .a-Video-frameItem {
  cursor: pointer;
}

.amis-scope .a-Video-frameLabel {
  text-align: center;
}

.amis-scope .a-Video .video-react-paused .video-react-big-play-button.big-play-button-hide {
  display: block;
}

.amis-scope .a-Video-player {
  position: relative;
}

.amis-scope .a-Video-error {
  position: absolute;
  display: block;
  width: 100%;
  padding: 5px 10px;
  color: var(--danger);
  background: rgba(255, 255, 255, 0.4);
  text-align: center;
  top: 0;
}

.amis-scope .a-Audio-original {
  display: none;
}

.amis-scope .a-Audio--inline {
  display: inline-block;
}

.amis-scope .a-Audio {
  box-sizing: border-box;
  height: var(--Audio-height);
  line-height: var(--Audio-lineHeight);
  border: var(--Audio-border);
  padding-left: var(--Audio-item-margin);
  overflow: hidden;
}

.amis-scope .a-Audio-controls {
  display: flex;
  flex-direction: row;
  align-items: center;
}

.amis-scope .a-Audio-rates {
  width: var(--Audio-rate-width);
  height: var(--Audio-rate-height);
  text-align: center;
  background: var(--Audio-rate-bg);
  cursor: pointer;
  margin-right: var(--Audio-item-margin);
}

.amis-scope .a-Audio-rateControl {
  margin-right: var(--Audio-item-margin);
}

.amis-scope .a-Audio-rateControl::after {
  clear: both;
  content: "";
}

.amis-scope .a-Audio-rateControl .a-Audio-rateControlItem {
  width: var(--Audio-rate-width);
  height: var(--Audio-rate-height);
  background: var(--Audio-rate-bg);
  cursor: pointer;
  text-align: center;
  float: left;
  box-sizing: border-box;
  border-right: var(--Audio-rateControlItem-borderRight);
}

.amis-scope .a-Audio-play {
  width: var(--Audio-play-width);
  cursor: pointer;
  margin-right: var(--Audio-item-margin);
}

.amis-scope .a-Audio-play svg {
  width: var(--Audio-svg-width);
  height: var(--Audio-svg-height);
  position: relative;
  top: var(--Audio-svg-top);
}

.amis-scope .a-Audio-times {
  min-width: var(--Audio-times-width);
  margin-right: var(--Audio-item-margin);
  cursor: default;
  flex-shrink: 0;
}

.amis-scope .a-Audio-process {
  flex: auto;
  cursor: pointer;
  min-width: var(--Audio-process-minWidth);
  margin-right: var(--Audio-item-margin);
}

.amis-scope .a-Audio-process input[type=range] {
  -webkit-appearance: none;
  outline: none;
  border: none;
  padding: 0;
  background: none;
}

.amis-scope .a-Audio-process input[type=range]::-webkit-slider-runnable-track {
  background: var(--Audio-track-bg);
  height: var(--Audio-track-height);
  border-radius: var(--Audio-track-borderRadius);
  border: var(--Audio-track-border);
}

.amis-scope .a-Audio-process input[type=range]::-webkit-slider-thumb {
  -webkit-appearance: none !important;
  border-radius: 100%;
  cursor: pointer;
  background: var(--Audio-thumb-bg);
  width: var(--Audio-thumb-width);
  height: var(--Audio-thumb-height);
  margin-top: var(--Audio-thumb-marginTop);
}

.amis-scope .a-Audio-volume {
  width: var(--Audio-volume-width);
  height: var(--Audio-volume-height);
  line-height: var(--Audio-volume-lineHeight);
  cursor: pointer;
  margin-right: var(--Audio-item-margin);
}

.amis-scope .a-Audio-volume svg {
  width: var(--Audio-svg-width);
  height: var(--Audio-svg-height);
  position: relative;
  top: var(--Audio-svg-top);
}

.amis-scope .a-Audio-volumeControl {
  display: flex;
  flex-direction: row;
  align-items: center;
  width: var(--Audio-volumeControl-width);
  height: var(--Audio-volume-height);
  line-height: var(--Audio-volume-lineHeight);
  margin-right: var(--Audio-item-margin);
}

.amis-scope .a-Audio-volumeControl input[type=range] {
  -webkit-appearance: none;
  outline: none;
  border: none;
  padding: 0;
  background: none;
}

.amis-scope .a-Audio-volumeControl input[type=range]::-webkit-slider-runnable-track {
  background: var(--Audio-track-bg);
  height: var(--Audio-track-height);
  border-radius: var(--Audio-track-borderRadius);
  border: var(--Audio-track-border);
}

.amis-scope .a-Audio-volumeControl input[type=range]::-webkit-slider-thumb {
  -webkit-appearance: none !important;
  border-radius: 100%;
  cursor: pointer;
  background: var(--Audio-thumb-bg);
  width: var(--Audio-thumb-width);
  height: var(--Audio-thumb-height);
  margin-top: var(--Audio-thumb-marginTop);
}

.amis-scope .a-Audio-volumeControl .a-Audio-volumeControlIcon {
  margin-right: var(--Audio-item-margin);
  cursor: pointer;
}

.amis-scope .a-Audio-volumeControl svg {
  width: var(--Audio-svg-width);
  height: var(--Audio-svg-height);
  position: relative;
  top: var(--Audio-svg-top);
}

.amis-scope .a-Panel {
  margin-bottom: var(--Panel-marginBottom);
  background: var(--Panel-bg);
  border: var(--Panel-border);
  border-radius: var(--Panel-borderRadius);
  -webkit-box-shadow: var(--Panel-boxShadow);
  box-shadow: var(--Panel-boxShadow);
  /* 主题 */
  /* 子组件 */
}

.amis-scope .a-Panel-fixedBottom {
  position: absolute;
  background: var(--white);
  z-index: -1;
  opacity: 0;
  bottom: 999999px;
  box-shadow: var(--Panel-fixedBottom-boxShadow);
  border-top: var(--Panel-fixedBottom-borderTop);
}

.amis-scope .a-Panel-fixedBottom.in {
  position: fixed;
  bottom: 0;
  z-index: 900;
  opacity: 1;
}

.amis-scope .a-Panel--default {
  border-color: var(--borderColor);
}

.amis-scope .a-Panel--default > .a-Panel-heading {
  background: var(--Panel--default-bg);
  color: var(--Panel--default-color);
}

.amis-scope .a-Panel--default > .a-Panel-heading .badge {
  color: var(--Panel--default-badgeColor);
  background: var(--Panel--default-badgeBg);
}

.amis-scope .a-Panel--default > .a-Panel-heading {
  border-color: var(--Panel--default-headingBorderColor);
}

.amis-scope .a-Panel--primary {
  border-color: var(--primary);
}

.amis-scope .a-Panel--primary > .a-Panel-heading {
  background: var(--primary);
  color: var(--white);
}

.amis-scope .a-Panel--primary > .a-Panel-heading .badge {
  color: var(--primary);
  background: var(--white);
}

.amis-scope .a-Panel--primary > .a-Panel-heading,
.amis-scope .a-Panel--primary > .a-Panel-footer {
  border-color: var(--primary);
}

.amis-scope .a-Panel--success {
  border-color: var(--success);
}

.amis-scope .a-Panel--success > .a-Panel-heading {
  background: var(--success);
  color: var(--white);
}

.amis-scope .a-Panel--success > .a-Panel-heading .badge {
  color: var(--success);
  background: var(--white);
}

.amis-scope .a-Panel--success > .a-Panel-heading,
.amis-scope .a-Panel--success > .a-Panel-footer {
  border-color: var(--success);
}

.amis-scope .a-Panel--info {
  border-color: var(--info);
}

.amis-scope .a-Panel--info > .a-Panel-heading {
  background: var(--info);
  color: var(--white);
}

.amis-scope .a-Panel--info > .a-Panel-heading .badge {
  color: var(--info);
  background: var(--white);
}

.amis-scope .a-Panel--info > .a-Panel-heading,
.amis-scope .a-Panel--info > .a-Panel-footer {
  border-color: var(--info);
}

.amis-scope .a-Panel--warning {
  border-color: var(--warning);
}

.amis-scope .a-Panel--warning > .a-Panel-heading {
  background: var(--warning);
  color: var(--white);
}

.amis-scope .a-Panel--warning > .a-Panel-heading .badge {
  color: var(--warning);
  background: var(--white);
}

.amis-scope .a-Panel--warning > .a-Panel-heading,
.amis-scope .a-Panel--warning > .a-Panel-footer {
  border-color: var(--warning);
}

.amis-scope .a-Panel--danger {
  border-color: var(--danger);
}

.amis-scope .a-Panel--danger > .a-Panel-heading {
  background: var(--danger);
  color: var(--white);
}

.amis-scope .a-Panel--danger > .a-Panel-heading .badge {
  color: var(--danger);
  background: var(--white);
}

.amis-scope .a-Panel--danger > .a-Panel-heading,
.amis-scope .a-Panel--danger > .a-Panel-footer {
  border-color: var(--danger);
}

.amis-scope .a-Panel-heading {
  padding: var(--Panel-headingPadding);
  border-bottom: var(--Panel-headingBorderBottom);
  border-radius: var(--Panel-headingBorderRadius);
}

.amis-scope .a-Panel-title {
  margin-top: var(--Panel-titleMarginTop);
  margin-bottom: var(--Panel-titleMarginBottom);
  font-size: var(--Panel-titleFontSize);
  color: var(--Panel-titleColor);
}

.amis-scope .a-Panel-body {
  padding: var(--Panel-bodyPadding);
}

.amis-scope .a-Panel-footer {
  border-color: var(--Panel-footerBorderColor);
  border-radius: var(--Panel-footerBorderRadius);
  background: var(--Panel-footerBg);
  padding: var(--Panel-footerPadding);
  border-style: solid;
  border-width: var(--Panel-borderWidth) 0 0 0;
  clear: both;
}

.amis-scope .a-Panel-footer .a-Button + .a-Button {
  margin-left: var(--Panel-footerButtonMarginLeft);
}

.amis-scope .a-Panel-btnToolbar {
  text-align: var(--Panel-btnToolbarTextAlign);
}

.amis-scope .a-Panel-btnToolbar::before,
.amis-scope .a-Panel-btnToolbar::after {
  display: table;
  content: "";
}

.amis-scope .a-Panel-btnToolbar::after {
  clear: both;
}

.amis-scope .a-Panel-btnToolbar .a-Button {
  margin-left: var(--Panel-footerButtonMarginLeft);
}

.amis-scope .a-Panel-btnToolbar:empty {
  display: none;
}

.amis-scope .a-Service {
  position: relative;
}

.amis-scope .a-Sparkline {
  display: inline-block;
  line-height: 1;
  vertical-align: middle;
}

.amis-scope .a-Sparkline-line {
  stroke: var(--Sparkline-line-color);
  stroke-width: 1px;
}

.amis-scope .a-Sparkline-area {
  fill: var(--Sparkline-area-color);
}

.amis-scope .a-Sparkline--clickable {
  cursor: pointer;
}

@keyframes rotate {
  0% {
    transform: rotate(0deg);
  }

  100% {
    transform: rotate(359deg);
  }
}

@keyframes spin {
  0% {
    transform: rotate(0deg);
  }

  to {
    transform: rotate(1turn);
  }
}

.amis-scope .is-spin {
  animation: spin 2s linear infinite;
}

.amis-scope .a-Spinner-overlay {
  position: absolute;
  z-index: 10;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background: var(--Spinner-overlay-bg);
  transition: ease-out opacity var(--animation-duration);
  opacity: 0;
}

.amis-scope .a-Spinner-overlay.in {
  opacity: 1;
}

.amis-scope .a-Spinner {
  width: var(--Spinner-width);
  height: var(--Spinner-height);
  transform: translateZ(0);
  display: inline-block;
  background: var(--Spinner-bg);
  background-size: 100%;
  transition: ease-out all var(--animation-duration);
}

.amis-scope .a-Spinner--lg {
  width: var(--Spinner--lg-width);
  height: var(--Spinner--lg-height);
}

.amis-scope .a-Spinner--sm {
  width: var(--Spinner--sm-width);
  height: var(--Spinner--sm-height);
}

.amis-scope .a-Spinner--icon {
  background: transparent;
  animation: spin 2s linear infinite;
  width: auto;
  height: auto;
}

.amis-scope .a-Spinner--overlay {
  position: absolute;
  z-index: 11;
  top: 50%;
  left: 50%;
  transform: translate3d(-50%, -50%, 0);
}

.amis-scope .a-Spinner--overlay.a-Spinner--lg {
  width: var(--Spinner--lg-width);
  height: var(--Spinner--lg-height);
  line-height: var(--Spinner--lg-height);
}

@media (min-width: 768px) {
  .amis-scope .a-Layout .a-Page-body > .a-Spinner-overlay {
    left: var(--Layout-aside-width);
  }

  .amis-scope .a-Layout--folded .a-Page-body > .a-Spinner-overlay {
    left: var(--Layout-aside--folded-width);
  }
}

.amis-scope .a-ButtonGroup {
  position: relative;
  display: inline-flex;
  vertical-align: middle;
}

.amis-scope .a-ButtonGroup > .a-Button {
  position: relative;
  flex: 0 1 auto;
}

.amis-scope .a-ButtonGroup > .a-Button:hover {
  z-index: 1;
}

.amis-scope .a-ButtonGroup > .a-Button:focus,
.amis-scope .a-ButtonGroup > .a-Button:active,
.amis-scope .a-ButtonGroup > .a-Button.active,
.amis-scope .a-ButtonGroup > .a-Button.is-active {
  z-index: 1;
}

.amis-scope .a-ButtonGroup .a-Button + .a-Button,
.amis-scope .a-ButtonGroup .a-Button + .a-ButtonGroup,
.amis-scope .a-ButtonGroup .a-ButtonGroup + .a-Button,
.amis-scope .a-ButtonGroup .a-ButtonGroup + .a-ButtonGroup {
  margin-left: calc(var(--Button-borderWidth) * -1);
}

.amis-scope .a-ButtonGroup--block {
  display: block;
}

.amis-scope .a-ButtonToolbar {
  display: inline-flex;
  flex-wrap: wrap;
  justify-content: flex-start;
  align-items: center;
}

.amis-scope .a-ButtonToolbar .a-ButtonGroup {
  margin-left: var(--gap-xs);
  margin-top: var(--gap-xs);
  width: auto;
}

.amis-scope .a-ButtonGroup > .a-Button:first-child {
  margin-left: 0;
}

.amis-scope .a-ButtonGroup .a-Button--primary.is-active {
  color: var(--ButtonGroup--primary-isActive-color);
  background: var(--ButtonGroup--primary-isActive-bg);
}

.amis-scope .a-ButtonGroup > .a-Button:not(:last-child),
.amis-scope .a-ButtonGroup > .a-ButtonGroup:not(:last-child) > .a-Button {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}

.amis-scope .a-ButtonGroup > .a-Button:not(:first-child),
.amis-scope .a-ButtonGroup > .a-ButtonGroup:not(:first-child) > .a-Button {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}

.amis-scope .a-ButtonGroup--vertical {
  flex-direction: column;
  align-items: flex-start;
  justify-content: center;
}

.amis-scope .a-ButtonGroup--vertical .a-Button,
.amis-scope .a-ButtonGroup--vertical .a-ButtonGroup {
  width: 100%;
}

.amis-scope .a-ButtonGroup--vertical > .a-Button + .a-Button,
.amis-scope .a-ButtonGroup--vertical > .a-Button + .a-ButtonGroup,
.amis-scope .a-ButtonGroup--vertical > .a-ButtonGroup + .a-Button,
.amis-scope .a-ButtonGroup--vertical > .a-ButtonGroup + .a-ButtonGroup {
  margin-top: calc(var(--Button-borderWidth) * -1);
  margin-left: 0;
}

.amis-scope .a-ButtonGroup--vertical > .a-Button:not(:last-child),
.amis-scope .a-ButtonGroup--vertical > .a-ButtonGroup:not(:last-child) > .a-Button {
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
}

.amis-scope .a-ButtonGroup--vertical > .a-Button:not(:first-child),
.amis-scope .a-ButtonGroup--vertical > .a-ButtonGroup:not(:first-child) > .btn {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}

.amis-scope .a-ButtonGroup--tiled {
  display: flex;
}

.amis-scope .a-ButtonGroup--tiled .a-Button,
.amis-scope .a-ButtonGroup--tiled .a-ButtonGroup {
  flex-grow: 1;
  text-align: center;
}

.amis-scope .a-DropDown {
  position: relative;
  display: inline-block;
}

.amis-scope .a-DropDown-caret {
  margin-left: var(--DropDown-caret-marginLeft);
  display: inline-block;
  vertical-align: top;
  transition: transform var(--animation-duration) ease;
}

.amis-scope .a-DropDown-caret > svg {
  width: 0.625rem;
  height: 0.625rem;
  top: 0.125em;
}

.amis-scope .a-DropDown.is-opened .a-DropDown-caret {
  transform: rotate(180deg);
}

.amis-scope .a-DropDown.is-actived .a-Button {
  color: var(--link-color);
}

.amis-scope .a-DropDown--block {
  display: block;
}

.amis-scope .a-DropDown--block .a-Button {
  display: block;
}

.amis-scope .a-DropDown-menu {
  position: absolute;
  z-index: 1000;
  top: 100%;
  left: 0;
  margin: 0.0625rem 0 0;
  background: var(--DropDown-menu-bg);
  list-style: none;
  padding: var(--DropDown-menu-paddingY) var(--DropDown-menu-paddingX);
  border: var(--DropDown-menu-borderWidth) solid var(--DropDown-menu-borderColor);
  border-radius: var(--DropDown-menu-borderRadius);
  box-shadow: var(--DropDown-menu-boxShadow);
  min-width: var(--DropDown-menu-minWidth);
  text-align: left;
}

.amis-scope .a-DropDown--alignRight .a-DropDown-menu {
  left: auto;
  right: 0;
}

.amis-scope .a-DropDown-menuItem,
.amis-scope .a-DropDown-menu > li {
  padding: var(--DropDown-menuItem-paddingY) var(--DropDown-menuItem-paddingX);
  white-space: nowrap;
  box-sizing: border-box;
  height: var(--DropDown-menu-height);
  vertical-align: middle;
  user-select: none;
  color: var(--link-color);
  text-decoration: var(--link-decoration);
}

.amis-scope .a-DropDown-menuItem:hover,
.amis-scope .a-DropDown-menu > li:hover {
  background: var(--DropDown-menuItem-onHover-bg);
  color: var(--DropDown-menuItem-onHover-color);
}

.amis-scope .a-DropDown-menuItem.is-active,
.amis-scope .a-DropDown-menu > li.is-active {
  color: var(--DropDown-menuItem-onActive-color);
}

.amis-scope .a-DropDown-menuItem:not(.is-disabled),
.amis-scope .a-DropDown-menuItem:not(.disabled),
.amis-scope .a-DropDown-menu > li:not(.is-disabled),
.amis-scope .a-DropDown-menu > li:not(.disabled) {
  cursor: pointer;
}

.amis-scope .a-DropDown-menuItem.is-disabled,
.amis-scope .a-DropDown-menu > li.is-disabled {
  cursor: not-allowed;
  color: var(--DropDown-menuItem-onDisabled-color);
  filter: grayscale(80%);
}

.amis-scope .a-DropDown-menuItem.a-DropDown-divider,
.amis-scope .a-DropDown-menu > li.a-DropDown-divider {
  height: 0.0625rem;
  margin: 0.5625rem 0;
  overflow: hidden;
  background: var(--DropDown-menu-borderColor);
  padding: 0;
}

.amis-scope .a-DropDown-menu > li a {
  color: inherit;
  display: block;
  text-decoration: none;
}

.amis-scope .a-DropDown-popover {
  border: none;
  box-shadow: none;
}

.amis-scope .a-DropDown > .a-Button {
  min-width: unset;
}

.amis-scope .a-Each-placeholder {
  color: var(--text--muted-color);
  text-align: left;
  padding: var(--gap-sm);
}

.amis-scope .a-Collapse {
  border: none;
  padding: 0;
  margin-bottom: var(--Form-item-gap);
}

.amis-scope .a-Collapse-header {
  font-size: var(--fontSizeMd);
  font-weight: var(--fontWeightNormal);
  color: var(--text--loud-color);
  padding: var(--gap-xs) 0;
  border-bottom: var(--borderWidth) solid var(--borderColorLight);
}

.amis-scope .a-Collapse-arrow {
  display: inline-block;
  width: 1rem;
  text-align: center;
  margin-left: var(--gap-xs);
  cursor: pointer;
}

.amis-scope .a-Collapse-arrow:before {
  content: "";
  position: relative;
  display: inline-block;
  width: 0.375rem;
  height: 0.375rem;
  top: -0.25rem;
  border-color: var(--text-color);
  border-style: solid;
  border-width: 0.0625rem 0.0625rem 0 0;
  transform: rotate(135deg);
  transform-origin: 50% 50%;
}

.amis-scope .a-Collapse.is-collapsed .a-Collapse-arrow:before {
  transform: rotate(45deg);
  transform-origin: 0% 50%;
}

.amis-scope .a-Collapse--collapsable .a-Collapse-header {
  cursor: pointer;
  user-select: none;
}

.amis-scope .a-Collapse--title-bottom .a-Collapse-header {
  text-align: center;
  color: var(--link-color);
  border-left: none;
  font-size: var(--fontSizeBase);
}

.amis-scope .a-Collapse--title-bottom .a-Collapse-arrow:before {
  top: 0.125rem;
  transform: rotate(-45deg);
  transform-origin: 0% 50%;
}

.amis-scope .a-Collapse--title-bottom.is-collapsed .a-Collapse-arrow:before {
  top: -0.375rem;
  transform: rotate(135deg);
  transform-origin: 0% 50%;
}

.amis-scope .a-Collapse-content {
  transition: height var(--animation-duration) ease;
}

.amis-scope .a-Collapse-content.in,
.amis-scope .a-Collapse-content.out {
  height: 0;
  overflow: hidden;
}

.amis-scope .a-ColorField {
  display: inline-block;
}

.amis-scope .a-ColorField-previewIcon {
  display: inline-block;
  vertical-align: middle;
  width: 1rem;
  height: 1rem;
  box-shadow: var(--boxShadowSm);
  background: #ccc;
}

.amis-scope .a-ColorField-value {
  display: inline-block;
  margin-left: 10px;
  vertical-align: middle;
}

.amis-scope .a-CBGroup {
  font-size: var(--fontSizeSm);
}

.amis-scope .a-CBGroup-toolbar {
  display: flex;
  flex-direction: row;
  padding-bottom: 10px;
}

.amis-scope .a-CBGroup-toolbar .a-Button {
  transition: padding var(--animation-duration);
  min-width: unset;
}

.amis-scope .a-CBGroup-toolbar .a-Button svg {
  width: 10px;
  height: 10px;
  top: 0;
  margin-right: 5px;
}

.amis-scope .a-CBGroup-toolbar:not(:hover) .a-CBGroup-toolbarCondition .a-Button:not(.is-active) {
  width: 0;
  padding: 0;
  overflow: hidden;
  opacity: 0;
  margin: 0;
  border: 0;
}

.amis-scope .a-CBGroup-toolbar .a-CBGroup-toolbarConditionAdd {
  transition: opacity var(--animation-duration);
  display: flex;
  align-items: center;
  margin-left: var(--gap-base);
}

.amis-scope .a-CBGroup-toolbar .a-CBGroup-toolbarConditionAdd .a-CBDelete {
  margin-left: var(--gap-xs);
}

.amis-scope .a-CBGroup-toolbar:not(:hover) .a-CBGroup-toolbarConditionAdd {
  opacity: 0;
}

.amis-scope .a-CBGroup-field,
.amis-scope .a-CBGroup-operator {
  position: relative;
  display: inline-block;
  margin: 0.1875rem;
  vertical-align: middle;
}

.amis-scope .a-CBGroup-fieldCaret,
.amis-scope .a-CBGroup-operatorCaret {
  transition: transform var(--animation-duration) ease-out;
  margin: 5px;
  display: flex;
  color: var(--Form-select-caret-iconColor);
}

.amis-scope .a-CBGroup-fieldCaret:hover,
.amis-scope .a-CBGroup-operatorCaret:hover {
  color: var(--Form-select-caret-onHover-iconColor);
}

.amis-scope .a-CBGroup-fieldCaret > svg,
.amis-scope .a-CBGroup-operatorCaret > svg {
  width: 0.625rem;
  height: 0.625rem;
  top: 0;
}

.amis-scope .a-CBGroup-fieldInput.is-active .a-CBGroup-fieldCaret,
.amis-scope .a-CBGroup-operatorInput.is-active .a-CBGroup-operatorCaret {
  transform: rotate(180deg);
}

.amis-scope .a-CBGroup-placeholder {
  color: var(--text--muted-color);
  position: relative;
  margin-left: 30px;
  padding: 10px;
  background: rgba(0, 0, 0, 0.03);
  border-radius: 5px;
}

.amis-scope .a-CBGroup-placeholder:before {
  position: absolute;
  content: "";
  top: -10px;
  left: -30px;
  width: var(--gap-md);
  border-left: solid 1px var(--borderColor);
  bottom: 0;
}

.amis-scope .a-CBGroup-placeholder:after {
  position: absolute;
  content: "";
  top: 50%;
  width: var(--gap-md);
  left: -30px;
  border-top: solid 1px var(--borderColor);
}

.amis-scope .a-CBGroup-placeholder:last-child:before {
  border-bottom-left-radius: 5px;
  border-bottom: solid 1px var(--borderColor);
  bottom: 50%;
}

.amis-scope .a-CBGroup-placeholder:last-child:after {
  display: none;
}

.amis-scope .a-CBDelete {
  color: var(--icon-color);
  cursor: pointer;
  margin-left: auto;
  transition: opacity var(--animation-duration);
}

.amis-scope .a-CBDelete:hover {
  color: var(--icon-onHover-color);
}

.amis-scope .a-CBGroupOrItem {
  position: relative;
  margin-left: 1.875rem;
}

.amis-scope .a-CBGroupOrItem + .a-CBGroupOrItem {
  margin-top: 0.625rem;
}

.amis-scope .a-CBGroupOrItem-body {
  display: flex;
  padding: 2px 7px;
  border-radius: 5px;
  flex-direction: row;
  align-items: center;
  position: relative;
  background: rgba(0, 0, 0, 0.03);
  transition: all var(--animation-duration) ease-out;
}

.amis-scope .a-CBGroupOrItem-body > .a-CBGroup {
  margin: 3px;
}

.amis-scope .a-CBGroupOrItem-body:not(:hover) .a-CBDelete {
  opacity: 0;
}

.amis-scope .a-CBGroupOrItem.is-dragging {
  display: none;
}

.amis-scope .a-CBGroupOrItem.is-ghost > .a-CBGroupOrItem-body:before {
  position: absolute;
  z-index: 2;
  content: "";
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background: rgba(35, 183, 229, 0.2);
}

.amis-scope .a-CBGroupOrItem-dragbar {
  cursor: move;
  width: 20px;
  margin-left: -5px;
  opacity: 0.6;
  text-align: center;
  transition: opacity var(--animation-duration) ease-out;
  color: var(--icon-color);
}

.amis-scope .a-CBGroupOrItem-dragbar:hover {
  color: var(--icon-onHover-color);
}

.amis-scope .a-CBGroupOrItem .a-CBGroup {
  flex-grow: 1;
}

.amis-scope .a-CBGroupOrItem:hover > .a-CBGroupOrItem-body {
  background: rgba(0, 0, 0, 0.05);
}

.amis-scope .a-CBGroupOrItem:hover > .a-CBGroupOrItem-body > .a-CBGroupOrItem-dragbar {
  opacity: 1;
}

.amis-scope .a-CBGroupOrItem:before {
  position: absolute;
  content: "";
  top: -10px;
  left: -30px;
  width: 20px;
  border-left: solid 1px var(--borderColor);
  bottom: 0;
}

.amis-scope .a-CBGroupOrItem:after {
  position: absolute;
  content: "";
  top: 50%;
  width: 20px;
  left: -30px;
  border-top: solid 1px var(--borderColor);
}

.amis-scope .a-CBGroupOrItem:last-child:before {
  border-bottom-left-radius: 5px;
  border-bottom: solid 1px var(--borderColor);
  bottom: 50%;
}

.amis-scope .a-CBGroupOrItem:last-child:after {
  display: none;
}

.amis-scope .a-CBInputSwitch {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  cursor: pointer;
}

.amis-scope .a-CBInputSwitch > a {
  color: var(--icon-color);
}

.amis-scope .a-CBInputSwitch > a:hover {
  color: var(--icon-onHover-color);
}

.amis-scope .a-CBInputSwitch svg {
  width: 0.625rem;
  height: 0.625rem;
}

.amis-scope .a-CBFunc {
  display: inline-block;
  vertical-align: middle;
  margin: 0.1875rem;
}

.amis-scope .a-CBFunc-select {
  display: inline-block;
  position: relative;
}

.amis-scope .a-CBFunc-error {
  color: var(--danger);
}

.amis-scope .a-CBFunc-args {
  display: inline-block;
}

.amis-scope .a-CBFunc-args > span {
  display: inline-block;
  padding: 0 5px;
  color: var(--info);
}

.amis-scope .a-CBFunc-args > div {
  display: inline-block;
}

.amis-scope .a-CBValue {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  margin: 0.1875rem;
}

.amis-scope .a-CBFormula {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  margin: 0.1875rem;
}

.amis-scope .a-CBFormula-label {
  background: var(--ResultBox-value-bg);
  color: var(--text--muted-color);
  display: block;
  font-size: var(--fontSizeSm);
  align-self: center;
  margin: -5px 5px -5px -8px;
  padding: 5px;
  border-radius: 5px;
  user-select: none;
}

.amis-scope .a-CBSeprator {
  width: 20px;
  text-align: center;
  display: inline-block;
  user-select: none;
}

@keyframes contextMenuInSpecial {
  from {
    transform: scale3d(1, 1, 1);
  }

  50% {
    transform: scale3d(1.05, 1.05, 1.05);
  }

  to {
    transform: scale3d(1, 1, 1);
  }
}

@keyframes contextMenuIn {
  from {
    opacity: 0;
  }
}

@keyframes contextMenuOut {
  to {
    opacity: 0;
  }
}

.amis-scope .a-ContextMenu {
  z-index: 1500;
  position: fixed;
  left: 0;
  top: 0;
}

.amis-scope .a-ContextMenu-menu {
  position: absolute;
  z-index: 1500;
  display: block;
  position: absolute;
  margin: 0;
  padding: 4px 0 5px;
  background: rgba(239, 239, 239, 0.95);
  box-shadow: 0px 4px 9px rgba(0, 0, 0, 0.34);
  color: rgba(0, 0, 0, 0.75);
  font-family: -apple-system, Lucida Grande;
  font-size: var(--fontSizeMd);
  line-height: 1.1;
}

.amis-scope .a-ContextMenu-menu.in,
.amis-scope .a-ContextMenu-menu.out {
  animation-duration: var(--animation-duration);
  animation-fill-mode: both;
}

.amis-scope .a-ContextMenu-menu.in {
  animation-name: contextMenuInSpecial;
  animation-duration: var(--animation-duration);
}

.amis-scope .a-ContextMenu-menu.out {
  animation-name: contextMenuOut;
}

.amis-scope .a-ContextMenu-menu::before {
  display: block;
  position: absolute;
  content: "";
  top: -1px;
  left: -1px;
  bottom: -1px;
  right: -1px;
  border-radius: 4px;
  border: 1px solid rgba(0, 0, 0, 0.125);
  z-index: -1;
}

.amis-scope .a-ContextMenu-divider {
  border: none;
  height: 1px;
  background: rgba(0, 0, 0, 0.1);
  margin: 6px 1px 5px;
  padding: 0;
}

.amis-scope .a-ContextMenu-list {
  list-style: none;
  margin: 0;
  padding: 0;
  width: 185px;
}

.amis-scope .a-ContextMenu-item {
  position: relative;
}

.amis-scope .a-ContextMenu-item > a {
  white-space: nowrap;
  display: block;
  padding: 0 20px;
  border-top: 1px solid rgba(0, 0, 0, 0);
  border-bottom: 1px solid rgba(0, 0, 0, 0);
  color: inherit;
}

.amis-scope .a-ContextMenu-item:not(.is-disabled):hover > a {
  text-decoration: none;
  color: #fff;
  background: -webkit-linear-gradient(top, #648bf5, #2866f2);
  background: linear-gradient(to bottom, #648bf5 0%, #2866f2 100%);
  border-top: 1px solid #5a82eb;
  border-bottom: 1px solid #1758e7;
  cursor: pointer;
}

.amis-scope .a-ContextMenu-item.is-disabled > a {
  color: #999;
  pointer-events: none;
}

.amis-scope .a-ContextMenu-item.has-child > a::after {
  content: "";
  width: 0;
  height: 0;
  border-width: 4px 7px;
  border-style: solid;
  border-color: transparent transparent transparent rgba(0, 0, 0, 0.75);
  text-shadow: 0px 4px 9px rgba(0, 0, 0, 0.34);
  position: absolute;
  top: 50%;
  right: 0;
  transform: translateY(-50%);
}

.amis-scope .a-ContextMenu-item.has-child:hover > a::after {
  border-color: transparent transparent transparent #fff;
}

.amis-scope .a-ContextMenu-itemIcon {
  margin-right: 5px;
}

.amis-scope .a-ContextMenu-subList {
  display: none;
  list-style: none;
}

.amis-scope .a-ContextMenu-item:hover > .a-ContextMenu-subList {
  display: block;
  animation-duration: var(--animation-duration);
  animation-fill-mode: both;
  animation-name: contextMenuIn;
  display: block;
  position: absolute;
  left: 100%;
  top: -3px;
  margin: 0;
  padding: 4px 0 5px;
  background: rgba(239, 239, 239, 0.95);
  box-shadow: 0px 4px 9px rgba(0, 0, 0, 0.34);
  border-radius: 7px;
  color: rgba(0, 0, 0, 0.75);
  font-family: -apple-system, Lucida Grande;
  font-size: var(--fontSizeMd);
  line-height: 1.1;
}

.amis-scope .a-ContextMenu-item:hover > .a-ContextMenu-subList::before {
  display: block;
  position: absolute;
  content: "";
  top: -1px;
  left: -1px;
  bottom: -1px;
  right: -1px;
  border-radius: 4px;
  border: 1px solid rgba(0, 0, 0, 0.125);
  z-index: -1;
}

.amis-scope .a-ContextMenu--left .a-ContextMenu-item:hover > .a-ContextMenu-subList {
  left: auto;
  right: 100%;
}

.amis-scope .a-ContextMenu-cursor {
  position: absolute;
  width: 1px;
  height: 1px;
  z-index: -1;
}

.amis-scope .a-ContextMenu-overlay {
  position: fixed !important;
  z-index: 1499;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background: transparent;
  pointer-events: none;
}

.amis-scope .a-Wizard {
  position: relative;
}

.amis-scope .a-Wizard::before,
.amis-scope .a-Wizard::after {
  display: table;
  content: "";
}

.amis-scope .a-Wizard::after {
  clear: both;
}

.amis-scope .a-Wizard,
.amis-scope .a-Wizard-tabs {
  padding: 0;
}

.amis-scope .a-Wizard .a-Badge,
.amis-scope .a-Wizard-tabs .a-Badge {
  display: inline-block;
  width: var(--Wizard-badge-size);
  height: var(--Wizard-badge-size);
  font-size: var(--Wizard-badge-fontSize);
  line-height: var(--Wizard-badge-size);
  color: var(--Wizard-badge-color);
  text-align: center;
  white-space: nowrap;
  vertical-align: middle;
  background: var(--Wizard-badge-bg);
  border-radius: var(--Wizard-badge-borderRadius);
  text-shadow: 0 0.0625rem 0 rgba(0, 0, 0, 0.2);
  margin-right: var(--Wizard-badge-marginRight);
  border: var(--Wizard-badge-border);
  box-sizing: content-box;
}

.amis-scope .a-Wizard .a-Badge.is-active,
.amis-scope .a-Wizard-tabs .a-Badge.is-active {
  color: var(--white);
  background: var(--Wizard-badge-onActive-backgroundColor);
}

.amis-scope .a-Wizard .a-Badge.is-complete,
.amis-scope .a-Wizard-tabs .a-Badge.is-complete {
  color: var(--white);
  background: var(--Wizard-badge-onComplete-backgroundColor);
}

.amis-scope .a-Wizard ul li.active,
.amis-scope .a-Wizard-tabs ul li.active {
  color: var(--info);
}

.amis-scope .a-Wizard .a-Panel-footer > .a-Form-group,
.amis-scope .a-Wizard .a-Panel-footer > .btn,
.amis-scope .a-Wizard-tabs .a-Panel-footer > .a-Form-group,
.amis-scope .a-Wizard-tabs .a-Panel-footer > .btn {
  margin-left: var(--gap-xs);
}

.amis-scope .a-Wizard > ul.nav,
.amis-scope .a-Wizard-tabs > ul.nav {
  padding: 0;
  margin: 0;
  border: var(--borderWidth) solid var(--borderColor);
}

.amis-scope .a-Wizard > ul.nav li,
.amis-scope .a-Wizard-tabs > ul.nav li {
  position: relative;
  float: left;
  padding: 0 var(--gap-md) 0 1.5625rem;
  margin: 0;
  color: #999999;
  cursor: pointer;
  height: var(--Wizard-steps-height);
  line-height: var(--Wizard-steps-height);
}

.amis-scope .a-Wizard > ul.nav li a,
.amis-scope .a-Wizard-tabs > ul.nav li a {
  border: 0 none !important;
  background: transparent !important;
  color: inherit;
  display: inline;
  padding: 0;
}

.amis-scope .a-Wizard > ul.nav li a div,
.amis-scope .a-Wizard-tabs > ul.nav li a div {
  display: inline;
}

.amis-scope .a-Wizard > ul.nav li:first-child,
.amis-scope .a-Wizard-tabs > ul.nav li:first-child {
  padding-left: var(--gap-md);
  border-radius: 0.25rem 0 0 0;
}

.amis-scope .a-Wizard > ul.nav li:before,
.amis-scope .a-Wizard > ul.nav li:after,
.amis-scope .a-Wizard-tabs > ul.nav li:before,
.amis-scope .a-Wizard-tabs > ul.nav li:after {
  content: "";
  position: absolute;
  right: -0.625rem;
  border: var(--gap-md) solid transparent;
  border-right: 0;
  border-left: 0.625rem solid var(--borderColor);
  border-left-color: rgba(0, 0, 0, 0.05);
  z-index: 1;
  bottom: 0;
}

.amis-scope .a-Wizard > ul.nav li:after,
.amis-scope .a-Wizard-tabs > ul.nav li:after {
  right: -0.5625rem;
  border-left-color: var(--Wizard-steps-bg);
  z-index: 2;
}

.amis-scope .a-Wizard > ul.nav li.is-active,
.amis-scope .a-Wizard-tabs > ul.nav li.is-active {
  color: var(--Wizard-steps-li-onActive-color);
  background: #fff;
}

.amis-scope .a-Wizard > ul.nav li.is-active:after,
.amis-scope .a-Wizard-tabs > ul.nav li.is-active:after {
  border-left-color: #fff;
}

.amis-scope .a-Wizard-steps {
  font-size: var(--fontSizeBase);
  padding: var(--Wizard-steps-padding);
  background: var(--Wizard-steps-bg);
  border-bottom: var(--Wizard-steps-borderWidth) solid var(--borderColor);
  text-align: var(--Wizard-steps-textAlign);
}

.amis-scope .a-Wizard-steps::before,
.amis-scope .a-Wizard-steps::after {
  display: table;
  content: "";
}

.amis-scope .a-Wizard-steps::after {
  clear: both;
}

.amis-scope .a-Wizard-steps ul {
  display: var(--Wizard-steps-ulDisplay);
  padding: 0;
  margin: 0;
  list-style: none outside none;
}

.amis-scope .a-Wizard-steps ul li {
  position: relative;
  float: left;
  padding: 0 var(--gap-md) 0 1.5625rem;
  margin: 0;
  color: #999999;
  cursor: default;
  height: var(--Wizard-steps-height);
  line-height: var(--Wizard-steps-height);
}

.amis-scope .a-Wizard-steps ul li:first-child {
  padding-left: var(--gap-md);
  border-radius: 0.25rem 0 0 0;
}

.amis-scope .a-Wizard-steps ul li:before,
.amis-scope .a-Wizard-steps ul li:after {
  font-family: var(--Wizard-steps-liVender);
  content: var(--Wizard-steps-liAfterContent);
  position: absolute;
  bottom: 0;
  right: -0.625rem;
  border: 1.125rem solid transparent;
  border-right: 0;
  border-left: 0.625rem solid var(--borderColor);
  border-left-color: rgba(0, 0, 0, 0.05);
  z-index: 2;
}

.amis-scope .a-Wizard-steps ul li:after {
  right: -0.5625rem;
  border-left-color: var(--Wizard-steps-bg);
  z-index: 2;
}

.amis-scope .a-Wizard-steps ul li.is-active {
  color: var(--Wizard-steps-li-onActive-color);
  background: var(--Wizard-steps-li-onActive-bg);
}

.amis-scope .a-Wizard-steps ul li.is-active:after {
  border-left-color: var(--Wizard-steps-li-onActive-arrow-bg);
}

.amis-scope .a-Wizard-steps ul li.is-complete,
.amis-scope .a-Wizard-steps ul li.is-complete:hover {
  color: var(--Wizard-steps-li-onActive-color);
  cursor: pointer;
}

.amis-scope .a-Wizard-stepContent {
  padding: var(--Wizard-stepsContent-padding);
}

.amis-scope .a-Wizard-stepContent .Step-pane {
  display: none;
}

.amis-scope .a-Wizard-stepContent .Step-pane.is-active {
  display: inherit;
}

.amis-scope .a-Wizard--vertical > .a-Wizard-step {
  display: flex;
  flex-direction: row;
  flex-wrap: wrap;
  border-bottom: none;
}

.amis-scope .a-Wizard--vertical > .a-Wizard-step > .a-Wizard-steps {
  height: auto;
  min-width: 40px;
  margin-right: 30px;
  margin-bottom: 1.875rem;
  background: none;
  border-bottom: none;
}

.amis-scope .a-Wizard--vertical > .a-Wizard-step > .a-Wizard-steps li {
  background: var(--Wizard-steps-bg);
}

.amis-scope .a-Wizard--vertical > .a-Wizard-step > .a-Wizard-steps ul li {
  height: 2.5rem;
  line-height: 2.5rem;
  position: relative;
  float: none;
  border-bottom: var(--borderWidth) solid var(--borderColor);
  padding-left: var(--gap-md);
}

.amis-scope .a-Wizard--vertical > .a-Wizard-step > .a-Wizard-steps ul li.is-active {
  background: #fff;
}

.amis-scope .a-Wizard--vertical > .a-Wizard-step > .a-Wizard-stepContent {
  flex-grow: 1;
  width: 0;
}

.amis-scope .a-Wizard--vertical > .a-Wizard-step > .a-Wizard-footer {
  width: 100%;
}

.amis-scope .a-Crud {
  position: relative;
}

.amis-scope .a-Crud-selection {
  margin-bottom: var(--gap-base);
}

.amis-scope .a-Crud-selectionLabel {
  display: inline-block;
  vertical-align: top;
  margin-top: var(--gap-xs);
}

.amis-scope .a-Crud-value {
  cursor: pointer;
  vertical-align: middle;
  user-select: none;
  line-height: calc( var(--Form-input-lineHeight) * var(--Form-input-fontSize) - 0.125rem );
  display: inline-block;
  font-size: var(--Form-selectValue-fontSize);
  color: var(--Form-selectValue-color);
  background: var(--Form-selectValue-bg);
  border: 0.0625rem solid var(--Form-selectValue-borderColor);
  border-radius: 2px;
  margin-right: var(--gap-xs);
  margin-top: var(--gap-xs);
}

.amis-scope .a-Crud-value:hover {
  background: var(--Form-selectValue-onHover-bg);
}

.amis-scope .a-Crud-value.is-disabled {
  pointer-events: none;
  opacity: var(--Button-onDisabled-opacity);
}

.amis-scope .a-Crud-valueIcon {
  cursor: pointer;
  border-right: 0.0625rem solid var(--Form-selectValue-borderColor);
  padding: 1px 5px;
}

.amis-scope .a-Crud-valueIcon:hover {
  background: var(--Form-selectValue-onHover-bg);
}

.amis-scope .a-Crud-valueLabel {
  padding: 0 var(--gap-xs);
}

.amis-scope .a-Crud-selectionClear {
  display: inline-block;
  cursor: pointer;
  user-select: none;
  margin-left: var(--gap-xs);
  margin-top: var(--gap-xs);
  vertical-align: middle;
}

.amis-scope .a-Crud-toolbar-item {
  margin-left: var(--Crud-toolbar-gap);
  margin-top: var(--Crud-toolbar-gap);
  line-height: var(--Crud-toolbar-lineHeight);
  height: var(--Crud-toolbar-height);
  vertical-align: middle;
  display: inline-flex;
  align-items: center;
}

.amis-scope .a-Crud-toolbar-item--left {
  float: left;
}

.amis-scope .a-Crud-toolbar-item--right {
  float: right;
}

.amis-scope .a-Crud-actions > * + .a-Button,
.amis-scope .a-Crud-actions > * + .a-ButtonGroup,
.amis-scope .a-Crud-actions > * + .a-ButtonToolbar {
  margin-left: var(--Crud-toolbar-gap);
}

.amis-scope .a-Crud-statistics {
  line-height: var(--Crud-toolbar-height);
  vertical-align: middle;
}

.amis-scope .a-Crud-pageSwitch .a-Select {
  margin-left: var(--Crud-toolbar-gap);
}

.amis-scope .a-Crud-pager {
  align-self: flex-start;
}

.amis-scope .a-Crud-filter {
  margin-bottom: var(--gap-base);
}

@media (min-width: 576px) {
  .amis-scope .a-Crud-toolbar {
    margin-left: calc(var(--Crud-toolbar-gap) * -1);
    margin-top: calc(var(--Crud-toolbar-gap) * -1);
    flex-basis: 0;
    flex-grow: 1;
  }

  .amis-scope .a-Crud-toolbar::before,
  .amis-scope .a-Crud-toolbar::after {
    display: table;
    content: "";
  }

  .amis-scope .a-Crud-toolbar::after {
    clear: both;
  }

  .amis-scope .a-Crud-toolbar-item {
    margin-left: var(--Crud-toolbar-gap);
    line-height: var(--Crud-toolbar-lineHeight);
    height: var(--Crud-toolbar-height);
    vertical-align: middle;
  }

  .amis-scope .a-Crud-toolbar-item--left {
    float: left;
  }

  .amis-scope .a-Crud-toolbar-item--right {
    float: right;
  }

  .amis-scope .a-Crud-actions > * + .a-Button,
  .amis-scope .a-Crud-actions > * + .a-Button--disabled-wrap {
    margin-left: var(--Crud-toolbar-gap);
  }
}

.amis-scope .a-Table {
  position: relative;
  border-radius: var(--Table-borderRadius);
  margin-bottom: var(--gap-md);
}

.amis-scope .a-Form-control > .a-Table {
  margin-bottom: var(--gap-sm);
}

.amis-scope .a-Table-fixedLeft,
.amis-scope .a-Table-fixedRight {
  position: absolute;
  background: var(--Table-bg);
  z-index: var(--Table-fixed-zIndex);
  top: auto;
  box-shadow: none;
}

.amis-scope .a-Table-fixedLeft {
  left: 0;
  top: -999999px;
}

.amis-scope .a-Table-fixedLeft.in {
  box-shadow: var(--Table-fixedLeft-boxShadow);
  top: auto;
}

.amis-scope .a-Table-fixedLeft > .a-Table-table > thead > tr > th:last-child,
.amis-scope .a-Table-fixedLeft > .a-Table-table > tbody > tr > td:last-child {
  padding-right: var(--TableCell-paddingX);
}

.amis-scope .a-Table-fixedRight {
  right: 0;
  top: -999999px;
}

.amis-scope .a-Table-fixedRight.in {
  box-shadow: var(--Table-fixedRight-boxShadow);
  top: auto;
}

.amis-scope .a-Table-fixedRight > .a-Table-table > thead > tr > th:first-child,
.amis-scope .a-Table-fixedRight > .a-Table-table > tbody > tr > td:first-child {
  padding-left: var(--TableCell-paddingX);
}

.amis-scope .a-Table-fixedTop {
  position: absolute;
  background: var(--Table-bg);
  z-index: -1;
  opacity: 0;
  box-shadow: var(--Table-fixedTop-boxShadow);
}

.amis-scope .a-Table-fixedTop.in {
  position: fixed;
  opacity: 1;
  z-index: 900;
}

.amis-scope .a-Table-fixedTop > .a-Table-fixedLeft,
.amis-scope .a-Table-fixedTop > .a-Table-fixedRight {
  z-index: 910;
  background: transparent;
}

.amis-scope .a-Table-fixedTop.is-fakeHide > .a-Table-fixedLeft,
.amis-scope .a-Table-fixedTop.is-fakeHide > .a-Table-fixedRight,
.amis-scope .a-Table-fixedTop.is-fakeHide > .a-Table-wrapper {
  visibility: hidden;
  position: absolute;
}

.amis-scope .a-Table-heading {
  background: var(--Table-heading-bg);
  padding: calc( ( var(--Table-heading-height) - var(--Table-fontSize) * var(--lineHeightBase) ) / 2 ) var(--gap-sm);
}

.amis-scope .a-Table--unsaved .a-Table-heading {
  background: var(--Table--unsaved-heading-bg);
  color: var(--Table--unsaved-heading-color);
}

.amis-scope .a-Table-wrapper {
  overflow: hidden;
}

.amis-scope .a-Table-placeholder {
  color: var(--text--muted-color);
  text-align: center;
  height: var(--Table-placeholder-height);
  background: transparent !important;
}

.amis-scope .a-Table-placeholder:hover {
  color: var(--text--muted-color);
  background: transparent !important;
}

.amis-scope .a-Table-placeholder > td {
  vertical-align: middle !important;
  text-align: center;
}

.amis-scope .a-Table-header {
  padding: var(--Table-toolbar-marginY) var(--Table-toolbar-marginX);
}

.amis-scope .a-Table-header > * + .a-Button,
.amis-scope .a-Table-header > * + .a-ButtonGroup,
.amis-scope .a-Table-header > * + .a-ButtonToolbar {
  margin-left: var(--Crud-toolbar-gap);
}

.amis-scope .a-Table-toolbar {
  display: flex;
  margin: 0 var(--Table-toolbar-marginX) var(--Table-toolbar-marginY);
  flex-wrap: wrap;
}

.amis-scope .a-Table-toolbar::before,
.amis-scope .a-Table-toolbar::after {
  display: table;
  content: "";
}

.amis-scope .a-Table-toolbar::after {
  clear: both;
}

.amis-scope .a-Table-toolbar .a-DropDown-menuItem {
  height: auto;
}

.amis-scope .a-Table-toolbar .a-DropDown-menuItem .a-Checkbox {
  display: flex;
  align-items: center;
}

.amis-scope .a-Table-header + .a-Table-toolbar {
  padding-top: 0;
}

.amis-scope .a-Table-contentWrap {
  position: relative;
  margin-bottom: var(--Table-toolbar-marginY);
}

.amis-scope .a-Table-actions {
  display: inline-block;
}

.amis-scope .a-Table-actions > * {
  margin-right: var(--Crud-toolbar-gap);
}

.amis-scope .a-Table-content {
  min-height: 0.01%;
  overflow-x: auto;
  transform: translateZ(0);
}

.amis-scope .a-Table-content th {
  position: relative;
}

.amis-scope .a-Table-content-colDragLine {
  position: absolute;
  width: 7px;
  top: 0;
  bottom: 0;
  right: -4px;
  cursor: col-resize;
  user-select: none;
  opacity: 0.5;
  z-index: 3000;
}

.amis-scope .a-Table-content-colDragLine:hover {
  background: var(--primary);
}

.amis-scope .a-Table-table {
  width: 100%;
  min-width: 100%;
  margin-bottom: 0;
  font-size: var(--Table-fontSize);
  color: var(--Table-color);
  background: var(--Table-bg);
  border-spacing: 0;
  border-collapse: collapse;
  border: var(--Table-borderWidth) solid var(--Table-borderColor);
}

.amis-scope .a-Table-table th,
.amis-scope .a-Table-table td {
  text-align: left;
}

.amis-scope .a-Table-table th.text-center,
.amis-scope .a-Table-table td.text-center,
.amis-scope .a-Table-table th[colspan],
.amis-scope .a-Table-table td[colspan] {
  text-align: center;
}

.amis-scope .a-Table-table th.text-right,
.amis-scope .a-Table-table td.text-right {
  text-align: right;
}

.amis-scope .a-Table-table--withCombine > thead > tr > th:first-child,
.amis-scope .a-Table-table--withCombine > tbody > tr > td:first-child {
  padding-left: var(--TableCell-paddingX) !important;
}

.amis-scope .a-Table-table--withCombine > thead > tr > th:last-child,
.amis-scope .a-Table-table--withCombine > tbody > tr > td:last-child {
  padding-right: var(--TableCell-paddingX) !important;
}

.amis-scope .a-Table-table--withCombine > tbody > tr.a-Table-tr--odd {
  background: transparent;
}

.amis-scope .a-Table-table--withCombine > tbody > tr:hover {
  background: transparent;
}

.amis-scope .a-Table-table--withCombine > tbody > tr > td {
  vertical-align: middle;
}

.amis-scope .a-Table-table--withCombine > tbody > tr > td:not(:last-child) {
  border-right: var(--Table-borderWidth) solid var(--Table-borderColor);
}

.amis-scope .a-Table-table > thead > tr > th {
  background: var(--Table-thead-bg);
  padding: var(--TableCell-paddingY) var(--TableCell-paddingX);
  border-bottom: var(--Table-thead-borderWidth) solid var(--Table-thead-borderColor);
  font-size: var(--Table-thead-fontSize);
  color: var(--Table-thead-color);
  font-weight: var(--fontWeightNormal);
  white-space: nowrap;
}

.amis-scope .a-Table-table > thead > tr > th:first-child {
  padding-left: var(--TableCell--edge-paddingX);
}

.amis-scope .a-Table-table > thead > tr > th:last-child {
  padding-right: var(--TableCell--edge-paddingX);
}

.amis-scope .a-Table-table > thead > tr > th:last-child .a-Table-content-colDragLine {
  width: 4px;
  right: 0;
}

.amis-scope .a-Table-table > thead > tr > th:not(:last-child) {
  border-right: var(--Table-thead-borderWidth) solid var(--Table-thead-borderColor);
}

.amis-scope .a-Table-table > thead > tr > th .a-Remark {
  margin-left: var(--gap-xs);
}

.amis-scope .a-Table-table > thead > tr + tr {
  border-top: var(--Table-borderWidth) solid var(--Table-borderColor);
}

.amis-scope .a-Table-table > thead > tr {
  border-bottom: var(--Table-borderWidth) solid var(--Table-borderColor);
}

.amis-scope .a-Table-table > tbody > tr {
  background: transparent;
}

.amis-scope .a-Table-table > tbody > tr + tr {
  border-top: var(--Table-borderWidth) solid var(--Table-borderColor);
}

.amis-scope .a-Table-table > tbody > tr + tr > th {
  border-top: var(--Table-thead-borderWidth) solid var(--Table-thead-borderColor);
}

.amis-scope .a-Table-table > tbody > tr > th {
  background: var(--Table-thead-bg);
  color: var(--Table-thead-color);
  font-weight: var(--fontWeightNormal);
  white-space: nowrap;
  border-right: var(--Table-thead-borderWidth) solid var(--Table-thead-borderColor);
}

.amis-scope .a-Table-table > tbody > tr > td,
.amis-scope .a-Table-table > tbody > tr > th {
  padding: var(--TableCell-paddingY) var(--TableCell-paddingX);
}

.amis-scope .a-Table-table > tbody > tr > td:first-child,
.amis-scope .a-Table-table > tbody > tr > th:first-child {
  padding-left: var(--TableCell--edge-paddingX);
}

.amis-scope .a-Table-table > tbody > tr > td:last-child,
.amis-scope .a-Table-table > tbody > tr > th:last-child {
  padding-right: var(--TableCell--edge-paddingX);
}

.amis-scope .a-Table-table > tbody > tr.a-Table-tr--odd {
  background: var(--Table-strip-bg);
}

.amis-scope .a-Table-table > tbody > tr:hover,
.amis-scope .a-Table-table > tbody > tr.is-hovered {
  background: var(--Table-onHover-bg);
  border-color: var(--Table-onHover-borderColor);
  color: var(--Table-onHover-color);
}

.amis-scope .a-Table-table > tbody > tr:hover + tr,
.amis-scope .a-Table-table > tbody > tr.is-hovered + tr {
  border-color: var(--Table-onHover-borderColor);
}

.amis-scope .a-Table-table > tbody > tr.is-checked {
  background: var(--Table-onChecked-bg);
  border-color: var(--Table-onChecked-borderColor);
  color: var(--Table-onChecked-color);
}

.amis-scope .a-Table-table > tbody > tr.is-checked + tr {
  border-color: var(--Table-onChecked-borderColor);
}

.amis-scope .a-Table-table > tbody > tr.is-moved,
.amis-scope .a-Table-table > tbody > tr.is-modified {
  background: var(--Table-onModified-bg);
  border-color: var(--Table-onModified-borderColor);
  color: var(--Table-onModified-color);
}

.amis-scope .a-Table-table > tbody > tr.is-moved + tr,
.amis-scope .a-Table-table > tbody > tr.is-modified + tr {
  border-color: var(--Table-onModified-borderColor);
}

.amis-scope .a-Table-table > tbody > tr.is-summary {
  background: var(--Table-thead-bg);
  color: var(--Table-thead-color);
  font-weight: var(--fontWeightNormal);
}

.amis-scope .a-Table-table > tbody > tr.bg-light {
  background-color: #edf1f2;
  color: #58666e;
}

.amis-scope .a-Table-table > tbody > tr.bg-light.lt,
.amis-scope .a-Table-table > tbody > tr.bg-light .lt {
  background: #f3f5f6;
}

.amis-scope .a-Table-table > tbody > tr.bg-light.lter,
.amis-scope .a-Table-table > tbody > tr.bg-light .lter {
  background: #f6f8f8;
}

.amis-scope .a-Table-table > tbody > tr.bg-light.dk,
.amis-scope .a-Table-table > tbody > tr.bg-light .dk {
  background: #e4eaec;
}

.amis-scope .a-Table-table > tbody > tr.bg-light.dker,
.amis-scope .a-Table-table > tbody > tr.bg-light .dker {
  background: #dde6e9;
}

.amis-scope .a-Table-table > tbody > tr.bg-light.bg,
.amis-scope .a-Table-table > tbody > tr.bg-light .bg {
  background-color: #edf1f2;
}

.amis-scope .a-Table-table > tbody > tr.bg-dark {
  background-color: #3a3f51;
  color: #a6a8b1;
}

.amis-scope .a-Table-table > tbody > tr.bg-dark.lt,
.amis-scope .a-Table-table > tbody > tr.bg-dark .lt {
  background: #474c5e;
}

.amis-scope .a-Table-table > tbody > tr.bg-dark.lter,
.amis-scope .a-Table-table > tbody > tr.bg-dark .lter {
  background: #54596a;
}

.amis-scope .a-Table-table > tbody > tr.bg-dark.dk,
.amis-scope .a-Table-table > tbody > tr.bg-dark .dk {
  background: #2e3344;
}

.amis-scope .a-Table-table > tbody > tr.bg-dark.dker,
.amis-scope .a-Table-table > tbody > tr.bg-dark .dker {
  background: #232735;
}

.amis-scope .a-Table-table > tbody > tr.bg-dark.bg,
.amis-scope .a-Table-table > tbody > tr.bg-dark .bg {
  background-color: #3a3f51;
}

.amis-scope .a-Table-table > tbody > tr.bg-dark a,
.amis-scope .a-Table-table > tbody > tr.bg-dark .a-Button--link {
  color: #c1c3c9;
}

.amis-scope .a-Table-table > tbody > tr.bg-dark a:hover,
.amis-scope .a-Table-table > tbody > tr.bg-dark .a-Button--link:hover {
  color: #fff;
}

.amis-scope .a-Table-table > tbody > tr.bg-dark .open > a,
.amis-scope .a-Table-table > tbody > tr.bg-dark .open > a:hover,
.amis-scope .a-Table-table > tbody > tr.bg-dark .open > a:focus {
  color: #fff;
}

.amis-scope .a-Table-table > tbody > tr.bg-dark .text-muted {
  color: #414c52 !important;
}

.amis-scope .a-Table-table > tbody > tr.bg-dark .text-lt {
  color: #99a6ad !important;
}

.amis-scope .a-Table-table > tbody > tr.bg-black {
  background-color: #1c2b36;
  color: #7793a7;
}

.amis-scope .a-Table-table > tbody > tr.bg-black.lt,
.amis-scope .a-Table-table > tbody > tr.bg-black .lt {
  background: #263845;
}

.amis-scope .a-Table-table > tbody > tr.bg-black.lter,
.amis-scope .a-Table-table > tbody > tr.bg-black .lter {
  background: #314554;
}

.amis-scope .a-Table-table > tbody > tr.bg-black.dk,
.amis-scope .a-Table-table > tbody > tr.bg-black .dk {
  background: #131e26;
}

.amis-scope .a-Table-table > tbody > tr.bg-black.dker,
.amis-scope .a-Table-table > tbody > tr.bg-black .dker {
  background: #0a1015;
}

.amis-scope .a-Table-table > tbody > tr.bg-black.bg,
.amis-scope .a-Table-table > tbody > tr.bg-black .bg {
  background-color: #1c2b36;
}

.amis-scope .a-Table-table > tbody > tr.bg-black a,
.amis-scope .a-Table-table > tbody > tr.bg-black .a-Button--link {
  color: #96abbb;
}

.amis-scope .a-Table-table > tbody > tr.bg-black a:hover,
.amis-scope .a-Table-table > tbody > tr.bg-black .a-Button--link:hover {
  color: #fff;
}

.amis-scope .a-Table-table > tbody > tr.bg-black .open > a,
.amis-scope .a-Table-table > tbody > tr.bg-black .open > a:hover,
.amis-scope .a-Table-table > tbody > tr.bg-black .open > a:focus {
  color: #fff;
}

.amis-scope .a-Table-table > tbody > tr.bg-black .text-muted {
  color: #414c52 !important;
}

.amis-scope .a-Table-table > tbody > tr.bg-black .text-lt {
  color: #99a6ad !important;
}

.amis-scope .a-Table-table > tbody > tr.bg-primary {
  background-color: #7266ba;
  color: #f4f3f9;
}

.amis-scope .a-Table-table > tbody > tr.bg-primary.lt,
.amis-scope .a-Table-table > tbody > tr.bg-primary .lt {
  background: #847abf;
}

.amis-scope .a-Table-table > tbody > tr.bg-primary.lter,
.amis-scope .a-Table-table > tbody > tr.bg-primary .lter {
  background: #958dc6;
}

.amis-scope .a-Table-table > tbody > tr.bg-primary.dk,
.amis-scope .a-Table-table > tbody > tr.bg-primary .dk {
  background: #6051b5;
}

.amis-scope .a-Table-table > tbody > tr.bg-primary.dker,
.amis-scope .a-Table-table > tbody > tr.bg-primary .dker {
  background: #5244a9;
}

.amis-scope .a-Table-table > tbody > tr.bg-primary.bg,
.amis-scope .a-Table-table > tbody > tr.bg-primary .bg {
  background-color: #7266ba;
}

.amis-scope .a-Table-table > tbody > tr.bg-primary a,
.amis-scope .a-Table-table > tbody > tr.bg-primary .a-Button--link {
  color: white;
}

.amis-scope .a-Table-table > tbody > tr.bg-primary a:hover,
.amis-scope .a-Table-table > tbody > tr.bg-primary .a-Button--link:hover {
  color: #fff;
}

.amis-scope .a-Table-table > tbody > tr.bg-primary .open > a,
.amis-scope .a-Table-table > tbody > tr.bg-primary .open > a:hover,
.amis-scope .a-Table-table > tbody > tr.bg-primary .open > a:focus {
  color: #fff;
}

.amis-scope .a-Table-table > tbody > tr.bg-primary .text-muted {
  color: #414c52 !important;
}

.amis-scope .a-Table-table > tbody > tr.bg-primary .text-lt {
  color: #99a6ad !important;
}

.amis-scope .a-Table-table > tbody > tr.bg-success {
  background-color: #27c24c;
  color: #c6efd0;
}

.amis-scope .a-Table-table > tbody > tr.bg-success.lt,
.amis-scope .a-Table-table > tbody > tr.bg-success .lt {
  background: #31d257;
}

.amis-scope .a-Table-table > tbody > tr.bg-success.lter,
.amis-scope .a-Table-table > tbody > tr.bg-success .lter {
  background: #48d46a;
}

.amis-scope .a-Table-table > tbody > tr.bg-success.dk,
.amis-scope .a-Table-table > tbody > tr.bg-success .dk {
  background: #20af42;
}

.amis-scope .a-Table-table > tbody > tr.bg-success.dker,
.amis-scope .a-Table-table > tbody > tr.bg-success .dker {
  background: #1a9c39;
}

.amis-scope .a-Table-table > tbody > tr.bg-success.bg,
.amis-scope .a-Table-table > tbody > tr.bg-success .bg {
  background-color: #27c24c;
}

.amis-scope .a-Table-table > tbody > tr.bg-success a,
.amis-scope .a-Table-table > tbody > tr.bg-success .a-Button--link {
  color: #eefaf1;
}

.amis-scope .a-Table-table > tbody > tr.bg-success a:hover,
.amis-scope .a-Table-table > tbody > tr.bg-success .a-Button--link:hover {
  color: #fff;
}

.amis-scope .a-Table-table > tbody > tr.bg-success .open > a,
.amis-scope .a-Table-table > tbody > tr.bg-success .open > a:hover,
.amis-scope .a-Table-table > tbody > tr.bg-success .open > a:focus {
  color: #fff;
}

.amis-scope .a-Table-table > tbody > tr.bg-success .text-muted {
  color: #414c52 !important;
}

.amis-scope .a-Table-table > tbody > tr.bg-success .text-lt {
  color: #99a6ad !important;
}

.amis-scope .a-Table-table > tbody > tr.bg-info {
  background-color: #23b7e5;
  color: #dcf2f8;
}

.amis-scope .a-Table-table > tbody > tr.bg-info.lt,
.amis-scope .a-Table-table > tbody > tr.bg-info .lt {
  background: #3dbde5;
}

.amis-scope .a-Table-table > tbody > tr.bg-info.lter,
.amis-scope .a-Table-table > tbody > tr.bg-info .lter {
  background: #55c3e6;
}

.amis-scope .a-Table-table > tbody > tr.bg-info.dk,
.amis-scope .a-Table-table > tbody > tr.bg-info .dk {
  background: #16aad8;
}

.amis-scope .a-Table-table > tbody > tr.bg-info.dker,
.amis-scope .a-Table-table > tbody > tr.bg-info .dker {
  background: #1199c4;
}

.amis-scope .a-Table-table > tbody > tr.bg-info.bg,
.amis-scope .a-Table-table > tbody > tr.bg-info .bg {
  background-color: #23b7e5;
}

.amis-scope .a-Table-table > tbody > tr.bg-info a,
.amis-scope .a-Table-table > tbody > tr.bg-info .a-Button--link {
  color: white;
}

.amis-scope .a-Table-table > tbody > tr.bg-info a:hover,
.amis-scope .a-Table-table > tbody > tr.bg-info .a-Button--link:hover {
  color: #fff;
}

.amis-scope .a-Table-table > tbody > tr.bg-info .open > a,
.amis-scope .a-Table-table > tbody > tr.bg-info .open > a:hover,
.amis-scope .a-Table-table > tbody > tr.bg-info .open > a:focus {
  color: #fff;
}

.amis-scope .a-Table-table > tbody > tr.bg-info .text-muted {
  color: #414c52 !important;
}

.amis-scope .a-Table-table > tbody > tr.bg-info .text-lt {
  color: #99a6ad !important;
}

.amis-scope .a-Table-table > tbody > tr.bg-warning {
  background-color: #fad733;
  color: #fffefa;
}

.amis-scope .a-Table-table > tbody > tr.bg-warning.lt,
.amis-scope .a-Table-table > tbody > tr.bg-warning .lt {
  background: #f8da4e;
}

.amis-scope .a-Table-table > tbody > tr.bg-warning.lter,
.amis-scope .a-Table-table > tbody > tr.bg-warning .lter {
  background: #f7de69;
}

.amis-scope .a-Table-table > tbody > tr.bg-warning.dk,
.amis-scope .a-Table-table > tbody > tr.bg-warning .dk {
  background: #fcd417;
}

.amis-scope .a-Table-table > tbody > tr.bg-warning.dker,
.amis-scope .a-Table-table > tbody > tr.bg-warning .dker {
  background: #face00;
}

.amis-scope .a-Table-table > tbody > tr.bg-warning.bg,
.amis-scope .a-Table-table > tbody > tr.bg-warning .bg {
  background-color: #fad733;
}

.amis-scope .a-Table-table > tbody > tr.bg-warning a,
.amis-scope .a-Table-table > tbody > tr.bg-warning .a-Button--link {
  color: white;
}

.amis-scope .a-Table-table > tbody > tr.bg-warning a:hover,
.amis-scope .a-Table-table > tbody > tr.bg-warning .a-Button--link:hover {
  color: #fff;
}

.amis-scope .a-Table-table > tbody > tr.bg-warning .open > a,
.amis-scope .a-Table-table > tbody > tr.bg-warning .open > a:hover,
.amis-scope .a-Table-table > tbody > tr.bg-warning .open > a:focus {
  color: #fff;
}

.amis-scope .a-Table-table > tbody > tr.bg-warning .text-muted {
  color: #414c52 !important;
}

.amis-scope .a-Table-table > tbody > tr.bg-warning .text-lt {
  color: #99a6ad !important;
}

.amis-scope .a-Table-table > tbody > tr.bg-danger {
  background-color: #f05050;
  color: white;
}

.amis-scope .a-Table-table > tbody > tr.bg-danger.lt,
.amis-scope .a-Table-table > tbody > tr.bg-danger .lt {
  background: #f06a6a;
}

.amis-scope .a-Table-table > tbody > tr.bg-danger.lter,
.amis-scope .a-Table-table > tbody > tr.bg-danger .lter {
  background: #f18282;
}

.amis-scope .a-Table-table > tbody > tr.bg-danger.dk,
.amis-scope .a-Table-table > tbody > tr.bg-danger .dk {
  background: #f13636;
}

.amis-scope .a-Table-table > tbody > tr.bg-danger.dker,
.amis-scope .a-Table-table > tbody > tr.bg-danger .dker {
  background: #f21b1b;
}

.amis-scope .a-Table-table > tbody > tr.bg-danger.bg,
.amis-scope .a-Table-table > tbody > tr.bg-danger .bg {
  background-color: #f05050;
}

.amis-scope .a-Table-table > tbody > tr.bg-danger a,
.amis-scope .a-Table-table > tbody > tr.bg-danger .a-Button--link {
  color: white;
}

.amis-scope .a-Table-table > tbody > tr.bg-danger a:hover,
.amis-scope .a-Table-table > tbody > tr.bg-danger .a-Button--link:hover {
  color: #fff;
}

.amis-scope .a-Table-table > tbody > tr.bg-danger .open > a,
.amis-scope .a-Table-table > tbody > tr.bg-danger .open > a:hover,
.amis-scope .a-Table-table > tbody > tr.bg-danger .open > a:focus {
  color: #fff;
}

.amis-scope .a-Table-table > tbody > tr.bg-danger .text-muted {
  color: #414c52 !important;
}

.amis-scope .a-Table-table > tbody > tr.bg-danger .text-lt {
  color: #99a6ad !important;
}

.amis-scope .a-Table-table > tbody > tr.is-dragging {
  opacity: var(--Table-onDragging-opacity);
}

.amis-scope .a-Table-table tr.a-Table-tr--2th.is-expanded .a-Table-expandCell:before {
  right: -0.6875rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--2th .a-Table-expandBtn {
  position: relative;
  right: -1.125rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--2th .a-Table-expandCell + td {
  position: relative;
  padding-left: 1.125rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--2th .a-Table-expandCell + td::before {
  content: "";
  position: absolute;
  width: 0.0625rem;
  top: 0;
  bottom: 0;
  left: -0.5rem;
  height: auto;
  background: var(--Table-tree-borderColor);
}

.amis-scope .a-Table-table tr.a-Table-tr--2th .a-Table-expandCell + td::after {
  content: "";
  position: absolute;
  height: 0.0625rem;
  top: 50%;
  left: -0.5rem;
  width: 0.625rem;
  background: var(--Table-tree-borderColor);
}

.amis-scope .a-Table-table tr.a-Table-tr--2th.is-expandable .a-Table-expandCell + td {
  padding-left: 1.125rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--2th.is-last:not(.is-expanded) .a-Table-expandCell + td::before {
  height: 50%;
  bottom: auto;
}

.amis-scope .a-Table-table tr.a-Table-tr--3th.is-expanded .a-Table-expandCell:before {
  right: -1.8125rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--3th .a-Table-expandBtn {
  position: relative;
  right: -2.25rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--3th .a-Table-expandCell + td {
  position: relative;
  padding-left: 2.25rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--3th .a-Table-expandCell + td::before {
  content: "";
  position: absolute;
  width: 0.0625rem;
  top: 0;
  bottom: 0;
  left: 0.625rem;
  height: auto;
  background: var(--Table-tree-borderColor);
}

.amis-scope .a-Table-table tr.a-Table-tr--3th .a-Table-expandCell + td::after {
  content: "";
  position: absolute;
  height: 0.0625rem;
  top: 50%;
  left: 0.625rem;
  width: 0.625rem;
  background: var(--Table-tree-borderColor);
}

.amis-scope .a-Table-table tr.a-Table-tr--3th.is-expandable .a-Table-expandCell + td {
  padding-left: 2.25rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--3th.is-last:not(.is-expanded) .a-Table-expandCell + td::before {
  height: 50%;
  bottom: auto;
}

.amis-scope .a-Table-table tr.a-Table-tr--4th.is-expanded .a-Table-expandCell:before {
  right: -2.9375rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--4th .a-Table-expandBtn {
  position: relative;
  right: -3.375rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--4th .a-Table-expandCell + td {
  position: relative;
  padding-left: 3.375rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--4th .a-Table-expandCell + td::before {
  content: "";
  position: absolute;
  width: 0.0625rem;
  top: 0;
  bottom: 0;
  left: 1.75rem;
  height: auto;
  background: var(--Table-tree-borderColor);
}

.amis-scope .a-Table-table tr.a-Table-tr--4th .a-Table-expandCell + td::after {
  content: "";
  position: absolute;
  height: 0.0625rem;
  top: 50%;
  left: 1.75rem;
  width: 0.625rem;
  background: var(--Table-tree-borderColor);
}

.amis-scope .a-Table-table tr.a-Table-tr--4th.is-expandable .a-Table-expandCell + td {
  padding-left: 3.375rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--4th.is-last:not(.is-expanded) .a-Table-expandCell + td::before {
  height: 50%;
  bottom: auto;
}

.amis-scope .a-Table-table tr.a-Table-tr--5th.is-expanded .a-Table-expandCell:before {
  right: -4.0625rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--5th .a-Table-expandBtn {
  position: relative;
  right: -4.5rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--5th .a-Table-expandCell + td {
  position: relative;
  padding-left: 4.5rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--5th .a-Table-expandCell + td::before {
  content: "";
  position: absolute;
  width: 0.0625rem;
  top: 0;
  bottom: 0;
  left: 2.875rem;
  height: auto;
  background: var(--Table-tree-borderColor);
}

.amis-scope .a-Table-table tr.a-Table-tr--5th .a-Table-expandCell + td::after {
  content: "";
  position: absolute;
  height: 0.0625rem;
  top: 50%;
  left: 2.875rem;
  width: 0.625rem;
  background: var(--Table-tree-borderColor);
}

.amis-scope .a-Table-table tr.a-Table-tr--5th.is-expandable .a-Table-expandCell + td {
  padding-left: 4.5rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--5th.is-last:not(.is-expanded) .a-Table-expandCell + td::before {
  height: 50%;
  bottom: auto;
}

.amis-scope .a-Table-table tr.a-Table-tr--6th.is-expanded .a-Table-expandCell:before {
  right: -5.1875rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--6th .a-Table-expandBtn {
  position: relative;
  right: -5.625rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--6th .a-Table-expandCell + td {
  position: relative;
  padding-left: 5.625rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--6th .a-Table-expandCell + td::before {
  content: "";
  position: absolute;
  width: 0.0625rem;
  top: 0;
  bottom: 0;
  left: 4rem;
  height: auto;
  background: var(--Table-tree-borderColor);
}

.amis-scope .a-Table-table tr.a-Table-tr--6th .a-Table-expandCell + td::after {
  content: "";
  position: absolute;
  height: 0.0625rem;
  top: 50%;
  left: 4rem;
  width: 0.625rem;
  background: var(--Table-tree-borderColor);
}

.amis-scope .a-Table-table tr.a-Table-tr--6th.is-expandable .a-Table-expandCell + td {
  padding-left: 5.625rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--6th.is-last:not(.is-expanded) .a-Table-expandCell + td::before {
  height: 50%;
  bottom: auto;
}

.amis-scope .a-Table-table tr.a-Table-tr--7th.is-expanded .a-Table-expandCell:before {
  right: -6.3125rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--7th .a-Table-expandBtn {
  position: relative;
  right: -6.75rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--7th .a-Table-expandCell + td {
  position: relative;
  padding-left: 6.75rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--7th .a-Table-expandCell + td::before {
  content: "";
  position: absolute;
  width: 0.0625rem;
  top: 0;
  bottom: 0;
  left: 5.125rem;
  height: auto;
  background: var(--Table-tree-borderColor);
}

.amis-scope .a-Table-table tr.a-Table-tr--7th .a-Table-expandCell + td::after {
  content: "";
  position: absolute;
  height: 0.0625rem;
  top: 50%;
  left: 5.125rem;
  width: 0.625rem;
  background: var(--Table-tree-borderColor);
}

.amis-scope .a-Table-table tr.a-Table-tr--7th.is-expandable .a-Table-expandCell + td {
  padding-left: 6.75rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--7th.is-last:not(.is-expanded) .a-Table-expandCell + td::before {
  height: 50%;
  bottom: auto;
}

.amis-scope .a-Table-table tr.a-Table-tr--8th.is-expanded .a-Table-expandCell:before {
  right: -7.4375rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--8th .a-Table-expandBtn {
  position: relative;
  right: -7.875rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--8th .a-Table-expandCell + td {
  position: relative;
  padding-left: 7.875rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--8th .a-Table-expandCell + td::before {
  content: "";
  position: absolute;
  width: 0.0625rem;
  top: 0;
  bottom: 0;
  left: 6.25rem;
  height: auto;
  background: var(--Table-tree-borderColor);
}

.amis-scope .a-Table-table tr.a-Table-tr--8th .a-Table-expandCell + td::after {
  content: "";
  position: absolute;
  height: 0.0625rem;
  top: 50%;
  left: 6.25rem;
  width: 0.625rem;
  background: var(--Table-tree-borderColor);
}

.amis-scope .a-Table-table tr.a-Table-tr--8th.is-expandable .a-Table-expandCell + td {
  padding-left: 7.875rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--8th.is-last:not(.is-expanded) .a-Table-expandCell + td::before {
  height: 50%;
  bottom: auto;
}

.amis-scope .a-Table-table tr.a-Table-tr--9th.is-expanded .a-Table-expandCell:before {
  right: -8.5625rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--9th .a-Table-expandBtn {
  position: relative;
  right: -9rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--9th .a-Table-expandCell + td {
  position: relative;
  padding-left: 9rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--9th .a-Table-expandCell + td::before {
  content: "";
  position: absolute;
  width: 0.0625rem;
  top: 0;
  bottom: 0;
  left: 7.375rem;
  height: auto;
  background: var(--Table-tree-borderColor);
}

.amis-scope .a-Table-table tr.a-Table-tr--9th .a-Table-expandCell + td::after {
  content: "";
  position: absolute;
  height: 0.0625rem;
  top: 50%;
  left: 7.375rem;
  width: 0.625rem;
  background: var(--Table-tree-borderColor);
}

.amis-scope .a-Table-table tr.a-Table-tr--9th.is-expandable .a-Table-expandCell + td {
  padding-left: 9rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--9th.is-last:not(.is-expanded) .a-Table-expandCell + td::before {
  height: 50%;
  bottom: auto;
}

.amis-scope .a-Table-table tr.a-Table-tr--10th.is-expanded .a-Table-expandCell:before {
  right: -9.6875rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--10th .a-Table-expandBtn {
  position: relative;
  right: -10.125rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--10th .a-Table-expandCell + td {
  position: relative;
  padding-left: 10.125rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--10th .a-Table-expandCell + td::before {
  content: "";
  position: absolute;
  width: 0.0625rem;
  top: 0;
  bottom: 0;
  left: 8.5rem;
  height: auto;
  background: var(--Table-tree-borderColor);
}

.amis-scope .a-Table-table tr.a-Table-tr--10th .a-Table-expandCell + td::after {
  content: "";
  position: absolute;
  height: 0.0625rem;
  top: 50%;
  left: 8.5rem;
  width: 0.625rem;
  background: var(--Table-tree-borderColor);
}

.amis-scope .a-Table-table tr.a-Table-tr--10th.is-expandable .a-Table-expandCell + td {
  padding-left: 10.125rem;
}

.amis-scope .a-Table-table tr.a-Table-tr--10th.is-last:not(.is-expanded) .a-Table-expandCell + td::before {
  height: 50%;
  bottom: auto;
}

.amis-scope .a-Table-table > thead > tr > th.a-Table-checkCell,
.amis-scope .a-Table-table > tbody > tr > td.a-Table-checkCell {
  border-right: 0;
  width: 0.0625rem;
  padding-right: var(--TableCell-paddingX);
  white-space: nowrap;
}

.amis-scope .a-Table-table > thead > tr > th.a-Table-checkCell .a-Checkbox,
.amis-scope .a-Table-table > tbody > tr > td.a-Table-checkCell .a-Checkbox {
  margin: 0;
}

.amis-scope .a-Table-table > thead > tr > th.a-Table-expandCell,
.amis-scope .a-Table-table > tbody > tr > td.a-Table-expandCell {
  border-right: 0;
  width: 0.0625rem;
  padding-right: 0;
}

.amis-scope .a-Table-table > thead > tr > th.a-Table-dragCell,
.amis-scope .a-Table-table > tbody > tr > td.a-Table-dragCell {
  border-right: 0;
  width: 0.0625rem;
  padding-right: 0;
  cursor: move;
}

.amis-scope .a-Table-table > tbody > tr > td.a-Table-expandCell {
  position: relative;
}

.amis-scope .a-Table-table > tbody > tr > td.a-Table-expandCell .a-Table-divider-1 {
  position: absolute;
  width: 0.0625rem;
  top: 0;
  bottom: 0;
  height: 100%;
  background: var(--Table-tree-borderColor);
  right: 0.4375rem;
}

.amis-scope .a-Table-table > tbody > tr > td.a-Table-expandCell .a-Table-divider-2 {
  position: absolute;
  width: 0.0625rem;
  top: 0;
  bottom: 0;
  height: 100%;
  background: var(--Table-tree-borderColor);
  right: -0.6875rem;
}

.amis-scope .a-Table-table > tbody > tr > td.a-Table-expandCell .a-Table-divider-3 {
  position: absolute;
  width: 0.0625rem;
  top: 0;
  bottom: 0;
  height: 100%;
  background: var(--Table-tree-borderColor);
  right: -1.8125rem;
}

.amis-scope .a-Table-table > tbody > tr > td.a-Table-expandCell .a-Table-divider-4 {
  position: absolute;
  width: 0.0625rem;
  top: 0;
  bottom: 0;
  height: 100%;
  background: var(--Table-tree-borderColor);
  right: -2.9375rem;
}

.amis-scope .a-Table-table > tbody > tr > td.a-Table-expandCell .a-Table-divider-5 {
  position: absolute;
  width: 0.0625rem;
  top: 0;
  bottom: 0;
  height: 100%;
  background: var(--Table-tree-borderColor);
  right: -4.0625rem;
}

.amis-scope .a-Table-table > tbody > tr > td.a-Table-expandCell .a-Table-divider-6 {
  position: absolute;
  width: 0.0625rem;
  top: 0;
  bottom: 0;
  height: 100%;
  background: var(--Table-tree-borderColor);
  right: -5.1875rem;
}

.amis-scope .a-Table-table > tbody > tr > td.a-Table-expandCell .a-Table-divider-7 {
  position: absolute;
  width: 0.0625rem;
  top: 0;
  bottom: 0;
  height: 100%;
  background: var(--Table-tree-borderColor);
  right: -6.3125rem;
}

.amis-scope .a-Table-table > tbody > tr.is-expanded > td.a-Table-expandCell::before {
  content: "";
  position: absolute;
  width: 0.0625rem;
  top: 50%;
  bottom: 0;
  right: 0.4375rem;
  height: auto;
  background: var(--Table-tree-borderColor);
}

.amis-scope .a-Table-table > thead > tr > th.a-TableCell--sortable {
  padding-right: calc( var(--TableCell-paddingX) + var(--TableCell-sortBtn-width) );
  position: relative;
}

.amis-scope .a-Table-table > thead > tr > th.a-TableCell--searchable {
  padding-right: calc( var(--TableCell-paddingX) + var(--TableCell-searchBtn-width) );
  position: relative;
}

.amis-scope .a-Table-table > thead > tr > th.a-TableCell--filterable {
  padding-right: calc( var(--TableCell-paddingX) + var(--TableCell-filterBtn-width) );
  position: relative;
}

.amis-scope .a-TableCell-sortBtn {
  cursor: pointer;
  width: var(--TableCell-sortBtn-width);
  height: var(--gap-md);
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  position: absolute;
  right: calc(var(--TableCell-paddingX) - var(--TableCell-sortBtn-width) / 2);
  top: 50%;
  transform: translateY(-50%);
  color: var(--icon-color);
}

.amis-scope .a-TableCell-sortBtn:hover {
  color: var(--icon-onHover-color);
}

.amis-scope .a-TableCell-sortBtn--up > svg,
.amis-scope .a-TableCell-sortBtn--down > svg,
.amis-scope .a-TableCell-sortBtn--default > svg {
  color: inherit;
  width: 12px;
  height: 12px;
}

.amis-scope .a-TableCell-sortBtn--up,
.amis-scope .a-TableCell-sortBtn--down,
.amis-scope .a-TableCell-sortBtn--default {
  display: none;
  position: absolute;
  z-index: 2;
  font-style: normal;
}

.amis-scope .a-TableCell-sortBtn--up.is-active,
.amis-scope .a-TableCell-sortBtn--down.is-active,
.amis-scope .a-TableCell-sortBtn--default.is-active {
  display: inline-block;
}

.amis-scope .a-TableCell-sortBtn--default.is-active {
  color: var(--text--muted-color);
}

.amis-scope .a-TableCell-sortBtn--default.is-active:hover {
  color: var(--text-color);
}

.amis-scope .a-TableCell-sortBtn--up.is-active,
.amis-scope .a-TableCell-sortBtn--down.is-active {
  color: var(--TableCell-sortBtn--onActive-color);
}

.amis-scope .a-TableCell-searchBtn {
  cursor: pointer;
  position: absolute;
  right: var(--gap-xs);
  top: 50%;
  transform: translateY(-50%);
  color: var(--text--muted-color);
}

.amis-scope .a-TableCell-searchBtn svg.icon {
  width: 12px;
  height: 12px;
}

.amis-scope .a-TableCell-searchBtn:hover {
  color: var(--text-color);
}

.amis-scope .a-TableCell-searchBtn.is-active {
  color: var(--TableCell-searchBtn--onActive-color);
}

.amis-scope .a-TableCell-searchPopOver {
  border: none;
  min-width: 20rem;
  max-width: 40rem;
}

.amis-scope .a-TableCell-searchPopOver .a-Panel {
  margin: 0;
}

.amis-scope .a-TableCell-filterBtn {
  cursor: pointer;
  width: var(--TableCell-filterBtn-width);
  position: absolute;
  right: calc( var(--TableCell-paddingX) - var(--TableCell-filterBtn-width) / 2 );
  top: 50%;
  transform: translateY(-50%);
  color: var(--text--muted-color);
}

.amis-scope .a-TableCell-filterBtn svg.icon {
  width: 12px;
  height: 12px;
}

.amis-scope .a-TableCell-filterBtn:hover {
  color: var(--text-color);
}

.amis-scope .a-TableCell-filterBtn.is-active {
  color: var(--TableCell-filterBtn--onActive-color);
}

.amis-scope .a-TableCell-filterBtn .a-Remark {
  display: inline;
}

.amis-scope .a-TableCell-filterPopOver {
  border: none;
  width: 10rem;
}

.amis-scope .a-TableCell-filterPopOver .a-DropDown-menu {
  margin: 0;
  padding: 0;
  border-radius: 0;
}

.amis-scope .a-TableCell-filterPopOver .a-DropDown-menu .a-DropDown-divider {
  height: var(--TableCell-filterPopOver-dropDownItem-height);
  line-height: var(--TableCell-filterPopOver-dropDownItem-height);
  padding: var(--TableCell-filterPopOver-dropDownItem-padding);
  background: var(--white);
  margin: 0;
}

.amis-scope .a-TableCell-filterPopOver .a-DropDown-menu .a-DropDown-divider:hover {
  background: var(--light);
  color: var(--primary);
}

.amis-scope .a-TableCell-filterPopOver .a-DropDown-menu .a-DropDown-divider.is-selected {
  background: var(--light);
  color: var(--primary);
}

.amis-scope .a-TableCell-filterPopOver .a-DropDown-menu .a-DropDown-divider .a-Checkbox {
  width: 100%;
  margin: 0;
}

.amis-scope .a-Table-itemActions-wrap {
  position: absolute;
  width: 100%;
  z-index: calc(var(--Table-fixed-zIndex) + 1);
  left: 0;
  top: 0;
  min-height: 30px;
  pointer-events: none;
  box-shadow: var(--Table-onHover-boxShadow);
}

.amis-scope .a-Table-itemActions {
  pointer-events: all;
  position: absolute;
  background: linear-gradient(90deg, rgba(var(--Table-onHover-bg-rgb), 0) 0%, rgba(var(--Table-onHover-bg-rgb), 1) 20%, rgba(var(--Table-onHover-bg-rgb), 1) 100%);
  top: var(--Table-borderWidth);
  bottom: 0;
  right: 0;
  padding-left: 3.125rem;
  padding-right: var(--TableCell-paddingX);
  display: flex;
  align-items: center;
}

.amis-scope .a-Table-itemActions a {
  cursor: pointer;
  padding: var(--gap-xs) var(--gap-sm);
  color: var(--link-color);
  text-decoration: var(--link-decoration);
}

.amis-scope .a-Table-itemActions a:hover {
  color: var(--link-onHover-color);
  text-decoration: var(--link-onHover-decoration);
}

.amis-scope .a-Table-itemActions a.is-disabled {
  pointer-events: none;
  opacity: var(--Button-onDisabled-opacity);
  color: var(--text--muted-color);
}

.amis-scope .a-Table-dragTip {
  color: var(--text--loud-color);
  clear: both;
  margin-top: var(--gap-xs);
  width: 100%;
  color: var(--info);
}

.amis-scope .a-Table-footTable {
  position: relative;
  width: 100%;
  border-spacing: 0;
  border-collapse: collapse;
  margin-bottom: 0;
  background: transparent;
}

.amis-scope .a-Table-footTable > tbody > tr > th {
  width: 7.5rem;
  text-align: right;
  padding: var(--TableCell-paddingY) var(--TableCell-paddingX);
}

.amis-scope .a-Table-footTable > tbody > tr > td {
  word-break: break-all;
  padding: var(--TableCell-paddingY) var(--TableCell-paddingX);
}

.amis-scope .a-Table-footTable > tbody > tr:not(:first-child) {
  border-top: var(--Table-borderWidth) solid var(--Table-tbody-borderTopColor);
}

.amis-scope .a-Table-expandBtn {
  position: relative;
  z-index: 1;
  color: var(--Table-expandBtn-color);
  display: inline-flex;
  justify-content: center;
  align-items: center;
  width: 0.875rem;
  line-height: 1;
  height: 16px;
}

.amis-scope .a-Table-expandBtn > svg {
  display: inline-block;
  text-align: center;
  cursor: pointer;
  transition: transform ease-in-out var(--animation-duration), top ease-in-out var(--animation-duration);
  position: relative;
  transform-origin: 50% 50%;
  width: 0.625rem;
  height: 0.625rem;
  top: 0;
}

.amis-scope .a-Table-expandBtn.is-active > svg {
  transform: rotate(90deg);
}

.amis-scope .a-Table-expandBtn:hover {
  text-decoration: none;
}

.amis-scope .a-Table-dragBtn {
  margin-right: var(--gap-xs);
  display: inline-block;
  visibility: hidden;
  cursor: move;
  color: var(--icon-color);
}

.amis-scope .a-Table-dragBtn:hover {
  text-decoration: none;
  color: var(--icon-onHover-color);
}

.amis-scope .a-Table-table > tbody > tr:hover .a-Table-dragBtn,
.amis-scope .a-Table-table > tbody > tr.is-dragging .a-Table-dragBtn,
.amis-scope .a-Table-table > tbody > tr.is-drop-allowed .a-Table-dragBtn {
  visibility: visible;
}

.amis-scope .a-Table .fake-hide {
  visibility: hidden;
  position: absolute;
}

.amis-scope .a-InputTable-toolbar {
  display: flex;
  flex-direction: row;
  flex-wrap: wrap;
  justify-content: space-between;
}

.amis-scope .a-InputTable-pager {
  margin-left: auto;
}

.amis-scope .a-OperationField {
  margin: -0.1875rem;
}

.amis-scope .a-OperationField > .a-Button,
.amis-scope .a-OperationField > .a-Button--disabled-wrap > .a-Button {
  margin: 0.1875rem;
}

.amis-scope .a-OperationField > .a-Button--disabled-wrap > .a-Button--link {
  padding: 0;
}

.amis-scope .a-OperationField > .a-Button--link {
  padding: 0;
  margin-right: 0.625rem;
}

.amis-scope .a-List {
  position: relative;
}

.amis-scope .a-List-items {
  border-radius: var(--List-borderRadius);
  border: var(--List-borderWidth) solid var(--List-borderColor);
  background: var(--List-bg);
  margin-bottom: var(--gap-sm);
}

.amis-scope .a-List-toolbar {
  display: flex;
  flex-wrap: wrap;
  margin: 0 var(--List-toolbar-marginX) var(--List-toolbar-marginY);
}

.amis-scope .a-List-toolbar::before,
.amis-scope .a-List-toolbar::after {
  display: table;
  content: "";
}

.amis-scope .a-List-toolbar::after {
  clear: both;
}

.amis-scope .a-List-actions {
  display: inline-block;
}

.amis-scope .a-List-actions > * {
  margin-right: var(--Crud-toolbar-gap);
}

.amis-scope .a-List-header {
  padding: var(--List-toolbar-marginY) var(--List-toolbar-marginX);
}

.amis-scope .a-List-header > * + .a-Button,
.amis-scope .a-List-header > * + .a-ButtonGroup,
.amis-scope .a-List-header > * + .a-ButtonToolbar {
  margin-left: var(--Crud-toolbar-gap);
}

.amis-scope .a-List-header + .a-List-toolbar {
  padding-top: 0;
}

.amis-scope .a-List-heading {
  padding: var(--gap-xs) 0;
}

.amis-scope .a-List-fixedTop {
  position: absolute;
  background: var(--white);
  z-index: -1;
  opacity: 0;
  box-shadow: var(--List-fixedTop-boxShadow);
}

.amis-scope .a-List-fixedTop.in {
  position: fixed;
  opacity: 1;
  z-index: 900;
}

.amis-scope .a-List-fixedTop .a-Cards-toolbar {
  margin-bottom: 0;
}

.amis-scope .a-List-fixedTop:empty {
  display: none;
}

.amis-scope .a-List--unsaved .a-List-heading {
  background: var(--List--unsaved-heading-bg);
  color: var(--List--unsaved-heading-color);
  padding: var(--gap-xs) var(--gap-sm);
  margin-bottom: var(--gap-sm);
}

.amis-scope .a-List-dragTip {
  width: 100%;
  color: var(--info);
  clear: both;
  margin-top: var(--gap-xs);
}

.amis-scope .a-List-placeholder {
  color: var(--text--muted-color);
  text-align: center;
  min-height: var(--List-placeholder-height);
  line-height: var(--List-placeholder-height);
}

.amis-scope .a-ListGroup {
  max-width: 25rem;
  display: flex;
  flex-direction: column;
}

.amis-scope .a-ListGroup-item {
  position: relative;
  display: block;
  padding: var(--ListItem-paddingY) var(--ListItem-paddingX);
  margin-bottom: -0.0625rem;
  background: var(--white);
  border: var(--ListItem-borderWidth) solid var(--List-borderColor);
}

.amis-scope .a-ListGroup-item:first-child {
  border-top-left-radius: var(--borderRadius);
  border-top-right-radius: var(--borderRadius);
}

.amis-scope .a-ListGroup-item:last-child {
  border-bottom-left-radius: var(--borderRadius);
  border-bottom-right-radius: var(--borderRadius);
  margin-bottom: 0;
}

.amis-scope .a-ListGroup-item:hover {
  z-index: 1;
}

.amis-scope .a-ListGroup-item.is-active {
  z-index: 2;
}

.amis-scope .a-ListGroup-item.is-disabled {
  color: var(--text--muted-color);
}

.amis-scope .a-ListGroup--expanded .a-ListGroup-item {
  border-radius: var(--borderRadius);
  margin-bottom: var(--gap-sm);
}

.amis-scope .a-ListGroup--expanded .a-ListGroup-item:last-child {
  margin-bottom: 0;
}

.amis-scope .a-ListItem {
  position: relative;
  display: block;
  padding: var(--ListItem-paddingY) var(--ListItem-paddingX);
}

.amis-scope .a-ListItem::before,
.amis-scope .a-ListItem::after {
  display: table;
  content: "";
}

.amis-scope .a-ListItem::after {
  clear: both;
}

.amis-scope .a-ListItem + .a-ListItem {
  border-top: var(--ListItem-borderWidth) solid var(--ListItem-borderColor);
}

.amis-scope .a-ListItem:nth-child(even) {
  background: var(--ListItem--strip-bg);
}

.amis-scope .a-ListItem-checkBtn {
  float: left;
  margin-right: var(--gap-sm);
}

.amis-scope .a-ListItem-dragBtn {
  cursor: move;
  float: left;
  margin-right: var(--gap-sm);
}

.amis-scope .a-ListItem-actions {
  float: right;
}

.amis-scope .a-ListItem--actions-at-left .a-ListItem-actions {
  float: left;
  margin-right: var(--gap-base);
}

.amis-scope .a-ListItem-title {
  margin: 0;
  padding: 0;
  font-size: var(--fontSizeBase);
  color: var(--text--loud-color);
  font-weight: var(--fontWeightNormal);
}

.amis-scope .a-ListItem-content {
  overflow: hidden;
}

.amis-scope .a-ListItem-field {
  position: relative;
  display: flex;
  flex-wrap: nowrap;
}

.amis-scope .a-ListItem-fieldValue {
  position: relative;
  flex-basis: 0;
  flex-grow: 1;
  max-width: 100%;
  width: 0;
  overflow: hidden;
  text-overflow: ellipsis;
}

.amis-scope .a-ListItem-fieldLabel {
  width: 9.375rem;
  color: var(--text--muted-color);
}

.amis-scope .a-ListItem.is-checked {
  background: var(--ListItem-onChecked-bg);
  border-color: var(--ListItem-onChecked-borderColor);
  color: var(--ListItem-onChecked-color);
}

.amis-scope .a-ListItem.is-checked + .a-ListItem {
  border-color: var(--ListItem-onChecked-borderColor);
}

.amis-scope .a-ListItem.is-checked .a-ListItem-fieldLabel {
  color: var(--ListItem-onChecked-fieldLabel-color);
}

.amis-scope .a-ListItem.is-modified,
.amis-scope .a-ListItem.is-moved {
  background: var(--ListItem-onModified-bg);
  border-color: var(--ListItem-onModified-borderColor);
  color: var(--ListItem-onModified-color);
}

.amis-scope .a-ListItem.is-modified + .a-ListItem,
.amis-scope .a-ListItem.is-moved + .a-ListItem {
  border-color: var(--ListItem-onModified-borderColor);
}

.amis-scope .a-ListItem.is-modified .a-ListItem-fieldLabel,
.amis-scope .a-ListItem.is-moved .a-ListItem-fieldLabel {
  color: var(--ListItem-onModified-fieldLabel-color);
}

.amis-scope .a-ListItem.is-dragging {
  opacity: var(--ListItem-onDragging-opacity);
}

.amis-scope .a-Cards-toolbar {
  margin: 0 var(--Cards-toolbar-marginX) var(--Cards-toolbar-marginY);
}

.amis-scope .a-Cards-toolbar::before,
.amis-scope .a-Cards-toolbar::after {
  display: table;
  content: "";
}

.amis-scope .a-Cards-toolbar::after {
  clear: both;
}

.amis-scope .a-Cards-actions {
  display: inline-block;
}

.amis-scope .a-Cards-actions > * {
  margin-right: var(--Crud-toolbar-gap);
}

.amis-scope .a-Cards-heading {
  padding: var(--gap-xs) 0;
}

.amis-scope .a-Cards-header {
  padding: var(--Cards-toolbar-marginY) var(--Cards-toolbar-marginX);
}

.amis-scope .a-Cards-header > * + .a-Button,
.amis-scope .a-Cards-header > * + .a-ButtonGroup,
.amis-scope .a-Cards-header > * + .a-ButtonToolbar {
  margin-left: var(--Crud-toolbar-gap);
}

.amis-scope .a-Cards-header + .a-Cards-toolbar {
  padding-top: 0;
}

.amis-scope .a-Cards-fixedTop {
  position: absolute;
  background: var(--white);
  z-index: -1;
  opacity: 0;
  box-shadow: var(--Cards-fixedTop-boxShadow);
  padding: var(--gap-sm);
}

.amis-scope .a-Cards-fixedTop.in {
  position: fixed;
  opacity: 1;
  z-index: 900;
}

.amis-scope .a-Cards-fixedTop .a-Cards-toolbar {
  margin-bottom: 0;
}

.amis-scope .a-Cards-fixedTop:empty {
  display: none;
}

.amis-scope .a-Cards--unsaved .a-Cards-heading {
  background: var(--Cards--unsaved-heading-bg);
  color: var(--Cards--unsaved-heading-color);
  padding: var(--gap-xs) var(--gap-sm);
  margin-bottom: var(--gap-sm);
}

.amis-scope .a-Cards-dragTip {
  width: 100%;
  color: var(--info);
  clear: both;
  margin-top: var(--gap-xs);
}

.amis-scope .a-Cards-placeholder {
  background: var(--white);
  color: var(--text--muted-color);
  text-align: center;
  height: var(--Cards-placeholder-height);
  line-height: var(--Cards-placeholder-height);
  border: var(--Card-borderWidth) solid var(--Card-borderColor);
  border-radius: var(--Card-borderRadius);
}

.amis-scope .a-Cards-body > div {
  display: flex;
}

.amis-scope .a-Cards--masonry {
  display: block;
  column-gap: 0;
  column-fill: initial;
}

.amis-scope .a-Cards--masonry:after {
  content: none;
}

.amis-scope .a-Cards--masonry > div {
  width: 100%;
  float: none;
  break-inside: avoid;
  max-width: unset;
  display: inline-block;
  flex: unset;
}

@media (min-width: 576px) {
  .amis-scope .a-Cards--masonrySm1 {
    column-count: 12;
  }

  .amis-scope .a-Cards--masonrySm2 {
    column-count: 6;
  }

  .amis-scope .a-Cards--masonrySm3 {
    column-count: 4;
  }

  .amis-scope .a-Cards--masonrySm4 {
    column-count: 3;
  }

  .amis-scope .a-Cards--masonrySm6 {
    column-count: 2;
  }

  .amis-scope .a-Cards--masonrySm12 {
    column-count: 1;
  }

  .amis-scope .a-Cards-toolbar {
    display: flex;
    flex-wrap: wrap;
  }
}

@media (min-width: 768px) {
  .amis-scope .a-Cards--masonryMd1 {
    column-count: 12;
  }

  .amis-scope .a-Cards--masonryMd2 {
    column-count: 6;
  }

  .amis-scope .a-Cards--masonryMd3 {
    column-count: 4;
  }

  .amis-scope .a-Cards--masonryMd4 {
    column-count: 3;
  }

  .amis-scope .a-Cards--masonryMd6 {
    column-count: 2;
  }

  .amis-scope .a-Cards--masonryMd12 {
    column-count: 1;
  }
}

@media (min-width: 992px) {
  .amis-scope .a-Cards--masonryLg1 {
    column-count: 12;
  }

  .amis-scope .a-Cards--masonryLg2 {
    column-count: 6;
  }

  .amis-scope .a-Cards--masonryLg3 {
    column-count: 4;
  }

  .amis-scope .a-Cards--masonryLg4 {
    column-count: 3;
  }

  .amis-scope .a-Cards--masonryLg6 {
    column-count: 2;
  }

  .amis-scope .a-Cards--masonryLg12 {
    column-count: 1;
  }
}

.amis-scope .a-Card {
  background: var(--Card-bg);
  border: var(--Card-borderWidth) solid var(--Card-borderColor);
  border-radius: var(--Card-borderRadius);
  margin-bottom: var(--gap-base);
  position: relative;
  display: flex;
  flex-direction: column;
  width: 100%;
}

.amis-scope .a-Card--link {
  cursor: pointer;
}

.amis-scope .a-Card-title {
  color: var(--text--loud-color);
  font-size: var(--fontSizeMd);
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
}

.amis-scope .a-Card-subTitle {
  max-height: calc(var(--fontSizeBase) * var(--lineHeightBase) * 2);
  overflow: hidden;
  text-overflow: ellipsis;
  color: var(--text--muted-color);
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
  display: -webkit-box;
}

.amis-scope .a-Card-title + .a-Card-subTitle {
  margin-top: var(--gap-xs);
}

.amis-scope .a-Card-checkBtn {
  position: absolute;
  top: 0;
  right: 0;
  margin: var(--gap-sm);
  z-index: 1;
}

.amis-scope .a-Card-checkBtn .a-Checkbox {
  margin-right: 0;
}

.amis-scope .a-Card-dragBtn {
  cursor: pointer;
  float: right;
  margin: var(--gap-sm);
}

.amis-scope .a-Card-heading {
  overflow: hidden;
  padding: var(--gap-sm) var(--gap-base);
  flex: 1 0 auto;
}

.amis-scope .a-Card-avtar {
  float: left;
  margin-right: var(--gap-base);
  max-width: 12.5rem;
}

.amis-scope .a-Card-avtar img {
  max-width: 100%;
}

.amis-scope .a-Card-avtarText {
  background: var(--primary);
  color: var(--white);
  width: 50px;
  height: 50px;
  line-height: 50px;
  text-align: center;
  vertical-align: middle;
  border-radius: 500px;
  float: left;
  margin-right: var(--gap-base);
  font-size: var(--fontSizeXl);
  text-transform: uppercase();
}

.amis-scope .a-Card-meta {
  display: block;
  height: 100%;
  overflow: hidden;
  position: relative;
  margin-right: var(--gap-md);
}

.amis-scope .a-Card-highlight {
  background: var(--success);
  width: 0.5rem;
  height: 0.5rem;
  border-radius: 100%;
  display: inline-block;
  position: absolute;
  top: var(--gap-xs);
  right: 0.125rem;
}

.amis-scope .a-Card-body {
  padding: var(--gap-base);
  flex: 1 0 auto;
}

.amis-scope .a-Card-heading + .a-Card-body {
  padding-top: var(--gap-xs);
}

.amis-scope .a-Card-field {
  position: relative;
  display: flex;
  flex-wrap: nowrap;
}

.amis-scope .a-Card-fieldValue {
  position: relative;
  flex-basis: 0;
  flex-grow: 1;
  width: 0;
  text-overflow: ellipsis;
  overflow: hidden;
}

.amis-scope .a-Card-fieldLabel {
  width: 3.75rem;
  color: var(--text--muted-color);
}

.amis-scope .a-Card-actions {
  border-top: var(--Card-borderWidth) solid var(--Card-actions-borderColor);
  display: flex;
  flex-direction: row;
  width: 100%;
  table-layout: fixed;
}

.amis-scope .a-Card-actions > a {
  background: transparent;
  flex-grow: 1;
  border-color: var(--Card-actions-borderColor);
  border-style: solid;
  border-width: 0 var(--Card-borderWidth) 0 0;
  color: var(--text-color);
  text-align: center;
  line-height: 2.5rem;
  font-size: var(--Card-actions-fontSize);
}

.amis-scope .a-Card-actions > a:not(.is-disabled) {
  cursor: pointer;
}

.amis-scope .a-Card-actions > a:not(.is-disabled):hover {
  background: var(--Card-actions-onHover-bg);
  color: var(--Card-actions-onHover-color);
  text-decoration: none;
}

.amis-scope .a-Card-actions > a:last-child {
  border: none;
}

.amis-scope .a-Card-actions > a.is-disabled {
  color: var(--text--muted-color);
}

.amis-scope .a-Card-actions > a.is-disabled:hover {
  text-decoration: none;
}

.amis-scope .a-Card.is-checked {
  background: var(--Card-onChecked-bg);
  border-color: var(--Card-onChecked-borderColor);
  color: var(--Card-onChecked-color);
}

.amis-scope .a-Card.is-checked .a-Card-actions,
.amis-scope .a-Card.is-checked .a-Card-actions > a {
  border-color: var(--Card-onChecked-borderColor);
  color: var(--Card-onChecked-color);
}

.amis-scope .a-Card.is-checked .a-Card-fieldLabel {
  color: var(--Card-onChecked-fieldLabel-color);
}

.amis-scope .a-Card.is-checked .a-Card-actions > a:hover {
  background: var(--Card-actions-onChecked-onHover-bg);
  color: var(--Card-actions-onChecked-onHover-color);
}

.amis-scope .a-Card.is-modified,
.amis-scope .a-Card.is-moved {
  background: var(--Card-onModified-bg);
  border-color: var(--Card-onModified-borderColor);
  color: var(--Card-onModified-color);
}

.amis-scope .a-Card.is-modified .a-Card-actions,
.amis-scope .a-Card.is-modified .a-Card-actions > a,
.amis-scope .a-Card.is-moved .a-Card-actions,
.amis-scope .a-Card.is-moved .a-Card-actions > a {
  border-color: var(--Card-onModified-borderColor);
  color: var(--Card-onModified-color);
}

.amis-scope .a-Card.is-modified .a-Card-fieldLabel,
.amis-scope .a-Card.is-moved .a-Card-fieldLabel {
  color: var(--Card-onModified-fieldLabel-color);
}

.amis-scope .a-Card.is-modified .a-Card-actions > a:hover,
.amis-scope .a-Card.is-moved .a-Card-actions > a:hover {
  background: var(--Card-onModified-onHover-bg);
  color: var(--Card-onModified-onHover-color);
}

.amis-scope .is-dragging > .a-Card {
  opacity: var(--Card-onDragging-opacity);
}

.amis-scope .a-Field-quickEditBtn {
  color: var(--QuickEdit-iconColor);
  margin-left: var(--gap-xs);
  display: inline-block;
  vertical-align: text-top;
  cursor: pointer;
  opacity: 0.6;
}

.amis-scope .a-Field-quickEditBtn:hover {
  color: var(--QuickEdit-onHover-iconColor);
  opacity: 1;
}

.amis-scope .a-Field--quickEditable {
  outline: none;
  position: relative;
}

.amis-scope .a-Field--quickEditable:focus {
  position: relative;
}

.amis-scope .a-Field--quickEditable:focus:after {
  content: "";
  left: 0;
  top: 0;
  right: 0;
  bottom: 0;
  position: absolute;
  pointer-events: none;
  z-index: 1;
  border: var(--QuickEdit-onFocus-borderWidth) dashed var(--QuickEdit-onFocus-borderColor);
}

.amis-scope .a-Field--quickEditable:hover .a-Field-quickEditBtn {
  visibility: visible;
}

.amis-scope .a-QuickEdit-popover {
  min-width: 20rem;
  max-width: 40rem;
}

.amis-scope .a-QuickEdit-popover .a-Panel {
  margin-bottom: 0;
  border: none;
}

.amis-scope .a-Field-popOverBtn {
  color: var(--PopOverAble-iconColor);
  margin-left: var(--gap-xs);
  display: inline-block;
  cursor: pointer;
  opacity: 0.6;
  vertical-align: middle;
}

.amis-scope .a-Field-popOverBtn:hover {
  color: var(--PopOverAble-onHover-iconColor);
  opacity: 1;
}

.amis-scope .a-Field--popOverAble {
  outline: none;
  position: relative;
}

.amis-scope .a-PopOverAble-popover {
  min-width: 20rem;
  max-width: 40rem;
}

.amis-scope .a-PopOverAble-popover .a-Panel {
  margin-bottom: 0;
  border: none;
}

.amis-scope .a-PopOverAble--fixed {
  position: fixed;
}

.amis-scope .a-PopOverAble--fixed > * {
  margin-bottom: 0;
}

.amis-scope .a-PopOverAble--fixed-center {
  top: 50%;
  left: 50%;
  transform: translate(-50%, -50%);
}

.amis-scope .a-PopOverAble--fixed-left-top {
  top: 0;
  left: 0;
}

.amis-scope .a-PopOverAble--fixed-right-top {
  top: 0;
  right: 0;
}

.amis-scope .a-PopOverAble--fixed-left-bottom {
  bottom: 0;
  left: 0;
}

.amis-scope .a-PopOverAble--fixed-right-bottom {
  bottom: 0;
  right: 0;
}

.amis-scope .a-Progress {
  height: 10px;
  background: #ebebeb;
  overflow: hidden;
}

.amis-scope .a-Progress-bar {
  float: left;
  width: 0;
  height: 100%;
  font-size: 12px;
  line-height: 10px;
  color: #fff;
  text-align: center;
  background: var(--primary);
  transition: width var(--animation-duration) ease;
}

.amis-scope .a-Progress-bar--stripe {
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-size: 2rem 2rem;
}

.amis-scope .a-Progress-bar--animate {
  animation: progress-bar-stripes 1s linear infinite;
}

@keyframes progress-bar-stripes {
  from {
    background-position: 2rem 0;
  }

  to {
    background-position: 0 0;
  }
}

.amis-scope .a-Property > table {
  width: 100%;
  border-collapse: collapse;
}

.amis-scope .a-Property > table > thead > tr > th {
  padding: var(--gap-sm);
  background: var(--Property-title-bg);
  border: 1px solid var(--borderColor);
}

.amis-scope .a-Property > table > tbody > tr {
  background: var(--background);
}

.amis-scope .a-Property > table > tbody > tr > td,
.amis-scope .a-Property > table > tbody > tr > th {
  border: 1px solid var(--borderColor);
  padding: var(--gap-sm);
}

.amis-scope .a-Property > table > tbody > tr > td .a-Form-item:last-child,
.amis-scope .a-Property > table > tbody > tr > th .a-Form-item:last-child {
  margin-bottom: 0;
}

.amis-scope .a-Property > table > tbody > tr > th {
  background: var(--Property-label-bg);
}

.amis-scope .a-Property--simple > table > thead > tr > th {
  background: transparent;
  border: none;
}

.amis-scope .a-Property--simple > table > tbody > tr {
  background: transparent;
}

.amis-scope .a-Property--simple > table > tbody > tr > td,
.amis-scope .a-Property--simple > table > tbody > tr > th {
  border: none;
}

.amis-scope .a-Field-copyBtn {
  color: var(--Copyable-iconColor);
  margin-left: var(--gap-xs);
  display: inline-block;
  cursor: pointer;
}

.amis-scope .a-Field-copyBtn:hover {
  color: var(--Copyable-onHover-iconColor);
}

.amis-scope .a-Divider {
  margin: var(--gap-base) calc(var(--gap-base) * -1);
  border-bottom: var(--borderWidth) var(--Divider-borderStyle) var(--borderColor);
  height: 0.125rem;
  font-size: 0;
}

.amis-scope .a-Divider--solid {
  border-bottom-style: solid;
}

.amis-scope .a-Pagination {
  display: inline-block;
  padding: 0;
  margin: 0 0 -0.625rem;
  border-radius: 0.25rem;
}

.amis-scope .a-Pagination > li {
  display: inline;
}

.amis-scope .a-Pagination > li > a,
.amis-scope .a-Pagination > li > span {
  user-select: none;
  cursor: pointer;
  position: relative;
  float: left;
  text-decoration: none;
  min-width: var(--Pagination-minWidth);
  height: var(--Pagination-height);
  border: 0;
  line-height: var(--Pagination-height);
  padding: var(--Pagination-padding);
  text-align: center;
  color: #666666;
  border-radius: 0;
  margin-left: 0;
  font-size: var(--Pagination-fontSize);
}

.amis-scope .a-Pagination > li > a:hover,
.amis-scope .a-Pagination > li > span:hover,
.amis-scope .a-Pagination > li > a:focus,
.amis-scope .a-Pagination > li > span:focus {
  background: transparent;
  color: var(--primary);
}

.amis-scope .a-Pagination > li.is-disabled > span,
.amis-scope .a-Pagination > li.is-disabled > a {
  cursor: not-allowed;
}

.amis-scope .a-Pagination > li.is-disabled > a,
.amis-scope .a-Pagination > li.is-disabled > span,
.amis-scope .a-Pagination > li.is-disabled > a:hover,
.amis-scope .a-Pagination > li.is-disabled > span:hover,
.amis-scope .a-Pagination > li.is-disabled > a:focus,
.amis-scope .a-Pagination > li.is-disabled > span:focus {
  color: #cccccc;
}

.amis-scope .a-Pagination > li.is-active > a,
.amis-scope .a-Pagination > li.is-active > span,
.amis-scope .a-Pagination > li.is-active > a:hover,
.amis-scope .a-Pagination > li.is-active > span:hover,
.amis-scope .a-Pagination > li.is-active > a:focus,
.amis-scope .a-Pagination > li.is-active > span:focus {
  background: var(--Pagination-onActive-backgroundColor);
  color: var(--Pagination-onActive-color);
  border: var(--Pagination-onActive-border);
  border-radius: var(--borderRadius);
}

.amis-scope .a-Pagination-prev > span {
  cursor: pointer;
}

.amis-scope .a-Pagination-ellipsis > a > span {
  position: relative;
  top: -0.25rem;
}

.amis-scope .a-Pagination-next > span {
  cursor: pointer;
}

.amis-scope .a-Pagination-inputGroup {
  display: inline-flex;
  flex-wrap: nowrap;
  align-items: center;
}

.amis-scope .a-Pagination-inputGroup input {
  width: 3.125rem;
  height: var(--Pagination-height);
  border: var(--borderWidth) solid var(--borderColor);
  border-radius: var(--borderRadius);
  padding: var(--gap-xs) 0.625rem;
  margin: 0 0.625rem;
  text-align: center;
}

.amis-scope .a-Pagination-inputGroup input:focus,
.amis-scope .a-Pagination-inputGroup input:hover {
  outline: none;
  border: var(--borderWidth) solid var(--primary);
}

.amis-scope .a-PaginationWrapper-pager {
  text-align: right;
}

.amis-scope .a-PaginationWrapper-pager:first-child {
  margin-bottom: var(--gap-sm);
}

.amis-scope .a-Wrapper--xs {
  padding: var(--gap-xs);
}

.amis-scope .a-Wrapper--sm {
  padding: var(--gap-sm);
}

.amis-scope .a-Wrapper--md {
  padding: var(--gap-md);
}

.amis-scope .a-Wrapper--lg {
  padding: var(--gap-lg);
}

.amis-scope .a-Wrapper--xl {
  padding: var(--gap-xl);
}

.amis-scope .a-StatusField {
  vertical-align: middle;
  white-space: nowrap;
  display: inline-flex;
  flex-wrap: nowrap;
  flex-direction: row;
  align-items: center;
}

.amis-scope .a-StatusField-label {
  font-size: var(--fontSizeSm);
  margin-left: var(--gap-sm);
}

@keyframes animation-rolling_red {
  0% {
    transform: translateX(0);
  }

  50% {
    transform: translateX(20px);
  }

  100% {
    transform: translateX(0);
  }
}

@keyframes animation-rolling_blue {
  0% {
    transform: translateX(0);
  }

  50% {
    transform: translateX(-20px);
  }

  100% {
    transform: translateX(0);
  }
}

.amis-scope .a-StatusField svg.a-Status-icon {
  width: var(--Satus-icon-width);
  height: var(--Satus-icon-height);
  top: 0;
}

.amis-scope .a-StatusField .a-Status-icon.rolling {
  width: 30px;
  height: 10px;
  display: inline-block;
  vertical-align: middle;
  position: relative;
}

.amis-scope .a-StatusField .a-Status-icon.rolling::before {
  content: "";
  display: inline-block;
  border: 5px solid var(--danger);
  border-radius: 500px;
  position: absolute;
  top: 0;
  left: 0;
  animation: animation-rolling_red 2s;
  animation-iteration-count: infinite;
}

.amis-scope .a-StatusField .a-Status-icon.rolling::after {
  content: "";
  display: inline-block;
  border: 5px solid var(--primary);
  border-radius: 500px;
  position: absolute;
  top: 0;
  left: 20px;
  animation: animation-rolling_blue 2s;
  animation-iteration-count: infinite;
}

.amis-scope .a-StatusField .a-Status-icon.icon-warning {
  color: var(--warning);
}

.amis-scope .a-Status-icon.rolling + .a-StatusField-label {
  color: var(--warning);
}

.amis-scope .a-Status-icon.icon-success + .a-StatusField-label {
  color: var(--success);
}

.amis-scope .a-Status-icon.icon-fail + .a-StatusField-label {
  color: var(--danger);
}

.amis-scope .a-Status-icon.icon-warning + .a-StatusField-label {
  color: var(--warning);
}

.amis-scope .a-Carousel {
  min-width: var(--Carousel-minWidth);
  height: var(--Carousel-height);
  position: relative;
  display: block;
  background: var(--Carousel-bg);
}

.amis-scope .a-Carousel.a-Carousel--light .a-Carousel-dot {
  background: var(--Carousel--light-control);
}

.amis-scope .a-Carousel.a-Carousel--light svg {
  fill: var(--Carousel--light-control);
}

.amis-scope .a-Carousel.a-Carousel--light .a-Carousel-item .title,
.amis-scope .a-Carousel.a-Carousel--light .a-Carousel-item .description {
  color: var(--Carousel--light-control);
}

.amis-scope .a-Carousel.a-Carousel--dark .a-Carousel-dot {
  background: var(--Carousel--dark-control);
}

.amis-scope .a-Carousel.a-Carousel--dark svg {
  fill: var(--Carousel--dark-control);
}

.amis-scope .a-Carousel.a-Carousel--dark .a-Carousel-item .title,
.amis-scope .a-Carousel.a-Carousel--dark .a-Carousel-item .description {
  color: var(--Carousel--dark-control);
}

.amis-scope .a-Carousel-container {
  position: relative;
  width: 100%;
  height: 100%;
  overflow: hidden;
}

.amis-scope .a-Carousel-container .a-Carousel-item {
  width: 100%;
  height: 100%;
  position: absolute;
  left: 0;
  top: 0;
  transition-duration: var(--Carousel-transitionDuration);
  transition-timing-function: ease-out;
  transition-property: transform, opacity;
}

.amis-scope .a-Carousel-container .a-Carousel-item.fade {
  opacity: 0;
}

.amis-scope .a-Carousel-container .a-Carousel-item.fade.in {
  opacity: 1;
}

.amis-scope .a-Carousel-container .a-Carousel-item.slide {
  transform: translateX(100%);
}

.amis-scope .a-Carousel-container .a-Carousel-item.slide.in {
  transform: translateX(0);
}

.amis-scope .a-Carousel-container .a-Carousel-item.slide.out {
  transform: translateX(-100%);
}

.amis-scope .a-Carousel-container .a-Carousel-item.slideRight {
  transform: translateX(-100%);
}

.amis-scope .a-Carousel-container .a-Carousel-item.slideRight.in {
  transform: translateX(0);
}

.amis-scope .a-Carousel-container .a-Carousel-item.slideRight.out {
  transform: translateX(100%);
}

.amis-scope .a-Carousel-container .a-Carousel-item .title {
  position: absolute;
  bottom: var(--Carousel-imageTitle-bottom);
  text-align: center;
  width: 100%;
  opacity: 0.8;
}

.amis-scope .a-Carousel-container .a-Carousel-item .description {
  position: absolute;
  bottom: var(--Carousel-imageDescription-bottom);
  text-align: center;
  width: 100%;
  opacity: 0.8;
}

.amis-scope .a-Carousel-container .a-Carousel-item .image {
  width: 100%;
  height: 100%;
  background-size: cover;
}

.amis-scope .a-Carousel-image {
  width: 100%;
  height: 100%;
}

.amis-scope .a-Carousel-image .a-Image-origin {
  height: 100%;
  width: 100%;
}

.amis-scope .a-Carousel-dotsControl {
  position: absolute;
  bottom: 0px;
  width: 100%;
  z-index: 100;
  text-align: center;
}

.amis-scope .a-Carousel-dotsControl .a-Carousel-dot {
  display: inline-block;
  height: var(--Carousel-dot-width);
  width: var(--Carousel-dot-height);
  border-radius: var(--Carousel-dot-borderRadius);
  margin: var(--Carousel-dot-margin);
  transition-duration: var(--Carousel-transitionDuration);
  opacity: 0.3;
}

.amis-scope .a-Carousel-dotsControl .a-Carousel-dot.is-active {
  opacity: 1;
}

.amis-scope .a-Carousel .a-Carousel-leftArrow {
  width: 10%;
  min-width: var(--Carousel-arrowControl-width);
  height: 100%;
  cursor: pointer;
  top: 0;
  bottom: 0;
  position: absolute;
  transition-duration: var(--Carousel-transitionDuration);
  display: none;
  left: 0;
}

.amis-scope .a-Carousel .a-Carousel-leftArrow svg {
  position: absolute;
  top: 50%;
  left: 50%;
  right: 50%;
  transform: translate(-50%, -50%);
  width: var(--Carousel-svg-width);
  height: var(--Carousel-svg-height);
}

.amis-scope .a-Carousel .a-Carousel-rightArrow {
  width: 10%;
  min-width: var(--Carousel-arrowControl-width);
  height: 100%;
  cursor: pointer;
  top: 0;
  bottom: 0;
  position: absolute;
  transition-duration: var(--Carousel-transitionDuration);
  display: none;
  right: 0;
}

.amis-scope .a-Carousel .a-Carousel-rightArrow svg {
  position: absolute;
  top: 50%;
  left: 50%;
  right: 50%;
  transform: translate(-50%, -50%);
  width: var(--Carousel-svg-width);
  height: var(--Carousel-svg-height);
}

.amis-scope .a-Carousel:hover .a-Carousel-leftArrow {
  display: block;
}

.amis-scope .a-Carousel:hover .a-Carousel-rightArrow {
  display: block;
}

.amis-scope .a-Carousel-arrowsControl {
  position: absolute;
  width: 100%;
  height: 100%;
  top: 0;
  left: 0;
  z-index: 100;
  text-align: center;
}

@keyframes disappear {
  to {
    opacity: 0;
  }
}

@keyframes appear {
  from {
    opacity: 0;
  }
}

.amis-scope .a-ImageGallery {
  display: flex;
  flex-direction: column;
  background: transparent;
  border: none;
  border-radius: 0;
  max-width: 1010px !important;
}

.amis-scope .a-ImageGallery-close {
  position: absolute;
  right: 0;
  top: 0;
  color: rgba(255, 255, 255, 0.8);
  cursor: pointer;
}

.amis-scope .a-ImageGallery-close:hover {
  color: #fff;
}

.amis-scope .a-ImageGallery-close > svg {
  width: 1rem;
  height: 1rem;
}

.amis-scope .a-ImageGallery-title {
  height: 1.875rem;
  vertical-align: top;
  line-height: 1.875rem;
  font-size: 0.75rem;
  color: var(--white);
  text-align: center;
}

.amis-scope .a-ImageGallery-main {
  background: #000;
  flex-basis: 0;
  flex-grow: 1;
  height: 0;
  position: relative;
  display: flex;
  justify-content: center;
  align-items: center;
  user-select: none;
}

.amis-scope .a-ImageGallery-main > img {
  display: block;
  max-width: 100%;
  max-height: 100%;
}

.amis-scope .a-ImageGallery-prevBtn,
.amis-scope .a-ImageGallery-nextBtn {
  position: absolute;
  top: 50%;
  transform: translateY(-50%);
  cursor: pointer;
  color: #999;
  text-shadow: rgba(0, 0, 0, 0.3) 0px 0px 4px;
  animation-name: disappear;
  animation-delay: var(--animation-duration);
  animation-duration: var(--animation-duration);
  animation-fill-mode: both;
}

.amis-scope .a-ImageGallery-prevBtn > svg,
.amis-scope .a-ImageGallery-nextBtn > svg {
  width: 3rem;
  height: 3rem;
}

.amis-scope .a-ImageGallery-prevBtn:hover,
.amis-scope .a-ImageGallery-nextBtn:hover {
  color: #fff;
  text-shadow: rgba(0, 0, 0, 0.5) 0px 0px 4px;
}

.amis-scope .a-ImageGallery-prevBtn.is-disabled,
.amis-scope .a-ImageGallery-nextBtn.is-disabled {
  pointer-events: none;
}

.amis-scope .a-ImageGallery-main:hover .a-ImageGallery-prevBtn,
.amis-scope .a-ImageGallery-main:hover .a-ImageGallery-nextBtn {
  animation-name: appear;
  animation-delay: 0s;
  animation-duration: var(--animation-duration);
}

.amis-scope .a-ImageGallery-prevBtn {
  left: var(--gap-md);
}

.amis-scope .a-ImageGallery-nextBtn {
  right: var(--gap-md);
}

.amis-scope .a-ImageGallery-footer {
  height: 4.625rem;
  background: #222;
  display: flex;
  flex-direction: row;
  user-select: none;
}

.amis-scope .a-ImageGallery-prevList,
.amis-scope .a-ImageGallery-nextList {
  width: var(--gap-md);
  display: flex;
  align-items: center;
  justify-content: center;
  cursor: pointer;
  background: rgba(0, 0, 0, 0.3);
  color: #fff;
}

.amis-scope .a-ImageGallery-prevList.is-disabled,
.amis-scope .a-ImageGallery-nextList.is-disabled {
  background: rgba(0, 0, 0, 0.3);
  color: rgba(255, 255, 255, 0.1);
  pointer-events: none;
}

.amis-scope .a-ImageGallery-prevList:hover,
.amis-scope .a-ImageGallery-nextList:hover {
  background: black;
  color: #fff;
}

.amis-scope .a-ImageGallery-itemsWrap {
  flex-grow: 1;
  flex-basis: 0;
  width: 0;
  overflow: hidden;
  align-items: center;
  justify-content: center;
  display: flex;
}

.amis-scope .a-ImageGallery-items {
  display: inline-block;
  white-space: nowrap;
}

.amis-scope .a-ImageGallery-item {
  margin: 10px 5px;
  width: 54px;
  height: 54px;
  display: inline-flex;
  position: relative;
  border: 1px solid #666;
  justify-content: center;
  align-items: center;
  cursor: pointer;
}

.amis-scope .a-ImageGallery-item > img {
  display: block;
  max-width: 100%;
  max-height: 100%;
}

@supports (object-fit: cover) {
  .amis-scope .a-ImageGallery-item > img {
    width: 100%;
    height: 100%;
    object-fit: cover;
  }
}

.amis-scope .a-ImageGallery-item:after {
  position: absolute;
  content: "";
  display: block;
  background: rgba(0, 0, 0, 0.5);
  z-index: 1;
  left: 0;
  top: 0;
  width: 100%;
  height: 100%;
}

.amis-scope .a-ImageGallery-item:hover {
  border: 1px solid #e5e5e5;
}

.amis-scope .a-ImageGallery-item:hover:after {
  display: none;
}

.amis-scope .a-ImageGallery-item.is-active {
  border: 1px solid #108cee;
}

.amis-scope .a-ImageGallery-item.is-active:after {
  display: none;
}

.amis-scope .a-Images {
  display: flex;
  flex-wrap: wrap;
  margin: calc(var(--gap-xs) * -1);
}

.amis-scope .a-Images-item {
  display: flex;
  margin: var(--gap-xs);
}

.amis-scope .a-Image {
  border: var(--borderWidth) solid var(--borderColor);
}

.amis-scope .a-Image--thumb {
  display: inline-block;
  padding: var(--gap-xs);
}

.amis-scope .a-Image-thumbWrap {
  position: relative;
}

.amis-scope .a-Image-image {
  display: block;
}

.amis-scope .a-Image--original .a-Image-image {
  max-width: 100%;
  max-height: 100%;
  width: auto;
  margin: auto;
}

.amis-scope .a-Image-thumb {
  width: 6.875rem;
  height: 6.875rem;
  position: relative;
  overflow: hidden;
}

.amis-scope .a-Image-thumb > img {
  position: absolute;
  left: 50%;
  top: 50%;
  max-height: 100%;
  width: auto;
  transform: translate(-50%, -50%);
}

.amis-scope .a-Image-info {
  padding: 5px 10px;
}

.amis-scope .a-Image--thumb .a-Image-info {
  width: 6.875rem;
  padding: 0;
}

.amis-scope .a-Image-thumb--4-3 {
  height: 5.15625rem;
}

.amis-scope .a-Image-thumb--16-9 {
  height: 3.8671875rem;
}

.amis-scope .a-Image-thumb--fixed-size {
  min-width: 6.875rem;
  min-height: 6.875rem;
  width: 100%;
  padding: 0;
  height: 100%;
}

.amis-scope .a-Image-thumb--fixed-size .a-Image-thumb {
  width: 100%;
  height: 100%;
}

.amis-scope .a-Image-thumb--fixed-size .a-Image-thumb > img {
  width: auto;
  height: 100%;
}

.amis-scope .a-Image-thumb--w-full > img {
  width: 100%;
  height: auto;
}

@supports (object-fit: contain) {
  .amis-scope .a-Image-thumb--contain > img {
    position: static;
    width: 100% !important;
    height: 100% !important;
    transform: translate(0, 0);
    top: 0;
    left: 0;
    object-fit: contain;
  }

  .amis-scope .a-Image-origin--contain > img {
    width: 100% !important;
    height: 100% !important;
    object-fit: contain;
  }
}

@supports (object-fit: cover) {
  .amis-scope .a-Image-thumb--cover > img {
    position: static;
    width: 100% !important;
    height: 100% !important;
    transform: translate(0, 0);
    top: 0;
    left: 0;
    object-fit: cover;
  }

  .amis-scope .a-Image-origin--cover > img {
    width: 100% !important;
    height: 100% !important;
    object-fit: cover;
  }
}

.amis-scope .a-Image-caption {
  font-size: var(--fontSizeSm);
}

.amis-scope .a-Image-title {
  font-size: var(--fontSizeBase);
  color: var(--text--loud-color);
}

.amis-scope .a-Image-overlay {
  background: rgba(0, 0, 0, 0.6);
  position: absolute;
  width: 100%;
  height: 100%;
  display: none;
  top: 0;
  left: 0;
  justify-content: center;
  align-items: center;
  align-content: center;
  flex-wrap: wrap;
  color: #fff;
}

.amis-scope .a-Image-overlay > div {
  width: 100%;
  text-align: center;
  margin-bottom: 5px;
}

.amis-scope .a-Image-overlay > a {
  cursor: pointer;
  color: #fff;
  display: inline-block;
  padding: 0 5px;
  line-height: 1;
  font-size: 1rem;
}

.amis-scope .a-Image-thumbWrap:hover .a-Image-overlay {
  display: flex;
}

.amis-scope .a-ImageField--thumb {
  display: inline-block;
  position: relative;
}

.amis-scope .a-ImageField--thumb::before,
.amis-scope .a-ImageField--thumb::after {
  display: table;
  content: "";
}

.amis-scope .a-ImageField--thumb::after {
  clear: both;
}

.amis-scope .a-ImagesField {
  position: relative;
}

.amis-scope .a-ImagesField::before,
.amis-scope .a-ImagesField::after {
  display: table;
  content: "";
}

.amis-scope .a-ImagesField::after {
  clear: both;
}

.amis-scope .a-InputBox {
  display: flex;
  background: var(--Form-input-bg);
  border: var(--Form-input-borderWidth) solid var(--Form-input-borderColor);
  border-radius: var(--Form-input-borderRadius);
  line-height: var(--Form-input-lineHeight);
  padding: var(--Form-input-paddingY) var(--Form-input-paddingX);
  font-size: var(--Form-input-fontSize);
  flex-wrap: wrap;
  justify-content: flex-start;
}

.amis-scope .a-InputBox input {
  flex-basis: 5rem;
  flex-grow: 1;
  outline: none;
  background: transparent;
  border: none;
  color: var(--Form-input-color);
  width: 100%;
  height: calc(var(--Form-input-lineHeight) * var(--Form-input-fontSize));
}

.amis-scope .a-InputBox input::placeholder {
  color: var(--Form-input-placeholderColor);
  user-select: none;
}

.amis-scope .a-InputBox:hover {
  border-color: var(--Form-input-onFocused-borderColor);
}

.amis-scope .a-InputBox--inline {
  display: inline-flex;
}

.amis-scope .a-InputBox > input[readonly] {
  cursor: inherit;
}

.amis-scope .a-InputBox.is-error {
  border-color: var(--Form-input-onError-borderColor);
  background: var(--Form-input-onError-bg);
}

.amis-scope .a-InputBox.is-focused {
  border-color: var(--Form-input-onFocused-borderColor);
  box-shadow: var(--Form-input-boxShadow);
  background: var(--Form-input-onFocused-bg);
}

.amis-scope .a-InputBox.is-clickable:hover {
  border-color: var(--Form-input-onFocused-borderColor);
  box-shadow: var(--Form-input-boxShadow);
  cursor: pointer;
}

.amis-scope .a-InputBox.is-error.is-focused {
  border-color: var(--Form-input-onError-borderColor);
}

.amis-scope .a-InputBox.is-disabled {
  color: var(--text--muted-color);
  background: var(--Form-input-onDisabled-bg);
  border-color: var(--Form-input-onDisabled-borderColor);
}

.amis-scope .a-InputBox-clear {
  padding: 0.1875rem;
  cursor: pointer;
  display: flex;
  align-items: center;
  justify-content: center;
  margin-left: auto;
}

.amis-scope .a-InputBox-clear svg {
  fill: var(--Form-input-iconColor);
  top: 0;
  width: 0.625rem;
  height: 0.625rem;
}

.amis-scope .a-InputBox-clear:hover svg {
  fill: var(--Form-input-onHover-iconColor);
}

.amis-scope .a-InputBox > svg {
  display: inline-block;
  width: 14px;
  color: var(--icon-color);
}

.amis-scope .a-InputBox > a {
  cursor: pointer;
}

.amis-scope .a-ResultBox {
  display: flex;
  background: var(--Form-input-bg);
  border: var(--Form-input-borderWidth) solid var(--Form-input-borderColor);
  border-radius: var(--Form-input-borderRadius);
  line-height: var(--Form-input-lineHeight);
  padding: var(--Form-input-paddingY) var(--Form-input-paddingX);
  font-size: var(--Form-input-fontSize);
  flex-wrap: wrap;
  justify-content: flex-start;
  flex-wrap: wrap;
  padding: 0 0.1875rem;
  min-height: var(--Form-input-height);
  align-items: center;
}

.amis-scope .a-ResultBox input {
  flex-basis: 5rem;
  flex-grow: 1;
  outline: none;
  background: transparent;
  border: none;
  color: var(--Form-input-color);
  width: 100%;
  height: calc(var(--Form-input-lineHeight) * var(--Form-input-fontSize));
}

.amis-scope .a-ResultBox input::placeholder {
  color: var(--Form-input-placeholderColor);
  user-select: none;
}

.amis-scope .a-ResultBox:hover {
  border-color: var(--Form-input-onFocused-borderColor);
}

.amis-scope .a-ResultBox.is-error {
  border-color: var(--Form-input-onError-borderColor);
  background: var(--Form-input-onError-bg);
}

.amis-scope .a-ResultBox.is-focused,
.amis-scope .a-ResultBox.is-active,
.amis-scope .a-ResultBox:focus {
  outline: none;
  border-color: var(--Form-input-onFocused-borderColor);
  box-shadow: var(--Form-input-boxShadow);
  background: var(--Form-input-onFocused-bg);
}

.amis-scope .a-ResultBox.is-clickable:not(.is-disabled) {
  cursor: pointer;
}

.amis-scope .a-ResultBox.is-clickable:not(.is-disabled):hover {
  border-color: var(--Form-input-onFocused-borderColor);
  box-shadow: var(--Form-input-boxShadow);
  background: var(--Form-input-onFocused-bg);
}

.amis-scope .a-ResultBox.is-error.is-focused {
  border-color: var(--Form-input-onError-borderColor);
}

.amis-scope .a-ResultBox.is-disabled {
  color: var(--text--muted-color);
  background: var(--Form-input-onDisabled-bg);
  border-color: var(--Form-input-onDisabled-borderColor);
  pointer-events: none;
}

.amis-scope .a-ResultBox-singleValue {
  padding: 0 calc(var(--Form-input-paddingX) - 0.1875rem);
  display: inline-block;
  max-width: 100%;
  overflow: hidden;
  text-overflow: ellipsis;
}

.amis-scope .a-ResultBox-clear {
  padding: 0.1875rem;
  cursor: pointer;
  display: flex;
  align-items: center;
  justify-content: center;
  margin-left: auto;
  width: 1.625rem;
  height: 1.625rem;
  margin: 0 -0.125rem;
  margin-left: auto;
}

.amis-scope .a-ResultBox-clear svg {
  fill: var(--Form-input-iconColor);
  top: 0;
  width: 0.625rem;
  height: 0.625rem;
}

.amis-scope .a-ResultBox-clear:hover svg {
  fill: var(--Form-input-onHover-iconColor);
}

.amis-scope .a-ResultBox-clear:hover {
  background: var(--ResultBox-value-bg);
}

.amis-scope .a-ResultBox-clear > svg {
  width: 0.75rem;
  height: 0.75rem;
}

.amis-scope .a-ResultBox > svg {
  display: inline-block;
  width: 0.875rem;
  color: var(--icon-color);
}

.amis-scope .a-ResultBox > a {
  cursor: pointer;
}

.amis-scope .a-ResultBox-value {
  background: var(--ResultBox-value-bg);
  color: var(--ResultBox-value-color);
  font-size: var(--Form-input-fontSize);
  padding: 0 var(--gap-xs);
  min-height: 1.5rem;
  flex-wrap: nowrap;
  display: inline-flex;
  align-items: center;
  margin: 2px 3px;
  user-select: none;
}

.amis-scope .a-ResultBox-value > a {
  cursor: pointer;
  margin-left: var(--gap-xs);
  color: var(--ResultBox-icon-color);
}

.amis-scope .a-ResultBox-value > a:hover {
  color: var(--ResultBox-icon--onHover-color);
}

.amis-scope .a-ResultBox-value > a > svg {
  width: 0.625rem;
  height: 0.625rem;
}

.amis-scope .a-ResultBox-value:hover {
  background: var(--ResultBox-value--onHover-bg);
}

.amis-scope .a-ResultBox-value.is-disabled {
  pointer-events: none;
  color: var(--ResultBox-value--onDisabled-color);
}

.amis-scope .a-ResultBox-value.is-disabled > a {
  color: var(--ResultBox-icon--onDisabled-color);
}

.amis-scope .a-ResultBox-placeholder {
  color: var(--Form-input-placeholderColor);
  user-select: none;
  margin-left: 8px;
}

.amis-scope .a-ResultBox > input {
  padding-left: 8px;
  min-height: 24px;
}

.amis-scope .a-SearchBox {
  display: inline-flex;
  flex-direction: row;
  line-height: var(--Form-input-lineHeight);
  font-size: var(--Form-input-fontSize);
  flex-wrap: nowrap;
  align-items: center;
  justify-content: flex-end;
  height: 30px;
  width: 30px;
  padding: 0 8px;
  transition: all var(--animation-duration) ease-in-out;
  border: var(--Form-input-borderWidth) solid transparent;
  border-radius: var(--Form-input-borderRadius);
  height: 30px;
}

.amis-scope .a-SearchBox:hover {
  background: var(--Form-input-onHover-bg);
}

.amis-scope .a-SearchBox.is-active {
  background: var(--Form-input-bg);
  border: var(--Form-input-borderWidth) solid var(--Form-input-borderColor);
  width: 150px;
}

.amis-scope .a-SearchBox.is-active > input {
  flex-grow: 1;
}

.amis-scope .a-SearchBox-activeBtn,
.amis-scope .a-SearchBox-searchBtn,
.amis-scope .a-SearchBox-cancelBtn {
  cursor: pointer;
  color: var(--icon-color);
}

.amis-scope .a-SearchBox-activeBtn:hover,
.amis-scope .a-SearchBox-searchBtn:hover,
.amis-scope .a-SearchBox-cancelBtn:hover {
  color: var(--icon-onHover-color);
}

.amis-scope .a-SearchBox.is-disabled .a-SearchBox-activeBtn,
.amis-scope .a-SearchBox.is-disabled .a-SearchBox-searchBtn,
.amis-scope .a-SearchBox.is-disabled .a-SearchBox-cancelBtn {
  color: var(--icon-onDisabled-color);
  pointer-events: none;
}

.amis-scope .a-SearchBox > input {
  outline: none;
  border: none;
  background: transparent;
  color: var(--Form-input-color);
  width: 0;
  height: calc(var(--Form-input-lineHeight) * var(--Form-input-fontSize));
}

.amis-scope .a-SearchBox > input::placeholder {
  color: var(--Form-input-placeholderColor);
  user-select: none;
}

.amis-scope .a-ListMenu {
  background: var(--ListMenu-item-bg);
  min-width: 12.5rem;
  border: var(--ListMenu-borderWidth) solid var(--ListMenu-bordrColor);
  border-radius: var(--ListMenu-borderRadius);
}

.amis-scope .a-ListMenu-groupLabel {
  font-size: var(--fontSizeXs);
  color: var(--text--muted-color);
  padding: calc( ( var(--ListMenu-item-height) - var(--Form-input-lineHeight) * var(--Form-input-fontSize) - var(--gap-sm) ) / 2 ) 0 0 calc(var(--Form-select-paddingX) - var(--gap-xs));
}

.amis-scope .a-ListMenu-group:not(:first-child) > .a-ListMenu-groupLabel {
  border-top: 0.0625rem solid var(--ListMenu-divider-color);
}

.amis-scope .a-ListMenu-item {
  display: flex;
  min-height: var(--ListMenu-item-height);
  color: var(--ListMenu-item-color);
  line-height: var(--Form-input-lineHeight);
  font-size: var(--Form-input-fontSize);
  cursor: pointer;
  padding: calc( ( var(--ListMenu-item-height) - var(--Form-input-lineHeight) * var(--Form-input-fontSize) ) / 2 ) var(--Form-select-paddingX);
}

.amis-scope .a-ListMenu-item.is-active {
  color: var(--ListMenu-item--onActive-color);
  background: var(--ListMenu-item--onActive-bg);
}

.amis-scope .a-ListMenu-item.is-highlight {
  color: var(--ListMenu-item--onHover-color);
  background: var(--ListMenu-item--onHover-bg);
}

.amis-scope .a-ListMenu-item.is-disabled {
  color: var(--ListMenu-item--onDisabled-color);
  background: var(--ListMenu-item--onDisabled-bg);
}

.amis-scope .a-ListMenu-placeholder {
  display: block;
  min-height: var(--ListMenu-item-height);
  color: var(--text--muted-color);
  line-height: var(--Form-input-lineHeight);
  font-size: var(--Form-input-fontSize);
  cursor: pointer;
  padding: calc( ( var(--ListMenu-item-height) - var(--Form-input-lineHeight) * var(--Form-input-fontSize) ) / 2 ) var(--Form-select-paddingX);
}

.amis-scope .a-PopOver > .a-ListMenu {
  border-color: var(--listMenu--onActive-borderColor);
}

.amis-scope .a-Log {
  background: var(--Log-bg);
  color: var(--Log-color);
  padding: var(--Log-padding);
  overflow-y: auto;
  font-family: var(--fontFamilyMonospace);
}

.amis-scope .a-Log-line {
  padding: var(--Log-line-padding);
  white-space: pre-wrap;
  word-wrap: break-word;
}

.amis-scope .a-Log-line code {
  color: inherit;
  background: inherit;
}

.amis-scope .a-Log-line:hover {
  background: var(--Log-line--onHover-bg);
}

.amis-scope .a-Log .ansi-bold {
  font-weight: 700;
}

.amis-scope .a-Log .ansi-italic {
  font-style: italic;
}

.amis-scope .a-Log .ansi-underline {
  text-decoration: underline;
}

.amis-scope .a-Log .ansi-black-fg,
.amis-scope .a-Log .ansi-bright-black-fg {
  color: #4e4e4e;
}

.amis-scope .a-Log .ansi-red-fg,
.amis-scope .a-Log .ansi-bright-red-fg {
  color: #ff6c60;
}

.amis-scope .a-Log .ansi-green-fg,
.amis-scope .a-Log .ansi-bright-green-fg {
  color: #0a0;
}

.amis-scope .a-Log .ansi-yellow-fg,
.amis-scope .a-Log .ansi-bright-yellow-fg {
  color: #ffffb6;
}

.amis-scope .a-Log .ansi-blue-fg,
.amis-scope .a-Log .ansi-bright-blue-fg {
  color: #96cbfe;
}

.amis-scope .a-Log .ansi-magenta-fg,
.amis-scope .a-Log .ansi-bright-magenta-fg {
  color: #ff73fd;
}

.amis-scope .a-Log .ansi-cyan-fg,
.amis-scope .a-Log .ansi-bright-cyan-fg {
  color: #5ff;
}

.amis-scope .a-Log .ansi-white-fg,
.amis-scope .a-Log .ansi-bright-white-fg {
  color: #eee;
}

.amis-scope .a-Log .ansi-grey-fg,
.amis-scope .a-Log .ansi-bright-grey-fg {
  color: #969696;
}

.amis-scope .a-Log .ansi-black-bg {
  background-color: #4e4e4e;
}

.amis-scope .a-Log .ansi-red-bg {
  background-color: #ff6c60;
}

.amis-scope .a-Log .ansi-green-bg {
  background-color: #0a0;
}

.amis-scope .a-Log .ansi-yellow-bg {
  background-color: #ffffb6;
}

.amis-scope .a-Log .ansi-blue-bg {
  background-color: #96cbfe;
}

.amis-scope .a-Log .ansi-magenta-bg {
  background-color: #ff73fd;
}

.amis-scope .a-Log .ansi-cyan-bg {
  background-color: #0aa;
}

.amis-scope .a-Log .ansi-white-bg {
  background-color: #eee;
}

.amis-scope .a-JsonField-nodeValue {
  white-space: normal;
  word-break: break-all;
  overflow-wrap: break-word;
}

.amis-scope .a-Icon {
  height: var(--fontSizeBase);
  vertical-align: middle;
}

.amis-scope .a-Steps {
  display: flex;
  list-style: none;
  padding: 0;
}

.amis-scope .a-Steps .a-StepsItem {
  flex: 1;
  overflow: hidden;
  padding: 0 1.25rem;
  height: auto;
  line-height: 2rem;
}

.amis-scope .a-Steps .a-StepsItem-containerIcon {
  vertical-align: top;
  display: inline-block;
  padding-right: 0.625rem;
}

.amis-scope .a-Steps .a-StepsItem-containerIcon .a-StepsItem-icon {
  display: inline-block;
  width: 1.875rem;
  height: 1.875rem;
  line-height: 1.75rem;
  border-radius: 50%;
  font-size: var(--Steps-icon-fontsize);
  text-align: center;
}

.amis-scope .a-Steps .a-StepsItem-containerWrapper {
  display: inline-block;
  position: relative;
}

.amis-scope .a-Steps .a-StepsItem-containerWrapper .a-StepsItem-body .a-StepsItem-title {
  font-size: var(--Steps-title-fontsize);
  color: var(--Steps-title-color);
  padding-right: 1.25rem;
  position: relative;
  display: inline-block;
}

.amis-scope .a-Steps .a-StepsItem-containerWrapper .a-StepsItem-body .a-StepsItem-title > span {
  display: inline-block;
}

.amis-scope .a-Steps .a-StepsItem-containerWrapper .a-StepsItem-body .a-StepsItem-title:after {
  content: "";
  position: absolute;
  right: 0;
  top: 1rem;
  height: 1px;
  left: 100%;
  width: 9999px;
  padding-right: 10px;
  background-color: var(--Steps-line-bg);
}

.amis-scope .a-Steps .a-StepsItem-containerWrapper .a-StepsItem-body .a-StepsItem-title.is-success:after {
  background-color: var(--Steps-line-success-bg);
}

.amis-scope .a-Steps .a-StepsItem-containerWrapper .a-StepsItem-body .a-StepsItem-subTitle {
  padding-left: 0.625rem;
  font-size: var(--Steps-sub-title-fontsize);
  color: var(--Steps-sub-title-color);
}

.amis-scope .a-Steps .a-StepsItem-containerWrapper .a-StepsItem-body .a-StepsItem-description {
  max-width: 8.75rem;
  white-space: nowrap;
}

.amis-scope .a-Steps .a-StepsItem:last-child {
  flex: none;
}

.amis-scope .a-Steps .a-StepsItem:last-child .a-StepsItem-title:after {
  display: none;
}

.amis-scope .a-Steps--vertical {
  flex-direction: column;
}

.amis-scope .a-Steps--vertical .a-StepsItem {
  padding: 0.3125rem 0;
  min-height: 75px;
}

.amis-scope .a-Steps--vertical .a-StepsItem-containerIcon > .a-StepsItem-icon {
  position: relative;
}

.amis-scope .a-Steps--vertical .a-StepsItem-containerIcon > .a-StepsItem-icon:after {
  content: "";
  position: absolute;
  right: 0;
  top: 2.1875rem;
  height: 9999px;
  left: 0.875rem;
  width: 1px;
  background-color: var(--Steps-line-bg);
}

.amis-scope .a-Steps--vertical .a-StepsItem-containerWrapper > .a-StepsItem-body > .a-StepsItem-title:after {
  display: none;
}

.amis-scope .a-Steps--vertical .a-StepsItem:last-child {
  flex: none;
}

.amis-scope .a-Steps--vertical .a-StepsItem:last-child .a-StepsItem-icon:after {
  display: none;
}

.amis-scope .a-Steps .a-StepsItem.is-wait .a-StepsItem-icon {
  background-color: var(--white);
  color: var(--Steps-bg);
  border: 1px solid var(--Steps-bg);
}

.amis-scope .a-Steps .a-StepsItem.is-error .a-StepsItem-icon {
  background-color: var(--Steps-status-error);
  color: var(--white);
  border: 1px solid var(--Steps-status-error);
}

.amis-scope .a-Steps .a-StepsItem.is-error .a-StepsItem-title,
.amis-scope .a-Steps .a-StepsItem.is-error .a-StepsItem-subTitle,
.amis-scope .a-Steps .a-StepsItem.is-error .a-StepsItem-description {
  color: var(--Steps-status-error);
}

.amis-scope .a-Steps .a-StepsItem.is-finish .a-StepsItem-icon,
.amis-scope .a-Steps .a-StepsItem.is-process .a-StepsItem-icon {
  background-color: var(--Steps-status-success);
  color: var(--white);
  border: 1px solid var(--Steps-status-success);
}

.amis-scope fieldset.a-Collapse--lg,
.amis-scope fieldset.a-Collapse--md,
.amis-scope fieldset.a-Collapse--base,
.amis-scope fieldset.a-Collapse--sm,
.amis-scope fieldset.a-Collapse--xs {
  position: relative;
}

.amis-scope fieldset.a-Collapse--lg:after,
.amis-scope fieldset.a-Collapse--md:after,
.amis-scope fieldset.a-Collapse--base:after,
.amis-scope fieldset.a-Collapse--sm:after,
.amis-scope fieldset.a-Collapse--xs:after {
  content: "";
  pointer-events: none;
  border: 1px solid var(--borderColor);
  position: absolute;
  z-index: 0;
  top: 11px;
  left: 0;
  bottom: 0;
  right: 0;
}

.amis-scope fieldset.a-Collapse--lg > legend,
.amis-scope fieldset.a-Collapse--md > legend,
.amis-scope fieldset.a-Collapse--base > legend,
.amis-scope fieldset.a-Collapse--sm > legend,
.amis-scope fieldset.a-Collapse--xs > legend {
  position: absolute;
  top: 0;
  left: 0;
  display: inline-block;
  border: 0;
  width: auto;
  z-index: 1;
  background: var(--Fieldset-legend-bgColor);
  border-left: 0 !important;
}

.amis-scope fieldset.a-Collapse--lg .collapse,
.amis-scope fieldset.a-Collapse--md .collapse,
.amis-scope fieldset.a-Collapse--base .collapse,
.amis-scope fieldset.a-Collapse--sm .collapse,
.amis-scope fieldset.a-Collapse--xs .collapse {
  position: relative;
}

.amis-scope fieldset.a-Collapse > legend {
  font-weight: var(--fontWeightNormal);
  padding: var(--gap-xs) 0;
  font-size: var(--fontSizeMd);
  color: var(--text--loud-color);
  border-left: var(--primary) 0.25rem solid;
  line-height: 1.2;
  margin: var(--gap-base) 0;
  padding: 0 0 0 14px;
  cursor: pointer;
  border-bottom: 0;
  display: flex;
  flex-direction: row;
  justify-content: space-between;
  width: 100%;
}

.amis-scope fieldset.a-Collapse--xs {
  padding: 20px 5px 5px 5px;
}

.amis-scope fieldset.a-Collapse--xs > legend {
  left: 5px;
  font-size: var(--fontSizeXs);
  padding: 0 3px;
  margin: 0 0 0 -3px;
}

.amis-scope fieldset.a-Collapse--xs:after {
  top: 6px;
}

.amis-scope fieldset.a-Collapse--sm {
  padding: 25px 10px 10px 10px;
}

.amis-scope fieldset.a-Collapse--sm > legend {
  left: 10px;
  font-size: var(--fontSizeSm);
  padding: 0 5px;
  margin: 0 0 0 -5px;
}

.amis-scope fieldset.a-Collapse--sm:after {
  top: 6px;
}

.amis-scope fieldset.a-Collapse--base {
  padding: 30px var(--gap-md) var(--gap-md) var(--gap-md);
}

.amis-scope fieldset.a-Collapse--base > legend {
  left: var(--gap-md);
  font-size: var(--fontSizeBase);
  padding: 0 8px;
  margin: 0 0 0 -8px;
}

.amis-scope fieldset.a-Collapse--base:after {
  top: 7px;
}

.amis-scope fieldset.a-Collapse--md {
  padding: 30px 20px 20px 20px;
}

.amis-scope fieldset.a-Collapse--md > legend {
  left: 20px;
  font-size: var(--fontSizeMd);
  padding: 0 10px;
  margin: 0 0 0 -10px;
}

.amis-scope fieldset.a-Collapse--md:after {
  top: 7px;
}

.amis-scope fieldset.a-Collapse--lg {
  padding: 40px 30px 30px 30px;
}

.amis-scope fieldset.a-Collapse--lg > legend {
  left: 30px;
  font-size: var(--fontSizeLg);
  padding: 0 var(--gap-md);
  margin: 0 0 0 calc(var(--gap-md) * -1);
}

.amis-scope fieldset.a-Collapse--lg:after {
  top: 9px;
}

.amis-scope .a-Form-groupColumn {
  margin-bottom: var(--gap-sm);
}

@media (min-width: 768px) {
  .amis-scope .a-Form-group {
    margin-bottom: var(--Form-item-gap);
  }

  .amis-scope .a-Form-value > .a-Form-group {
    margin-bottom: var(--Form-input-marginBottom);
  }

  .amis-scope .a-Form-group--hor {
    display: flex;
    flex-wrap: wrap;
    margin-left: calc(var(--Form-group-gutterWidth) / -2);
    margin-right: calc(var(--Form-group-gutterWidth) / -2);
    align-items: flex-start;
  }

  .amis-scope .a-Form-group--hor.v-middle {
    align-items: center;
  }

  .amis-scope .a-Form-group--hor.v-bottom {
    align-items: flex-end;
  }

  .amis-scope .a-Form-group--hor > * {
    padding-left: calc(var(--Form-group-gutterWidth) / 2);
    padding-right: calc(var(--Form-group-gutterWidth) / 2);
  }

  .amis-scope .a-Form-group--hor > .a-Form-item--inline {
    margin-right: 0;
  }

  .amis-scope .a-Form-group--hor > .a-Form-item,
  .amis-scope .a-Form-group--hor > div > .a-Form-item {
    margin-bottom: 0;
  }

  .amis-scope .a-Form-group--hor .a-Form-input > .a-Form-group {
    margin-bottom: 0;
  }

  .amis-scope .a-Form-group--lg {
    margin-left: calc(var(--Form-group--lg-gutterWidth) / -2);
    margin-right: calc(var(--Form-group--lg-gutterWidth) / -2);
  }

  .amis-scope .a-Form-group--lg > * {
    padding-left: calc(var(--Form-group--lg-gutterWidth) / 2);
    padding-left: calc(var(--Form-group--lg-gutterWidth) / 2);
  }

  .amis-scope .a-Form-group--md {
    margin-left: calc(var(--Form-group--md-gutterWidth) / -2);
    margin-right: calc(var(--Form-group--md-gutterWidth) / -2);
  }

  .amis-scope .a-Form-group--md > * {
    padding-left: calc(var(--Form-group--md-gutterWidth) / 2);
    padding-right: calc(var(--Form-group--md-gutterWidth) / 2);
  }

  .amis-scope .a-Form-group--sm {
    margin-left: calc(var(--Form-group--sm-gutterWidth) / -2);
    margin-right: calc(var(--Form-group--sm-gutterWidth) / -2);
  }

  .amis-scope .a-Form-group--sm > * {
    padding-left: calc(var(--Form-group--sm-gutterWidth) / 2);
    padding-right: calc(var(--Form-group--sm-gutterWidth) / 2);
  }

  .amis-scope .a-Form-group--xs {
    margin-left: calc(var(--Form-group--xs-gutterWidth) / -2);
    margin-right: calc(var(--Form-group--xs-gutterWidth) / -2);
  }

  .amis-scope .a-Form-group--xs > * {
    padding-left: calc(var(--Form-group--xs-gutterWidth) / 2);
    padding-right: calc(var(--Form-group--xs-gutterWidth) / 2);
  }

  .amis-scope .a-Form-groupColumn {
    flex-basis: 0;
    flex-grow: 1;
    width: 100%;
    max-width: 100%;
    margin-bottom: 0;
  }

  .amis-scope .a-Form-groupColumn--1 {
    flex: 0 0 8.3333333333%;
    max-width: 8.3333333333%;
    min-height: 1px;
  }

  .amis-scope .a-Form-groupColumn--2 {
    flex: 0 0 16.6666666667%;
    max-width: 16.6666666667%;
    min-height: 1px;
  }

  .amis-scope .a-Form-groupColumn--3 {
    flex: 0 0 25%;
    max-width: 25%;
    min-height: 1px;
  }

  .amis-scope .a-Form-groupColumn--4 {
    flex: 0 0 33.3333333333%;
    max-width: 33.3333333333%;
    min-height: 1px;
  }

  .amis-scope .a-Form-groupColumn--5 {
    flex: 0 0 41.6666666667%;
    max-width: 41.6666666667%;
    min-height: 1px;
  }

  .amis-scope .a-Form-groupColumn--6 {
    flex: 0 0 50%;
    max-width: 50%;
    min-height: 1px;
  }

  .amis-scope .a-Form-groupColumn--7 {
    flex: 0 0 58.3333333333%;
    max-width: 58.3333333333%;
    min-height: 1px;
  }

  .amis-scope .a-Form-groupColumn--8 {
    flex: 0 0 66.6666666667%;
    max-width: 66.6666666667%;
    min-height: 1px;
  }

  .amis-scope .a-Form-groupColumn--9 {
    flex: 0 0 75%;
    max-width: 75%;
    min-height: 1px;
  }

  .amis-scope .a-Form-groupColumn--10 {
    flex: 0 0 83.3333333333%;
    max-width: 83.3333333333%;
    min-height: 1px;
  }

  .amis-scope .a-Form-groupColumn--11 {
    flex: 0 0 91.6666666667%;
    max-width: 91.6666666667%;
    min-height: 1px;
  }

  .amis-scope .a-Form-groupColumn--12 {
    flex: 0 0 100%;
    max-width: 100%;
    min-height: 1px;
  }

  .amis-scope .a-Form-groupColumn--auto {
    flex: 0 0 auto;
    width: auto;
    max-width: 100%;
    min-height: 1px;
  }
}

.amis-scope .a-InputGroup {
  display: inline-flex;
  flex-wrap: nowrap;
}

.amis-scope .a-InputGroup.a-Form-control--sizeXs,
.amis-scope .a-InputGroup.a-Form-control--sizeSm,
.amis-scope .a-InputGroup.a-Form-control--sizeMd,
.amis-scope .a-InputGroup.a-Form-control--sizeLg {
  display: inline-flex;
}

.amis-scope .a-InputGroup-addOn,
.amis-scope .a-InputGroup .a-Form-control {
  display: inline-block;
  white-space: nowrap;
}

.amis-scope .a-InputGroup-addOn {
  background: var(--InputGroup-addOn-bg);
  border: var(--InputGroup-addOn-borderWidth) solid var(--InputGroup-addOn-borderColor);
  line-height: calc( var(--InputGroup-height) - var(--InputGroup-paddingY) * 2 - var(--InputGroup-addOn-borderWidth) * 2 );
  height: var(--InputGroup-height);
  box-sizing: border-box;
  padding: var(--InputGroup-paddingY) var(--InputGroup-paddingX);
}

.amis-scope .a-InputGroup-addOn:not(:last-child) {
  border-right: 0;
}

.amis-scope .a-InputGroup-addOn:first-child {
  border-top-left-radius: var(--InputGroup-addOn-borderRadius);
  border-bottom-left-radius: var(--InputGroup-addOn-borderRadius);
}

.amis-scope .a-InputGroup-addOn:last-child {
  border-top-right-radius: var(--InputGroup-addOn-borderRadius);
  border-bottom-right-radius: var(--InputGroup-addOn-borderRadius);
}

.amis-scope .a-InputGroup-btn .a-Button {
  border-radius: 0;
  border: var(--InputGroup-button-borderWidth) solid var(--InputGroup-button-borderColor);
}

.amis-scope .a-InputGroup-btn:not(:last-child) .a-Button {
  border-right: 0;
}

.amis-scope .a-InputGroup-btn:first-child .a-Button {
  border-top-left-radius: var(--InputGroup-button-borderRadius);
  border-bottom-left-radius: var(--InputGroup-button-borderRadius);
}

.amis-scope .a-InputGroup-btn:last-child .a-Button {
  border-top-right-radius: var(--InputGroup-button-borderRadius);
  border-bottom-right-radius: var(--InputGroup-button-borderRadius);
}

.amis-scope .a-InputGroup .a-TextControl-input {
  flex-basis: 0;
  flex-grow: 1;
  display: inline-flex;
}

.amis-scope .a-InputGroup .a-TextControl-input:not(:first-child) {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}

.amis-scope .a-InputGroup .a-TextControl-input:not(:last-child) {
  border-right-width: 0;
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}

.amis-scope .a-InputGroup .a-SelectControl .a-Select {
  background: var(--InputGroup-select-bg);
  border: var(--InputGroup-select-borderWidth) solid var(--InputGroup-select-borderColor);
  color: var(--InputGroup-select-color);
}

.amis-scope .a-InputGroup .a-SelectControl:not(:last-child) .a-Select {
  border-right: 0;
}

.amis-scope .a-InputGroup .a-SelectControl:first-child .a-Select {
  border-top-left-radius: var(--InputGroup-select-borderRadius);
  border-bottom-left-radius: var(--InputGroup-select-borderRadius);
}

.amis-scope .a-InputGroup .a-SelectControl:last-child .a-Select {
  border-top-right-radius: var(--InputGroup-select-borderRadius);
  border-bottom-right-radius: var(--InputGroup-select-borderRadius);
}

.amis-scope .a-InputGroup .a-SelectControl:not(:first-child) .a-Select {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}

.amis-scope .a-InputGroup .a-SelectControl:not(:last-child) .a-Select {
  border-right-width: 0;
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}

.amis-scope .a-InputGroup .a-Select-arrow {
  color: var(--InputGroup-select-arrowColor);
}

.amis-scope .a-InputGroup.is-focused .a-InputGroup-addOn,
.amis-scope .a-InputGroup.is-focused .a-TextControl-input,
.amis-scope .a-InputGroup.is-focused .a-Select,
.amis-scope .a-InputGroup.is-focused .a-InputGroup-btn .a-Button {
  border-color: var(--InputGroup-addOn-onFocused-borderColor);
}

.amis-scope .a-InputGroup.is-focused .a-Select {
  background: var(--InputGroup-select-onFocused-bg);
}

.amis-scope .a-InputGroup.is-focused .a-Select {
  color: var(--InputGroup-select-onFocused-color);
}

.amis-scope .a-InputGroup.is-focused .a-Select-arrow {
  color: var(--InputGroup-select-onFocused-arrowColor);
}

.amis-scope .a-InputGroup.is-focused .a-InputGroup-addOn {
  color: var(--primary);
}

.amis-scope .a-InputGroup:not(.is-inline) {
  display: flex;
}

.amis-scope .a-TextControl {
  position: relative;
  max-width: 100%;
}

.amis-scope .a-TextControl.is-inline {
  display: inline-block;
  width: var(--Form-control-widthBase);
}

.amis-scope .a-TextControl-input {
  display: flex;
  background: var(--Form-input-bg);
  border: var(--Form-input-borderWidth) solid var(--Form-input-borderColor);
  border-radius: var(--Form-input-borderRadius);
  line-height: var(--Form-input-lineHeight);
  padding: var(--Form-input-paddingY) var(--Form-input-paddingX);
  font-size: var(--Form-input-fontSize);
  flex-wrap: wrap;
  justify-content: flex-start;
}

.amis-scope .a-TextControl-input input {
  flex-basis: 5rem;
  flex-grow: 1;
  outline: none;
  background: transparent;
  border: none;
  color: var(--Form-input-color);
  width: 100%;
  height: calc(var(--Form-input-lineHeight) * var(--Form-input-fontSize));
}

.amis-scope .a-TextControl-input input::placeholder {
  color: var(--Form-input-placeholderColor);
  user-select: none;
}

.amis-scope .a-TextControl-input:hover {
  border-color: var(--Form-input-onFocused-borderColor);
}

.amis-scope .a-TextControl-input--borderHalf {
  border-left-color: transparent !important;
  border-right-color: transparent !important;
  border-top-color: transparent !important;
}

.amis-scope .a-TextControl-input--borderNone {
  border-color: transparent !important;
}

.amis-scope .a-TextControl.is-error > .a-TextControl-input {
  border-color: var(--Form-input-onError-borderColor);
  background: var(--Form-input-onError-bg);
  transition: all var(--animation-duration);
}

.amis-scope .a-TextControl.is-focused > .a-TextControl-input {
  border-color: var(--Form-input-onFocused-borderColor);
  box-shadow: var(--Form-input-boxShadow);
  background: var(--Form-input-onFocused-bg);
  transition: all var(--animation-duration);
}

.amis-scope .a-TextControl.is-error.is-focused > .a-TextControl-input {
  border-color: var(--Form-input-onError-borderColor);
}

.amis-scope .a-TextControl.is-disabled > .a-TextControl-input {
  color: var(--text--muted-color);
  background: var(--Form-input-onDisabled-bg);
  border-color: var(--Form-input-onDisabled-borderColor);
  transition: all var(--animation-duration);
}

.amis-scope .a-TextControl-spinner {
  line-height: calc( var(--Form-input-lineHeight) * var(--Form-input-fontSize) );
}

.amis-scope .a-TextControl-clear {
  padding: 0.1875rem;
  cursor: pointer;
  display: flex;
  align-items: center;
  justify-content: center;
  margin-left: auto;
}

.amis-scope .a-TextControl-clear svg {
  fill: var(--Form-input-iconColor);
  top: 0;
  width: 0.625rem;
  height: 0.625rem;
}

.amis-scope .a-TextControl-clear:hover svg {
  fill: var(--Form-input-onHover-iconColor);
}

@media (min-width: 576px) {
  .amis-scope .a-TextControl.a-Form-control--sizeXs > .a-TextControl-input,
  .amis-scope .a-TextControl.a-Form-control--sizeSm > .a-TextControl-input,
  .amis-scope .a-TextControl.a-Form-control--sizeMd > .a-TextControl-input,
  .amis-scope .a-TextControl.a-Form-control--sizeLg > .a-TextControl-input {
    min-width: 100%;
    display: inline-flex;
  }
}

.amis-scope .a-TextControl-placeholder {
  color: var(--Form-input-placeholderColor);
  user-select: none;
  position: absolute;
  left: var(--Form-input-paddingX);
  top: var(--Form-input-paddingY);
  margin-top: calc(2 * var(--Form-input-borderWidth));
  line-height: var(--Form-input-lineHeight);
}

.amis-scope .a-TextControl--withAddOn {
  display: flex;
  flex-wrap: nowrap;
}

@media (min-width: 576px) {
  .amis-scope .a-TextControl--withAddOn.a-Form-control--sizeXs,
  .amis-scope .a-TextControl--withAddOn.a-Form-control--sizeSm,
  .amis-scope .a-TextControl--withAddOn.a-Form-control--sizeMd,
  .amis-scope .a-TextControl--withAddOn.a-Form-control--sizeLg {
    display: inline-flex;
  }

  .amis-scope .a-TextControl--withAddOn.a-Form-control--sizeXs > .a-TextControl-input,
  .amis-scope .a-TextControl--withAddOn.a-Form-control--sizeSm > .a-TextControl-input,
  .amis-scope .a-TextControl--withAddOn.a-Form-control--sizeMd > .a-TextControl-input,
  .amis-scope .a-TextControl--withAddOn.a-Form-control--sizeLg > .a-TextControl-input {
    min-width: unset;
  }
}

.amis-scope .a-TextControl--withAddOn > .a-TextControl-input {
  flex-basis: 1;
  flex-grow: 1;
  min-width: 0;
  border-radius: 0;
}

.amis-scope .a-TextControl--withAddOn > .a-TextControl-input:first-child {
  border-top-left-radius: var(--Form-input-borderRadius);
  border-bottom-left-radius: var(--Form-input-borderRadius);
}

.amis-scope .a-TextControl--withAddOn > .a-TextControl-input:last-child {
  border-top-right-radius: var(--Form-input-borderRadius);
  border-bottom-right-radius: var(--Form-input-borderRadius);
}

.amis-scope .a-TextControl-addOn {
  display: flex;
  align-items: center;
  justify-content: center;
  padding-left: 0.625rem;
  padding-right: 0.625rem;
  background: var(--Form-input-addOnBg);
  color: var(--Form-input-addOnColor);
  border-color: var(--Form-input-borderColor);
  border-style: solid;
  border-width: 0.0625rem 0;
}

.amis-scope .a-TextControl-addOn:first-child {
  border-left-width: 0.0625rem;
}

.amis-scope .a-TextControl-addOn:last-child {
  border-right-width: 0.0625rem;
  border-top-right-radius: var(--Form-input-borderRadius);
  border-bottom-right-radius: var(--Form-input-borderRadius);
}

.amis-scope .a-TextControl--withAddOn > .a-TextControl-button > .a-Button {
  position: relative;
  border-radius: 0;
  margin-left: -0.0625rem;
  border: var(--InputGroup-button-borderWidth) solid var(--InputGroup-button-borderColor);
}

.amis-scope .a-TextControl--withAddOn > .a-TextControl-button:not(:last-child) .a-Button {
  border-right: 0;
}

.amis-scope .a-TextControl--withAddOn > .a-TextControl-button:first-child .a-Button {
  border-top-left-radius: var(--InputGroup-button-borderRadius);
  border-bottom-left-radius: var(--InputGroup-button-borderRadius);
}

.amis-scope .a-TextControl--withAddOn > .a-TextControl-button:last-child .a-Button {
  border-top-right-radius: var(--InputGroup-button-borderRadius);
  border-bottom-right-radius: var(--InputGroup-button-borderRadius);
}

.amis-scope .a-TextControl--withAddOn.is-focused > .a-TextControl-button .a-Button {
  border-color: var(--Form-input-onFocused-borderColor);
}

.amis-scope .a-TextControl--withAddOn.is-error > .a-TextControl-addOn {
  border-color: var(--Form-input-onError-borderColor);
}

.amis-scope .a-TextControl--withAddOn.is-focused > .a-TextControl-addOn {
  border-color: var(--Form-input-onFocused-borderColor);
  color: var(--Form-input-onFocus-addOnColor);
  box-shadow: var(--Form-input-boxShadow);
}

.amis-scope .a-TextControl--withAddOn.is-disabled > .a-TextControl-addOn {
  color: var(--text--muted-color);
}

.amis-scope .a-TextControl--withAddOn.is-inline {
  display: inline-block;
}

@media (min-width: 576px) {
  .amis-scope .a-TextControl--withAddOn.is-inline.a-Form-control--sizeXs > .a-TextControl-input,
  .amis-scope .a-TextControl--withAddOn.is-inline.a-Form-control--sizeSm > .a-TextControl-input,
  .amis-scope .a-TextControl--withAddOn.is-inline.a-Form-control--sizeMd > .a-TextControl-input,
  .amis-scope .a-TextControl--withAddOn.is-inline.a-Form-control--sizeLg > .a-TextControl-input {
    min-width: 100%;
  }
}

.amis-scope .a-TextControl-input--withAC {
  position: relative;
  flex-wrap: wrap;
}

.amis-scope .a-TextControl-input--withAC input {
  width: auto;
}

.amis-scope .a-TextControl-sugs {
  position: absolute;
  background: var(--Form-select-menu-bg);
  color: var(--Form-select-menu-color);
  border: var(--Form-input-borderWidth) solid var(--Form-input-onFocused-borderColor);
  left: -0.0625rem;
  right: -0.0625rem;
  top: 100%;
  z-index: 10;
  max-height: 18.75rem;
  overflow: auto;
}

.amis-scope .a-TextControl-sugItem {
  padding: calc( ( var(--Form-selectOption-height) - var(--Form-input-lineHeight) * var(--Form-input-fontSize) - 0.125rem ) / 2 ) 0.75rem;
}

.amis-scope .a-TextControl-sugItem svg {
  width: 1rem;
  margin-top: 0.25rem;
  float: right;
  fill: var(--Form-input-onHover-iconColor);
}

.amis-scope .a-TextControl-sugItem:not(.is-disabled) {
  cursor: pointer;
}

.amis-scope .a-TextControl-sugItem.is-highlight {
  color: var(--Form-select-menu-onHover-color);
  background: var(--Form-select-menu-onHover-bg);
}

.amis-scope .a-TextControl-value {
  user-select: none;
  line-height: calc( var(--Form-input-lineHeight) * var(--Form-input-fontSize) );
  vertical-align: middle;
  display: inline-block;
}

.amis-scope .a-TextControl-input--multiple {
  height: auto;
  min-height: var(--Form-input-height);
  padding: calc(var(--Form-input-paddingY) - 0.125rem) calc(var(--Form-input-paddingX) - 0.1875rem);
}

.amis-scope .a-TextControl-input--multiple .a-TextControl-placeholder {
  margin-top: 0;
}

.amis-scope .a-TextControl-input--multiple > input {
  margin-top: 2px;
}

.amis-scope .a-TextControl-input--multiple .a-TextControl-valueWrap {
  white-space: normal;
  margin-bottom: calc(var(--gap-xs) * -1);
}

.amis-scope .a-TextControl-input--multiple .a-TextControl-valueWrap > input {
  margin-bottom: var(--gap-xs);
}

.amis-scope .a-TextControl-input--multiple .a-TextControl-value {
  white-space: nowrap;
  line-height: calc( var(--Form-input-lineHeight) * var(--Form-input-fontSize) - 0.125rem );
  font-size: var(--Form-selectValue-fontSize);
  color: var(--Form-selectValue-color);
  background: var(--Form-selectValue-bg);
  border: 0.0625rem solid var(--Form-selectValue-borderColor);
  border-radius: 0.125rem;
  margin: 2px 3px;
}

.amis-scope .a-TextControl-valueIcon {
  cursor: pointer;
  border-right: 0.0625rem solid var(--Form-selectValue-borderColor);
  padding: 1px 5px;
}

.amis-scope .a-TextControl-valueIcon:hover {
  background: var(--Form-selectValue-onHover-bg);
}

.amis-scope .a-TextControl-input--multiple .a-TextControl-valueLabel {
  padding: 0 var(--gap-xs);
}

.amis-scope .a-TextControl-counter {
  color: var(--text--muted-color);
}

.amis-scope .has-error--maxLength .a-TextControl-counter {
  color: var(--danger);
}

.amis-scope .a-TextareaControl {
  position: relative;
}

.amis-scope .a-TextareaControl > textarea {
  border: 1px solid var(--Form-input-borderColor);
  border-radius: var(--Form-input-borderRadius);
  background: var(--Form-input-bg);
  padding: var(--Form-input-paddingY) var(--Form-input-paddingX);
  font-size: var(--Form-input-fontSize);
  display: block;
  width: 100%;
  line-height: var(--Form-input-lineHeight);
  outline: none;
  resize: none;
}

.amis-scope .a-TextareaControl > textarea--borderHalf {
  border-left-color: transparent !important;
  border-right-color: transparent !important;
  border-top-color: transparent !important;
}

.amis-scope .a-TextareaControl > textarea--borderNone {
  border-color: transparent !important;
}

.amis-scope .a-TextareaControl > textarea::placeholder {
  color: var(--Form-input-placeholderColor);
}

.amis-scope .a-TextareaControl > textarea:focus,
.amis-scope .a-TextareaControl.is-focused > textarea {
  border-color: var(--Form-input-onFocused-borderColor);
  box-shadow: var(--Form-input-boxShadow);
}

.amis-scope .a-TextareaControl.is-disabled > textarea,
.amis-scope .a-TextareaControl > textarea[disabled] {
  background: #e5e7eb;
  color: var(--text--muted-color);
}

.amis-scope .a-TextareaControl.is-error > textarea {
  border-color: var(--Form-input-onError-borderColor);
}

.amis-scope .a-TextareaControl-counter {
  position: absolute;
  right: var(--Form-input-paddingX);
  bottom: var(--Form-input-paddingY);
  font-size: var(--fontSizeSm);
  padding: 0 5px;
  border-radius: 3px;
  color: #fff;
  background: rgba(0, 0, 0, 0.6);
}

.amis-scope .a-TextareaControl-counter.is-empty {
  color: #666;
  background: rgba(0, 0, 0, 0.4);
}

.amis-scope .has-error--maxLength .a-TextareaControl-counter {
  background: var(--danger);
}

.amis-scope .a-Checkbox {
  margin: 0 var(--gap-sm) 0 0;
  font-weight: var(--fontWeightNormal);
  user-select: none;
  pointer-events: none;
}

.amis-scope .a-Checkbox input {
  position: absolute;
  clip: rect(1px 1px 1px 1px);
  clip: rect(1px, 1px, 1px, 1px);
  pointer-events: none;
}

.amis-scope .a-Checkbox:hover input:not(:disabled) + i {
  border-color: var(--Checkbox-onHover-color);
}

.amis-scope .a-Checkbox > i {
  cursor: pointer;
  line-height: 1;
  background: var(--Checkbox-gb);
  display: inline-block;
  vertical-align: middle;
  position: relative;
  pointer-events: all;
}

.amis-scope .a-Checkbox > i + span {
  pointer-events: all;
  margin-left: var(--Checkbox-gap);
  cursor: pointer;
}

.amis-scope .a-Checkbox > i + span > a {
  margin-left: var(--gap-xs);
  display: none;
}

.amis-scope .a-Checkbox > i + span:empty {
  display: none;
}

.amis-scope .a-Checkbox > i:before {
  content: "";
  position: absolute;
  left: 50%;
  top: 50%;
  width: 0px;
  height: 0px;
  background: transparent;
  transition: all var(--animation-duration);
  transform-origin: 50% 50%;
  transform: translate(-50%, -50%);
}

.amis-scope .a-Checkbox:hover > i + span > a {
  display: inline-block;
}

.amis-scope .a-Checkbox--checkbox {
  padding-left: var(--Checkbox-size);
}

.amis-scope .a-Checkbox--checkbox input {
  margin-left: calc(var(--Checkbox-size) * -1);
}

.amis-scope .a-Checkbox--checkbox input:checked + i {
  border-color: var(--Checkbox-onHover-color);
}

.amis-scope .a-Checkbox--checkbox input:checked + i:before {
  width: var(--Checkbox-inner-size);
  height: var(--Checkbox-inner-size);
  background: var(--Checkbox-onHover-color);
}

.amis-scope .a-Checkbox--checkbox input[disabled] + i {
  border-color: var(--Checkbox-onDisabled-color);
  cursor: not-allowed;
}

.amis-scope .a-Checkbox--checkbox input[disabled] + i:before {
  width: var(--Checkbox-inner-size);
  height: calc(var(--Checkbox-inner-size) / 2);
  background: var(--Checkbox-onDisabled-bg);
}

.amis-scope .a-Checkbox--checkbox input[disabled] + i + span {
  cursor: not-allowed;
  color: var(--text--muted-color);
}

.amis-scope .a-Checkbox--checkbox > i {
  width: var(--Checkbox-size);
  height: var(--Checkbox-size);
  border: 0.0625rem solid var(--Checkbox-color);
  border-radius: var(--Checkbox-borderRadius);
  margin-left: calc(var(--Checkbox-size) * -1);
}

.amis-scope .a-Checkbox--full.a-Checkbox--checkbox:not(:disabled) + i:hover {
  border-color: var(--Checkbox-color);
}

.amis-scope .a-Checkbox--full.a-Checkbox--checkbox input:checked + i {
  border-color: var(--Checkbox-onHover-color);
  background: var(--Checkbox-onHover-color);
}

.amis-scope .a-Checkbox--full.a-Checkbox--checkbox input:checked + i:before {
  width: var(--Checkbox--full-inner-size);
  height: calc(var(--Checkbox--full-inner-size) / 2);
  border-color: var(--Checkbox-gb);
}

.amis-scope .a-Checkbox--full.a-Checkbox--checkbox input[disabled] + i {
  border-color: var(--Checkbox-onDisabled-color);
  background: var(--Checkbox-onDisabled-bg);
}

.amis-scope .a-Checkbox--full.a-Checkbox--checkbox input[disabled]:checked + i:before {
  border-color: var(--Checkbox-onDisabled-color);
}

.amis-scope .a-Checkbox--full.a-Checkbox--checkbox input:checked[disabled] + i {
  border-color: var(--Checkbox-onDisabled-color);
  background: var(--Checkbox-onDisabled-bg);
}

.amis-scope .a-Checkbox--full.a-Checkbox--checkbox > i {
  position: relative;
  cursor: pointer;
}

.amis-scope .a-Checkbox--full.a-Checkbox--checkbox > i:before {
  content: "";
  position: absolute;
  left: 50%;
  top: 50%;
  width: 0;
  height: 0;
  border-color: transparent;
  transition: width var(--animation-duration), height var(--animation-duration), transform var(--animation-duration);
  border-width: 0 0 0.125rem 0.125rem;
  transform: translate(-50%, -60%) rotate(-40deg);
  border-style: solid;
}

.amis-scope .a-Checkbox--radio {
  padding-left: var(--Radio-size);
}

.amis-scope .a-Checkbox--radio input {
  margin-left: calc(var(--Radio-size) * -1);
}

.amis-scope .a-Checkbox--radio input:checked + i {
  border-color: var(--Radio-onHover-color);
}

.amis-scope .a-Checkbox--radio input:checked + i:before {
  width: var(--Radio-inner-size);
  height: var(--Radio-inner-size);
  background: var(--Radio-onHover-color);
  border-radius: 50%;
}

.amis-scope .a-Checkbox--radio input[disabled] + i {
  border-color: var(--Radio-onDisabled-color);
  background: var(--Radio-onDisabled-bg);
  cursor: not-allowed;
}

.amis-scope .a-Checkbox--radio input[disabled] + i:before {
  background: var(--Radio-onDisabled-color);
}

.amis-scope .a-Checkbox--radio input[disabled] + i + span {
  cursor: not-allowed;
  color: var(--text--muted-color);
}

.amis-scope .a-Checkbox--radio input:focus + i {
  box-shadow: var(--Radio-onFocus-boxShadow);
}

.amis-scope .a-Checkbox--radio > i {
  cursor: pointer;
  width: var(--Radio-size);
  height: var(--Radio-size);
  border: 0.0625rem solid var(--Radio-color);
  margin-left: calc(var(--Radio-size) * -1);
  margin-top: -0.125rem;
  border-radius: 50%;
}

.amis-scope .a-Checkbox--sm {
  padding-left: var(--Checkbox--sm-size);
}

.amis-scope .a-Checkbox--sm input {
  margin-left: calc(var(--Checkbox--sm-size) * -1);
}

.amis-scope .a-Checkbox--sm input:checked + i:before {
  width: var(--Checkbox--sm-inner-size);
  height: var(--Checkbox--sm-inner-size);
}

.amis-scope .a-Checkbox--sm > i {
  width: var(--Checkbox--sm-size);
  height: var(--Checkbox--sm-size);
  margin-left: calc(var(--Checkbox--sm-size) * -1);
  margin-top: 0;
}

.amis-scope .a-Checkbox--sm > i + span {
  margin-left: var(--gap-xs);
}

.amis-scope .a-Checkbox--sm.a-Checkbox--full input[type=checkbox]:checked + i:before {
  width: var(--Checkbox--sm--full-inner-size);
  height: calc(var(--Checkbox--sm--full-inner-size) / 2);
}

.amis-scope .a-Checkbox-desc {
  color: var(--text--muted-color);
  margin-left: var(--Checkbox-gap);
  margin-top: var(--gap-xs);
  pointer-events: all;
}

.amis-scope .a-CheckboxControl,
.amis-scope .a-RadiosControl,
.amis-scope .a-CheckboxesControl {
  padding-top: calc( (var(--Form-input-height) - var(--Checkbox-size)) / 2 - 3px );
}

.amis-scope .a-RadiosControl .a-Checkbox,
.amis-scope .a-CheckboxesControl .a-Checkbox {
  display: block;
  margin-bottom: var(--Form-label-paddingTop);
}

.amis-scope .a-RadiosControl.is-inline .a-Checkbox,
.amis-scope .a-CheckboxesControl.is-inline .a-Checkbox {
  display: inline-block;
  margin-right: var(--gap-md);
}

.amis-scope .a-RadiosControl-group:not(:first-child),
.amis-scope .a-CheckboxesControl-group:not(:first-child) {
  margin-top: 0.625rem;
}

.amis-scope .a-RadiosControl-group .a-RadiosControl-groupLabel,
.amis-scope .a-RadiosControl-group .a-CheckboxesControl-groupLabel,
.amis-scope .a-CheckboxesControl-group .a-RadiosControl-groupLabel,
.amis-scope .a-CheckboxesControl-group .a-CheckboxesControl-groupLabel {
  display: block;
  font-size: var(--fontSizeSm);
  color: #999;
}

.amis-scope .a-Checkboxes > .a-Checkbox {
  display: block;
  height: var(--Form-input-height);
  line-height: var(--Form-input-lineHeight);
  font-size: var(--Form-input-fontSize);
  padding: calc( ( var(--Form-input-height) - var(--Form-input-lineHeight) * var(--Form-input-fontSize) ) / 2 ) var(--gap-sm) calc( ( var(--Form-input-height) - var(--Form-input-lineHeight) * var(--Form-input-fontSize) ) / 2 ) calc(var(--gap-sm) + var(--Checkbox-size));
}

.amis-scope .a-Checkboxes--inline > .a-Checkbox {
  display: inline-block;
}

.amis-scope .a-Checkboxes-addBtn {
  display: block;
  cursor: pointer;
}

.amis-scope .a-Checkboxes-addBtn:hover {
  text-decoration: none;
}

.amis-scope .a-Checkboxes-addBtn > svg {
  width: 0.875rem;
  height: 0.875rem;
  margin-right: var(--Checkbox-gap);
}

.amis-scope .a-ListCheckboxes-group:not(:first-child) > .a-ListCheckboxes-itemLabel,
.amis-scope .a-ListCheckboxes-group:not(:first-child) > .a-ListRadios-itemLabel,
.amis-scope .a-ListRadios-group:not(:first-child) > .a-ListCheckboxes-itemLabel,
.amis-scope .a-ListRadios-group:not(:first-child) > .a-ListRadios-itemLabel {
  border-top: 0.0625rem solid var(--ListMenu-divider-color);
}

.amis-scope .a-ListCheckboxes-group > .a-ListCheckboxes-itemLabel,
.amis-scope .a-ListCheckboxes-group > .a-ListRadios-itemLabel,
.amis-scope .a-ListRadios-group > .a-ListCheckboxes-itemLabel,
.amis-scope .a-ListRadios-group > .a-ListRadios-itemLabel {
  font-size: var(--fontSizeSm);
  padding: var(--gap-xs) var(--gap-xs);
  color: var(--text--muted-color);
}

.amis-scope .a-ListCheckboxes-item,
.amis-scope .a-ListRadios-item {
  display: flex;
  height: var(--Form-input-height);
  line-height: var(--Form-input-lineHeight);
  font-size: var(--Form-input-fontSize);
  padding: calc( ( var(--Form-input-height) - var(--Form-input-lineHeight) * var(--Form-input-fontSize) ) / 2 ) var(--gap-sm);
  flex-direction: row;
  cursor: pointer;
  user-select: none;
}

.amis-scope .a-ListCheckboxes-item > .a-Checkbox,
.amis-scope .a-ListRadios-item > .a-Checkbox {
  margin-right: 0;
}

.amis-scope .a-ListCheckboxes-item.is-active,
.amis-scope .a-ListRadios-item.is-active {
  color: var(--Form-select-menu-onActive-color);
  background: var(--Form-select-menu-onActive-bg);
}

.amis-scope .a-ListCheckboxes-item:hover,
.amis-scope .a-ListRadios-item:hover {
  background: var(--Tree-item-onHover-bg);
}

.amis-scope .a-ListCheckboxes-item.is-disabled,
.amis-scope .a-ListRadios-item.is-disabled {
  pointer-events: none;
  color: var(--text--muted-color);
}

.amis-scope .a-ListCheckboxes-group > .a-ListCheckboxes-items > .a-ListCheckboxes-item,
.amis-scope .a-ListCheckboxes-group > .a-ListCheckboxes-items > .a-ListRadios-item,
.amis-scope .a-ListCheckboxes-group > .a-ListRadios-items > .a-ListCheckboxes-item,
.amis-scope .a-ListCheckboxes-group > .a-ListRadios-items > .a-ListRadios-item,
.amis-scope .a-ListRadios-group > .a-ListCheckboxes-items > .a-ListCheckboxes-item,
.amis-scope .a-ListRadios-group > .a-ListCheckboxes-items > .a-ListRadios-item,
.amis-scope .a-ListRadios-group > .a-ListRadios-items > .a-ListCheckboxes-item,
.amis-scope .a-ListRadios-group > .a-ListRadios-items > .a-ListRadios-item {
  padding-left: var(--gap-base);
}

.amis-scope .a-ListCheckboxes-itemLabel,
.amis-scope .a-ListRadios-itemLabel {
  flex-grow: 1;
}

.amis-scope .a-ListCheckboxes-itemLabel span,
.amis-scope .a-ListRadios-itemLabel span {
  white-space: nowrap;
}

.amis-scope .a-ListCheckboxes-placeholder,
.amis-scope .a-ListRadios-placeholder {
  height: var(--Form-input-height);
  line-height: var(--Form-input-lineHeight);
  font-size: var(--Form-input-fontSize);
  padding: calc( ( var(--Form-input-height) - var(--Form-input-lineHeight) * var(--Form-input-fontSize) ) / 2 ) var(--gap-sm);
  color: var(--text--muted-color);
}

.amis-scope .a-TableCheckboxes .a-Table-content {
  border-top: var(--Table-borderWidth) solid var(--Table-borderColor);
}

.amis-scope .a-TableCheckboxes .a-Table-table > thead > tr > th,
.amis-scope .a-TableCheckboxes .a-Table-table > tbody > tr > td {
  font-size: var(--fontSizeSm);
  padding-top: var(--gap-xs);
  padding-bottom: 0.375rem;
  vertical-align: middle;
}

.amis-scope .a-TableCheckboxes .a-Table-table > thead > tr > th {
  padding-top: 0.375rem;
}

.amis-scope .a-TableCheckboxes .a-Table-table > thead > tr > th:first-child,
.amis-scope .a-TableCheckboxes .a-Table-table > tbody > tr > td:first-child {
  padding-left: 0.625rem;
  padding-right: 0;
}

.amis-scope .a-TableCheckboxes .a-Table-table > thead > tr > th:last-child,
.amis-scope .a-TableCheckboxes .a-Table-table > tbody > tr > td:last-child {
  padding-right: var(--gap-md);
}

.amis-scope .a-TableCheckboxes .a-Table-table > tbody > tr {
  cursor: pointer;
}

.amis-scope .a-TreeCheckboxes .a-Table-expandBtn,
.amis-scope .a-TreeRadios .a-Table-expandBtn {
  color: var(--icon-color);
  margin-right: 5px;
}

.amis-scope .a-TreeCheckboxes-sublist,
.amis-scope .a-TreeRadios-sublist {
  position: relative;
  margin: 0 0 0 2.1875rem;
  display: none;
}

.amis-scope .a-TreeCheckboxes-sublist:before,
.amis-scope .a-TreeRadios-sublist:before {
  width: 1px;
  content: "";
  display: block;
  position: absolute;
  top: calc(var(--gap-xs) * -1);
  bottom: calc(var(--Form-input-height) / 2);
  left: -19px;
  border-left: dashed 1px var(--icon-color);
}

.amis-scope .a-TreeCheckboxes-item,
.amis-scope .a-TreeRadios-item {
  position: relative;
}

.amis-scope .a-TreeCheckboxes-item.is-expanded > .a-TreeCheckboxes-sublist,
.amis-scope .a-TreeCheckboxes-item.is-expanded > .a-TreeRadios-sublist,
.amis-scope .a-TreeRadios-item.is-expanded > .a-TreeCheckboxes-sublist,
.amis-scope .a-TreeRadios-item.is-expanded > .a-TreeRadios-sublist {
  display: block;
}

.amis-scope .a-TreeCheckboxes-item:not(:last-child) > .a-TreeCheckboxes-sublist:before,
.amis-scope .a-TreeCheckboxes-item:not(:last-child) > .a-TreeRadios-sublist:before,
.amis-scope .a-TreeRadios-item:not(:last-child) > .a-TreeCheckboxes-sublist:before,
.amis-scope .a-TreeRadios-item:not(:last-child) > .a-TreeRadios-sublist:before {
  bottom: 0;
}

.amis-scope .a-TreeCheckboxes-sublist .a-TreeCheckboxes-item:before,
.amis-scope .a-TreeCheckboxes-sublist .a-TreeRadios-item:before,
.amis-scope .a-TreeRadios-sublist .a-TreeCheckboxes-item:before,
.amis-scope .a-TreeRadios-sublist .a-TreeRadios-item:before {
  height: 1px;
  content: "";
  display: block;
  position: absolute;
  top: calc(var(--Form-input-height) / 2);
  width: 19px;
  left: -19px;
  border-top: dashed 1px var(--icon-color);
}

.amis-scope .a-TreeCheckboxes-itemInner,
.amis-scope .a-TreeRadios-itemInner {
  display: flex;
  align-items: center;
  height: var(--Form-input-height);
  line-height: var(--Form-input-lineHeight);
  font-size: var(--Form-input-fontSize);
  padding: calc( ( var(--Form-input-height) - var(--Form-input-lineHeight) * var(--Form-input-fontSize) ) / 2 ) var(--gap-sm);
  flex-direction: row;
  cursor: pointer;
  user-select: none;
  position: relative;
}

.amis-scope .a-TreeCheckboxes-itemInner > .a-Checkbox,
.amis-scope .a-TreeRadios-itemInner > .a-Checkbox {
  margin-right: 0;
  margin-left: var(--gap-sm);
}

.amis-scope .a-TreeCheckboxes-itemInner > *,
.amis-scope .a-TreeRadios-itemInner > * {
  position: relative;
  z-index: 2;
}

.amis-scope .a-TreeCheckboxes-itemInner:hover:after,
.amis-scope .a-TreeRadios-itemInner:hover:after {
  position: absolute;
  content: "";
  z-index: 1;
  top: 0;
  right: 0;
  bottom: 0;
  left: -99999px;
  background: var(--Tree-item-onHover-bg);
}

.amis-scope .a-TreeCheckboxes-itemInner.is-active,
.amis-scope .a-TreeRadios-itemInner.is-active {
  color: var(--Form-select-menu-onActive-color);
}

.amis-scope .a-TreeCheckboxes-itemInner.is-disabled,
.amis-scope .a-TreeRadios-itemInner.is-disabled {
  pointer-events: none;
  color: var(--text--muted-color);
}

.amis-scope .a-TreeCheckboxes-itemLabel,
.amis-scope .a-TreeRadios-itemLabel {
  flex-grow: 1;
}

.amis-scope .a-TreeCheckboxes-placeholder,
.amis-scope .a-TreeRadios-placeholder {
  height: var(--Form-input-height);
  line-height: var(--Form-input-lineHeight);
  font-size: var(--Form-input-fontSize);
  padding: calc( ( var(--Form-input-height) - var(--Form-input-lineHeight) * var(--Form-input-fontSize) ) / 2 ) var(--gap-sm);
  color: var(--text--muted-color);
}

.amis-scope .a-ChainedCheckboxes {
  display: flex;
  flex-direction: row;
}

.amis-scope .a-ChainedCheckboxes-col {
  flex-grow: 1;
  min-width: 150px;
}

.amis-scope .a-ChainedCheckboxes-col:not(:last-child) {
  border-right: 1px solid var(--borderColor);
}

.amis-scope .a-ChainedCheckboxes-subTitle {
  font-size: var(--fontSizeSm);
  padding: var(--gap-xs) var(--gap-xs);
  color: var(--text--muted-color);
}

.amis-scope .a-ChainedCheckboxes-item {
  display: flex;
  height: var(--Form-input-height);
  line-height: var(--Form-input-lineHeight);
  font-size: var(--Form-input-fontSize);
  padding: calc( ( var(--Form-input-height) - var(--Form-input-lineHeight) * var(--Form-input-fontSize) ) / 2 ) var(--gap-sm);
  flex-direction: row;
  cursor: pointer;
  user-select: none;
}

.amis-scope .a-ChainedCheckboxes-item > .a-Checkbox {
  margin-right: 0;
}

.amis-scope .a-ChainedCheckboxes-item.is-active {
  color: var(--Form-select-menu-onActive-color);
  background: var(--Form-select-menu-onActive-bg);
}

.amis-scope .a-ChainedCheckboxes-item:hover {
  background: var(--Tree-item-onHover-bg);
}

.amis-scope .a-ChainedCheckboxes-item.is-disabled {
  pointer-events: none;
  color: var(--text--muted-color);
}

.amis-scope .a-ChainedCheckboxes-itemLabel {
  flex-grow: 1;
}

.amis-scope .a-ChainedCheckboxes-placeholder {
  height: var(--Form-input-height);
  line-height: var(--Form-input-lineHeight);
  font-size: var(--Form-input-fontSize);
  padding: calc( ( var(--Form-input-height) - var(--Form-input-lineHeight) * var(--Form-input-fontSize) ) / 2 ) var(--gap-sm);
  color: var(--text--muted-color);
}

.amis-scope .a-AssociatedCheckboxes {
  display: flex;
  flex-direction: row;
}

.amis-scope .a-AssociatedCheckboxes-left,
.amis-scope .a-AssociatedCheckboxes-right {
  flex-grow: 1;
  width: 0;
  height: 10.9375rem;
  overflow: auto;
}

.amis-scope .a-AssociatedCheckboxes-left {
  border-right: 1px solid var(--borderColor);
}

.amis-scope .a-AssociatedCheckboxes-reload {
  text-align: center;
  color: var(--info);
  margin: 20px 0 0;
}

.amis-scope .a-AssociatedCheckboxes-reload.is-clickable {
  cursor: pointer;
}

.amis-scope .a-AssociatedCheckboxes-box {
  line-height: var(--Form-input-lineHeight);
  font-size: var(--fontSizeSm);
  color: var(--text--muted-color);
  flex-grow: 1;
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  height: 100%;
}

.amis-scope .a-AssociatedCheckboxes-box > p {
  text-align: center;
  margin: 10px 0 20px;
  color: var(--text--muted-color);
}

.amis-scope .a-CityPicker .a-Select {
  margin-right: var(--gap-xs);
  margin-bottom: var(--gap-xs);
}

.amis-scope .a-CityPicker-input {
  outline: none;
  vertical-align: top;
  border: var(--Form-input-borderWidth) solid var(--Form-input-borderColor);
  border-radius: var(--Form-input-borderRadius);
  line-height: var(--Form-input-lineHeight);
  padding: var(--Form-input-paddingY) var(--Form-input-paddingX);
  font-size: var(--Form-input-fontSize);
}

.amis-scope .a-CityPicker-input::placeholder {
  color: var(--Form-input-placeholderColor);
  user-select: none;
}

.amis-scope .a-CityPicker-input:focus {
  border-color: var(--Form-input-onFocused-borderColor);
  box-shadow: var(--Form-input-boxShadow);
  background: var(--Form-input-onFocused-bg);
}

.amis-scope .a-Form-item--inline > .a-Form-value > .a-CityPicker {
  display: inline-block;
}

.amis-scope .a-Switch {
  cursor: pointer;
  position: relative;
  display: inline-block;
  height: var(--Switch-height);
  min-width: var(--Switch-width);
  overflow: hidden;
  border-radius: 1.875rem;
  background: var(--Switch-bgColor);
  margin: 0;
  vertical-align: middle;
  text-align: left;
}

.amis-scope .a-Switch.is-disabled {
  cursor: not-allowed;
  opacity: 0.4;
}

.amis-scope .a-Switch .text {
  margin: 0 0.4375rem 0 1.5625rem;
  color: var(--Switch-valueColor);
  text-indent: calc(var(--Switch-width) / 2);
  text-transform: uppercase;
  font-size: var(--fontSizeSm);
  line-height: var(--Switch-height);
  font-style: normal;
  font-weight: bold;
  transition: all var(--animation-duration);
}

.amis-scope .a-Switch .slider:before {
  content: "";
  position: absolute;
  background: var(--white);
  width: calc(var(--Switch-height) - 0.125rem);
  top: 0.0625rem;
  bottom: 0.0625rem;
  left: 0.0625rem;
  border-radius: 50%;
  transition: margin-left var(--animation-duration);
}

.amis-scope .a-Switch.is-checked {
  background: var(--Switch-onActive-bgColor);
}

.amis-scope .a-Switch.is-checked .slider::before {
  left: auto;
  right: 0.0625rem;
  border-width: 0;
}

.amis-scope .a-Switch.is-checked .text {
  margin: 0 25px 0 7px;
  color: var(--white);
  text-indent: var(--gap-xs);
}

.amis-scope .a-Switch.is-checked.is-disabled .slider:before {
  color: var(--Switch-onDisabled-color);
}

.amis-scope .a-Switch.is-checked.is-disabled .text {
  color: var(--Switch-onDisabled-color);
}

.amis-scope .a-Switch input {
  position: absolute;
  opacity: 0;
}

.amis-scope .a-Switch-option {
  vertical-align: middle;
  margin-left: var(--Switch-gap);
}

.amis-scope .a-Switch-option:first-child {
  margin-left: 0;
  margin-right: var(--Switch-gap);
}

.amis-scope .a-Switch-option:empty {
  display: none;
}

.amis-scope .a-SwitchControl {
  padding-top: calc((var(--Form-input-height) - var(--Switch-height)) / 2);
}

.amis-scope .a-SwitchControl.is-inline {
  display: inline-block;
}

.amis-scope .a-Number {
  margin: 0;
  padding: 0;
  line-height: var(--Form-input-height);
  font-size: var(--Form-input-fontSize);
  height: var(--Form-input-height);
  display: inline-block;
  vertical-align: middle;
  background: var(--Number-bg);
  border: var(--Number-borderWidth) solid var(--Number-borderColor);
  border-radius: var(--Number-borderRadius);
}

.amis-scope .a-Number--borderHalf {
  border-left-color: transparent !important;
  border-right-color: transparent !important;
  border-top-color: transparent !important;
}

.amis-scope .a-Number--borderNone {
  border-color: transparent !important;
}

.amis-scope .a-Number.no-steps > .a-Number-handler-wrap {
  display: none;
}

.amis-scope .a-Number-focused {
  border-color: var(--Form-input-onFocused-borderColor);
  box-shadow: var(--Form-input-boxShadow);
}

.amis-scope .a-Number-handler {
  text-align: center;
  overflow: hidden;
  display: block;
  touch-action: none;
}

.amis-scope .a-Number-handler-active {
  background: #ddd;
}

.amis-scope .a-Number-handler-up-inner,
.amis-scope .a-Number-handler-down-inner {
  user-select: none;
  -webkit-user-select: none;
  display: inline-block;
}

.amis-scope .a-Number:hover {
  border-color: var(--Form-input-onFocused-borderColor);
}

.amis-scope .a-Number:hover .a-Number-handler-up,
.amis-scope .a-Number:hover .a-Number-handler-wrap {
  border-color: var(--Form-input-onFocused-borderColor);
}

.amis-scope .a-Number-disabled:hover {
  border-color: var(--Form-input-borderColor);
}

.amis-scope .a-Number-disabled:hover .a-Number-handler-up,
.amis-scope .a-Number-disabled:hover .a-Number-handler-wrap {
  border-color: var(--Form-input-borderColor);
}

.amis-scope .a-Number-input-wrap {
  overflow: hidden;
  height: 100%;
}

.amis-scope .a-Number-input {
  width: 100%;
  background: transparent;
  text-align: left;
  vertical-align: top;
  outline: 0;
  -moz-appearance: textfield;
  line-height: calc(var(--Form-input-height) - var(--Number-borderWidth) * 2);
  height: 100%;
  transition: all var(--animation-duration) ease;
  border: 0;
  border-radius: var(--Form-input-borderRadius);
  padding: 0 var(--Form-input-paddingX);
}

.amis-scope .a-Number-handler {
  background: var(--Number-handler-bg);
  color: var(--Number-handler-color);
  font-family: var(--Number-handler-fontFamily);
  font-size: var(--Number-handler-fontSize);
}

.amis-scope .a-Number-handler:hover {
  background: var(--Number-handler-onHover-bg);
  color: var(--Number-handler-onHover-color);
}

.amis-scope .a-Number-handler:hover:active {
  background: var(--Number-handler-onActive-bg);
}

.amis-scope .a-Number-handler-up-inner {
  transform: var(--Number-handler--up-transform);
}

.amis-scope .a-Number-handler-up-inner:after {
  content: var(--Number-handler--up-content);
}

.amis-scope .a-Number-handler-down-inner:after {
  content: var(--Number-handler--down-content);
}

.amis-scope .a-Number-handler-wrap {
  float: right;
  border-left: 0.0625rem solid var(--Form-input-borderColor);
  width: var(--Number-handler-width);
  height: 100%;
}

.amis-scope .a-Number-handler {
  line-height: calc((var(--Form-input-height) - 0.375rem) / 2);
  height: calc( (var(--Form-input-height) - var(--Number-borderWidth) * 2) / 2 );
}

.amis-scope .a-Number-handler-up {
  border-bottom: var(--Number-handler-borderBottom);
  padding-top: 0.0625rem;
}

.amis-scope .a-Number-handler-down-disabled,
.amis-scope .a-Number-handler-up-disabled {
  background: var(--Number-handler-onDisabled-bg);
  pointer-events: none;
  color: var(--Number-handler-onDisabled-color);
}

.amis-scope .a-Number-disabled .a-Number-input {
  opacity: 0.72;
  cursor: not-allowed;
  background: var(--Number-onDisabled-bg);
}

.amis-scope .a-Number-disabled .a-Number-handler {
  opacity: 0.72;
}

.amis-scope .a-Number-disabled .a-Number-handler:hover {
  color: var(--text--muted-color);
  border-color: var(--Form-input-borderColor);
}

.amis-scope .a-NumberControl:not(.is-inline) > .a-Number {
  display: block;
}

.amis-scope .a-Number--borderHalf .a-Number-handler-wrap,
.amis-scope .a-Number--borderNone .a-Number-handler-wrap {
  border-left: none;
}

.amis-scope .a-Select {
  display: inline-flex;
  vertical-align: middle;
  text-align: left;
  outline: none;
  position: relative;
  font-size: var(--Form-input-fontSize);
  border: var(--Form-select-borderWidth) solid var(--Form-select-borderColor);
  background: var(--Form-select-bg);
  border-radius: var(--Form-select-borderRadius);
  min-height: var(--Form-selectOption-height);
  padding: calc( ( var(--Form-selectOption-height) - var(--Form-input-lineHeight) * var(--Form-input-fontSize) - var(--Form-select-borderWidth) * 2 ) / 2 ) 0 calc( ( var(--Form-selectOption-height) - var(--Form-input-lineHeight) * var(--Form-input-fontSize) - var(--Form-select-borderWidth) * 2 ) / 2 ) var(--Form-select-paddingX);
  cursor: pointer;
  color: var(--Form-select-color);
}

.amis-scope .a-Select:hover {
  background: var(--Form-select-onHover-bg);
  border-color: var(--Form-select-onHover-borderColor);
}

.amis-scope .a-Select:hover .a-Select-arrow:before {
  color: var(--Form-select-caret-onHover-iconColor);
}

.amis-scope .a-Select.is-disabled {
  color: var(--text--muted-color);
  background: var(--Form-input-onDisabled-bg);
  border-color: var(--Form-input-onDisabled-borderColor);
}

.amis-scope .a-Select:focus {
  box-shadow: var(--Form-select-onFocus-boxShadow);
}

.amis-scope .a-Select--borderHalf {
  border-left-color: transparent !important;
  border-right-color: transparent !important;
  border-top-color: transparent !important;
}

.amis-scope .a-Select--borderNone {
  border-color: transparent !important;
}

.amis-scope .a-Select-valueWrap {
  user-select: none;
  position: relative;
  flex-grow: 1;
  line-height: 1;
  max-width: 100%;
}

.amis-scope .a-Select-valuesNoWrap {
  white-space: nowrap;
  text-overflow: ellipsis;
  overflow: hidden;
  line-height: 1.25rem;
}

.amis-scope .a-Select-placeholder {
  color: var(--Form-select-placeholderColor);
  line-height: var(--Form-input-lineHeight);
  user-select: none;
  white-space: nowrap;
}

.amis-scope .a-Select-value {
  line-height: calc( var(--Form-input-lineHeight) * var(--Form-input-fontSize) );
  white-space: nowrap;
  max-width: 100%;
  overflow: hidden;
  text-overflow: ellipsis;
}

.amis-scope .a-Select--multi {
  height: auto;
  min-height: var(--Form-selectOption-height);
}

.amis-scope .a-Select--multi .a-Select-valueWrap {
  margin-bottom: calc(var(--gap-xs) * -1);
}

.amis-scope .a-Select--multi .a-Select-valueWrap > input {
  display: inline-block;
  width: 6.25rem;
  margin-bottom: var(--gap-xs);
}

.amis-scope .a-Select--multi .a-Select-values + .a-Select-input {
  transform: translateY(0);
}

.amis-scope .a-Select--multi .a-Select-value {
  position: static;
  white-space: normal;
  user-select: none;
  line-height: calc( var(--Form-input-lineHeight) * var(--Form-input-fontSize) - 0.125rem );
  display: inline-block;
  vertical-align: middle;
  font-size: var(--Form-selectValue-fontSize);
  color: var(--Form-selectValue-color);
  background: var(--Form-selectValue-bg);
  border: 0.0625rem solid var(--Form-selectValue-borderColor);
  border-radius: 0.125rem;
  margin-right: var(--gap-xs);
  margin-bottom: var(--gap-xs);
}

.amis-scope .a-Select--multi .a-Select-valueLabel {
  padding: 0 var(--gap-xs);
}

.amis-scope .a-Select-valueIcon {
  cursor: pointer;
  border-right: 0.0625rem solid var(--Form-selectValue-borderColor);
  padding: 1px 5px;
}

.amis-scope .a-Select-valueIcon:hover {
  background: var(--Form-selectValue-onHover-bg);
}

.amis-scope .a-Select-valueIcon.is-disabled {
  pointer-events: none;
  display: none;
  cursor: not-allowed;
  background: var(--Form-selectValue-onDisable-bg);
}

.amis-scope .a-Select-arrow {
  margin-right: var(--gap-xs);
  width: var(--gap-md);
  text-align: center;
  display: flex;
  align-items: center;
  justify-content: center;
  line-height: 1;
}

.amis-scope .a-Select-arrow > svg {
  transition: transform var(--animation-duration);
  display: inline-block;
  color: var(--Form-select-caret-iconColor);
  width: 10px;
  height: 10px;
  top: 0;
}

.amis-scope .a-Select.is-opened .a-Select-arrow > svg {
  transform: rotate(180deg);
}

.amis-scope .a-Select-menu {
  max-height: 18.75rem;
  overflow: auto;
  user-select: none;
}

.amis-scope .a-Select-menu .a-Checkbox--sm > i {
  margin-top: -0.1875rem;
}

.amis-scope .a-Select--longlist {
  overflow: hidden;
  max-height: max-content;
}

.amis-scope .a-Select-input {
  cursor: pointer;
  outline: none;
  border: none;
  margin: 0 var(--Form-select-paddingX);
  height: var(--Form-select-search-height);
  font-size: var(--Form-select-input-fontSize);
  border-bottom: 1px solid var(--borderColor);
  display: flex;
  align-items: center;
}

.amis-scope .a-Select-input > svg {
  fill: #999;
  width: 0.875rem;
  min-width: 0.875rem;
  height: 0.875rem;
  margin-right: var(--gap-xs);
}

.amis-scope .a-Select-input > input {
  outline: none;
  border: none;
  flex-grow: 1;
  background: transparent;
  position: relative;
  top: 0.125em;
}

.amis-scope .a-Select-option {
  cursor: pointer;
  min-width: 7.5rem;
  padding: calc( ( var(--Form-select-menu-height) - var(--Form-input-lineHeight) * var(--Form-input-fontSize) ) / 2 ) var(--Form-select-paddingX);
}

.amis-scope .a-Select-option.is-active {
  color: var(--Form-select-menu-onActive-color);
  background: var(--Form-select-menu-onActive-bg);
}

.amis-scope .a-Select-option.is-highlight {
  color: var(--Form-select-menu-onHover-color);
  background: var(--Form-select-menu-onHover-bg);
}

.amis-scope .a-Select-option.is-disabled {
  color: var(--Form-select-menu-onDisabled-color);
  background: var(--Form-select-menu-onDisabled-bg);
}

.amis-scope .a-Select-option--placeholder {
  color: var(--Form-input-placeholderColor);
}

.amis-scope .a-Select-option > label {
  display: block;
}

.amis-scope .a-Select-option > a {
  float: right;
  margin-left: var(--gap-xs);
  display: none;
}

.amis-scope .a-Select-option.is-highlight > a {
  display: block;
}

.amis-scope .a-Select-noResult {
  color: var(--Form-select-placeholderColor);
  line-height: var(--Form-input-lineHeight);
  font-size: var(--Form-select-input-fontSize);
  user-select: none;
  padding: calc( ( var(--Form-select-menu-height) - var(--Form-input-lineHeight) * var(--Form-input-fontSize) ) / 2 ) var(--Form-select-paddingX);
}

.amis-scope .a-Select-option-hl {
  color: var(--danger);
}

.amis-scope .a-Select-addBtn {
  display: block;
  cursor: pointer;
  padding: calc( ( var(--Form-select-menu-height) - var(--Form-input-lineHeight) * var(--Form-input-fontSize) ) / 2 ) var(--Form-select-paddingX);
}

.amis-scope .a-Select-addBtn:hover {
  text-decoration: none;
}

.amis-scope .a-Select-addBtn > svg {
  width: 0.875rem;
  height: 0.875rem;
  margin-right: var(--Checkbox-gap);
}

.amis-scope .a-Select.is-focused,
.amis-scope .a-Select.is-opened {
  border-color: var(--Form-input-onFocused-borderColor);
  color: var(--Form-select-onFocused-color);
}

.amis-scope .a-Select-spinner {
  line-height: calc( var(--Form-input-lineHeight) * var(--Form-input-fontSize) );
}

.amis-scope .a-Select-clear {
  padding: 0.1875rem;
  cursor: pointer;
  display: flex;
  align-items: center;
  justify-content: center;
  position: relative;
  z-index: 2;
}

.amis-scope .a-Select-clear svg {
  fill: var(--Form-input-iconColor);
  width: 0.625rem;
  height: 0.625rem;
  top: 0;
}

.amis-scope .a-Select-clear:hover svg {
  fill: var(--Form-input-onHover-iconColor);
}

.amis-scope .a-Select-popover {
  margin-top: calc(var(--Form-select-outer-borderWidth) * -1);
  background: var(--Form-select-menu-bg);
  color: var(--Form-select-menu-color);
  border: var(--Form-select-outer-borderWidth) solid var(--Form-input-onFocused-borderColor);
  box-shadow: var(--Form-select-outer-boxShadow);
  border-top-left-radius: 0;
  border-top-right-radius: 0;
  min-width: 6.25rem;
}

.amis-scope .a-Select-popover.a-PopOver--leftTopLeftBottom {
  margin-top: calc( (var(--Form-select-popoverGap) - var(--Form-select-outer-borderWidth)) * -1 );
}

.amis-scope .a-SelectControl:not(.is-inline) > .a-Select {
  display: flex;
}

.amis-scope .a-SelectControl.is-error > .a-Select {
  border-color: var(--Form-input-onError-borderColor);
  background: var(--Form-input-onError-bg);
}

@media (min-width: 576px) {
  .amis-scope .a-Form-control--sizeXs > .a-Select,
  .amis-scope .a-Form-control--sizeSm > .a-Select,
  .amis-scope .a-Form-control--sizeMd > .a-Select,
  .amis-scope .a-Form-control--sizeLg > .a-Select {
    min-width: 100%;
    max-width: 100%;
    display: inline-flex !important;
  }

  .amis-scope .a-Form-control--sizeXs > .a-Select .a-Select-valueWrap,
  .amis-scope .a-Form-control--sizeSm > .a-Select .a-Select-valueWrap,
  .amis-scope .a-Form-control--sizeMd > .a-Select .a-Select-valueWrap,
  .amis-scope .a-Form-control--sizeLg > .a-Select .a-Select-valueWrap {
    width: 0;
  }
}

.amis-scope .a-Selections {
  height: 100%;
  min-width: 12.5rem;
  position: relative;
  display: flex;
  flex-direction: column;
}

.amis-scope .a-Selections-title {
  height: var(--Form-input-height);
  background: var(--Table-thead-bg);
  font-size: var(--Form-input-fontSize);
  padding: calc( ( var(--Form-input-height) - var(--Form-input-lineHeight) * var(--Form-input-fontSize) ) / 2 ) var(--gap-sm);
}

.amis-scope .a-Selections-placeholder {
  color: var(--Form-input-placeholderColor);
  text-align: center;
  width: 100%;
  flex-basis: var(--Form-input-height);
  flex-grow: 1;
  display: flex;
  flex-direction: column;
  justify-content: center;
  font-size: var(--Form-input-fontSize);
}

.amis-scope .a-Selections-items {
  flex-grow: 1;
}

.amis-scope .a-Selections-item {
  display: flex;
  flex-direction: row;
  height: var(--Form-input-height);
  line-height: var(--Form-input-lineHeight);
  font-size: var(--Form-input-fontSize);
  padding: calc( ( var(--Form-input-height) - var(--Form-input-lineHeight) * var(--Form-input-fontSize) ) / 2 ) var(--gap-sm);
}

.amis-scope .a-Selections-item > label {
  flex-basis: 3.125rem;
  flex-grow: 1;
}

.amis-scope .a-Selections-item > .a-Selections-dragbar {
  width: var(--gap-lg);
  position: relative;
  left: calc(var(--gap-xs) * -1);
  color: var(--icon-color);
  cursor: move;
}

.amis-scope .a-Selections-item--dragging > * {
  opacity: 0.2;
}

.amis-scope .a-Selections-delBtn {
  color: var(--icon-color);
  cursor: pointer;
}

.amis-scope .a-Selections-delBtn:hover {
  color: var(--icon-onHover-color);
}

.amis-scope .a-Selections-delBtn > svg {
  width: 12px;
  height: 12px;
}

.amis-scope .a-ListControl-items {
  display: block;
  margin: calc(var(--ListControl-gutterWidth) / -2);
}

.amis-scope .a-ListControl-items:empty {
  display: none;
}

.amis-scope .a-ListControl-item {
  position: relative;
  user-select: none;
  font-size: var(--ListControl-fontSize);
  display: inline-block;
  vertical-align: middle;
  margin: calc(var(--ListControl-gutterWidth) / 2);
  border: var(--ListControl-item-borderWidth) solid var(--ListControl-item-borderColor);
  background: var(--ListControl-item-bg);
  padding: var(--ListControl-item-paddingY) var(--ListControl-item-paddingX);
  color: var(--ListControl-item-color);
  transition: var(--ListControl-item-transition);
  max-width: calc(12.5rem + 2 * var(--ListControl-item-paddingX));
}

.amis-scope .a-ListControl-item:not(.is-disabled) {
  cursor: pointer;
}

.amis-scope .a-ListControl-item .b-inherit {
  border-color: var(--ListControl-item-color);
}

.amis-scope .a-ListControl-item:hover {
  background: var(--ListControl-item-onHover-bg);
  border-color: var(--ListControl-item-onHover-borderColor);
  color: var(--ListControl-item-onHover-color);
}

.amis-scope .a-ListControl-item:hover .b-inherit {
  border-color: var(--ListControl-item-onHover-borderColor);
}

.amis-scope .a-ListControl-item:hover:active,
.amis-scope .a-ListControl-item.is-active {
  background: var(--ListControl-item-onActive-bg);
  border-color: var(--ListControl-item-onActive-borderColor);
  color: var(--ListControl-item-onActive-color);
}

.amis-scope .a-ListControl-item:hover:active:hover,
.amis-scope .a-ListControl-item.is-active:hover {
  background: var(--ListControl-item-onActive-onHover-bg);
}

.amis-scope .a-ListControl-item:hover:active .b-inherit,
.amis-scope .a-ListControl-item.is-active .b-inherit {
  border-color: var(--ListControl-item-onActive-color);
}

.amis-scope .a-ListControl-item:hover:active:before,
.amis-scope .a-ListControl-item.is-active:before {
  content: "";
  position: absolute;
  width: 0.875rem;
  height: 0.875rem;
  background: var(--ListControl-item-onActive-before-bg);
  right: 0;
  bottom: 0;
}

.amis-scope .a-ListControl-item:hover:active:after,
.amis-scope .a-ListControl-item.is-active:after {
  content: "";
  position: absolute;
  width: 0.625rem;
  height: var(--gap-xs);
  border-color: var(--ListControl-item-onActive-after-borderColor);
  border-style: solid;
  border-width: 0 0 0.125rem 0.125rem;
  right: 0.0625rem;
  bottom: var(--gap-xs);
  transform: rotate(-40deg);
}

.amis-scope .a-ListControl-item.is-disabled {
  pointer-events: none;
  opacity: var(--ListControl-item-onDisabled-opacity);
  border-color: var(--ListControl-item-onDisabled-borderColor);
  background: var(--ListControl-item-onDisabled-bg);
  color: var(--ListControl-item-onDisabled-color);
}

.amis-scope .a-ListControl-item.is-disabled:before {
  background: var(--ListControl-item-onDisabled-color);
}

.amis-scope .a-ListControl-item.is-disabled .b-inherit {
  border-color: var(--ListControl-item-onDisabled-borderColor);
}

.amis-scope .a-ListControl-itemImage {
  margin: calc(var(--ListControl-item-paddingY) * -1) calc(var(--ListControl-item-paddingX) * -1);
}

.amis-scope .a-ListControl-itemImage img {
  display: block;
  max-width: 100%;
}

.amis-scope .a-ListControl-itemLabel {
  text-align: center;
}

.amis-scope .a-ListControl-itemImage + .a-ListControl-itemLabel {
  margin-top: var(--ListControl-item-paddingY);
}

.amis-scope .a-ListControl-placeholder {
  color: var(--Form-input-placeholderColor);
}

.amis-scope .a-LocationPicker {
  position: relative;
  display: inline-flex;
  flex-wrap: nowrap;
  border: var(--DatePicker-borderWidth) solid var(--DatePicker-borderColor);
  font-size: var(--DatePicker-fontSize);
  padding: var(--DatePicker-paddingY) var(--DatePicker-paddingX);
  height: var(--DatePicker-height);
  outline: none;
  white-space: nowrap;
  color: var(--DatePicker-color);
  background: var(--DatePicker-bg);
  border-radius: var(--DatePicker-borderRadius);
}

.amis-scope .a-LocationPicker:not(.is-disabled) {
  cursor: pointer;
}

.amis-scope .a-LocationPicker:not(.is-disabled):hover {
  background: var(--DatePicker-onHover-bg);
  border-color: var(--DatePicker-onHover-borderColor);
}

.amis-scope .a-LocationPicker:not(.is-disabled):hover .a-DatePicker-toggler:before {
  color: var(--DatePicker-onHover-iconColor);
}

.amis-scope .a-LocationPicker.is-focused,
.amis-scope .a-LocationPicker.is-active {
  border-color: var(--DatePicker-onFocused-borderColor);
  box-shadow: var(--Form-input-boxShadow);
}

.amis-scope .a-LocationPicker.is-disabled {
  background: #e5e7eb;
}

.amis-scope .a-LocationPicker.is-disabled > a-LocationPicker-input {
  color: var(--text--muted-color);
}

.amis-scope .a-LocationPicker-placeholder {
  color: var(--DatePicker-placeholderColor);
  user-select: none;
  margin-right: var(--gap-base);
  flex-basis: 0;
  flex-grow: 1;
}

.amis-scope .a-LocationPicker-value {
  margin-right: var(--gap-base);
  flex-basis: 0;
  flex-grow: 1;
}

.amis-scope .a-LocationPicker-toggler {
  cursor: pointer;
  color: var(--DatePicker-iconColor);
}

.amis-scope .a-LocationPicker-toggler:hover {
  color: var(--DatePicker-onHover-iconColor);
}

.amis-scope .a-LocationPicker-clear {
  display: inline-block;
  padding: 0.1875rem;
  cursor: pointer;
  display: flex;
  align-items: center;
  justify-content: center;
  margin-left: auto;
  line-height: 1;
  margin-right: var(--gap-xs);
}

.amis-scope .a-LocationPicker-clear svg {
  fill: var(--Form-input-iconColor);
  top: 0;
  width: 0.625rem;
  height: 0.625rem;
}

.amis-scope .a-LocationPicker-clear:hover svg {
  fill: var(--Form-input-onHover-iconColor);
}

.amis-scope .a-LocationControl {
  position: relative;
  width: 100%;
}

.amis-scope .a-LocationControl:not(.is-inline) > .a-LocationPicker {
  display: flex;
}

.amis-scope .a-LocationPicker-popover {
  min-width: 320px;
  width: 100%;
  max-width: 100%;
  margin-top: -1px;
  border-color: var(--Form-input-onFocused-borderColor);
}

.amis-scope .a-MapPicker-search {
  padding: 5px 10px;
}

.amis-scope .a-MapPicker-map {
  display: block;
  width: 100%;
  height: 200px;
}

.amis-scope .a-MapPicker-item {
  padding: 10px 10px;
  position: relative;
  border-top: 1px solid var(--borderColor);
}

.amis-scope .a-MapPicker-item > svg {
  position: absolute;
  right: 20px;
  top: 50%;
  transform: translateY(-50%);
}

.amis-scope .a-MapPicker-itemTitle {
  font-size: var(--fontSizeBase);
}

.amis-scope .a-MapPicker-itemDesc {
  font-size: var(--fontSizeSm);
}

.amis-scope .a-MapPicker-sugItem {
  cursor: pointer;
  padding: calc( ( var(--Form-select-menu-height) - var(--Form-input-lineHeight) * var(--Form-input-fontSize) ) / 2 ) var(--Form-select-paddingX);
}

.amis-scope .a-MapPicker-sugItem:hover {
  color: var(--Form-select-menu-onActive-color);
  background: var(--Form-select-menu-onActive-bg);
}

.amis-scope .tangram-suggestion-main {
  display: none !important;
}

.amis-scope .a-MatrixControl-error {
  margin-bottom: 0;
}

.amis-scope .a-ColorPicker {
  position: relative;
  display: inline-flex;
  flex-wrap: nowrap;
  white-space: nowrap;
  border: var(--ColorPicker-borderWidth) solid var(--ColorPicker-borderColor);
  font-size: var(--ColorPicker-fontSize);
  padding: var(--ColorPicker-paddingY) var(--ColorPicker-paddingX);
  background: var(--ColorPicker-bg);
  color: var(--ColorPicker-color);
}

.amis-scope .a-ColorPicker:not(.is-disabled) {
  cursor: pointer;
}

.amis-scope .a-ColorPicker:not(.is-disabled):hover {
  background: var(--ColorPicker-onHover-bg);
  border-color: var(--ColorPicker-onHover-borderColor);
}

.amis-scope .a-ColorPicker-input {
  border: 0;
  background: transparent;
  outline: none;
  width: 100%;
  flex-basis: 0;
  flex-grow: 1;
  padding: 0;
  margin: 0;
  height: calc(var(--ColorPicker-fontSize) * var(--ColorPicker-lineHeight));
}

.amis-scope .a-ColorPicker-input::placeholder {
  color: var(--ColorPicker-placeholderColor);
}

.amis-scope .a-ColorPicker.is-focused {
  border-color: var(--ColorPicker-onFocused-borderColor);
  box-shadow: var(--Form-input-boxShadow);
}

.amis-scope .a-ColorPicker.is-disabled {
  background: var(--ColorPicker-onDisabled-bg);
  color: var(--ColorPicker-onDisabled-color);
  pointer-events: none;
}

.amis-scope .a-ColorPicker.is-disabled > .a-ColorPicker-input {
  color: var(--ColorPicker-onDisabled-color);
}

.amis-scope .a-ColorPicker.is-disabled > .a-ColorPicker-input::placeholder {
  color: var(--ColorPicker-onDisabled-color);
}

.amis-scope .a-ColorPicker-preview {
  display: flex;
  align-items: center;
  margin-left: var(--gap-xs);
  cursor: pointer;
}

.amis-scope .a-ColorPicker-previewIcon {
  display: block;
  width: 1rem;
  height: 1rem;
  box-shadow: var(--boxShadowSm);
}

.amis-scope .a-ColorPicker-clear {
  padding: 0.1875rem;
  cursor: pointer;
  display: flex;
  align-items: center;
  justify-content: center;
  margin-left: auto;
  display: inline-block;
  line-height: 1;
}

.amis-scope .a-ColorPicker-clear svg {
  fill: var(--Form-input-iconColor);
  top: 0;
  width: 0.625rem;
  height: 0.625rem;
}

.amis-scope .a-ColorPicker-clear:hover svg {
  fill: var(--Form-input-onHover-iconColor);
}

.amis-scope .a-ColorControl:not(.is-inline) > .a-ColorPicker {
  display: flex;
}

.amis-scope .sketch-picker {
  box-shadow: none !important;
  border-radius: 0 !important;
  border: none !important;
}

.amis-scope .a-DatePicker {
  position: relative;
  display: inline-flex;
  flex-wrap: nowrap;
  border: var(--DatePicker-borderWidth) solid var(--DatePicker-borderColor);
  font-size: var(--DatePicker-fontSize);
  padding: var(--DatePicker-paddingY) var(--DatePicker-paddingX);
  height: var(--DatePicker-height);
  outline: none;
  white-space: nowrap;
  color: var(--DatePicker-color);
  background: var(--DatePicker-bg);
  border-radius: var(--DatePicker-borderRadius);
}

.amis-scope .a-DatePicker--borderHalf {
  border-left-color: transparent !important;
  border-right-color: transparent !important;
  border-top-color: transparent !important;
}

.amis-scope .a-DatePicker--borderNone {
  border-color: transparent !important;
}

.amis-scope .a-DatePicker:not(.is-disabled) {
  cursor: pointer;
}

.amis-scope .a-DatePicker:not(.is-disabled):hover {
  background: var(--DatePicker-onHover-bg);
  border-color: var(--DatePicker-onHover-borderColor);
}

.amis-scope .a-DatePicker:not(.is-disabled):hover .a-DatePicker-toggler:before {
  color: var(--DatePicker-onHover-iconColor);
}

.amis-scope .a-DatePicker.is-focused {
  border-color: var(--DatePicker-onFocused-borderColor);
  box-shadow: var(--Form-input-boxShadow);
}

.amis-scope .a-DatePicker.is-disabled {
  background: #e5e7eb;
}

.amis-scope .a-DatePicker.is-disabled > .a-DatePicker-input {
  color: var(--text--muted-color);
}

.amis-scope .a-DatePicker-placeholder {
  color: var(--DatePicker-placeholderColor);
  user-select: none;
  margin-right: var(--gap-base);
  min-width: 3.125rem;
  flex-basis: 0;
  flex-grow: 1;
}

.amis-scope .a-DatePicker-value {
  margin-right: var(--gap-base);
  flex-basis: 0;
  flex-grow: 1;
}

.amis-scope .a-DatePicker-toggler {
  cursor: pointer;
  color: var(--DatePicker-iconColor);
}

.amis-scope .a-DatePicker-toggler:hover {
  color: var(--DatePicker-onHover-iconColor);
}

.amis-scope .a-DatePicker-clear {
  display: inline-block;
  padding: 0.1875rem;
  cursor: pointer;
  display: flex;
  align-items: center;
  justify-content: center;
  margin-left: auto;
  line-height: 1;
  margin-right: var(--gap-xs);
}

.amis-scope .a-DatePicker-clear svg {
  fill: var(--Form-input-iconColor);
  top: 0;
  width: 0.625rem;
  height: 0.625rem;
}

.amis-scope .a-DatePicker-clear:hover svg {
  fill: var(--Form-input-onHover-iconColor);
}

.amis-scope .a-DateControl:not(.is-inline) > .a-DatePicker {
  display: flex;
}

.amis-scope .a-DatePicker-shortcuts {
  margin: 0;
  background: var(--Calendar-shortcuts-bg);
  padding: calc( ( var(--Calendar-shortcuts-height) - var(--Calendar-fontSize) * var(--lineHeightBase) ) / 2 ) var(--gap-sm);
  list-style: none;
  width: 15.625rem;
}

.amis-scope .a-DatePicker-shortcuts + .rdt .rdtPicker {
  padding-top: 0;
}

.amis-scope .a-DatePicker-shortcut {
  display: inline-block;
  margin-right: var(--gap-sm);
}

.amis-scope .a-DatePicker-shortcut a {
  font-size: var(--Calendar-fontSize);
  cursor: pointer;
  color: var(--Calendar-shortcut-color);
  text-decoration: var(--Calendar-shortcut-decoration);
}

.amis-scope .a-DatePicker-shortcut a:hover {
  color: var(--Calendar-shortcut-onHover-color);
  text-decoration: var(--Calendar-shortcut-onHover-decoration);
}

.amis-scope .a-DatePicker-popover {
  margin: 0.125rem 0 0;
}

.amis-scope .a-DatePicker-popover.a-PopOver--leftTopLeftBottom,
.amis-scope .a-DatePicker-popover.a-PopOver--rightTopRightBottom {
  margin: -0.125rem 0 0;
}

.amis-scope .rdt {
  user-select: none;
  font-size: var(--Calendar-fontSize);
  color: var(--Calendar-color);
}

.amis-scope .rdt .rdtPicker {
  margin-top: 0;
  padding: var(--gap-sm);
  background: transparent;
  border: none;
}

.amis-scope .rdt .rdtPicker .dow {
  color: var(--Calendar-wLabel-color);
  font-weight: normal;
}

.amis-scope .rdt .rdtPicker td.rdtDay,
.amis-scope .rdt .rdtPicker td.rdtHour,
.amis-scope .rdt .rdtPicker td.rdtMinute,
.amis-scope .rdt .rdtPicker td.rdtSecond,
.amis-scope .rdt .rdtPicker .rdtTimeToggle {
  background: var(--Calendar-cell-bg);
}

.amis-scope .rdt .rdtPicker td.rdtDay:hover,
.amis-scope .rdt .rdtPicker td.rdtHour:hover,
.amis-scope .rdt .rdtPicker td.rdtMinute:hover,
.amis-scope .rdt .rdtPicker td.rdtSecond:hover,
.amis-scope .rdt .rdtPicker .rdtTimeToggle:hover {
  background: var(--Calendar-cell-onHover-bg);
}

.amis-scope .rdt .rdtPicker td.rdtBetween {
  background: var(--Calendar-cell-onBetween-bg);
}

.amis-scope .rdt .rdtPicker td.rdtToday:before {
  border-bottom-color: var(--Calendar-cell-onActive-bg);
}

.amis-scope .rdt .rdtPicker td.rdtActive.rdtToday:before {
  border-bottom-color: var(--Calendar-cell-bg);
}

.amis-scope .rdt .rdtPicker td.rdtActive,
.amis-scope .rdt .rdtPicker td.rdtActive:hover {
  background: var(--Calendar-cell-onActive-bg);
}

.amis-scope .rdt .rdtPicker td.rdtDisabled,
.amis-scope .rdt .rdtPicker td.rdtDisabled:hover {
  background: var(--Calendar-cell-onDisabled-bg);
}

.amis-scope .rdt thead tr:first-child th {
  cursor: default;
  font-weight: normal;
  border-bottom: none;
}

.amis-scope .rdt thead tr:first-child th:hover {
  background: transparent;
}

.amis-scope .rdt tfoot {
  border-top: 0;
}

.amis-scope .rdt tfoot td {
  padding-top: var(--gap-xs);
  text-align: left;
}

.amis-scope .rdt tfoot td span {
  width: 10px;
  display: inline-block;
  text-align: center;
}

.amis-scope .rdt tfoot td .rdtActions {
  margin-top: var(--gap-sm);
  text-align: right;
}

.amis-scope .a-CalendarInputWrapper {
  display: inline-block;
  position: relative;
}

.amis-scope .a-CalendarInputWrapper .a-CalendarInput-sugs {
  list-style: none;
  position: absolute;
  background: var(--Form-select-menu-bg);
  color: var(--Form-select-menu-color);
  border: var(--Form-input-borderWidth) solid var(--Form-input-onFocused-borderColor);
  left: -0.0625rem;
  right: -0.0625rem;
  top: 100%;
  z-index: 10;
  max-height: 12.5rem;
  overflow: auto;
}

.amis-scope .a-CalendarInputWrapper .a-CalendarInput-sugsItem {
  padding-left: 4px;
}

.amis-scope .a-CalendarInputWrapper .a-CalendarInput-sugsItem.is-highlight,
.amis-scope .a-CalendarInputWrapper .a-CalendarInput-sugsItem:hover {
  color: var(--Form-select-menu-onHover-color);
  background: var(--Form-select-menu-onHover-bg);
}

.amis-scope .a-CalendarInput {
  outline: none;
  width: 40px;
  font-size: var(--Calendar-input-fontSize);
  color: var(--Calendar-input-color);
  border: 1px solid var(--Calendar-input-borderColor);
  border-radius: var(--Calendar-input-borderRadius);
  height: var(--Calendar-input-height);
  line-height: var(--Calendar-input-lineHeight);
  padding: var(--Calendar-input-paddingY) var(--Calendar-input-paddingX);
  box-shadow: none;
}

.amis-scope .a-CalendarInput:focus {
  border-color: var(--Calendar-input-onFocused-borderColor);
  box-shadow: none;
}

.amis-scope .a-CalendarTime {
  display: flex;
  flex-direction: row;
  justify-content: center;
  align-items: center;
}

.amis-scope .a-CalendarCounter-btn {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 25px;
  text-align: center;
  color: var(--Button--primary-bg);
}

.amis-scope .a-CalendarCounter-btn:hover {
  color: var(--Button--primary-onActive-bg);
}

.amis-scope .a-CalendarCounter-btn > svg {
  width: 16px;
  height: 16px;
}

.amis-scope .a-CalendarCounter-btn--up > svg {
  transform: rotate(-90deg);
}

.amis-scope .a-CalendarCounter-btn--down > svg {
  transform: rotate(90deg);
}

.amis-scope .a-CalendarCounter-sep {
  width: var(--gap-md);
  text-align: center;
}

.amis-scope .a-CalendarCounter--daypart {
  margin-left: 10px;
}

.amis-scope .a-CalendarCounter--daypart .a-CalendarCounter-value {
  height: 30px;
  display: flex;
  align-items: center;
  padding: 0 5px;
}

.amis-scope .rdtBtn {
  line-height: var(--Calendar-btn-lineHeight);
  padding: var(--Calendar-btn-paddingY) var(--Calendar-btn-paddingX);
  display: inline-block;
  vertical-align: middle;
  text-align: center;
  user-select: none;
  cursor: pointer;
  text-decoration: none;
  font-size: var(--Calendar-btn-fontSize);
  border: 1px solid var(--Calendar-btn-border);
  color: var(--Calendar-btn-color);
  background: var(--Calendar-btn-bg);
  border-color: var(--Calendar-btn-border);
  box-shadow: var(--Button-boxShadow);
  text-shadow: var(--Button-textShadow);
  border-radius: var(--Calendar-btn-borderRadius);
}

.amis-scope .rdtBtn:hover {
  text-decoration: none;
}

.amis-scope .rdtBtn.is-disabled {
  border-color: var(--Button-onDisabled-borderColor);
  opacity: 0.6;
  pointer-events: none;
}

.amis-scope .rdtBtn .fa,
.amis-scope .rdtBtn .iconfont {
  font-size: var(--fontSizeSm);
}

.amis-scope .rdtBtn:not(:disabled):not(.is-disabled):hover {
  color: var(--Calendar-btn-onHover-color);
  background: var(--Calendar-btn-onHover-bg);
  border-color: var(--Calendar-btn-onHover-border);
}

.amis-scope .rdtBtn:hover:focus {
  box-shadow: var(--Button-boxShadow);
}

.amis-scope .rdtBtn + .rdtBtn {
  margin-left: var(--gap-xs);
}

.amis-scope .rdtBtnCancel {
  color: var(--Calendar-btnCancel-color);
  background: var(--Calendar-btnCancel-bg);
  border-color: var(--Calendar-btnCancel-border);
  box-shadow: var(--Button-boxShadow);
  text-shadow: var(--Button-textShadow);
}

.amis-scope .rdtBtnCancel:not(:disabled):not(.is-disabled):hover {
  color: var(--Calendar-btnCancel-onHover-color);
  background: var(--Calendar-btnCancel-onHover-bg);
  border-color: var(--Calendar-btnCancel-onHover-border);
}

.amis-scope .rdtBtnCancel:hover:focus {
  box-shadow: var(--Button-boxShadow);
}

.amis-scope .rdtBtnPrev:before,
.amis-scope .rdtBtnNext:before {
  display: inline-block;
  color: inherit;
  font-style: normal;
  line-height: 1;
}

.amis-scope .rdtPrev,
.amis-scope .rdtNext {
  cursor: pointer !important;
  width: var(--gap-md);
  padding: 0;
  color: #999;
  font-size: var(--fontSizeXl);
  text-decoration: none;
  font-family: auto;
  font-weight: normal;
}

.amis-scope .rdtPrev:hover,
.amis-scope .rdtNext:hover {
  text-decoration: none;
  color: #000;
}

.amis-scope .rdtSwitch {
  text-align: center;
  color: #000;
  cursor: pointer;
  font-weight: normal;
}

.amis-scope .rdtSwitch:hover {
  color: var(--link-onHover-color);
  text-decoration: none;
}

.amis-scope .rdtHeader {
  display: table;
  table-layout: fixed;
  border-collapse: separate;
  width: 100%;
}

.amis-scope .rdtHeader > * {
  display: table-cell;
  vertical-align: middle;
  text-align: center;
}

.amis-scope .rdtHeader .rdtSwitch + .rdtSwitch {
  margin-left: var(--gap-xs);
}

.amis-scope td.rdtMonth,
.amis-scope td.rdtYear,
.amis-scope td.rdtQuarter {
  width: 3.125rem;
  height: 2.5rem;
}

.amis-scope td.rdtMonth > span,
.amis-scope td.rdtYear > span,
.amis-scope td.rdtQuarter > span {
  height: 1.5rem;
  display: block;
}

.amis-scope td.rdtMonth.rdtBetween,
.amis-scope td.rdtYear.rdtBetween,
.amis-scope td.rdtQuarter.rdtBetween {
  background: transparent !important;
}

.amis-scope td.rdtMonth.rdtBetween > span,
.amis-scope td.rdtYear.rdtBetween > span,
.amis-scope td.rdtQuarter.rdtBetween > span {
  background: var(--Calendar-cell-onBetween-bg);
}

.amis-scope td.rdtMonth:hover,
.amis-scope td.rdtMonth.rdtActive,
.amis-scope td.rdtYear:hover,
.amis-scope td.rdtYear.rdtActive,
.amis-scope td.rdtQuarter:hover,
.amis-scope td.rdtQuarter.rdtActive {
  background: transparent !important;
}

.amis-scope td.rdtMonth:hover > span,
.amis-scope td.rdtMonth.rdtActive > span,
.amis-scope td.rdtYear:hover > span,
.amis-scope td.rdtYear.rdtActive > span,
.amis-scope td.rdtQuarter:hover > span,
.amis-scope td.rdtQuarter.rdtActive > span {
  background: var(--info);
  color: var(--white);
}

.amis-scope td.rdtMonth.rdtDisabled,
.amis-scope td.rdtYear.rdtDisabled,
.amis-scope td.rdtQuarter.rdtDisabled {
  background: transparent !important;
}

.amis-scope td.rdtMonth.rdtDisabled > span,
.amis-scope td.rdtYear.rdtDisabled > span,
.amis-scope td.rdtQuarter.rdtDisabled > span {
  background: #edf1f2;
  color: #999;
}

.amis-scope .a-DateCalendar {
  display: inline-block;
  border: var(--DatePicker-borderWidth) solid var(--DatePicker-borderColor);
  background: var(--DatePicker-bg);
  border-radius: var(--DatePicker-borderRadius);
}

.amis-scope .a-DateRangePicker {
  position: relative;
  display: inline-flex;
  flex-wrap: nowrap;
  border: var(--DatePicker-borderWidth) solid var(--DatePicker-borderColor);
  font-size: var(--DatePicker-fontSize);
  padding: var(--DatePicker-paddingY) var(--DatePicker-paddingX);
  height: var(--DatePicker-height);
  outline: none;
  border-radius: var(--DatePicker-borderRadius);
  color: var(--DatePicker-color);
  background: var(--DatePicker-bg);
}

.amis-scope .a-DateRangePicker--borderHalf {
  border-left-color: transparent !important;
  border-right-color: transparent !important;
  border-top-color: transparent !important;
}

.amis-scope .a-DateRangePicker--borderNone {
  border-color: transparent !important;
}

.amis-scope .a-DateRangePicker:not(.is-disabled) {
  cursor: pointer;
}

.amis-scope .a-DateRangePicker:not(.is-disabled):hover {
  background: var(--DatePicker-onHover-bg);
  border-color: var(--DatePicker-onHover-borderColor);
}

.amis-scope .a-DateRangePicker:not(.is-disabled):hover .a-DateRangePicker-toggler {
  color: var(--DatePicker-onHover-iconColor);
}

.amis-scope .a-DateRangePicker.is-focused {
  border-color: var(--DatePicker-onFocused-borderColor);
  box-shadow: var(--Form-input-boxShadow);
}

.amis-scope .a-DateRangePicker.is-disabled {
  background: #e5e7eb;
}

.amis-scope .a-DateRangePicker.is-disabled > .a-DateRangePicker-input {
  color: var(--text--muted-color);
}

.amis-scope .a-DateRangePicker-placeholder {
  color: var(--DatePicker-placeholderColor);
  user-select: none;
  margin-right: var(--gap-base);
  flex-basis: 0;
  flex-grow: 1;
}

.amis-scope .a-DateRangePicker-value {
  margin-right: var(--gap-base);
  flex-basis: 0;
  flex-grow: 1;
}

.amis-scope .a-DateRangePicker-toggler {
  cursor: pointer;
  color: var(--DatePicker-iconColor);
}

.amis-scope .a-DateRangePicker-toggler:hover {
  color: var(--DatePicker-onHover-iconColor);
}

.amis-scope .a-DateRangePicker-clear {
  padding: 0.1875rem;
  cursor: pointer;
  display: flex;
  align-items: center;
  justify-content: center;
  margin-left: auto;
  display: inline-block;
  line-height: 1;
  margin-right: var(--gap-xs);
}

.amis-scope .a-DateRangePicker-clear svg {
  fill: var(--Form-input-iconColor);
  top: 0;
  width: 0.625rem;
  height: 0.625rem;
}

.amis-scope .a-DateRangePicker-clear:hover svg {
  fill: var(--Form-input-onHover-iconColor);
}

.amis-scope .a-DateRangePicker-wrap {
  width: auto;
  padding: var(--gap-sm);
}

.amis-scope .a-DateRangePicker-start,
.amis-scope .a-DateRangePicker-end {
  display: inline-block;
  vertical-align: top;
}

.amis-scope .a-DateRangePicker-start .rdtPicker,
.amis-scope .a-DateRangePicker-end .rdtPicker {
  padding: 0;
  box-shadow: none;
  border: none;
}

.amis-scope .a-DateRangePicker-end {
  margin-top: 20px;
}

.amis-scope .a-DateRangePicker-rangers {
  margin: 0 0 var(--gap-sm);
  padding: 0;
  list-style: none;
}

.amis-scope .a-DateRangePicker-ranger {
  display: inline-block;
  margin-right: var(--gap-sm);
}

.amis-scope .a-DateRangePicker-ranger a {
  cursor: pointer;
}

.amis-scope .a-DateRangePicker-actions {
  text-align: right;
  margin-top: var(--gap-sm);
}

.amis-scope .a-DateRangeControl:not(.is-inline) > .a-DateRangePicker {
  display: flex;
}

.amis-scope .a-DateRangePicker-popover {
  margin: 0.125rem 0 0;
}

.amis-scope .a-DateRangePicker-popover.a-PopOver--leftTopLeftBottom,
.amis-scope .a-DateRangePicker-popover.a-PopOver--rightTopRightBottom {
  margin: -0.125rem 0 0;
}

@media (min-width: 576px) {
  .amis-scope .a-DateRangePicker-wrap {
    white-space: nowrap;
  }

  .amis-scope .a-DateRangePicker-end {
    margin-top: 0;
    margin-left: var(--gap-sm);
  }
}

.amis-scope .a-DateRangeCalendar {
  display: inline-block;
  border: var(--DatePicker-borderWidth) solid var(--DatePicker-borderColor);
  background: var(--DatePicker-bg);
  border-radius: var(--DatePicker-borderRadius);
}

.amis-scope .a-ImageControl {
  position: relative;
}

.amis-scope .a-ImageControl-dropzone {
  outline: none;
}

.amis-scope .a-ImageControl-addBtn {
  margin: 0;
  width: 7.5rem;
  height: 7.5rem;
  display: inline-flex;
  justify-content: center;
  align-items: center;
  border: var(--borderWidth) solid var(--borderColor);
  cursor: pointer;
  margin-right: var(--gap-base);
  color: var(--ImageControl-addBtn-color);
  background: var(--ImageControl-addBtn-bg);
  border-color: var(--ImageControl-addBtn-border);
  box-shadow: var(--Button-boxShadow);
  text-shadow: var(--Button-textShadow);
}

.amis-scope .a-ImageControl-addBtn:not(:disabled):not(.is-disabled):hover {
  color: var(--ImageControl-addBtn-onHover-color);
  background: var(--ImageControl-addBtn-onHover-bg);
  border-color: var(--ImageControl-addBtn-onHover-border);
}

.amis-scope .a-ImageControl-addBtn:hover:focus {
  box-shadow: var(--Button-boxShadow);
}

.amis-scope .a-ImageControl-addBtn > svg {
  width: 2.5rem;
  height: 2.5rem;
  top: 0;
}

.amis-scope .a-ImageControl-addBtn.is-disabled {
  pointer-events: none;
  border: 0.0625rem solid var(--ImageControl-addBtn-onDisabled-border);
  background: var(--ImageControl-addBtn-onDisabled-bg);
  color: var(--ImageControl-addBtn-onDisabled-color);
}

.amis-scope .a-ImageControl-pasteTip {
  pointer-events: none;
  left: 0;
  top: 50%;
  transform: translateY(-50%);
  position: absolute;
  font-size: var(--Tooltip--attr-fontSize);
  line-height: var(--Tooltip--attr-lineHeigt);
  text-align: left;
  white-space: nowrap;
  background: var(--Tooltip--attr-bg);
  border: var(--Tooltip--attr-borderWidth) solid var(--Tooltip--attr-borderColor);
  border-radius: var(--Tooltip--attr-borderRadius);
  box-shadow: var(--Tooltip--attr-boxShadow);
  left: 100%;
  color: var(--Tooltip--attr-color);
  padding: var(--Tooltip--attr-paddingY) var(--Tooltip--attr-paddingX);
  margin: 30px 0 0 var(--Tooltip--attr-gap);
}

.amis-scope .a-ImageControl-dropzone:focus .a-ImageControl-addBtn {
  border-color: var(--ImageControl-addBtn-onHover-border);
  background: var(--ImageControl-addBtn-onHover-bg);
  color: var(--ImageControl-addBtn-onHover-color);
}

.amis-scope .a-ImageControl-item {
  border: var(--borderWidth) solid var(--borderColor);
  vertical-align: top;
  padding: var(--gap-xs);
  display: inline-block;
  margin-right: var(--gap-base);
  margin-bottom: var(--gap-base);
  position: relative;
  width: 7.5rem;
}

.amis-scope .a-ImageControl-image {
  width: 100%;
  height: 100%;
  padding: 0;
  border: none;
  display: block;
}

.amis-scope .a-ImageControl-itemClear {
  position: absolute;
  cursor: pointer;
  color: #999;
  top: 5px;
  right: 5px;
  line-height: 1;
}

.amis-scope .a-ImageControl-itemClear > svg {
  top: 0;
  width: 10px;
  height: 10px;
}

.amis-scope .a-ImageControl-itemInfo {
  display: inline-flex;
  width: 110px;
  height: 110px;
  justify-content: center;
  align-items: center;
  align-content: center;
  flex-wrap: wrap;
}

.amis-scope .a-ImageControl-itemInfo > p {
  width: 100%;
  text-align: center;
  font-size: 12px;
  margin-bottom: 5px;
}

.amis-scope .a-ImageControl-progress {
  width: 70px;
  height: 5px;
  background: #ebebeb;
}

.amis-scope .a-ImageControl-progressValue {
  height: 5px;
  display: block;
  background: var(--info);
  min-width: 10%;
  transition: ease-out width var(--animation-duration);
}

.amis-scope .a-ImageControl-item.is-invalid .a-ImageControl-itemClear {
  display: none;
}

.amis-scope .a-ImageControl-item.is-invalid:hover .a-ImageControl-itemClear {
  display: block;
}

.amis-scope .a-ImageControl-retryBtn {
  margin: 0;
  width: 6.875rem;
  height: 6.875rem;
  display: inline-flex;
  cursor: pointer;
  justify-content: center;
  align-items: center;
  align-content: center;
  flex-wrap: wrap;
  color: #666;
}

.amis-scope .a-ImageControl-retryBtn:hover {
  color: #333;
  text-decoration: none;
}

.amis-scope .a-ImageControl-retryBtn > p {
  width: 100%;
  text-align: center;
  color: var(--danger);
  margin: 10px 0 0;
}

.amis-scope .a-ImageControl-errorMsg {
  color: var(--danger);
  margin: 5px 0 0;
}

.amis-scope .a-ImageControl-uploadBtn {
  margin-top: 5px;
}

.amis-scope .a-ImageControl-cropperWrapper {
  position: relative;
}

.amis-scope .a-ImageControl-cropperWrapper img {
  max-width: 100%;
  max-height: 400px;
}

.amis-scope .a-ImageControl-croperToolbar {
  display: inline-flex;
  width: 50px;
  position: absolute;
  right: 0;
  bottom: 0;
  flex-direction: column;
  align-items: flex-end;
}

.amis-scope .a-ImageControl-croperToolbar > a {
  color: #fff;
  padding: 2px 5px;
  cursor: pointer;
  font-size: 20px;
}

.amis-scope .a-ImageControl-croperToolbar > a .icon-retry polygon {
  fill: #fff;
}

.amis-scope .a-ImageControl-croperToolbar > a .icon-retry path {
  stroke: #fff;
}

.amis-scope .a-ImageControl-acceptTip {
  height: 120px;
  color: #999;
  border: 2px dashed var(--borderColor);
  border-color: var(--info);
  background: #f3f9fe;
  border-radius: var(--borderRadius);
  line-height: 120px;
  text-align: center;
}

.amis-scope .a-ImageControl-fixed-size {
  width: 100%;
  height: 100%;
  padding: 0;
}

.amis-scope .a-ImageControl-fixed-size .a-ImageControl-itemOverlay {
  width: 100%;
  height: 100%;
}

.amis-scope .a-FileControl-dropzone {
  outline: none;
}

.amis-scope .a-FileControl-selectBtn {
  width: 7.5rem;
}

.amis-scope .a-FileControl-selectBtn > svg {
  margin-right: 10px;
  width: pxrem(16px);
  height: pxrem(16px);
}

.amis-scope .a-FileControl-description {
  margin-left: 10px;
  color: #999;
  font-size: 12px;
}

.amis-scope .a-FileControl-list {
  list-style: none;
  margin: 10px 0;
  padding: 0;
}

.amis-scope .a-FileControl-list > li {
  color: #333;
  font-size: 12px;
}

.amis-scope .a-FileControl-list > li:hover {
  color: #108cee;
  background: #f3f3f3;
}

.amis-scope .a-FileControl-itemInfo {
  padding: 0px 6px;
  line-height: 26px;
  height: auto;
}

.amis-scope .a-FileControl-itemInfo span {
  word-break: break-all;
}

.amis-scope .a-FileControl-itemInfo.is-invalid {
  color: #999;
}

.amis-scope .a-FileControl-itemInfo > svg:first-child {
  margin-right: 10px;
}

.amis-scope .a-FileControl-itemInfo > svg:not(:first-child) {
  margin-left: 10px;
  width: 1rem;
  height: 1rem;
  top: var(--gap-xs);
}

.amis-scope .a-FileControl-itemInfoText {
  white-space: nowrap;
  max-width: 170px;
  overflow: hidden;
  text-overflow: ellipsis;
  display: inline-block;
  vertical-align: middle;
}

.amis-scope .a-FileControl-clear {
  float: right;
  color: #999;
  display: none;
  cursor: pointer;
}

.amis-scope .a-FileControl-clear:hover {
  color: #333;
}

.amis-scope .a-FileControl-list:empty {
  display: none;
}

.amis-scope .a-FileControl-list > li:hover .a-FileControl-clear {
  display: block;
}

.amis-scope .a-FileControl-progressInfo {
  display: inline-flex;
  height: 20px;
  padding: 0 6px;
  transform: translateY(-3px);
  width: 100%;
  align-items: center;
  white-space: nowrap;
  text-overflow: ellipsis;
}

.amis-scope .a-FileControl-progressInfo > span {
  display: inline-block;
  padding: 0 4px 0 10px;
  font-size: 12px;
}

.amis-scope .a-FileControl-progressInfo > svg {
  display: inline-block;
  margin: 0 4px 0 10px;
  width: 14px;
  height: 14px;
  top: 0;
}

.amis-scope .a-FileControl-progress {
  height: 5px;
  flex: 1;
  background: #ebebeb;
}

.amis-scope .a-FileControl-progress > span {
  display: block;
  background: var(--info);
  height: 100%;
  min-width: 10%;
  transition: ease-out width var(--animation-duration);
}

.amis-scope .a-FileControl-acceptTip {
  height: 120px;
  color: #999;
  border: 2px dashed var(--info);
  border-radius: var(--borderRadius);
  background: #f3f9fe;
  line-height: 120px;
  text-align: center;
}

.amis-scope .a-FileControl-sum {
  font-size: var(--fontSizeSm);
}

.amis-scope .a-FileControl-sum > a {
  cursor: pointer;
}

.amis-scope .a-ExcelControl-container {
  display: flex;
  flex-direction: column;
  font-family: sans-serif;
  cursor: pointer;
}

.amis-scope .a-ExcelControl-container > p {
  font-size: 1rem;
}

.amis-scope .a-ExcelControl-container > em {
  font-size: 0.8rem;
}

.amis-scope .a-ExcelControl-dropzone {
  flex: 1;
  display: flex;
  flex-direction: column;
  align-items: center;
  padding: var(--gap-md);
  border-width: 2px;
  border-radius: 2px;
  border-color: #eeeeee;
  border-style: dashed;
  background-color: #fafafa;
  color: #bdbdbd;
  outline: none;
  transition: border 0.24s ease-in-out;
}

.amis-scope .a-ExcelControl-dropzone:focus {
  border-color: var(--primary);
}

.amis-scope .a-ExcelControl-dropzone.disabled {
  opacity: 0.6;
}

.amis-scope .a-EditorControl {
  min-height: 12.5rem;
  max-height: 25rem;
  overflow: visible;
  height: auto;
  border: var(--Form-input-borderWidth) solid var(--Form-input-borderColor);
  max-width: 100%;
  box-sizing: content-box;
}

.amis-scope .a-EditorControl > .a-MonacoEditor,
.amis-scope .a-EditorControl > .a-MonacoEditor > .monaco-diff-editor {
  min-height: 12.375rem;
}

.amis-scope .a-EditorControl.is-error {
  border-color: var(--Form-input-onError-borderColor);
}

.amis-scope .a-EditorControl.is-focused {
  border-color: var(--Form-input-onFocused-borderColor);
}

.amis-scope .a-EditorControl .a-MonacoEditor {
  position: relative;
}

.amis-scope .a-EditorControl .a-MonacoEditor-header {
  position: absolute;
  right: 0.875rem;
  top: 0;
  padding: 0;
  width: 1.125rem;
  height: 1.125rem;
  z-index: 5;
  display: flex;
  flex-flow: row nowrap;
  justify-content: center;
  align-items: center;
  background: var(--Modal-header-bg);
  box-sizing: border-box;
}

.amis-scope .a-EditorControl .a-MonacoEditor-fullscreen {
  cursor: pointer;
  color: var(--Modal-close-color);
  line-height: inherit;
  text-decoration: none;
  text-align: center;
  vertical-align: middle;
}

.amis-scope .a-EditorControl .a-MonacoEditor-fullscreen:hover {
  color: var(--Model-close-onHover-color);
}

.amis-scope .a-EditorControl .a-MonacoEditor-fullscreen:hover svg {
  fill: var(--Model-close-onHover-color);
}

.amis-scope .a-EditorControl--sm {
  min-height: 100px;
}

.amis-scope .a-EditorControl--sm > .a-MonacoEditor {
  min-height: 100px;
}

.amis-scope .a-EditorControl--md {
  min-height: 250px;
}

.amis-scope .a-EditorControl--md > .a-MonacoEditor {
  min-height: 250px;
}

.amis-scope .a-EditorControl--lg {
  min-height: 300px;
}

.amis-scope .a-EditorControl--lg > .a-MonacoEditor {
  min-height: 300px;
}

.amis-scope .a-EditorControl--xl {
  min-height: 400px;
}

.amis-scope .a-EditorControl--xl > .a-MonacoEditor {
  min-height: 400px;
}

.amis-scope .a-EditorControl--xxl {
  min-height: 500px;
}

.amis-scope .a-EditorControl--xxl > .a-MonacoEditor {
  min-height: 500px;
}

.monaco-inputbox > .wrapper {
  padding: 0;
}

.amis-scope .is-fullscreen {
  margin: 0 !important;
  position: fixed !important;
  top: 0;
  left: 0;
  bottom: 0;
  right: 0;
  z-index: 2147483630 !important;
  width: auto !important;
}

.fr-popup {
  z-index: 1300 !important;
}

.amis-scope .a-RichTextControl {
  min-height: 12.5rem;
  height: auto;
  border: var(--Form-input-borderWidth) solid var(--Form-input-borderColor);
  width: 100%;
}

.amis-scope .a-RichTextControl > .tox-tinymce {
  border: 0;
}

.amis-scope .a-RichTextControl > textarea {
  width: 100%;
}

.amis-scope .a-RichTextControl--borderHalf {
  border-left-color: transparent !important;
  border-right-color: transparent !important;
  border-top-color: transparent !important;
}

.amis-scope .a-RichTextControl--borderNone {
  border-color: transparent !important;
}

.amis-scope .a-RichTextControl .fr-toolbar.fr-top {
  box-shadow: none;
  border: 0;
  position: relative;
}

.amis-scope .a-RichTextControl .fr-box.fr-basic.fr-top:not(.fr-fullscreen) .fr-wrapper {
  min-height: 150px;
  max-height: 400px;
  box-shadow: none;
  overflow: auto;
  border: none;
}

.amis-scope .a-RichTextControl .second-toolbar {
  border: none;
}

.amis-scope .a-RichTextControl .fr-toolbar .fr-command.fr-btn,
.amis-scope .a-RichTextControl .fr-popup .fr-command.fr-btn {
  color: var(--Button--default-color);
}

.amis-scope .a-RichTextControl .fr-toolbar .fr-command.fr-btn.fr-active,
.amis-scope .a-RichTextControl .fr-popup .fr-command.fr-btn.fr-active {
  color: var(--info);
  background: var(--Form-select-onHover-bg);
}

.amis-scope .a-RichTextControl .fr-desktop .fr-command:hover,
.amis-scope .a-RichTextControl .fr-desktop .fr-command:focus {
  background: var(--Form-select-onHover-bg);
}

.amis-scope .a-RichTextControl .fr-toolbar .fr-command.fr-btn.fr-dropdown.fr-active,
.amis-scope .a-RichTextControl .fr-popup .fr-command.fr-btn.fr-dropdown.fr-active {
  background: var(--Form-select-onHover-bg);
}

.amis-scope .a-RichTextControl .fr-command.fr-btn + .fr-dropdown-menu .fr-dropdown-wrapper .fr-dropdown-content ul.fr-dropdown-list li a.fr-active {
  background: var(--info);
  color: #fff;
}

.amis-scope .a-RichTextControl.is-focused {
  border: var(--Form-input-borderWidth) solid var(--Form-input-onFocused-borderColor);
}

.amis-scope .a-RichTextControl .fr-box.fr-basic .fr-element {
  min-height: 150px;
}

.amis-scope .a-RichTextControl .fr-sticky-dummy {
  position: absolute;
}

.amis-scope .a-RichTextControl.is-disabled {
  border-color: var(--Form-input-onDisabled-borderColor);
  pointer-events: none;
  opacity: 0.6;
}

.amis-scope .a-RichTextControl.is-disabled .fr-box.fr-basic.fr-top .fr-wrapper {
  border-color: var(--Form-input-onDisabled-borderColor);
}

.tox-tinymce-aux {
  z-index: 3000;
}

.tox-fullscreen .tox.tox-tinymce-aux {
  z-index: 3000;
}

.amis-scope .a-RangeControl {
  position: relative;
  padding-top: 1rem;
  padding-bottom: 1.1rem;
}

.amis-scope .a-RangeControl::before,
.amis-scope .a-RangeControl::after {
  display: table;
  content: "";
}

.amis-scope .a-RangeControl::after {
  clear: both;
}

.amis-scope .a-RangeControl--withInput .a-InputRange {
  width: calc(100% - 120px);
}

.amis-scope .a-RangeControl--withInput .a-InputRange-label--mid {
  left: calc(50% - 60px);
}

.amis-scope .a-RangeControl--withInput.is-multiple .a-InputRange {
  width: calc(100% - 210px);
}

.amis-scope .a-RangeControl .a-InputRange-input {
  font-size: var(--fontSizeSm);
  position: absolute;
  right: 1.625rem;
  top: 0.75rem;
  height: 1.875rem;
}

.amis-scope .a-RangeControl .a-InputRange-input input {
  padding: 0.625rem;
  width: 4.625rem;
  height: 100%;
}

.amis-scope .a-RangeControl .a-InputRange-input input:focus {
  outline: none;
  border: var(--borderWidth) solid var(--info);
}

.amis-scope .a-RangeControl .a-InputRange-input-separator {
  display: inline-block;
  padding: 0 5px;
}

.amis-scope .a-RangeControl .a-InputRange-unit {
  position: absolute;
  right: 0.625rem;
  top: 0.4375rem;
}

.amis-scope .a-RangeControl .a-InputRange-clear {
  position: absolute;
  top: 1.125rem;
  right: 0;
  cursor: pointer;
}

.amis-scope .a-RangeControl .a-InputRange-clear svg {
  height: 1rem;
  width: 1rem;
  fill: #999;
}

.amis-scope .a-InputRange {
  height: var(--InputRange-slider-height);
  position: relative;
  width: 100%;
}

.amis-scope .a-InputRange-slider {
  appearance: none;
  background: var(--InputRange-slider-bg);
  border: var(--InputRange-slider-border);
  cursor: pointer;
  display: block;
  width: var(--InputRange-slider-width);
  height: var(--InputRange-slider-height);
  margin-left: calc(var(--InputRange-slider-width) / -2);
  margin-top: calc( var(--InputRange-slider-height) / -2 + var(--InputRange-track-height) / -2 );
  outline: none;
  position: absolute;
  z-index: 2;
  top: 50%;
  transition: var(--InputRange-slider-transition);
}

.amis-scope .a-InputRange-slider:active {
  transform: var(--InputRange-slider-onActive-transform);
}

.amis-scope .a-InputRange-slider:focus {
  box-shadow: var(--InputRange-slider-onFocus-boxShadow);
}

.amis-scope .input-range--disabled .a-InputRange-slider {
  background: var(--InputRange-slider-onDisabled-bg);
  border: var(--InputRange-slider-onDisabled-border);
  box-shadow: none;
  transform: none;
}

.amis-scope .a-InputRange-slider:before {
  content: "||";
  color: #fff;
  display: block;
  line-height: 1.375rem;
  text-align: center;
}

.amis-scope .a-InputRange-sliderContainer {
  transition: var(--InputRange-sliderContainer-transition);
}

.amis-scope .a-InputRange-label {
  color: var(--InputRange-label-color);
  font-size: var(--InputRange-label-fontSize);
  transform: translateZ(0);
  white-space: nowrap;
}

.amis-scope .a-InputRange-label--min,
.amis-scope .a-InputRange-label--max,
.amis-scope .a-InputRange-label--mid {
  bottom: var(--InputRange-label-positionBottom);
  position: absolute;
}

.amis-scope .a-InputRange-label--mid {
  left: 50%;
  bottom: calc(var(--gap-xs) * -1);
  transform: translateX(-50%);
}

.amis-scope .a-InputRange-label--max {
  right: 0;
}

.amis-scope .a-InputRange-label--value {
  position: absolute;
  display: var(--InputRange-label--value-display);
  top: var(--InputRange-label--value-positionTop);
  left: var(--InputRange-label--value-positionLeft);
}

.amis-scope .a-InputRange-track {
  background: var(--InputRange-track-bg);
  cursor: pointer;
  display: block;
  height: var(--InputRange-track-height);
  position: relative;
  transition: var(--InputRange-track-transition);
}

.amis-scope .a-InputRange.is-disabled .a-InputRange-track {
  background: var(--InputRange-track-onDisabled-bg);
}

.amis-scope .a-InputRange-track.is-active {
  background: var(--InputRange-track-onActive-bg);
}

.amis-scope .a-InputRange-track--background {
  left: 0.5rem;
  margin-top: calc(-0.5 * var(--InputRange-track-height));
  position: absolute;
  right: 0.5rem;
  top: 50%;
}

.amis-scope .a-InputRange-track--background::before,
.amis-scope .a-InputRange-track--background::after {
  content: "";
  width: 0.5rem;
  height: 100%;
  position: absolute;
  top: 0;
  background: inherit;
  z-index: 1;
}

.amis-scope .a-InputRange-track--background::before {
  left: -0.5rem;
}

.amis-scope .a-InputRange-track--background::after {
  right: -0.5rem;
}

.amis-scope .a-InputRange-track--active {
  background: var(--InputRange-track-onActive-bg);
}

.amis-scope .a-RepeatControl .repeat-btn {
  width: 5rem;
}

.amis-scope .a-RepeatControl .Select {
  display: inline-block;
  min-width: 100px;
}

.amis-scope .a-RepeatControl .input-range {
  margin-top: 0;
}

@media (min-width: 768px) {
  .amis-scope .repeat-control.form-contorl-inline,
  .amis-scope .form-group-inline .repeat-control {
    display: inline-block;
    min-width: 280px;
    width: auto;
  }
}

.amis-scope .a-TreeControl {
  border: 1px solid var(--Form-input-borderColor);
  padding: 6px 12px;
  border-radius: 2px;
  max-height: 300px;
  overflow: auto;
}

.amis-scope .a-TreeControl.h-full {
  max-height: none;
  overflow: visible;
}

.amis-scope .a-TreeControl.no-border {
  border: 0;
}

.amis-scope .a-Tree-list,
.amis-scope .a-Tree-sublist {
  list-style: none;
  padding: 0;
  margin: 0;
}

.amis-scope .a-Tree-sublist {
  margin-left: var(--Tree-indent);
}

.amis-scope .a-Tree-sublist.is-folded {
  display: none;
}

.amis-scope .a-Tree-item {
  line-height: var(--Tree-itemHeight);
  position: relative;
}

.amis-scope .a-Tree-item > div:hover {
  text-decoration: none;
}

.amis-scope .a-Tree-item > div:hover > .a-Tree-item-icons {
  visibility: visible;
}

.amis-scope .a-Tree-item > div > span > svg {
  display: inline-block;
  cursor: pointer;
  position: relative;
  top: 2px;
  width: 1rem;
  height: 1rem;
  margin-left: var(--gap-xs);
}

.amis-scope .a-Tree.is-disabled {
  pointer-events: none;
}

.amis-scope .a-Tree--outline .a-Tree-sublist .a-Tree-item--isLeaf:before {
  position: absolute;
  top: -8px;
  left: calc((var(--Tree-indent) - 5px) * -1);
  bottom: 0px;
  border-left: 1px solid var(--borderColor);
  content: "";
}

.amis-scope .a-Tree-rootItem {
  line-height: var(--Tree-itemHeight);
}

.amis-scope .a-Tree-item > div:hover > .a-Tree-item-icons,
.amis-scope .a-Tree-rootItem > div:hover > .a-Tree-item-icons {
  visibility: visible;
}

.amis-scope .a-Tree-itemLabel {
  display: flex;
  align-items: center;
  position: relative;
}

.amis-scope .a-Tree-itemLabel > * {
  position: relative;
  z-index: 2;
}

.amis-scope .a-Tree-itemLabel:hover:after {
  position: absolute;
  content: "";
  z-index: 1;
  background: var(--Tree-item-onHover-bg);
  top: 0;
  right: 0;
  bottom: 0;
  left: -99999px;
}

.amis-scope .a-Tree-item-icons {
  visibility: hidden;
  transition: visibility var(--animation-duration) ease;
  display: inline-block;
  vertical-align: top;
  height: var(--Tree-itemHeight);
  line-height: var(--Tree-itemHeight);
  padding-right: var(--gap-xs);
}

.amis-scope .a-Tree-item-icons > a {
  display: inline-block;
  vertical-align: middle;
  margin-left: var(--gap-xs);
  cursor: pointer;
}

.amis-scope .a-Tree-item-icons > a > svg {
  width: 0.75rem;
  height: 0.75rem;
  top: 0;
}

.amis-scope .a-Tree-itemInput {
  padding-left: var(--Tree-itemArrowWidth);
  display: flex;
  flex-direction: row;
  flex-wrap: nowrap;
}

.amis-scope .a-Tree-itemInput > a {
  display: inline-block;
  cursor: pointer;
  margin-left: var(--gap-sm);
  color: var(--icon-color);
}

.amis-scope .a-Tree-itemInput > a:hover {
  color: var(--icon-onHover-color);
  text-decoration: none;
}

.amis-scope .a-Tree-itemInput > input {
  flex-grow: 1;
  width: 100%;
  outline: none;
  background: var(--Form-input-bg);
  border: var(--Form-input-borderWidth) solid var(--Form-input-borderColor);
  border-radius: var(--Form-input-borderRadius);
  line-height: var(--Form-input-lineHeight);
  padding: calc( ( var(--Tree-inputHeight) - var(--Form-input-lineHeight) * var(--Form-input-fontSize) - 0.125rem ) / 2 ) var(--Form-input-paddingX);
  font-size: var(--Form-input-fontSize);
}

.amis-scope .a-Tree-itemInput > input::placeholder {
  color: var(--Form-input-placeholderColor);
  user-select: none;
}

.amis-scope .a-Tree-itemInput > input:focus {
  border-color: var(--Form-input-onFocused-borderColor);
  box-shadow: var(--Form-input-boxShadow);
  background: var(--Form-input-onFocused-bg);
}

.amis-scope .a-Tree-addTopBtn {
  cursor: pointer;
  height: var(--Tree-itemHeight);
  line-height: var(--Tree-itemHeight);
  display: block;
}

.amis-scope .a-Tree-addTopBtn:hover {
  text-decoration: none;
}

.amis-scope .a-Tree-addTopBtn.is-disabled {
  pointer-events: none;
  color: var(--text--muted-color);
}

.amis-scope .a-Tree-addTopBtn > svg {
  width: 0.875rem;
  height: 0.875rem;
  top: 0.109375rem;
  margin-right: var(--gap-xs);
}

.amis-scope .a-Tree-itemArrow {
  cursor: pointer;
  width: var(--Tree-itemArrowWidth);
  display: inline-flex;
  margin-right: var(--gap-xs);
}

.amis-scope .a-Tree-itemArrow > svg {
  width: var(--Tree-itemArrowWidth);
  height: var(--Tree-itemArrowWidth);
  display: block;
  transition: transform var(--animation-duration);
  top: 0;
  transform: rotate(90deg);
}

.amis-scope .a-Tree-itemArrow.is-folded > svg {
  transform: rotate(0deg);
}

.amis-scope .a-Tree-itemArrowPlaceholder {
  display: inline-block;
  width: calc(var(--Tree-itemArrowWidth) + var(--gap-xs));
}

.amis-scope .a-Tree-spinner {
  margin-right: var(--gap-xs);
}

.amis-scope .a-Tree-itemIcon {
  display: inline-flex;
  margin-right: var(--gap-xs);
}

.amis-scope .a-Tree-rootIcon > svg,
.amis-scope .a-Tree-folderIcon > svg,
.amis-scope .a-Tree-leafIcon > svg {
  top: 0;
  width: 0.875rem;
  height: 0.875rem;
}

.amis-scope .a-Tree-itemLabel {
  user-select: none;
}

.amis-scope .a-Tree-itemLabel.is-checked,
.amis-scope .a-Tree-itemLabel.is-children-checked {
  color: var(--Tree-itemLabel--onChecked-color);
}

.amis-scope .a-Tree-itemLabel.is-disabled {
  color: var(--text--muted-color);
}

.amis-scope .a-Tree-itemLabel > .a-Checkbox {
  display: inline-flex;
  align-self: center;
}

.amis-scope .a-Tree-itemText {
  cursor: pointer;
  flex: 1 auto;
  line-height: var(--lineHeightBase);
  padding: 0.25rem 0;
}

.amis-scope .a-Tree-placeholder {
  color: var(--text--muted-color);
}

.amis-scope .a-TreeSelectControl {
  position: relative;
}

.amis-scope .a-TreeSelectControl > .a-TreeSelect-popover {
  width: 100%;
}

.amis-scope .a-TreeSelect {
  position: relative;
  max-width: 100%;
  outline: none;
}

.amis-scope .a-TreeSelect.is-inline {
  display: inline-block;
  width: var(--Form-control-widthBase);
}

.amis-scope .a-TreeSelect-input {
  display: flex;
  background: var(--Form-input-bg);
  border: var(--Form-input-borderWidth) solid var(--Form-input-borderColor);
  border-radius: var(--Form-input-borderRadius);
  line-height: var(--Form-input-lineHeight);
  padding: var(--Form-input-paddingY) var(--Form-input-paddingX);
  font-size: var(--Form-input-fontSize);
  flex-wrap: wrap;
  justify-content: flex-start;
}

.amis-scope .a-TreeSelect-input input {
  flex-basis: 5rem;
  flex-grow: 1;
  outline: none;
  background: transparent;
  border: none;
  color: var(--Form-input-color);
  width: 100%;
  height: calc(var(--Form-input-lineHeight) * var(--Form-input-fontSize));
}

.amis-scope .a-TreeSelect-input input::placeholder {
  color: var(--Form-input-placeholderColor);
  user-select: none;
}

.amis-scope .a-TreeSelect-input:hover {
  border-color: var(--Form-input-onFocused-borderColor);
}

.amis-scope .a-TreeSelect-input--borderHalf {
  border-left-color: transparent !important;
  border-right-color: transparent !important;
  border-top-color: transparent !important;
}

.amis-scope .a-TreeSelect-input--borderNone {
  border-color: transparent !important;
}

.amis-scope .a-TreeSelect.is-error > .a-TreeSelect-input {
  border-color: var(--Form-input-onError-borderColor);
  background: var(--Form-input-onError-bg);
  transition: all var(--animation-duration);
}

.amis-scope .a-TreeSelect.is-focused > .a-TreeSelect-input {
  border-color: var(--Form-input-onFocused-borderColor);
  box-shadow: var(--Form-input-boxShadow);
  background: var(--Form-input-onFocused-bg);
  transition: all var(--animation-duration);
}

.amis-scope .a-TreeSelect.is-error.is-focused > .a-TreeSelect-input {
  border-color: var(--Form-input-onError-borderColor);
}

.amis-scope .a-TreeSelect.is-disabled > .a-TreeSelect-input {
  color: var(--text--muted-color);
  background: var(--Form-input-onDisabled-bg);
  border-color: var(--Form-input-onDisabled-borderColor);
  transition: all var(--animation-duration);
}

.amis-scope .a-TreeSelect-spinner {
  line-height: calc( var(--Form-input-lineHeight) * var(--Form-input-fontSize) );
}

.amis-scope .a-TreeSelect-clear {
  padding: 0.1875rem;
  cursor: pointer;
  display: flex;
  align-items: center;
  justify-content: center;
  margin-left: auto;
}

.amis-scope .a-TreeSelect-clear svg {
  fill: var(--Form-input-iconColor);
  top: 0;
  width: 0.625rem;
  height: 0.625rem;
}

.amis-scope .a-TreeSelect-clear:hover svg {
  fill: var(--Form-input-onHover-iconColor);
}

@media (min-width: 576px) {
  .amis-scope .a-TreeSelect.a-Form-control--sizeXs > .a-TreeSelect-input,
  .amis-scope .a-TreeSelect.a-Form-control--sizeSm > .a-TreeSelect-input,
  .amis-scope .a-TreeSelect.a-Form-control--sizeMd > .a-TreeSelect-input,
  .amis-scope .a-TreeSelect.a-Form-control--sizeLg > .a-TreeSelect-input {
    min-width: 100%;
    display: inline-flex;
  }
}

.amis-scope .a-TreeSelect.is-opened {
  border-color: var(--Form-input-onFocused-borderColor);
  box-shadow: var(--Form-input-boxShadow);
  background: var(--Form-input-onFocused-bg);
}

.amis-scope .a-TreeSelect-popover {
  background: transparent;
  border: none;
  box-shadow: none;
}

.amis-scope .a-TreeSelect-popover > .a-Tree {
  background: var(--TreeSelect-popover-bg);
  border: var(--Form-input-borderWidth) solid var(--Form-input-onFocused-borderColor);
  padding: var(--gap-xs) var(--Form-input-paddingX);
  border-radius: 0;
  margin-top: -1px;
  max-height: 400px;
  overflow: auto;
}

.amis-scope .a-Combo-placeholder {
  color: var(--text--muted-color);
  padding-top: var(--Form-label-paddingTop);
}

.amis-scope .a-Combo-toolbarBtn {
  line-height: var(--Combo-toolbarBtn-lineHeight);
  height: var(--Combo-toolbarBtn-height);
  color: var(--Combo-toolbarBtn-color);
  padding: var(--Combo-toolbarBtn-paddingY) var(--Combo-toolbarBtn-paddingX);
  cursor: pointer;
}

.amis-scope .a-Combo-toolbarBtn:hover {
  color: var(--Combo-toolbarBtn-onHover-color);
}

.amis-scope .a-Combo-setNullBtn {
  margin-top: var(--gap-xs);
  display: inline-block;
}

.amis-scope .a-Combo-addBtn {
  font-size: var(--Combo-addBtn-fontSize);
  padding: var(--Combo-addBtn-paddingY) var(--Combo-addBtn-paddingX);
  font-size: var(--Combo-addBtn-fontSize);
  line-height: var(--Combo-addBtn-lineHeight);
  border-radius: var(--Combo-addBtn-borderRadius);
  height: var(--Combo-addBtn-height);
  color: var(--Combo-addBtn-color);
  background: var(--Combo-addBtn-bg);
  border-color: var(--Combo-addBtn-border);
  box-shadow: var(--Button-boxShadow);
  text-shadow: var(--Button-textShadow);
}

.amis-scope .a-Combo-addBtn > svg {
  width: var(--Combo-addBtn-fontSize);
  height: var(--Combo-addBtn-fontSize);
}

.amis-scope .a-Combo-addBtn .a-Button-icon:first-child:not(:last-child):not(.pull-right),
.amis-scope .a-Combo-addBtn > svg.icon:not(:last-child):not(.pull-right),
.amis-scope .a-Combo-addBtn > .pull-left {
  margin-right: var(--Combo-addBtn-paddingX);
}

.amis-scope .a-Combo-addBtn .a-Button-icon:last-child:not(:first-child):not(.pull-left),
.amis-scope .a-Combo-addBtn > .pull-right {
  margin-left: var(--Combo-addBtn-paddingX);
}

.amis-scope .a-Combo-addBtn img.a-Button-icon {
  height: var(--Button-fontSize);
  vertical-align: middle;
}

.amis-scope .a-Combo-addBtn:not(:disabled):not(.is-disabled):hover {
  color: var(--Combo-addBtn-onHover-color);
  background: var(--Combo-addBtn-onHover-bg);
  border-color: var(--Combo-addBtn-onHover-border);
}

.amis-scope .a-Combo-addBtn:hover:focus {
  box-shadow: var(--Button-boxShadow);
}

.amis-scope .a-Combo-addBtn.is-disabled {
  pointer-events: none;
  opacity: var(--Button-onDisabled-opacity);
}

.amis-scope .a-Combo-delBtn {
  color: var(--icon-color);
  cursor: pointer;
}

.amis-scope .a-Combo-delBtn:hover {
  color: var(--icon-onHover-color);
}

.amis-scope .a-Combo-tab-delBtn {
  color: var(--icon-color);
  cursor: pointer;
  margin-left: var(--gap-sm);
  display: inline-block;
}

.amis-scope .a-Combo-tab-delBtn > svg {
  width: 0.6875rem;
  height: 0.6875rem;
}

.amis-scope .a-Combo-tab-delBtn:hover {
  color: var(--icon-onHover-color);
}

.amis-scope .a-Combo-items {
  margin-bottom: var(--Combo-items-marginBottom);
}

.amis-scope .a-Combo-items:empty {
  display: none;
}

.amis-scope .a-Combo-items:empty + .a-Combo-toolbar {
  padding-top: calc( (var(--Form-input-height) - var(--Combo-addBtn-height)) / 2 );
}

.amis-scope .a-Combo-item {
  background: var(--Page-main-bg);
}

.amis-scope .a-Combo-itemDrager {
  cursor: move;
}

.amis-scope .a-Combo-itemDrager > a {
  color: var(--icon-color);
}

.amis-scope .a-Combo-itemDrager > a:hover {
  color: var(--icon-onHover-color);
}

.amis-scope .a-Combo-itemDrager svg {
  width: 1rem;
  height: 1rem;
}

.amis-scope .a-Combo--hor .a-Combo-item {
  display: flex;
  flex-wrap: nowrap;
}

.amis-scope .a-Combo--hor .a-Combo-item + .a-Combo-item {
  margin-top: var(--Combo--horizontal-item-gap);
}

.amis-scope .a-Combo--hor .a-Combo-itemInner {
  flex-basis: 0;
  flex-grow: 1;
}

.amis-scope .a-Combo--hor .a-Combo-itemTag {
  margin-right: var(--gap-sm);
}

.amis-scope .a-Combo--hor .a-Combo-itemTag label {
  color: var(--info);
  margin-right: var(--gap-sm);
}

.amis-scope .a-Combo--hor .a-Combo-delBtn {
  margin-left: var(--gap-xs);
  display: flex;
  white-space: nowrap;
  align-items: flex-start;
  padding-top: var(--Form-label-paddingTop);
}

.amis-scope .a-Combo--hor .a-Combo-delBtn.is-disabled {
  pointer-events: none;
  opacity: var(--Button-onDisabled-opacity);
}

.amis-scope .a-Combo--hor.is-draggable .a-Combo-toolbar {
  padding-left: 1.5rem;
}

.amis-scope .a-Combo--hor .a-Combo-itemDrager {
  padding: var(--Combo--horizontal-dragger-top) 0.375rem 0 0;
}

.amis-scope .a-Combo--ver:not(.a-Combo--noBorder)::before,
.amis-scope .a-Combo--ver:not(.a-Combo--noBorder)::after {
  display: table;
  content: "";
}

.amis-scope .a-Combo--ver:not(.a-Combo--noBorder)::after {
  clear: both;
}

.amis-scope .a-Combo--ver:not(.a-Combo--noBorder) > .a-Combo-items {
  margin: calc(var(--Combo--vertical-item-gap) * -2) calc(var(--Combo--vertical-item-gap) * -2) 0 calc(var(--Combo--vertical-item-gap) * -2);
}

.amis-scope .a-Combo--ver:not(.a-Combo--noBorder) > .a-Combo-items > .a-Combo-placeholder {
  margin: calc(var(--Combo--vertical-item-gap) * 2);
}

.amis-scope .a-Combo--ver:not(.a-Combo--noBorder) .a-Combo-itemTag {
  text-align: right;
}

.amis-scope .a-Combo--ver:not(.a-Combo--noBorder) .a-Combo-itemTag label {
  color: var(--info);
  margin-right: var(--gap-sm);
}

.amis-scope .a-Combo--ver:not(.a-Combo--noBorder) > .a-Combo-item,
.amis-scope .a-Combo--ver:not(.a-Combo--noBorder) > .a-Combo-items > .a-Combo-item {
  border: var(--Combo--vertical-item-borderWidth) dashed var(--Combo--vertical-item-borderColor);
  padding: var(--Combo--vertical-item-paddingY) var(--Combo--vertical-item-paddingX);
  position: relative;
}

.amis-scope .a-Combo--ver:not(.a-Combo--noBorder) > .a-Combo-items > .a-Combo-item {
  margin: calc(var(--Combo--vertical-item-gap) * 2);
}

.amis-scope .a-Combo--ver:not(.a-Combo--noBorder) > .a-Combo-items > .a-Combo-item > .a-Combo-delBtn {
  position: absolute;
  opacity: 0;
  top: var(--gap-xs);
  right: var(--gap-xs);
}

.amis-scope .a-Combo--ver:not(.a-Combo--noBorder):not(.is-disabled) > .a-Combo-item:hover,
.amis-scope .a-Combo--ver:not(.a-Combo--noBorder):not(.is-disabled) > .a-Combo-items > .a-Combo-item:hover {
  border-color: var(--Combo--vertical-item-onHover-borderColor);
}

.amis-scope .a-Combo--ver:not(.a-Combo--noBorder):not(.is-disabled) > .a-Combo-item:hover > .a-Combo-delBtn,
.amis-scope .a-Combo--ver:not(.a-Combo--noBorder):not(.is-disabled) > .a-Combo-items > .a-Combo-item:hover > .a-Combo-delBtn {
  opacity: 1;
}

.amis-scope .a-Combo--ver:not(.a-Combo--noBorder) > .a-Combo-items > .a-Combo-item > .a-Combo-itemDrager {
  position: absolute;
  top: var(--Combo--horizontal-dragger-top);
  left: -1.875rem;
}

.amis-scope .a-Combo--ver:not(.a-Combo--noBorder).is-draggable > .a-Combo-items > .a-Combo-item {
  margin-left: 2.1875rem;
}

.amis-scope .a-Combo--ver:not(.a-Combo--noBorder).is-draggable > .a-Combo-toolbar {
  padding-left: 1.5625rem;
}

.amis-scope .a-Combo-item--dragging {
  position: relative;
}

.amis-scope .a-Combo-item--dragging:after {
  content: "";
  display: block;
  position: absolute;
  z-index: 5;
  left: 0;
  top: 0;
  right: 0;
  bottom: 0;
  width: 100%;
  height: 100%;
  background: rgba(0, 0, 0, 0.1);
}

.amis-scope .a-ComboTabs > .a-Tabs-links::before,
.amis-scope .a-ComboTabs > .a-Tabs-links::after {
  display: table;
  content: "";
}

.amis-scope .a-ComboTabs > .a-Tabs-links::after {
  clear: both;
}

.amis-scope .a-ComboTabs > .a-Tabs-links .a-Tabs-link > a {
  word-break: break-all;
}

.amis-scope .a-ComboTabs-addLink {
  float: right;
}

.amis-scope .a-ComboTabs-addLink > a svg {
  margin-right: var(--gap-xs);
}

.amis-scope .a-Combo-dragableTip {
  color: var(--text--muted-color);
  font-size: var(--fontSizeSm);
  margin-left: var(--gap-xs);
}

.amis-scope .a-Combo-dragableTip:empty {
  display: none;
}

.amis-scope .a-ComboControl.is-inline .a-Combo--hor .a-Combo-itemInner {
  flex-grow: unset;
  flex-basis: unset;
}

.amis-scope .a-ComboControl.is-inline .a-Combo--ver .a-Combo-item {
  display: inline-block;
  min-width: var(--Form-control-widthBase);
}

@media (min-width: 576px) {
  .amis-scope .a-Combo-form .a-Form-item:last-child {
    margin-bottom: 0;
  }
}

.amis-scope .a-SubForm-values {
  margin: 2px -3px;
}

.amis-scope .a-SubForm-values:empty {
  display: none;
}

.amis-scope .a-SubForm-value {
  background: var(--ResultBox-value-bg);
  color: var(--ResultBox-value-color);
  font-size: var(--Form-input-fontSize);
  padding: 0 var(--gap-xs);
  min-height: 1.5rem;
  flex-wrap: nowrap;
  display: inline-flex;
  align-items: center;
  margin: 2px 3px;
  user-select: none;
}

.amis-scope .a-SubForm-valueLabel {
  color: inherit;
}

.amis-scope .a-SubForm-valueDel,
.amis-scope .a-SubForm-valueEdit,
.amis-scope .a-SubForm-valueDragBar {
  cursor: pointer;
  margin-left: var(--gap-xs);
  color: var(--ResultBox-icon-color);
}

.amis-scope .a-SubForm-valueDel:hover,
.amis-scope .a-SubForm-valueEdit:hover,
.amis-scope .a-SubForm-valueDragBar:hover {
  color: var(--ResultBox-icon--onHover-color);
}

.amis-scope .a-SubForm-valueDel > svg,
.amis-scope .a-SubForm-valueEdit > svg,
.amis-scope .a-SubForm-valueDragBar > svg {
  width: 0.75rem;
  height: 0.75rem;
}

.amis-scope .a-SubForm-valueDragBar {
  margin-left: 0;
  margin-right: var(--gap-xs);
  cursor: move;
}

.amis-scope .a-SubForm-value:hover {
  background: var(--ResultBox-value--onHover-bg);
}

.amis-scope .a-SubForm-value.is-disabled {
  pointer-events: none;
  color: var(--ResultBox-value--onDisabled-color);
}

.amis-scope .a-SubForm-value.is-disabled > a {
  color: var(--ResultBox-icon--onDisabled-color);
}

.amis-scope .a-SubForm-value--dragging {
  position: relative;
}

.amis-scope .a-SubForm-value--dragging:after {
  content: "";
  display: block;
  position: absolute;
  z-index: 5;
  left: 0;
  top: 0;
  right: 0;
  bottom: 0;
  width: 100%;
  height: 100%;
  background: rgba(0, 0, 0, 0.1);
}

.amis-scope .a-SubForm-addBtn {
  width: auto;
  min-width: auto;
  font-weight: var(--fontWeightNormal);
  color: var(--Button--link-color);
  text-decoration: var(--link-decoration);
  border: none;
  height: auto;
  padding: 0 4px;
  display: inline-flex;
  align-items: center;
}

.amis-scope .a-SubForm-addBtn:hover:focus {
  color: var(--Button--link-onHover-color);
  text-decoration: var(--link-onHover-decoration);
  box-shadow: none;
}

.amis-scope .a-SubForm-addBtn > svg {
  width: 12px;
  height: 12px;
  margin-right: 4px !important;
  top: 0;
}

.amis-scope .a-SubForm-addBtn:disabled,
.amis-scope .a-SubForm-addBtn.is-disabled {
  color: var(--text--muted-color);
  pointer-events: none;
  background: transparent;
}

.amis-scope .a-SubForm-placeholder {
  color: var(--Form-input-placeholderColor);
  user-select: none;
  padding: 4px;
}

.amis-scope .a-ChainedSelectControl .a-Select {
  margin-right: var(--gap-xs);
}

.amis-scope .a-Picker {
  position: relative;
  max-width: 100%;
  outline: none;
}

.amis-scope .a-Picker.is-inline {
  display: inline-block;
  width: var(--Form-control-widthBase);
}

.amis-scope .a-Picker-input {
  display: flex;
  background: var(--Form-input-bg);
  border: var(--Form-input-borderWidth) solid var(--Form-input-borderColor);
  border-radius: var(--Form-input-borderRadius);
  line-height: var(--Form-input-lineHeight);
  padding: var(--Form-input-paddingY) var(--Form-input-paddingX);
  font-size: var(--Form-input-fontSize);
  flex-wrap: wrap;
  justify-content: flex-start;
}

.amis-scope .a-Picker-input input {
  flex-basis: 5rem;
  flex-grow: 1;
  outline: none;
  background: transparent;
  border: none;
  color: var(--Form-input-color);
  width: 100%;
  height: calc(var(--Form-input-lineHeight) * var(--Form-input-fontSize));
}

.amis-scope .a-Picker-input input::placeholder {
  color: var(--Form-input-placeholderColor);
  user-select: none;
}

.amis-scope .a-Picker-input:hover {
  border-color: var(--Form-input-onFocused-borderColor);
}

.amis-scope .a-Picker-input--borderHalf {
  border-left-color: transparent !important;
  border-right-color: transparent !important;
  border-top-color: transparent !important;
}

.amis-scope .a-Picker-input--borderNone {
  border-color: transparent !important;
}

.amis-scope .a-Picker.is-error > .a-Picker-input {
  border-color: var(--Form-input-onError-borderColor);
  background: var(--Form-input-onError-bg);
  transition: all var(--animation-duration);
}

.amis-scope .a-Picker.is-focused > .a-Picker-input {
  border-color: var(--Form-input-onFocused-borderColor);
  box-shadow: var(--Form-input-boxShadow);
  background: var(--Form-input-onFocused-bg);
  transition: all var(--animation-duration);
}

.amis-scope .a-Picker.is-error.is-focused > .a-Picker-input {
  border-color: var(--Form-input-onError-borderColor);
}

.amis-scope .a-Picker.is-disabled > .a-Picker-input {
  color: var(--text--muted-color);
  background: var(--Form-input-onDisabled-bg);
  border-color: var(--Form-input-onDisabled-borderColor);
  transition: all var(--animation-duration);
}

.amis-scope .a-Picker-spinner {
  line-height: calc( var(--Form-input-lineHeight) * var(--Form-input-fontSize) );
}

.amis-scope .a-Picker-clear {
  padding: 0.1875rem;
  cursor: pointer;
  display: flex;
  align-items: center;
  justify-content: center;
  margin-left: auto;
}

.amis-scope .a-Picker-clear svg {
  fill: var(--Form-input-iconColor);
  top: 0;
  width: 0.625rem;
  height: 0.625rem;
}

.amis-scope .a-Picker-clear:hover svg {
  fill: var(--Form-input-onHover-iconColor);
}

@media (min-width: 576px) {
  .amis-scope .a-Picker.a-Form-control--sizeXs > .a-Picker-input,
  .amis-scope .a-Picker.a-Form-control--sizeSm > .a-Picker-input,
  .amis-scope .a-Picker.a-Form-control--sizeMd > .a-Picker-input,
  .amis-scope .a-Picker.a-Form-control--sizeLg > .a-Picker-input {
    min-width: 100%;
    display: inline-flex;
  }
}

.amis-scope .a-Picker.is-focus > .a-Picker-input {
  border-color: var(--Form-input-onFocused-borderColor);
  box-shadow: var(--Form-input-boxShadow);
  background: var(--Form-input-onFocused-bg);
}

.amis-scope .a-Picker.is-disabled {
  pointer-events: none;
  opacity: var(--Button-onDisabled-opacity);
}

.amis-scope .a-Picker-placeholder {
  color: var(--Form-input-placeholderColor);
  user-select: none;
  position: absolute;
  line-height: var(--Form-input-lineHeight);
}

.amis-scope .a-Picker-input {
  min-height: var(--Form-input-height);
  height: auto;
}

.amis-scope .a-Picker .a-Picker-values {
  display: inline;
}

.amis-scope .a-Picker-valueWrap {
  flex-grow: 1;
  position: relative;
}

.amis-scope .a-Picker-valueWrap > input {
  width: 1rem;
  display: inline-block;
}

.amis-scope .a-Picker .a-Picker-valueWrap {
  margin-bottom: calc(var(--gap-xs) * -1);
  line-height: 1;
}

.amis-scope .a-Picker .a-Picker-value {
  cursor: pointer;
  user-select: none;
  white-space: nowrap;
  vertical-align: middle;
  line-height: calc( var(--Form-input-lineHeight) * var(--Form-input-fontSize) - 0.125rem );
  display: inline-block;
  font-size: var(--Form-selectValue-fontSize);
  color: var(--Form-selectValue-color);
  background: var(--Form-selectValue-bg);
  border: 0.0625rem solid var(--Form-selectValue-borderColor);
  border-radius: 2px;
  margin-right: var(--gap-xs);
  margin-bottom: var(--gap-xs);
}

.amis-scope .a-Picker .a-Picker-valueIcon {
  cursor: pointer;
  border-right: 0.0625rem solid var(--Form-selectValue-borderColor);
  padding: 1px 5px;
}

.amis-scope .a-Picker .a-Picker-valueIcon:hover {
  background: var(--Form-selectValue-onHover-bg);
}

.amis-scope .a-Picker .a-Picker-valueLabel {
  padding: 0 var(--gap-xs);
}

.amis-scope .a-Picker-btn {
  cursor: pointer;
  color: var(--Picker-iconColor);
}

.amis-scope .a-Picker-btn:hover {
  color: var(--Picker-onHover-iconColor);
}

.amis-scope .a-Picker-clear {
  display: inline-block;
  padding: 0.1875rem;
  cursor: pointer;
  display: flex;
  align-items: center;
  justify-content: center;
  margin-left: auto;
  line-height: 1;
  margin-right: var(--gap-xs);
}

.amis-scope .a-Picker-clear svg {
  fill: var(--Form-input-iconColor);
  top: 0;
  width: 0.625rem;
  height: 0.625rem;
}

.amis-scope .a-Picker-clear:hover svg {
  fill: var(--Form-input-onHover-iconColor);
}

.amis-scope .a-PickerControl.is-inline .a-Picker {
  display: inline-block;
  min-width: 9.375rem;
}

.amis-scope .a-QrCode {
  min-height: var(--Form-input-height);
  padding: 0.4375rem 0;
}

.amis-scope .a-TagControl {
  position: relative;
}

.amis-scope .a-TagControl-input.is-focused {
  border-radius: 0;
}

.amis-scope .a-TagControl-input.is-disabled {
  border-style: dashed;
  background: transparent;
}

.amis-scope .a-TagControl.is-inline {
  display: inline-block;
}

.amis-scope .a-TagControl > .a-TagControl-popover {
  padding: 0;
  border: none;
  width: 100%;
  margin-top: calc( var(--Form-select-popoverGap) - var(--Form-select-outer-borderWidth) );
}

.amis-scope .a-TagControl > .a-TagControl-popover.a-PopOver--leftBottomLeftTop {
  top: 100% !important;
}

.amis-scope .a-TagControl > .a-TagControl-popover.a-PopOver--leftTopLeftBottom {
  top: auto !important;
  bottom: 100% !important;
}

.amis-scope .a-TagControl-sug {
  margin-top: var(--Form-input-marginBottom);
}

.amis-scope .a-TagControl-sugTip {
  color: var(--TagControl-sugTip-color);
  margin-bottom: var(--Form-input-marginBottom);
}

.amis-scope .a-TagControl-sugItem {
  margin-right: var(--gap-sm);
  margin-bottom: var(--gap-sm);
  display: inline-block;
  font-size: var(--TagControl-sugBtn-fontSize);
  cursor: pointer;
  user-select: none;
  border: var(--TagControl-sugBtn-borderWidth) solid transparent;
  padding: var(--TagControl-sugBtn-paddingY) var(--TagControl-sugBtn-paddingX);
  font-size: var(--TagControl-sugBtn-fontSize);
  line-height: var(--TagControl-sugBtn-lineHeight);
  border-radius: var(--TagControl-sugBtn-borderRadius);
  height: var(--TagControl-sugBtn-height);
  color: var(--TagControl-sugBtn-color);
  background: var(--TagControl-sugBtn-bg);
  border-color: var(--TagControl-sugBtn-border);
  box-shadow: var(--Button-boxShadow);
  text-shadow: var(--Button-textShadow);
}

.amis-scope .a-TagControl-sugItem .a-Button-icon:first-child:not(:last-child):not(.pull-right),
.amis-scope .a-TagControl-sugItem > svg.icon:not(:last-child):not(.pull-right),
.amis-scope .a-TagControl-sugItem > .pull-left {
  margin-right: var(--TagControl-sugBtn-paddingX);
}

.amis-scope .a-TagControl-sugItem .a-Button-icon:last-child:not(:first-child):not(.pull-left),
.amis-scope .a-TagControl-sugItem > .pull-right {
  margin-left: var(--TagControl-sugBtn-paddingX);
}

.amis-scope .a-TagControl-sugItem img.a-Button-icon {
  height: var(--Button-fontSize);
  vertical-align: middle;
}

.amis-scope .a-TagControl-sugItem:not(:disabled):not(.is-disabled):hover {
  color: var(--TagControl-sugBtn-onHover-color);
  background: var(--TagControl-sugBtn-onHover-bg);
  border-color: var(--TagControl-sugBtn-onHover-border);
}

.amis-scope .a-TagControl-sugItem:hover:focus {
  box-shadow: var(--Button-boxShadow);
}

.amis-scope .a-TagControl-sugItem.is-disabled {
  pointer-events: none;
  opacity: var(--Button-onDisabled-opacity);
}

.amis-scope .a-TagControl-popover.a-PopOver--leftBottomLeftTop > .a-ListMenu {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}

.amis-scope .a-TagControl-popover.a-PopOver--leftTopLeftBottom > .a-ListMenu {
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
}

.amis-scope .a-Rating {
  position: relative;
  overflow: hidden;
  display: block;
  float: left;
  font-size: 1.5rem;
  color: var(--dark);
  cursor: pointer;
}

.amis-scope .a-Rating.is-active {
  color: var(--Rating-onActive-color);
}

.amis-scope .a-Rating.is-disabled {
  cursor: not-allowed;
  pointer-events: none;
}

.amis-scope .a-Rating-half:before {
  position: absolute;
  overflow: hidden;
  display: block;
  z-index: 1;
  top: 0;
  left: 0;
  width: 50%;
  content: attr(data-forhalf);
  color: var(--Rating-onActive-color);
}

.amis-scope .a-RatingControl {
  position: relative;
  overflow: hidden;
}

.amis-scope .a-Transfer {
  display: flex;
  flex-direction: row;
  flex-wrap: wrap;
  min-height: 18.75rem;
  position: relative;
}

.amis-scope .a-Transfer--inline {
  display: inline-flex;
  flex-wrap: nowrap;
}

.amis-scope .a-Transfer-title {
  display: flex;
  align-items: center;
  background: var(--Transfer-title-bg);
  height: 1.875rem;
  line-height: var(--Form-input-lineHeight);
  font-size: var(--Form-input-fontSize);
  padding: calc( ( 1.875rem - var(--Form-input-lineHeight) * var(--Form-input-fontSize) ) / 2 ) var(--gap-sm);
  flex-direction: row;
}

.amis-scope .a-Transfer-title--light {
  background: transparent;
}

.amis-scope .a-Transfer-title > span {
  flex-grow: 1;
}

.amis-scope .a-Transfer-select,
.amis-scope .a-Transfer-result {
  width: 0;
  min-width: 12.5rem;
  max-height: 25rem;
  flex-grow: 1;
  border: var(--Form-input-borderWidth) solid var(--Form-input-borderColor);
  display: flex;
  flex-direction: column;
}

.amis-scope .a-Transfer-select > .a-Transfer-checkboxes,
.amis-scope .a-Transfer-result > .a-Transfer-selections {
  flex-grow: 1;
  max-height: 100%;
  overflow: auto;
  position: relative;
}

.amis-scope .a-Transfer-search + .a-Transfer-checkboxes {
  border-top: 1px solid var(--borderColor);
}

.amis-scope .a-Transfer-checkboxes .a-ListCheckboxes-placeholder {
  height: 100%;
  display: flex;
  align-items: center;
  text-align: center;
  justify-content: center;
}

.amis-scope .a-Transfer-search {
  padding: var(--gap-sm);
}

.amis-scope .a-Transfer-mid {
  min-width: 0.625rem;
  display: flex;
  flex-direction: column;
  justify-content: center;
}

.amis-scope .a-Transfer-arrow {
  width: 40px;
  height: 30px;
  display: flex;
  justify-content: center;
  align-items: center;
  border: 1px solid var(--borderColor);
  margin: 0 10px;
  color: var(--icon-color);
}

.amis-scope .a-Transfer-arrow > svg {
  top: 0;
  width: 14px;
  height: 14px;
}

.amis-scope .a-Transfer-checkAll,
.amis-scope .a-Transfer-clearAll {
  user-select: none;
  cursor: pointer;
}

.amis-scope .a-Transfer-checkAll.is-disabled,
.amis-scope .a-Transfer-clearAll.is-disabled {
  pointer-events: none;
  color: var(--text--muted-color);
}

.amis-scope .a-Transfer-tabs {
  display: flex;
  flex-direction: column;
  height: 100%;
}

.amis-scope .a-Transfer-tabs > .a-Tabs-links {
  border-top: 0 none;
  padding: 5px 0 0 5px;
  display: flex;
  flex-direction: row;
  flex-wrap: wrap;
  align-items: center;
}

.amis-scope .a-Transfer-tabs > .a-Tabs-links > .a-Tabs-link > a:first-child {
  font-size: 12px;
  padding: 7px 8px;
}

.amis-scope .a-Transfer-tabs > .a-Tabs-links .a-TabsTransfer-tabsMid {
  flex-grow: 1;
}

.amis-scope .a-Transfer-tabs > .a-Tabs-links > .a-SearchBox {
  margin: -5px 5px 0 10px;
}

.amis-scope .a-Transfer-tabs > .a-Tabs-links > .a-SearchBox.is-active {
  width: 150px;
  margin-right: 10px;
  padding-left: 10px;
}

.amis-scope .a-Transfer-tabs > .a-Tabs-content {
  flex-grow: 1;
  position: relative;
  padding: 5px 0 0;
}

.amis-scope .a-Transfer-tabs > .a-Tabs-content > .a-Tabs-pane {
  position: relative;
  min-height: 100%;
}

.amis-scope .a-Transfer-tabs > .a-Tabs-content > .a-Tabs-pane.is-active {
  display: flex;
  flex-direction: column;
}

.amis-scope .a-Transfer-tabs > .a-Tabs-content > .a-Tabs-pane.is-active > .a-Transfer-checkboxes {
  flex-grow: 1;
  max-height: 100%;
  overflow: auto;
}

.amis-scope .a-TabsTransfer .a-Transfer-title {
  height: 40px;
}

.amis-scope .a-TabsTransfer-placeholder {
  height: var(--Form-input-height);
  line-height: var(--Form-input-lineHeight);
  font-size: var(--Form-input-fontSize);
  padding: calc( ( var(--Form-input-height) - var(--Form-input-lineHeight) * var(--Form-input-fontSize) ) / 2 ) var(--gap-sm);
  color: var(--text--muted-color);
}

.amis-scope .a-TransferControl {
  position: relative;
}

.amis-scope .a-TransferControl.is-inline {
  display: inline-block;
}

.amis-scope .a-NestedSelect {
  position: relative;
}

.amis-scope .a-NestedSelect--borderHalf {
  border-left-color: transparent !important;
  border-right-color: transparent !important;
  border-top-color: transparent !important;
}

.amis-scope .a-NestedSelect--borderNone {
  border-color: transparent !important;
}

.amis-scope .a-NestedSelect-optionArrowRight {
  display: inline-block;
  padding-right: 0.625rem;
}

.amis-scope .a-NestedSelect-optionArrowRight svg {
  width: 0.75rem;
  height: 0.75rem;
  fill: var(--Form-input-iconColor);
}

.amis-scope .a-NestedSelect-menuOuter {
  display: flex;
}

.amis-scope .a-NestedSelect-noResult {
  width: 10rem;
  padding: 0 var(--gap-xs);
  color: var(--Form-select-placeholderColor);
  line-height: var(--Form-input-lineHeight);
  font-size: var(--Form-select-input-fontSize);
  user-select: none;
  padding: calc( ( var(--Form-select-menu-height) - var(--Form-input-lineHeight) * var(--Form-input-fontSize) ) / 2 ) var(--Form-select-paddingX);
}

.amis-scope .a-NestedSelect-menu {
  width: 10rem;
  height: 10.9375rem;
  background: var(--Form-select-menu-bg);
  color: var(--Form-select-menu-color);
  border: var(--Form-select-outer-borderWidth) solid var(--Form-input-onFocused-borderColor);
  box-shadow: var(--Form-select-outer-boxShadow);
  overflow-y: auto;
  overflow-x: hidden;
}

.amis-scope .a-NestedSelect-menu:not(:first-child) {
  border-left: 0;
}

.amis-scope .a-NestedSelect-menu .a-NestedSelect-option {
  position: relative;
  padding-left: var(--gap-md);
  min-height: var(--Form-input-height);
  line-height: var(--Form-input-height);
  cursor: pointer;
  display: flex;
}

.amis-scope .a-NestedSelect-menu .a-NestedSelect-option > .a-NestedSelect-optionLabel {
  flex: 1;
}

.amis-scope .a-NestedSelect-menu .a-NestedSelect-option > .a-NestedSelect-optionLabel.is-disabled {
  cursor: not-allowed;
  color: var(--text--muted-color);
}

.amis-scope .a-NestedSelect-menu .a-NestedSelect-option.is-active {
  color: var(--Form-select-menu-onActive-color);
  background: var(--Form-select-menu-onActive-bg);
}

.amis-scope .a-NestedSelect-menu .a-NestedSelect-option:hover {
  color: var(--Form-select-menu-onHover-color);
  background: var(--Form-select-menu-onHover-bg);
}

.amis-scope .a-NestedSelect-menu .a-NestedSelect-option:hover > .a-NestedSelect-childrenOuter {
  display: block;
}

.amis-scope .a-NestedSelect-menu .a-NestedSelect-option.checkall {
  border-bottom: 0.0625rem solid #eceff8;
}

.amis-scope .a-IconPickerControl {
  position: relative;
  max-width: 100%;
}

.amis-scope .a-IconPickerControl.is-inline {
  display: inline-block;
  width: var(--Form-control-widthBase);
}

.amis-scope .a-IconPickerControl-input {
  display: flex;
  background: var(--Form-input-bg);
  border: var(--Form-input-borderWidth) solid var(--Form-input-borderColor);
  border-radius: var(--Form-input-borderRadius);
  line-height: var(--Form-input-lineHeight);
  padding: var(--Form-input-paddingY) var(--Form-input-paddingX);
  font-size: var(--Form-input-fontSize);
  flex-wrap: wrap;
  justify-content: flex-start;
}

.amis-scope .a-IconPickerControl-input input {
  flex-basis: 5rem;
  flex-grow: 1;
  outline: none;
  background: transparent;
  border: none;
  color: var(--Form-input-color);
  width: 100%;
  height: calc(var(--Form-input-lineHeight) * var(--Form-input-fontSize));
}

.amis-scope .a-IconPickerControl-input input::placeholder {
  color: var(--Form-input-placeholderColor);
  user-select: none;
}

.amis-scope .a-IconPickerControl-input:hover {
  border-color: var(--Form-input-onFocused-borderColor);
}

.amis-scope .a-IconPickerControl-input--borderHalf {
  border-left-color: transparent !important;
  border-right-color: transparent !important;
  border-top-color: transparent !important;
}

.amis-scope .a-IconPickerControl-input--borderNone {
  border-color: transparent !important;
}

.amis-scope .a-IconPickerControl.is-error > .a-IconPickerControl-input {
  border-color: var(--Form-input-onError-borderColor);
  background: var(--Form-input-onError-bg);
  transition: all var(--animation-duration);
}

.amis-scope .a-IconPickerControl.is-focused > .a-IconPickerControl-input {
  border-color: var(--Form-input-onFocused-borderColor);
  box-shadow: var(--Form-input-boxShadow);
  background: var(--Form-input-onFocused-bg);
  transition: all var(--animation-duration);
}

.amis-scope .a-IconPickerControl.is-error.is-focused > .a-IconPickerControl-input {
  border-color: var(--Form-input-onError-borderColor);
}

.amis-scope .a-IconPickerControl.is-disabled > .a-IconPickerControl-input {
  color: var(--text--muted-color);
  background: var(--Form-input-onDisabled-bg);
  border-color: var(--Form-input-onDisabled-borderColor);
  transition: all var(--animation-duration);
}

.amis-scope .a-IconPickerControl-spinner {
  line-height: calc( var(--Form-input-lineHeight) * var(--Form-input-fontSize) );
}

.amis-scope .a-IconPickerControl-clear {
  padding: 0.1875rem;
  cursor: pointer;
  display: flex;
  align-items: center;
  justify-content: center;
  margin-left: auto;
}

.amis-scope .a-IconPickerControl-clear svg {
  fill: var(--Form-input-iconColor);
  top: 0;
  width: 0.625rem;
  height: 0.625rem;
}

.amis-scope .a-IconPickerControl-clear:hover svg {
  fill: var(--Form-input-onHover-iconColor);
}

@media (min-width: 576px) {
  .amis-scope .a-IconPickerControl.a-Form-control--sizeXs > .a-IconPickerControl-input,
  .amis-scope .a-IconPickerControl.a-Form-control--sizeSm > .a-IconPickerControl-input,
  .amis-scope .a-IconPickerControl.a-Form-control--sizeMd > .a-IconPickerControl-input,
  .amis-scope .a-IconPickerControl.a-Form-control--sizeLg > .a-IconPickerControl-input {
    min-width: 100%;
    display: inline-flex;
  }
}

.amis-scope .a-IconPickerControl-placeholder {
  color: var(--Form-input-placeholderColor);
  user-select: none;
  position: absolute;
  left: var(--Form-input-paddingX);
  top: var(--Form-input-paddingY);
  margin-top: calc(2 * var(--Form-input-borderWidth));
  line-height: var(--Form-input-lineHeight);
}

.amis-scope .a-IconPickerControl-valueWrap {
  flex-grow: 1;
  line-height: 1;
  white-space: nowrap;
}

.amis-scope .a-IconPickerControl-valueWrap > input {
  display: inline-block;
  width: auto;
  vertical-align: middle;
}

.amis-scope .a-IconPickerControl-input--withAC {
  position: relative;
  flex-wrap: wrap;
}

.amis-scope .a-IconPickerControl-input--withAC > input {
  width: auto;
}

.amis-scope .a-IconPickerControl-sugsPanel {
  position: absolute;
  background: var(--Form-select-menu-bg);
  color: var(--Form-select-menu-color);
  border: var(--Form-input-borderWidth) solid var(--Form-input-onFocused-borderColor);
  left: -0.0625rem;
  right: -0.0625rem;
  top: 100%;
  z-index: 10;
  height: auto;
}

.amis-scope .a-IconPickerControl-tabs {
  background: var(--IconPicker-tabs-bg);
}

.amis-scope .a-IconPickerControl-tab {
  display: inline-block;
  padding: var(--IconPicker-tab-padding);
  height: var(--IconPicker-tab-height);
  line-height: var(--IconPicker-tab-lineHeight);
  cursor: pointer;
  text-align: center;
  font-size: var(--fontSizeSm);
  user-select: none;
}

.amis-scope .a-IconPickerControl-tab.active {
  background: var(--IconPicker-tab-onActive-bg);
}

.amis-scope .a-IconPickerControl-sugs {
  position: relative;
  padding: var(--IconPicker-padding);
  max-height: var(--IconPicker-content-maxHeight);
  overflow-y: auto;
}

.amis-scope .a-IconPickerControl-sugItem {
  display: inline-block;
  width: var(--IconPicker-sugItem-width);
  height: var(--IconPicker-sugItem-height);
  text-align: center;
  line-height: var(--IconPicker-sugItem-lineHeight);
  cursor: pointer;
}

.amis-scope .a-IconPickerControl-sugItem:hover {
  background: var(--Form-select-menu-onHover-bg);
}

.amis-scope .a-IconPickerControl-sugItem.is-active {
  color: var(--white);
  background: var(--Form-select-menu-onActive-color);
}

.amis-scope .a-IconPickerControl-value {
  user-select: none;
  line-height: calc( var(--Form-input-lineHeight) * var(--Form-input-fontSize) );
  vertical-align: middle;
  display: inline-block;
}

.amis-scope .a-IconPickerControl-value > i {
  display: inline-block;
  margin-right: var(--IconPicker-selectedIcon-marginRight);
}

.amis-scope .a-Form {
  font-size: var(--Form-fontSize);
  position: relative;
}

.amis-scope .a-Form--quickEdit > div:last-of-type {
  margin-bottom: 0;
}

.amis-scope .a-Form--inline > .a-Button {
  margin-bottom: calc(var(--Form-item-gap) / 2);
  margin-right: calc(var(--Form-item-gap) / 2);
}

.amis-scope .a-Form--inline > .a-PlainField {
  display: inline-block;
  padding-top: var(--Form-input-paddingY);
}

.amis-scope .a-Form-static {
  min-height: var(--Form-input-height);
  padding-top: var(--Form-label-paddingTop);
  padding-bottom: var(--Form-label-paddingTop);
  margin-bottom: 0;
}

.amis-scope .a-Form-item--inline > .a-Form-value > .a-Form-static {
  display: inline-block;
  vertical-align: top;
}

.amis-scope .a-Form-static--borderFull {
  border: var(--Form-input-borderWidth) solid var(--Form-input-borderColor);
  border-radius: var(--Form-input-borderRadius);
  padding: var(--Form-input-paddingY) var(--Form-input-paddingX);
}

.amis-scope .a-Form-static--borderHalf {
  border-bottom: var(--Form-input-borderWidth) solid var(--Form-input-borderColor);
  border-radius: var(--Form-input-borderRadius);
  padding: var(--Form-input-paddingY) var(--Form-input-paddingX);
}

.amis-scope .a-Form-label {
  font-weight: var(--fontWeightNormal);
  margin-bottom: var(--gap-xs);
  position: relative;
}

.amis-scope .a-Form-label > span {
  position: relative;
}

.amis-scope .a-Form-star {
  color: var(--danger);
  font-size: var(--fontSizeXs);
  line-height: 1;
}

.amis-scope .a-Form-feedback {
  color: var(--danger);
  margin: var(--Form-input-marginBottom) 0 0;
  padding-left: var(--gap-base);
  font-size: var(--fontSizeSm);
}

.amis-scope .a-Form-description {
  display: block;
  color: var(--Form-description-color);
  margin: var(--Form-input-marginBottom) 0 0;
  font-size: var(--Form-description-fontSize);
}

.amis-scope .a-Form-hint {
  display: inline-block;
  margin-left: var(--gap-sm);
  padding-top: var(--Form-input-paddingY);
  vertical-align: top;
}

.amis-scope .a-Form-item {
  margin-bottom: var(--Form-item-gap);
}

.amis-scope .a-Form-item:last-child {
  margin-bottom: 0;
}

.amis-scope .a-Grid-form > .a-Form-item:last-child {
  margin-bottom: 0;
}

.amis-scope .a-Form--inline > .a-Form-item--inline:last-child {
  margin-right: 0;
  margin-bottom: 0;
}

.amis-scope .a-Form-item .a-Form-remark {
  padding-top: var(--Form-label-paddingTop);
  vertical-align: top;
}

.amis-scope .a-Form-item--inline {
  margin-bottom: calc(var(--Form-item-gap) / 2);
  margin-right: calc(var(--Form-item-gap) / 2);
}

.amis-scope .a-Form-item--horizontal > .a-Form-label {
  text-align: var(--Form--horizontal-label-align);
  white-space: var(--Form--horizontal-label-whiteSpace);
}

.amis-scope .a-Form-item--normal > .a-Form-label {
  display: block;
}

.amis-scope .a-Form-item--normal > .a-Form-label .a-Form-star {
  position: absolute;
  left: -0.375rem;
  top: 0.1875rem;
}

.amis-scope .a-Form-item.is-error > .a-Form-label {
  color: var(--danger);
}

.amis-scope .a-Form-placeholder {
  color: var(--Form-input-placeholderColor);
}

.amis-scope .a-Form-caption {
  display: inline-block;
  line-height: var(--Form-input-height);
  height: var(--Form-input-height);
  margin-left: 0.625rem;
}

@media (min-width: 576px) {
  .amis-scope .a-Form-label {
    display: inline-block;
    max-width: 100%;
  }

  .amis-scope .a-Form-control--sizeXs {
    width: var(--Form-control-widthXs);
    max-width: 100%;
    display: inline-block;
    vertical-align: top;
  }

  .amis-scope .a-Form-control--sizeXs.a-NumberControl {
    width: var(--Form-control-widthXs);
  }

  .amis-scope .a-Form-control--sizeXs.a-TextareaControl {
    width: auto;
  }

  .amis-scope .a-Form-control--sizeSm {
    width: var(--Form-control-widthSm);
    max-width: 100%;
    display: inline-block;
    vertical-align: top;
  }

  .amis-scope .a-Form-control--sizeSm.a-NumberControl {
    width: var(--Form-control-widthSm);
  }

  .amis-scope .a-Form-control--sizeSm.a-TextareaControl {
    width: auto;
  }

  .amis-scope .a-Form-control--sizeMd {
    width: var(--Form-control-widthMd);
    max-width: 100%;
    display: inline-block;
    vertical-align: top;
  }

  .amis-scope .a-Form-control--sizeMd.a-TextareaControl {
    width: auto;
  }

  .amis-scope .a-Form-control--sizeLg {
    width: var(--Form-control-widthLg);
    max-width: 100%;
    display: inline-block;
    vertical-align: top;
  }

  .amis-scope .a-Form-control--sizeLg.a-NumberControl {
    width: var(--Form-control-widthLg);
  }

  .amis-scope .a-Form-control--sizeLg.a-TextareaControl {
    width: auto;
  }

  .amis-scope .a-Form-item--horizontal {
    display: flex;
    flex-wrap: nowrap;
    margin-left: calc(var(--Form--horizontal-gutterWidth) / 2 * -1);
    margin-right: calc(var(--Form--horizontal-gutterWidth) / 2 * -1);
  }

  .amis-scope .a-Form-item--horizontal > * {
    padding-left: calc(var(--Form--horizontal-gutterWidth) / 2);
    padding-right: calc(var(--Form--horizontal-gutterWidth) / 2);
  }

  .amis-scope .a-Form-item--horizontal > .a-Form-value {
    flex-basis: 0;
    flex-grow: 1;
    max-width: 100%;
    min-width: 0;
  }

  .amis-scope .a-Form-item--horizontal .a-Form-itemColumn--xs,
  .amis-scope .a-Form-item--horizontal .a-Form-itemColumn--sm,
  .amis-scope .a-Form-item--horizontal .a-Form-itemColumn--normal,
  .amis-scope .a-Form-item--horizontal .a-Form-itemColumn--auto,
  .amis-scope .a-Form-item--horizontal .a-Form-itemColumn--md,
  .amis-scope .a-Form-item--horizontal .a-Form-itemColumn--lg {
    flex-grow: unset;
    flex-basis: unset;
  }

  .amis-scope .a-Form-item--horizontal > .a-Form-label {
    padding-top: var(--Form-label-paddingTop);
    margin-bottom: 0;
    flex-shrink: 0;
  }

  .amis-scope .a-Form-item--horizontal > .a-Form-label .a-Form-star {
    position: absolute;
    left: -0.375rem;
    top: 0.1875rem;
  }

  .amis-scope .a-Form-item--horizontal .a-Form-itemColumn--xs {
    width: var(--Form--horizontal-label-widthXs);
  }

  .amis-scope .a-Form-item--horizontal .a-Form-itemColumn--sm {
    width: var(--Form--horizontal-label-widthSm);
  }

  .amis-scope .a-Form-item--horizontal .a-Form-itemColumn--normal {
    width: var(--Form--horizontal-label-widthBase);
  }

  .amis-scope .a-Form-item--horizontal .a-Form-itemColumn--md {
    width: var(--Form--horizontal-label-widthMd);
  }

  .amis-scope .a-Form-item--horizontal .a-Form-itemColumn--lg {
    width: var(--Form--horizontal-label-widthLg);
  }

  .amis-scope .a-Form-item--horizontal .a-Form-itemColumn--auto {
    width: auto;
  }

  .amis-scope .a-Form-item--horizontal .a-Form-itemColumn--1 {
    flex: 0 0 8.3333333333%;
    max-width: 8.3333333333%;
    min-height: 1px;
  }

  .amis-scope .a-Form-item--horizontal .a-Form-itemColumn--2 {
    flex: 0 0 16.6666666667%;
    max-width: 16.6666666667%;
    min-height: 1px;
  }

  .amis-scope .a-Form-item--horizontal .a-Form-itemColumn--3 {
    flex: 0 0 25%;
    max-width: 25%;
    min-height: 1px;
  }

  .amis-scope .a-Form-item--horizontal .a-Form-itemColumn--4 {
    flex: 0 0 33.3333333333%;
    max-width: 33.3333333333%;
    min-height: 1px;
  }

  .amis-scope .a-Form-item--horizontal .a-Form-itemColumn--5 {
    flex: 0 0 41.6666666667%;
    max-width: 41.6666666667%;
    min-height: 1px;
  }

  .amis-scope .a-Form-item--horizontal .a-Form-itemColumn--6 {
    flex: 0 0 50%;
    max-width: 50%;
    min-height: 1px;
  }

  .amis-scope .a-Form-item--horizontal .a-Form-itemColumn--7 {
    flex: 0 0 58.3333333333%;
    max-width: 58.3333333333%;
    min-height: 1px;
  }

  .amis-scope .a-Form-item--horizontal .a-Form-itemColumn--8 {
    flex: 0 0 66.6666666667%;
    max-width: 66.6666666667%;
    min-height: 1px;
  }

  .amis-scope .a-Form-item--horizontal .a-Form-itemColumn--9 {
    flex: 0 0 75%;
    max-width: 75%;
    min-height: 1px;
  }

  .amis-scope .a-Form-item--horizontal .a-Form-itemColumn--10 {
    flex: 0 0 83.3333333333%;
    max-width: 83.3333333333%;
    min-height: 1px;
  }

  .amis-scope .a-Form-item--horizontal .a-Form-itemColumn--11 {
    flex: 0 0 91.6666666667%;
    max-width: 91.6666666667%;
    min-height: 1px;
  }

  .amis-scope .a-Form-item--horizontal .a-Form-itemColumn--12 {
    flex: 0 0 100%;
    max-width: 100%;
    min-height: 1px;
  }

  .amis-scope .a-Form-item--inline {
    display: inline-block;
    vertical-align: top;
  }

  .amis-scope .a-Form-item--inline > .a-Form-label {
    padding-top: var(--Form-label-paddingTop);
    margin-bottom: 0;
    margin-right: calc(var(--Form-item-gap) / 2);
  }

  .amis-scope .a-Form-item--inline > .a-Form-label .a-Form-star {
    position: static;
  }

  .amis-scope .a-Form-item--inline > .a-Form-value {
    display: inline-block;
    vertical-align: top;
  }

  .amis-scope .a-Form-item--inline > .a-Form-value > .a-Button--link {
    padding-top: var(--Form-label-paddingTop);
  }

  .amis-scope .a-Form-item--inline > .a-Form-value > .a-Form-control {
    vertical-align: top;
    display: inline-block;
  }

  .amis-scope .a-Form-item--inline > .a-Form-value > .a-Form-control.a-InputGroup {
    display: inline-flex;
  }

  .amis-scope .a-Form-item--inline > .a-Form-value > .a-TextControl--withAddOn {
    display: inline-flex;
  }

  .amis-scope .a-Form-row {
    display: flex;
    flex-wrap: wrap;
    margin-left: calc(var(--Form-row-gutterWidth) / -2);
    margin-right: calc(var(--Form-row-gutterWidth) / -2);
    align-items: flex-start;
  }

  .amis-scope .a-Form-row > * {
    padding-left: calc(var(--Form-row-gutterWidth) / 2);
    padding-right: calc(var(--Form-row-gutterWidth) / 2);
  }

  .amis-scope .a-Form-col {
    flex-basis: 0;
    flex-grow: 1;
    flex-shrink: 1;
  }

  .amis-scope .a-Form-rowInner {
    display: flex;
    flex-wrap: nowrap;
  }

  .amis-scope .a-Form-rowInner > .a-Form-label {
    display: inline-block;
    vertical-align: top;
    padding-top: var(--Form-label-paddingTop);
    padding-right: var(--Form-row-gutterWidth);
  }

  .amis-scope .a-Form-rowInner > .a-Form-control {
    flex-basis: 0;
    flex-grow: 1;
  }
}

.amis-scope .a-Form--quickEdit {
  min-width: var(--Form-control-widthSm);
}

.amis-scope .a-AnchorNav {
  display: flex;
  height: 25rem;
}

.amis-scope .a-AnchorNav-link-wrap {
  margin: 0;
  padding: 0;
  width: var(--Tabs--vertical-width);
  border-right: var(--AnchorNav-links-container-borderRight);
  padding-bottom: 3.75rem;
}

.amis-scope .a-AnchorNav-link-wrap > .a-AnchorNav-link {
  position: relative;
  display: block;
}

.amis-scope .a-AnchorNav-link-wrap > .a-AnchorNav-link > a {
  display: block;
  border: var(--Tabs-borderWidth) solid transparent;
  border-width: var(--AnchorNav-onActive-borderWidth);
  color: var(--Tabs-color);
  padding: var(--Tabs-linkPadding);
  font-size: var(--Tabs-linkFontSize);
  outline: none;
  text-align: right;
  text-decoration: none;
  cursor: pointer;
  margin: 0;
}

.amis-scope .a-AnchorNav-link-wrap > .a-AnchorNav-link > a:hover {
  color: var(--primary);
}

.amis-scope .a-AnchorNav-link-wrap > .a-AnchorNav-link.is-active > a,
.amis-scope .a-AnchorNav-link-wrap > .a-AnchorNav-link.is-active > a:hover {
  color: var(--Tabs--vertical-onActive-color);
  border-color: var(--Tabs--vertical-onActive-border);
}

.amis-scope .a-AnchorNav-section-wrap {
  border: none;
  flex-grow: 1;
  overflow: auto;
  background: var(--Tabs-content-bg);
}

.amis-scope .a-AnchorNav-section-wrap > .a-AnchorNav-section {
  display: block;
  padding: var(--gap-base);
}

/*
 * utilities
 */

.amis-scope .bg-light {
  background-color: #edf1f2;
  color: #58666e;
}

.amis-scope .bg-light.lt,
.amis-scope .bg-light .lt {
  background: #f3f5f6;
}

.amis-scope .bg-light.lter,
.amis-scope .bg-light .lter {
  background: #f6f8f8;
}

.amis-scope .bg-light.dk,
.amis-scope .bg-light .dk {
  background: #e4eaec;
}

.amis-scope .bg-light.dker,
.amis-scope .bg-light .dker {
  background: #dde6e9;
}

.amis-scope .bg-light.bg,
.amis-scope .bg-light .bg {
  background-color: #edf1f2;
}

.amis-scope .bg-dark {
  background-color: #3a3f51;
  color: #a6a8b1;
}

.amis-scope .bg-dark.lt,
.amis-scope .bg-dark .lt {
  background: #474c5e;
}

.amis-scope .bg-dark.lter,
.amis-scope .bg-dark .lter {
  background: #54596a;
}

.amis-scope .bg-dark.dk,
.amis-scope .bg-dark .dk {
  background: #2e3344;
}

.amis-scope .bg-dark.dker,
.amis-scope .bg-dark .dker {
  background: #232735;
}

.amis-scope .bg-dark.bg,
.amis-scope .bg-dark .bg {
  background-color: #3a3f51;
}

.amis-scope .bg-dark a,
.amis-scope .bg-dark .a-Button--link {
  color: #c1c3c9;
}

.amis-scope .bg-dark a:hover,
.amis-scope .bg-dark .a-Button--link:hover {
  color: #fff;
}

.amis-scope .bg-dark .open > a,
.amis-scope .bg-dark .open > a:hover,
.amis-scope .bg-dark .open > a:focus {
  color: #fff;
}

.amis-scope .bg-dark .text-muted {
  color: #414c52 !important;
}

.amis-scope .bg-dark .text-lt {
  color: #99a6ad !important;
}

.amis-scope .bg-black {
  background-color: #1c2b36;
  color: #7793a7;
}

.amis-scope .bg-black.lt,
.amis-scope .bg-black .lt {
  background: #263845;
}

.amis-scope .bg-black.lter,
.amis-scope .bg-black .lter {
  background: #314554;
}

.amis-scope .bg-black.dk,
.amis-scope .bg-black .dk {
  background: #131e26;
}

.amis-scope .bg-black.dker,
.amis-scope .bg-black .dker {
  background: #0a1015;
}

.amis-scope .bg-black.bg,
.amis-scope .bg-black .bg {
  background-color: #1c2b36;
}

.amis-scope .bg-black a,
.amis-scope .bg-black .a-Button--link {
  color: #96abbb;
}

.amis-scope .bg-black a:hover,
.amis-scope .bg-black .a-Button--link:hover {
  color: #fff;
}

.amis-scope .bg-black .open > a,
.amis-scope .bg-black .open > a:hover,
.amis-scope .bg-black .open > a:focus {
  color: #fff;
}

.amis-scope .bg-black .text-muted {
  color: #414c52 !important;
}

.amis-scope .bg-black .text-lt {
  color: #99a6ad !important;
}

.amis-scope .bg-primary {
  background-color: #7266ba;
  color: #f4f3f9;
}

.amis-scope .bg-primary.lt,
.amis-scope .bg-primary .lt {
  background: #847abf;
}

.amis-scope .bg-primary.lter,
.amis-scope .bg-primary .lter {
  background: #958dc6;
}

.amis-scope .bg-primary.dk,
.amis-scope .bg-primary .dk {
  background: #6051b5;
}

.amis-scope .bg-primary.dker,
.amis-scope .bg-primary .dker {
  background: #5244a9;
}

.amis-scope .bg-primary.bg,
.amis-scope .bg-primary .bg {
  background-color: #7266ba;
}

.amis-scope .bg-primary a,
.amis-scope .bg-primary .a-Button--link {
  color: white;
}

.amis-scope .bg-primary a:hover,
.amis-scope .bg-primary .a-Button--link:hover {
  color: #fff;
}

.amis-scope .bg-primary .open > a,
.amis-scope .bg-primary .open > a:hover,
.amis-scope .bg-primary .open > a:focus {
  color: #fff;
}

.amis-scope .bg-primary .text-muted {
  color: #414c52 !important;
}

.amis-scope .bg-primary .text-lt {
  color: #99a6ad !important;
}

.amis-scope .bg-success {
  background-color: #27c24c;
  color: #c6efd0;
}

.amis-scope .bg-success.lt,
.amis-scope .bg-success .lt {
  background: #31d257;
}

.amis-scope .bg-success.lter,
.amis-scope .bg-success .lter {
  background: #48d46a;
}

.amis-scope .bg-success.dk,
.amis-scope .bg-success .dk {
  background: #20af42;
}

.amis-scope .bg-success.dker,
.amis-scope .bg-success .dker {
  background: #1a9c39;
}

.amis-scope .bg-success.bg,
.amis-scope .bg-success .bg {
  background-color: #27c24c;
}

.amis-scope .bg-success a,
.amis-scope .bg-success .a-Button--link {
  color: #eefaf1;
}

.amis-scope .bg-success a:hover,
.amis-scope .bg-success .a-Button--link:hover {
  color: #fff;
}

.amis-scope .bg-success .open > a,
.amis-scope .bg-success .open > a:hover,
.amis-scope .bg-success .open > a:focus {
  color: #fff;
}

.amis-scope .bg-success .text-muted {
  color: #414c52 !important;
}

.amis-scope .bg-success .text-lt {
  color: #99a6ad !important;
}

.amis-scope .bg-info {
  background-color: #23b7e5;
  color: #dcf2f8;
}

.amis-scope .bg-info.lt,
.amis-scope .bg-info .lt {
  background: #3dbde5;
}

.amis-scope .bg-info.lter,
.amis-scope .bg-info .lter {
  background: #55c3e6;
}

.amis-scope .bg-info.dk,
.amis-scope .bg-info .dk {
  background: #16aad8;
}

.amis-scope .bg-info.dker,
.amis-scope .bg-info .dker {
  background: #1199c4;
}

.amis-scope .bg-info.bg,
.amis-scope .bg-info .bg {
  background-color: #23b7e5;
}

.amis-scope .bg-info a,
.amis-scope .bg-info .a-Button--link {
  color: white;
}

.amis-scope .bg-info a:hover,
.amis-scope .bg-info .a-Button--link:hover {
  color: #fff;
}

.amis-scope .bg-info .open > a,
.amis-scope .bg-info .open > a:hover,
.amis-scope .bg-info .open > a:focus {
  color: #fff;
}

.amis-scope .bg-info .text-muted {
  color: #414c52 !important;
}

.amis-scope .bg-info .text-lt {
  color: #99a6ad !important;
}

.amis-scope .bg-warning {
  background-color: #fad733;
  color: #fffefa;
}

.amis-scope .bg-warning.lt,
.amis-scope .bg-warning .lt {
  background: #f8da4e;
}

.amis-scope .bg-warning.lter,
.amis-scope .bg-warning .lter {
  background: #f7de69;
}

.amis-scope .bg-warning.dk,
.amis-scope .bg-warning .dk {
  background: #fcd417;
}

.amis-scope .bg-warning.dker,
.amis-scope .bg-warning .dker {
  background: #face00;
}

.amis-scope .bg-warning.bg,
.amis-scope .bg-warning .bg {
  background-color: #fad733;
}

.amis-scope .bg-warning a,
.amis-scope .bg-warning .a-Button--link {
  color: white;
}

.amis-scope .bg-warning a:hover,
.amis-scope .bg-warning .a-Button--link:hover {
  color: #fff;
}

.amis-scope .bg-warning .open > a,
.amis-scope .bg-warning .open > a:hover,
.amis-scope .bg-warning .open > a:focus {
  color: #fff;
}

.amis-scope .bg-warning .text-muted {
  color: #414c52 !important;
}

.amis-scope .bg-warning .text-lt {
  color: #99a6ad !important;
}

.amis-scope .bg-danger {
  background-color: #f05050;
  color: white;
}

.amis-scope .bg-danger.lt,
.amis-scope .bg-danger .lt {
  background: #f06a6a;
}

.amis-scope .bg-danger.lter,
.amis-scope .bg-danger .lter {
  background: #f18282;
}

.amis-scope .bg-danger.dk,
.amis-scope .bg-danger .dk {
  background: #f13636;
}

.amis-scope .bg-danger.dker,
.amis-scope .bg-danger .dker {
  background: #f21b1b;
}

.amis-scope .bg-danger.bg,
.amis-scope .bg-danger .bg {
  background-color: #f05050;
}

.amis-scope .bg-danger a,
.amis-scope .bg-danger .a-Button--link {
  color: white;
}

.amis-scope .bg-danger a:hover,
.amis-scope .bg-danger .a-Button--link:hover {
  color: #fff;
}

.amis-scope .bg-danger .open > a,
.amis-scope .bg-danger .open > a:hover,
.amis-scope .bg-danger .open > a:focus {
  color: #fff;
}

.amis-scope .bg-danger .text-muted {
  color: #414c52 !important;
}

.amis-scope .bg-danger .text-lt {
  color: #99a6ad !important;
}

.amis-scope .bg-white {
  background-color: #fff;
  color: #58666e;
}

.amis-scope .bg-white.lt,
.amis-scope .bg-white .lt {
  background: white;
}

.amis-scope .bg-white.lter,
.amis-scope .bg-white .lter {
  background: white;
}

.amis-scope .bg-white.dk,
.amis-scope .bg-white .dk {
  background: #f3f2f2;
}

.amis-scope .bg-white.dker,
.amis-scope .bg-white .dker {
  background: #e7e4e4;
}

.amis-scope .bg-white.bg,
.amis-scope .bg-white .bg {
  background-color: #fff;
}

.amis-scope .bg-none {
  background: none !important;
}

.amis-scope a.bg-primary:hover {
  background: #6254b2;
}

.amis-scope a.text-primary:hover {
  color: #6254b2;
}

.amis-scope .text-primary {
  color: #7266ba;
}

.amis-scope .text-primary-lt {
  color: #6254b2;
}

.amis-scope .text-primary-lter {
  color: #564aa3;
}

.amis-scope .text-primary-dk {
  color: #6254b2;
}

.amis-scope .text-primary-dker {
  color: #564aa3;
}

.amis-scope a.bg-info:hover {
  background: #19a9d5;
}

.amis-scope a.text-info:hover {
  color: #19a9d5;
}

.amis-scope .text-info {
  color: #23b7e5;
}

.amis-scope .text-info-lt {
  color: #19a9d5;
}

.amis-scope .text-info-lter {
  color: #1797be;
}

.amis-scope .text-info-dk {
  color: #19a9d5;
}

.amis-scope .text-info-dker {
  color: #1797be;
}

.amis-scope a.bg-success:hover {
  background: #23ad44;
}

.amis-scope a.text-success:hover {
  color: #23ad44;
}

.amis-scope .text-success {
  color: #27c24c;
}

.amis-scope .text-success-lt {
  color: #23ad44;
}

.amis-scope .text-success-lter {
  color: #1e983b;
}

.amis-scope .text-success-dk {
  color: #23ad44;
}

.amis-scope .text-success-dker {
  color: #1e983b;
}

.amis-scope a.bg-warning:hover {
  background: #f9d21a;
}

.amis-scope a.text-warning:hover {
  color: #f9d21a;
}

.amis-scope .text-warning {
  color: #fad733;
}

.amis-scope .text-warning-lt {
  color: #f9d21a;
}

.amis-scope .text-warning-lter {
  color: #f4ca06;
}

.amis-scope .text-warning-dk {
  color: #f9d21a;
}

.amis-scope .text-warning-dker {
  color: #f4ca06;
}

.amis-scope a.bg-danger:hover {
  background: #ee3939;
}

.amis-scope a.text-danger:hover {
  color: #ee3939;
}

.amis-scope .text-danger {
  color: #f05050;
}

.amis-scope .text-danger-lt {
  color: #ee3939;
}

.amis-scope .text-danger-lter {
  color: #ec2121;
}

.amis-scope .text-danger-dk {
  color: #ee3939;
}

.amis-scope .text-danger-dker {
  color: #ec2121;
}

.amis-scope a.bg-dark:hover {
  background: #2f3342;
}

.amis-scope a.text-dark:hover {
  color: #2f3342;
}

.amis-scope .text-dark {
  color: #3a3f51;
}

.amis-scope .text-dark-lt {
  color: #2f3342;
}

.amis-scope .text-dark-lter {
  color: #252833;
}

.amis-scope .text-dark-dk {
  color: #2f3342;
}

.amis-scope .text-dark-dker {
  color: #252833;
}

.amis-scope a.bg-white:hover {
  background: #f2f2f2;
}

.amis-scope a.text-white:hover {
  color: #f2f2f2;
}

.amis-scope .text-white {
  color: #fff;
}

.amis-scope .text-white-lt {
  color: #f2f2f2;
}

.amis-scope .text-white-lter {
  color: #e6e6e6;
}

.amis-scope .text-white-dk {
  color: #f2f2f2;
}

.amis-scope .text-white-dker {
  color: #e6e6e6;
}

.amis-scope a.bg-black:hover {
  background: #131e25;
}

.amis-scope a.text-black:hover {
  color: #131e25;
}

.amis-scope .text-black {
  color: #1c2b36;
}

.amis-scope .text-black-lt {
  color: #131e25;
}

.amis-scope .text-black-lter {
  color: #0b1014;
}

.amis-scope .text-black-dk {
  color: #131e25;
}

.amis-scope .text-black-dker {
  color: #0b1014;
}

.amis-scope .text-muted {
  color: var(--text--muted-color);
}

.amis-scope .text-loud {
  color: var(--text--loud-color);
}

.amis-scope .clearfix::before,
.amis-scope .clearfix::after {
  display: table;
  content: "";
}

.amis-scope .clearfix::after {
  clear: both;
}

.amis-scope .pos-rlt {
  position: relative;
}

.amis-scope .pos-stc {
  position: static !important;
}

.amis-scope .pos-abt {
  position: absolute;
}

.amis-scope .pos-fix {
  position: fixed;
}

.amis-scope .show {
  visibility: visible;
}

.amis-scope .line {
  height: 2px;
  margin: 10px 0;
  font-size: 0;
  overflow: hidden;
}

.amis-scope .line-xs {
  margin: 0;
}

.amis-scope .line-lg {
  margin-top: 15px;
  margin-bottom: 15px;
}

.amis-scope .line-dashed {
  border-style: dashed !important;
  background: transparent;
  border-width: 0;
}

.amis-scope .no-line {
  border-width: 0;
}

.amis-scope .no-border,
.amis-scope .no-borders {
  border-color: transparent;
  border-width: 0;
}

.amis-scope .no-b-t {
  border-top-width: 0;
}

.amis-scope .no-b-r {
  border-right-width: 0;
}

.amis-scope .no-b-b {
  border-bottom-width: 0;
}

.amis-scope .no-b-l {
  border-left-width: 0;
}

.amis-scope .no-radius {
  border-radius: 0;
}

.amis-scope .block {
  display: block;
}

.amis-scope .block.hide {
  display: none;
}

.amis-scope .inline {
  display: inline-block;
}

.amis-scope .none {
  display: none;
}

.amis-scope .pull-none {
  float: none;
}

.amis-scope .pull-right {
  float: right;
}

.amis-scope .pull-left {
  float: left;
}

.amis-scope .rounded {
  border-radius: 500px;
}

.amis-scope .clear {
  display: block;
  overflow: hidden;
}

.amis-scope .no-bg {
  background: transparent;
  color: inherit;
}

.amis-scope .no-select {
  user-select: none;
}

.amis-scope .l-h {
  line-height: var(--lineHeightBase);
}

.amis-scope .l-h-0x {
  line-height: 0;
}

.amis-scope .l-h-1x {
  line-height: 1.2;
}

.amis-scope .l-h-2x {
  line-height: 2em;
}

.amis-scope .l-s-1x {
  letter-spacing: 1;
}

.amis-scope .l-s-2x {
  letter-spacing: 2;
}

.amis-scope .l-s-3x {
  letter-spacing: 3;
}

.amis-scope .font-normal {
  font-weight: normal;
}

.amis-scope .font-thin {
  font-weight: 300;
}

.amis-scope .font-bold {
  font-weight: 700;
}

.amis-scope .text-5x {
  font-size: 5em;
}

.amis-scope .text-4x {
  font-size: 4em;
}

.amis-scope .text-3x {
  font-size: 3em;
}

.amis-scope .text-2x {
  font-size: 2em;
}

.amis-scope .text-xl {
  font-size: var(--fontSizeXl) !important;
}

.amis-scope .text-lg {
  font-size: var(--fontSizeLg) !important;
}

.amis-scope .text-md {
  font-size: var(--fontSizeMd) !important;
}

.amis-scope .text-base {
  font-size: var(--fontSizeBase) !important;
}

.amis-scope .text-sm {
  font-size: var(--fontSizeSm) !important;
}

.amis-scope .text-xs {
  font-size: var(--fontSizeXs) !important;
}

.amis-scope .text-xxs {
  text-indent: -9999px;
}

.amis-scope .text-ellipsis {
  display: block;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
}

.amis-scope .text-u-c {
  text-transform: uppercase;
}

.amis-scope .text-l-t {
  text-decoration: line-through;
}

.amis-scope .text-u-l {
  text-decoration: underline;
}

.amis-scope .text-left {
  text-align: left;
}

.amis-scope .text-center {
  text-align: center;
}

.amis-scope .text-right {
  text-align: right;
}

.amis-scope .box-shadow {
  box-shadow: 0 2px 2px rgba(0, 0, 0, 0.05), 0 1px 0 rgba(0, 0, 0, 0.05);
}

.amis-scope .box-shadow-lg {
  box-shadow: 5px 5px 10px rgba(0, 0, 0, 0.05);
}

.amis-scope .text-shadow {
  font-size: 170px;
  text-shadow: 0 1px 0 var(--borderColor), 0 2px 0 var(--borderColorLight), 0 5px 10px rgba(0, 0, 0, 0.125), 0 10px 20px rgba(0, 0, 0, 0.2);
}

.amis-scope .no-shadow {
  box-shadow: none !important;
}

.amis-scope .wrapper-xs {
  padding: 5px;
}

.amis-scope .wrapper-sm {
  padding: 10px;
}

.amis-scope .wrapper {
  padding: 15px;
}

.amis-scope .wrapper-md {
  padding: 20px;
}

.amis-scope .wrapper-lg {
  padding: 30px;
}

.amis-scope .wrapper-xl {
  padding: 50px;
}

.amis-scope .padder-lg {
  padding-left: 30px;
  padding-right: 30px;
}

.amis-scope .padder-md {
  padding-left: 20px;
  padding-right: 20px;
}

.amis-scope .padder {
  padding-left: 15px;
  padding-right: 15px;
}

.amis-scope .padder-v-xs {
  padding-top: 5px;
  padding-bottom: 5px;
}

.amis-scope .padder-v-sm {
  padding-top: 10px;
  padding-bottom: 10px;
}

.amis-scope .padder-v {
  padding-top: 15px;
  padding-bottom: 15px;
}

.amis-scope .padder-v-md {
  padding-top: 20px;
  padding-bottom: 20px;
}

.amis-scope .padder-v-lg {
  padding-top: 30px;
  padding-bottom: 30px;
}

.amis-scope .no-padder {
  padding: 0 !important;
}

.amis-scope .pull-in {
  margin-left: -15px;
  margin-right: -15px;
}

.amis-scope .pull-in-md {
  margin-left: -20px;
  margin-right: -20px;
}

.amis-scope .pull-in-sm {
  margin-left: -10px;
  margin-right: -10px;
}

.amis-scope .pull-out {
  margin: -10px -15px;
}

.amis-scope .b {
  border: 1px solid rgba(0, 0, 0, 0.05);
}

.amis-scope .b-a {
  border: 1px solid var(--borderColor);
}

.amis-scope .b-t {
  border-top: 1px solid var(--borderColor);
}

.amis-scope .b-t-none {
  border-top-width: 0;
}

.amis-scope .b-r {
  border-right: 1px solid var(--borderColor);
}

.amis-scope .b-r-none {
  border-right-width: 0;
}

.amis-scope .b-b {
  border-bottom: 1px solid var(--borderColor);
}

.amis-scope .b-b-none {
  border-bottom-width: 0;
}

.amis-scope .b-l {
  border-left: 1px solid var(--borderColor);
}

.amis-scope .b-l-none {
  border-left-width: 0;
}

.amis-scope .b-light {
  border-color: var(--light);
}

.amis-scope .b-dark {
  border-color: var(--dark);
}

.amis-scope .b-black {
  border-color: var(--dark);
}

.amis-scope .b-primary {
  border-color: var(--primary);
}

.amis-scope .b-success {
  border-color: var(--success);
}

.amis-scope .b-info {
  border-color: var(--info);
}

.amis-scope .b-warning {
  border-color: var(--warning);
}

.amis-scope .b-danger {
  border-color: var(--danger);
}

.amis-scope .b-white {
  border-color: #fff;
}

.amis-scope .b-dashed {
  border-style: dashed !important;
}

.amis-scope .b-l-light {
  border-left-color: var(--light);
}

.amis-scope .b-l-dark {
  border-left-color: var(--dark);
}

.amis-scope .b-l-black {
  border-left-color: var(--dark);
}

.amis-scope .b-l-primary {
  border-left-color: var(--primary);
}

.amis-scope .b-l-success {
  border-left-color: var(--success);
}

.amis-scope .b-l-info {
  border-left-color: var(--info);
}

.amis-scope .b-l-warning {
  border-left-color: var(--warning);
}

.amis-scope .b-l-danger {
  border-left-color: var(--danger);
}

.amis-scope .b-l-white {
  border-left-color: #fff;
}

.amis-scope .b-l-2x {
  border-left-width: 2px;
}

.amis-scope .b-l-3x {
  border-left-width: 3px;
}

.amis-scope .b-l-4x {
  border-left-width: 4px;
}

.amis-scope .b-l-5x {
  border-left-width: 5px;
}

.amis-scope .b-2x {
  border-width: 2px;
}

.amis-scope .b-3x {
  border-width: 3px;
}

.amis-scope .b-4x {
  border-width: 4px;
}

.amis-scope .b-5x {
  border-width: 5px;
}

.amis-scope .r {
  border-radius: var(--borderRadius) var(--borderRadius) var(--borderRadius) var(--borderRadius);
}

.amis-scope .r-2x {
  border-radius: var(--borderRadiusMd);
}

.amis-scope .r-3x {
  border-radius: var(--borderRadiusLg);
}

.amis-scope .r-l {
  border-radius: var(--borderRadius) 0 0 var(--borderRadius);
}

.amis-scope .r-r {
  border-radius: 0 var(--borderRadius) var(--borderRadius) 0;
}

.amis-scope .r-t {
  border-radius: var(--borderRadius) var(--borderRadius) 0 0;
}

.amis-scope .r-b {
  border-radius: 0 0 var(--borderRadius) var(--borderRadius);
}

.amis-scope .m-xxs {
  margin: 2px 4px;
}

.amis-scope .m-xs {
  margin: 5px;
}

.amis-scope .m-sm {
  margin: 10px;
}

.amis-scope .m {
  margin: 15px;
}

.amis-scope .m-md {
  margin: 20px;
}

.amis-scope .m-lg {
  margin: 30px;
}

.amis-scope .m-xl {
  margin: 50px;
}

.amis-scope .m-n,
.amis-scope .m-none {
  margin: 0 !important;
}

.amis-scope .m-l-none {
  margin-left: 0 !important;
}

.amis-scope .m-l-xs {
  margin-left: 5px;
}

.amis-scope .m-l-sm {
  margin-left: 10px;
}

.amis-scope .m-l {
  margin-left: 15px;
}

.amis-scope .m-l-md {
  margin-left: 20px;
}

.amis-scope .m-l-lg {
  margin-left: 30px;
}

.amis-scope .m-l-xl {
  margin-left: 40px;
}

.amis-scope .m-l-xxl {
  margin-left: 50px;
}

.amis-scope .m-l-n-xxs {
  margin-left: -1px;
}

.amis-scope .m-l-n-xs {
  margin-left: -5px;
}

.amis-scope .m-l-n-sm {
  margin-left: -10px;
}

.amis-scope .m-l-n {
  margin-left: -15px;
}

.amis-scope .m-l-n-md {
  margin-left: -20px;
}

.amis-scope .m-l-n-lg {
  margin-left: -30px;
}

.amis-scope .m-l-n-xl {
  margin-left: -40px;
}

.amis-scope .m-l-n-xxl {
  margin-left: -50px;
}

.amis-scope .m-t-none {
  margin-top: 0 !important;
}

.amis-scope .m-t-xxs {
  margin-top: 1px;
}

.amis-scope .m-t-xs {
  margin-top: 5px;
}

.amis-scope .m-t-sm {
  margin-top: 10px;
}

.amis-scope .m-t {
  margin-top: 15px;
}

.amis-scope .m-t-md {
  margin-top: 20px;
}

.amis-scope .m-t-lg {
  margin-top: 30px;
}

.amis-scope .m-t-xl {
  margin-top: 40px;
}

.amis-scope .m-t-xxl {
  margin-top: 50px;
}

.amis-scope .m-t-n-xxs {
  margin-top: -1px;
}

.amis-scope .m-t-n-xs {
  margin-top: -5px;
}

.amis-scope .m-t-n-sm {
  margin-top: -10px;
}

.amis-scope .m-t-n {
  margin-top: -15px;
}

.amis-scope .m-t-n-md {
  margin-top: -20px;
}

.amis-scope .m-t-n-lg {
  margin-top: -30px;
}

.amis-scope .m-t-n-xl {
  margin-top: -40px;
}

.amis-scope .m-t-n-xxl {
  margin-top: -50px;
}

.amis-scope .m-r-none {
  margin-right: 0 !important;
}

.amis-scope .m-r-xxs {
  margin-right: 1px;
}

.amis-scope .m-r-xs {
  margin-right: 5px;
}

.amis-scope .m-r-sm {
  margin-right: 10px;
}

.amis-scope .m-r {
  margin-right: 15px;
}

.amis-scope .m-r-md {
  margin-right: 20px;
}

.amis-scope .m-r-lg {
  margin-right: 30px;
}

.amis-scope .m-r-xl {
  margin-right: 40px;
}

.amis-scope .m-r-xxl {
  margin-right: 50px;
}

.amis-scope .m-r-n-xxs {
  margin-right: -1px;
}

.amis-scope .m-r-n-xs {
  margin-right: -5px;
}

.amis-scope .m-r-n-sm {
  margin-right: -10px;
}

.amis-scope .m-r-n {
  margin-right: -15px;
}

.amis-scope .m-r-n-md {
  margin-right: -20px;
}

.amis-scope .m-r-n-lg {
  margin-right: -30px;
}

.amis-scope .m-r-n-xl {
  margin-right: -40px;
}

.amis-scope .m-r-n-xxl {
  margin-right: -50px;
}

.amis-scope .m-b-none {
  margin-bottom: 0 !important;
}

.amis-scope .m-b-xxs {
  margin-bottom: 1px;
}

.amis-scope .m-b-xs {
  margin-bottom: 5px;
}

.amis-scope .m-b-sm {
  margin-bottom: 10px;
}

.amis-scope .m-b {
  margin-bottom: 15px;
}

.amis-scope .m-b-md {
  margin-bottom: 20px;
}

.amis-scope .m-b-lg {
  margin-bottom: 30px;
}

.amis-scope .m-b-xl {
  margin-bottom: 40px;
}

.amis-scope .m-b-xxl {
  margin-bottom: 50px;
}

.amis-scope .m-b-n-xxs {
  margin-bottom: -1px;
}

.amis-scope .m-b-n-xs {
  margin-bottom: -5px;
}

.amis-scope .m-b-n-sm {
  margin-bottom: -10px;
}

.amis-scope .m-b-n {
  margin-bottom: -15px;
}

.amis-scope .m-b-n-md {
  margin-bottom: -20px;
}

.amis-scope .m-b-n-lg {
  margin-bottom: -30px;
}

.amis-scope .m-b-n-xl {
  margin-bottom: -40px;
}

.amis-scope .m-b-n-xxl {
  margin-bottom: -50px;
}

.amis-scope .p-xxs {
  padding: 2px 4px;
}

.amis-scope .p-xs {
  padding: 5px;
}

.amis-scope .p-sm {
  padding: 10px;
}

.amis-scope .p {
  padding: 15px;
}

.amis-scope .p-md {
  padding: 20px;
}

.amis-scope .p-lg {
  padding: 30px;
}

.amis-scope .p-xl {
  padding: 50px;
}

.amis-scope .p-n,
.amis-scope .p-none {
  padding: 0 !important;
}

.amis-scope .p-l-none {
  padding-left: 0 !important;
}

.amis-scope .p-l-xs {
  padding-left: 5px;
}

.amis-scope .p-l-sm {
  padding-left: 10px;
}

.amis-scope .p-l {
  padding-left: 15px;
}

.amis-scope .p-l-md {
  padding-left: 20px;
}

.amis-scope .p-l-lg {
  padding-left: 30px;
}

.amis-scope .p-l-xl {
  padding-left: 40px;
}

.amis-scope .p-l-xxl {
  padding-left: 50px;
}

.amis-scope .p-t-none {
  padding-top: 0 !important;
}

.amis-scope .p-t-xxs {
  padding-top: 1px;
}

.amis-scope .p-t-xs {
  padding-top: 5px;
}

.amis-scope .p-t-sm {
  padding-top: 10px;
}

.amis-scope .p-t {
  padding-top: 15px;
}

.amis-scope .p-t-md {
  padding-top: 20px;
}

.amis-scope .p-t-lg {
  padding-top: 30px;
}

.amis-scope .p-t-xl {
  padding-top: 40px;
}

.amis-scope .p-t-xxl {
  padding-top: 50px;
}

.amis-scope .p-t-n-xxs {
  padding-top: -1px;
}

.amis-scope .p-r-none {
  padding-right: 0 !important;
}

.amis-scope .p-r-xxs {
  padding-right: 1px;
}

.amis-scope .p-r-xs {
  padding-right: 5px;
}

.amis-scope .p-r-sm {
  padding-right: 10px;
}

.amis-scope .p-r {
  padding-right: 15px;
}

.amis-scope .p-r-md {
  padding-right: 20px;
}

.amis-scope .p-r-lg {
  padding-right: 30px;
}

.amis-scope .p-r-xl {
  padding-right: 40px;
}

.amis-scope .p-r-xxl {
  padding-right: 50px;
}

.amis-scope .p-b-none {
  padding-bottom: 0 !important;
}

.amis-scope .p-b-xxs {
  padding-bottom: 1px;
}

.amis-scope .p-b-xs {
  padding-bottom: 5px;
}

.amis-scope .p-b-sm {
  padding-bottom: 10px;
}

.amis-scope .p-b {
  padding-bottom: 15px;
}

.amis-scope .p-b-md {
  padding-bottom: 20px;
}

.amis-scope .p-b-lg {
  padding-bottom: 30px;
}

.amis-scope .p-b-xl {
  padding-bottom: 40px;
}

.amis-scope .p-b-xxl {
  padding-bottom: 50px;
}

.amis-scope .avatar {
  position: relative;
  display: block;
  border-radius: 500px;
  white-space: nowrap;
}

.amis-scope .avatar img {
  border-radius: 500px;
  width: 100%;
}

.amis-scope .avatar i {
  position: absolute;
  left: 0;
  top: 0;
  width: 10px;
  height: 10px;
  margin: 2px;
  border-width: 2px;
  border-style: solid;
  border-radius: 100%;
}

.amis-scope .avatar i.right {
  left: auto;
  right: 0;
}

.amis-scope .avatar i.bottom {
  left: auto;
  top: auto;
  bottom: 0;
  right: 0;
}

.amis-scope .avatar i.left {
  top: auto;
  bottom: 0;
}

.amis-scope .avatar i.on {
  background: var(--success);
}

.amis-scope .avatar i.off {
  background: var(--text--muted-color);
}

.amis-scope .avatar i.busy {
  background: var(--danger);
}

.amis-scope .avatar i.away {
  background: var(--warning);
}

.amis-scope .avatar.thumb-md i {
  width: 12px;
  height: 12px;
  margin: 3px;
}

.amis-scope .avatar.thumb-sm i {
  margin: 1px;
}

.amis-scope .avatar.thumb-xs i {
  margin: 0;
}

.amis-scope .w-1x {
  width: 1em;
}

.amis-scope .w-2x {
  width: 2em;
}

.amis-scope .w-3x {
  width: 3em;
}

.amis-scope .w-xxs {
  width: 60px;
}

.amis-scope .h-xxs {
  height: 60px;
}

.amis-scope .w-xs {
  width: 90px;
}

.amis-scope .h-xs {
  height: 90px;
}

.amis-scope .w-ssm {
  width: 120px;
}

.amis-scope .w-sm {
  width: 150px;
}

.amis-scope .h-sm {
  height: 150px;
}

.amis-scope .h-ssm {
  height: 120px;
}

.amis-scope .w {
  width: 200px;
}

.amis-scope .h {
  height: 200px;
}

.amis-scope .w-md {
  width: 240px;
}

.amis-scope .h-md {
  height: 240px;
}

.amis-scope .w-lg {
  width: 280px;
}

.amis-scope .h-lg {
  height: 280px;
}

.amis-scope .w-xl {
  width: 320px;
}

.amis-scope .h-xl {
  height: 320px;
}

.amis-scope .w-xxl {
  width: 360px;
}

.amis-scope .h-xxl {
  height: 360px;
}

.amis-scope .w-xxxl {
  width: 420px;
}

.amis-scope .h-xxxl {
  height: 420px;
}

.amis-scope .w-full {
  width: 100%;
}

.amis-scope .w-auto {
  width: auto;
}

.amis-scope .h-auto {
  height: auto;
}

.amis-scope .h-full {
  height: 100%;
}

.amis-scope .no-grow {
  flex-grow: unset !important;
  flex-basis: unset !important;
}

.amis-scope .nowrap {
  white-space: nowrap;
  flex-wrap: nowrap;
}

@media (min-width: 576px) {
  .amis-scope .a-Form-col.w,
  .amis-scope .a-Form-col.w-xs,
  .amis-scope .a-Form-col.w-sm,
  .amis-scope .a-Form-col.w-md,
  .amis-scope .a-Form-col.w-lg {
    flex-basis: unset;
    flex-grow: unset;
  }
}

.amis-scope .thumb-xl {
  width: 128px;
  display: inline-block;
}

.amis-scope .thumb-lg {
  width: 96px;
  display: inline-block;
}

.amis-scope .thumb-md {
  width: 64px;
  display: inline-block;
}

.amis-scope .thumb {
  width: 50px;
  display: inline-block;
}

.amis-scope .thumb-sm {
  width: 40px;
  display: inline-block;
}

.amis-scope .thumb-xs {
  width: 34px;
  display: inline-block;
}

.amis-scope .thumb-xxs {
  width: 30px;
  display: inline-block;
}

.amis-scope .thumb-wrapper {
  padding: 2px;
  border: 1px solid var(--borderColor);
}

.amis-scope .thumb img,
.amis-scope .thumb-xxs img,
.amis-scope .thumb-xs img,
.amis-scope .thumb-sm img,
.amis-scope .thumb-md img,
.amis-scope .thumb-lg img,
.amis-scope .thumb-btn img,
.amis-scope .thumb-xl img {
  height: auto;
  max-width: 100%;
  vertical-align: middle;
}

.amis-scope .img-full {
  width: 100%;
}

.amis-scope .img-full img {
  width: 100%;
}

.amis-scope .v-top {
  vertical-align: top !important;
  align-self: flex-start;
}

.amis-scope .v-middle {
  vertical-align: middle !important;
  align-self: center;
}

.amis-scope .v-bottom {
  vertical-align: bottom !important;
  align-self: flex-end;
}

.amis-scope .scrollable {
  overflow-x: hidden;
  overflow-y: auto;
  -webkit-overflow-scrolling: touch;
}

.amis-scope .scrollable.hover,
.amis-scope .scrollable.hover > .cell-inner {
  overflow-y: hidden !important;
}

.amis-scope .scrollable.hover:hover,
.amis-scope .scrollable.hover:focus,
.amis-scope .scrollable.hover:active {
  overflow: visible;
  overflow-y: auto;
}

.amis-scope .scrollable.hover:hover > .cell-inner,
.amis-scope .scrollable.hover:focus > .cell-inner,
.amis-scope .scrollable.hover:active > .cell-inner {
  overflow-y: auto !important;
}

.amis-scope .smart .scrollable,
.amis-scope .smart .scrollable > .cell-inner {
  overflow-y: auto !important;
}

.amis-scope .scroll-x,
.amis-scope .scroll-y {
  overflow: hidden;
  -webkit-overflow-scrolling: touch;
}

.amis-scope .scroll-y {
  overflow-y: auto;
}

.amis-scope .scroll-x {
  overflow-x: auto;
}

.amis-scope .hover-action {
  display: none;
}

.amis-scope .hover-rotate {
  transition: all var(--animation-duration) ease-in-out var(--animation-duration);
}

.amis-scope .hover-anchor:hover > .hover-action,
.amis-scope .hover-anchor:focus > .hover-action,
.amis-scope .hover-anchor:active > .hover-action {
  display: inherit;
}

.amis-scope .hover-anchor:hover > .hover-rotate,
.amis-scope .hover-anchor:focus > .hover-rotate,
.amis-scope .hover-anchor:active > .hover-rotate {
  transform: rotate(90deg);
}

.amis-scope .backdrop {
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 1050;
}

.amis-scope .backdrop.fade {
  opacity: 0;
}

.amis-scope .backdrop.in {
  opacity: 0.8;
}

.amis-scope .col-xs-2-4,
.amis-scope .col-sm-2-4,
.amis-scope .col-md-2-4,
.amis-scope .col-lg-2-4,
.amis-scope .col-xs-1-5,
.amis-scope .col-sm-1-5,
.amis-scope .col-md-1-5,
.amis-scope .col-lg-1-5 {
  position: relative;
  min-height: 1px;
  padding-right: 15px;
  padding-left: 15px;
}

.amis-scope .col-xs-2-4 {
  width: 20%;
  float: left;
}

.amis-scope .col-xs-1-5 {
  width: 12.5%;
  float: left;
}

.amis-scope .invisible {
  position: absolute !important;
  clip: rect(1px 1px 1px 1px);
  clip: rect(1px, 1px, 1px, 1px);
}

.amis-scope .invisible2 {
  visibility: hidden;
}

.amis-scope .hbox {
  display: table;
  table-layout: fixed;
  border-spacing: 0;
  width: 100%;
  height: 100%;
}

.amis-scope .hbox > .col {
  display: table-cell;
  vertical-align: top;
  height: 100%;
  float: none;
}

.amis-scope .vbox {
  display: table;
  border-spacing: 0;
  position: relative;
  width: 100%;
  height: 100%;
  min-height: 240px;
}

.amis-scope .vbox .row-row {
  display: table-row;
  height: 100%;
}

.amis-scope .vbox .row-row .cell {
  position: relative;
  height: 100%;
  width: 100%;
}

.amis-scope .ie .vbox .row-row .cell {
  display: table-cell;
  overflow: auto;
}

.amis-scope .ie .vbox .row-row .cell .cell-inner {
  overflow: visible !important;
}

.amis-scope .vbox .row-row .cell .cell-inner {
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
  -webkit-overflow-scrolling: touch;
  overflow: auto;
}

.amis-scope .word-break {
  white-space: normal;
  word-break: break-all;
  word-wrap: break-word;
}

.amis-scope .white-space-pre {
  white-space: pre;
}

.amis-scope .label {
  display: inline;
  padding: 0.2em 0.6em 0.3em;
  font-size: 75%;
  font-weight: 700;
  line-height: 1;
  color: var(--label-color);
  text-align: center;
  white-space: nowrap;
  vertical-align: baseline;
  border-radius: 0.25em;
}

.amis-scope .label:empty {
  display: none;
}

.amis-scope .btn .label {
  position: relative;
  top: -1px;
}

.amis-scope a.label:hover,
.amis-scope a.label:focus {
  color: var(--label-link--hover-color);
  text-decoration: none;
  cursor: pointer;
}

.amis-scope .label-default {
  background: var(--label--default-bg);
}

.amis-scope .label-primary {
  background: var(--label--primary-bg);
}

.amis-scope .label-success {
  background: var(--label--success-bg);
}

.amis-scope .label-info {
  background: var(--label--info-bg);
}

.amis-scope .label-warning {
  background: var(--label--warning-bg);
}

.amis-scope .label-danger {
  background: var(--label--danger-bg);
}

@keyframes apearSensor {
  from {
    opacity: 0;
  }
}

@media (min-width: 768px) {
  .amis-scope .col-sm-2-4 {
    width: 20%;
    float: left;
  }

  .amis-scope .col-sm-1-5 {
    width: 12.5%;
    float: left;
  }
}

@media (min-width: 992px) {
  .amis-scope .col-md-2-4 {
    width: 20%;
    float: left;
  }

  .amis-scope .col-md-1-5 {
    width: 12.5%;
    float: left;
  }
}

@media (min-width: 1200px) {
  .amis-scope .col-lg-2-4 {
    width: 20%;
    float: left;
  }

  .amis-scope .col-lg-1-5 {
    width: 12.5%;
    float: left;
  }
}

@media (min-width: 768px) and (max-width: 991px) {
  .amis-scope .hidden-sm.show {
    display: inherit !important;
  }

  .amis-scope .no-m-sm {
    margin: 0 !important;
  }

  .amis-scope .no-padder-sm {
    padding: 0 !important;
  }
}

.amis-scope .visible-xs {
  display: none;
}

/*phone*/

@media (max-width: 767px) {
  .amis-scope .visible-xs {
    display: block !important;
  }

  .amis-scope .hidden-xs {
    display: none !important;
  }

  .amis-scope .w-auto-xs {
    width: auto;
  }

  .amis-scope .shift {
    display: none !important;
  }

  .amis-scope .shift.in {
    display: block !important;
  }

  .amis-scope .row-2 [class*=col] {
    width: 50%;
    float: left;
  }

  .amis-scope .row-2 .col-0 {
    clear: none;
  }

  .amis-scope .row-2 li:nth-child(odd) {
    clear: left;
    margin-left: 0;
  }

  .amis-scope .text-center-xs {
    text-align: center;
  }

  .amis-scope .text-left-xs {
    text-align: left;
  }

  .amis-scope .text-right-xs {
    text-align: right;
  }

  .amis-scope .no-border-xs {
    border-width: 0;
  }

  .amis-scope .pull-none-xs {
    float: none !important;
  }

  .amis-scope .pull-right-xs {
    float: right !important;
  }

  .amis-scope .pull-left-xs {
    float: left !important;
  }

  .amis-scope .dropdown-menu.pull-none-xs {
    left: 0;
  }

  .amis-scope .hidden-xs.show {
    display: inherit !important;
  }

  .amis-scope .wrapper-lg,
  .amis-scope .wrapper-md {
    padding: 15px;
  }

  .amis-scope .padder-lg,
  .amis-scope .padder-md {
    padding-left: 15px;
    padding-right: 15px;
  }

  .amis-scope .no-m-xs {
    margin: 0 !important;
  }

  .amis-scope .no-padder-xs {
    padding: 0 !important;
  }
}