@charset "UTF-8";
/*!markdown

---
title: 背景色
---

| Class       | Properties               |
| ----------- | ------------------------ |
| bg-transparent | background: transparent |
| bg-none | background: none !important |
| bg-transparent | background: transparent |
| bg-current | background: currentColor |
| bg-black | background: #000 |
| bg-white | background: #fff |
| bg-primary | background: #007bff |
| bg-secondary | background: #6c757d |
| bg-success | background: #28a745 |
| bg-info | background: #17a2b8 |
| bg-warning | background: #28a745 |
| bg-danger | background: #dc3545 |
| bg-light | background: #f8f9fa |
| bg-dark | background: #343a40 |
| bg-gray-transparent | background: transparent |
| bg-gray-current | background: currentColor |
| bg-gray-50 | background: #f9fafb |
| bg-gray-100 | background: #f3f4f6 |
| bg-gray-200 | background: #e5e7eb |
| bg-gray-300 | background: #d1d5db |
| bg-gray-400 | background: #9ca3af |
| bg-gray-500 | background: #6b7280 |
| bg-gray-600 | background: #4b5563 |
| bg-gray-700 | background: #374151 |
| bg-gray-800 | background: #1f2937 |
| bg-gray-900 | background: #111827 |
| bg-red-transparent | background: transparent |
| bg-red-current | background: currentColor |
| bg-red-50 | background: #fef2f2 |
| bg-red-100 | background: #fee2e2 |
| bg-red-200 | background: #fecaca |
| bg-red-300 | background: #fca5a5 |
| bg-red-400 | background: #f87171 |
| bg-red-500 | background: #ef4444 |
| bg-red-600 | background: #dc2626 |
| bg-red-700 | background: #b91c1c |
| bg-red-800 | background: #991b1b |
| bg-red-900 | background: #7f1d1d |
| bg-yellow-transparent | background: transparent |
| bg-yellow-current | background: currentColor |
| bg-yellow-50 | background: #fffbeb |
| bg-yellow-100 | background: #fef3c7 |
| bg-yellow-200 | background: #fde68a |
| bg-yellow-300 | background: #fcd34d |
| bg-yellow-400 | background: #fbbf24 |
| bg-yellow-500 | background: #f59e0b |
| bg-yellow-600 | background: #d97706 |
| bg-yellow-700 | background: #b45309 |
| bg-yellow-800 | background: #92400e |
| bg-yellow-900 | background: #78350f |
| bg-green-transparent | background: transparent |
| bg-green-current | background: currentColor |
| bg-green-50 | background: #ecfdf5 |
| bg-green-100 | background: #d1fae5 |
| bg-green-200 | background: #a7f3d0 |
| bg-green-300 | background: #6ee7b7 |
| bg-green-400 | background: #34d399 |
| bg-green-500 | background: #10b981 |
| bg-green-600 | background: #059669 |
| bg-green-700 | background: #047857 |
| bg-green-800 | background: #065f46 |
| bg-green-900 | background: #064e3b |
| bg-blue-transparent | background: transparent |
| bg-blue-current | background: currentColor |
| bg-blue-50 | background: #eff6ff |
| bg-blue-100 | background: #dbeafe |
| bg-blue-200 | background: #bfdbfe |
| bg-blue-300 | background: #93c5fd |
| bg-blue-400 | background: #60a5fa |
| bg-blue-500 | background: #3b82f6 |
| bg-blue-600 | background: #2563eb |
| bg-blue-700 | background: #1d4ed8 |
| bg-blue-800 | background: #1e40af |
| bg-blue-900 | background: #1e3a8a |
| bg-cyan-transparent | background: transparent |
| bg-cyan-current | background: currentColor |
| bg-cyan-50 | background: #ecfeff |
| bg-cyan-100 | background: #cffafe |
| bg-cyan-200 | background: #a5f3fc |
| bg-cyan-300 | background: #67e8f9 |
| bg-cyan-400 | background: #22d3ee |
| bg-cyan-500 | background: #06b6d4 |
| bg-cyan-600 | background: #0891b2 |
| bg-cyan-700 | background: #0e7490 |
| bg-cyan-800 | background: #155e75 |
| bg-cyan-900 | background: #164e63 |
| bg-indigo-transparent | background: transparent |
| bg-indigo-current | background: currentColor |
| bg-indigo-50 | background: #eef2ff |
| bg-indigo-100 | background: #e0e7ff |
| bg-indigo-200 | background: #c7d2fe |
| bg-indigo-300 | background: #a5b4fc |
| bg-indigo-400 | background: #818cf8 |
| bg-indigo-500 | background: #6366f1 |
| bg-indigo-600 | background: #4f46e5 |
| bg-indigo-700 | background: #4338ca |
| bg-indigo-800 | background: #3730a3 |
| bg-indigo-900 | background: #312e81 |
| bg-purple-transparent | background: transparent |
| bg-purple-current | background: currentColor |
| bg-purple-50 | background: #f5f3ff |
| bg-purple-100 | background: #ede9fe |
| bg-purple-200 | background: #ddd6fe |
| bg-purple-300 | background: #c4b5fd |
| bg-purple-400 | background: #a78bfa |
| bg-purple-500 | background: #8b5cf6 |
| bg-purple-600 | background: #7c3aed |
| bg-purple-700 | background: #6d28d9 |
| bg-purple-800 | background: #5b21b6 |
| bg-purple-900 | background: #4c1d95 |
| bg-pink-transparent | background: transparent |
| bg-pink-current | background: currentColor |
| bg-pink-50 | background: #fdf2f8 |
| bg-pink-100 | background: #fce7f3 |
| bg-pink-200 | background: #fbcfe8 |
| bg-pink-300 | background: #f9a8d4 |
| bg-pink-400 | background: #f472b6 |
| bg-pink-500 | background: #ec4899 |
| bg-pink-600 | background: #db2777 |
| bg-pink-700 | background: #be185d |
| bg-pink-800 | background: #9d174d |
| bg-pink-900 | background: #831843 |

还有 hover、active、focus、disabled 扩展，比如 `hover:bg-black`

*/
.bg-transparent {
  background: transparent;
}

.bg-none {
  background: none !important;
}

.bg-transparent {
  background: transparent;
}

.bg-current {
  background: currentColor;
}

.bg-black {
  background-color: #000;
}

.bg-white {
  background-color: #fff;
}

.bg-primary {
  background-color: #007bff;
}

.bg-secondary {
  background-color: #6c757d;
}

.bg-success {
  background-color: #28a745;
}

.bg-info {
  background-color: #17a2b8;
}

.bg-warning {
  background-color: #fad733;
}

.bg-danger {
  background-color: #dc3545;
}

.bg-light {
  background-color: #f8f9fa;
}

.bg-dark {
  background-color: #343a40;
}

.bg-gray-transparent {
  background: transparent;
}

.bg-gray-current {
  background: currentColor;
}

.bg-gray-50 {
  background-color: #f9fafb;
}

.bg-gray-100 {
  background-color: #f3f4f6;
}

.bg-gray-200 {
  background-color: #e5e7eb;
}

.bg-gray-300 {
  background-color: #d1d5db;
}

.bg-gray-400 {
  background-color: #9ca3af;
}

.bg-gray-500 {
  background-color: #6b7280;
}

.bg-gray-600 {
  background-color: #4b5563;
}

.bg-gray-700 {
  background-color: #374151;
}

.bg-gray-800 {
  background-color: #1f2937;
}

.bg-gray-900 {
  background-color: #111827;
}

.bg-red-transparent {
  background: transparent;
}

.bg-red-current {
  background: currentColor;
}

.bg-red-50 {
  background-color: #fef2f2;
}

.bg-red-100 {
  background-color: #fee2e2;
}

.bg-red-200 {
  background-color: #fecaca;
}

.bg-red-300 {
  background-color: #fca5a5;
}

.bg-red-400 {
  background-color: #f87171;
}

.bg-red-500 {
  background-color: #ef4444;
}

.bg-red-600 {
  background-color: #dc2626;
}

.bg-red-700 {
  background-color: #b91c1c;
}

.bg-red-800 {
  background-color: #991b1b;
}

.bg-red-900 {
  background-color: #7f1d1d;
}

.bg-yellow-transparent {
  background: transparent;
}

.bg-yellow-current {
  background: currentColor;
}

.bg-yellow-50 {
  background-color: #fffbeb;
}

.bg-yellow-100 {
  background-color: #fef3c7;
}

.bg-yellow-200 {
  background-color: #fde68a;
}

.bg-yellow-300 {
  background-color: #fcd34d;
}

.bg-yellow-400 {
  background-color: #fbbf24;
}

.bg-yellow-500 {
  background-color: #f59e0b;
}

.bg-yellow-600 {
  background-color: #d97706;
}

.bg-yellow-700 {
  background-color: #b45309;
}

.bg-yellow-800 {
  background-color: #92400e;
}

.bg-yellow-900 {
  background-color: #78350f;
}

.bg-green-transparent {
  background: transparent;
}

.bg-green-current {
  background: currentColor;
}

.bg-green-50 {
  background-color: #ecfdf5;
}

.bg-green-100 {
  background-color: #d1fae5;
}

.bg-green-200 {
  background-color: #a7f3d0;
}

.bg-green-300 {
  background-color: #6ee7b7;
}

.bg-green-400 {
  background-color: #34d399;
}

.bg-green-500 {
  background-color: #10b981;
}

.bg-green-600 {
  background-color: #059669;
}

.bg-green-700 {
  background-color: #047857;
}

.bg-green-800 {
  background-color: #065f46;
}

.bg-green-900 {
  background-color: #064e3b;
}

.bg-blue-transparent {
  background: transparent;
}

.bg-blue-current {
  background: currentColor;
}

.bg-blue-50 {
  background-color: #eff6ff;
}

.bg-blue-100 {
  background-color: #dbeafe;
}

.bg-blue-200 {
  background-color: #bfdbfe;
}

.bg-blue-300 {
  background-color: #93c5fd;
}

.bg-blue-400 {
  background-color: #60a5fa;
}

.bg-blue-500 {
  background-color: #3b82f6;
}

.bg-blue-600 {
  background-color: #2563eb;
}

.bg-blue-700 {
  background-color: #1d4ed8;
}

.bg-blue-800 {
  background-color: #1e40af;
}

.bg-blue-900 {
  background-color: #1e3a8a;
}

.bg-cyan-transparent {
  background: transparent;
}

.bg-cyan-current {
  background: currentColor;
}

.bg-cyan-50 {
  background-color: #ecfeff;
}

.bg-cyan-100 {
  background-color: #cffafe;
}

.bg-cyan-200 {
  background-color: #a5f3fc;
}

.bg-cyan-300 {
  background-color: #67e8f9;
}

.bg-cyan-400 {
  background-color: #22d3ee;
}

.bg-cyan-500 {
  background-color: #06b6d4;
}

.bg-cyan-600 {
  background-color: #0891b2;
}

.bg-cyan-700 {
  background-color: #0e7490;
}

.bg-cyan-800 {
  background-color: #155e75;
}

.bg-cyan-900 {
  background-color: #164e63;
}

.bg-indigo-transparent {
  background: transparent;
}

.bg-indigo-current {
  background: currentColor;
}

.bg-indigo-50 {
  background-color: #eef2ff;
}

.bg-indigo-100 {
  background-color: #e0e7ff;
}

.bg-indigo-200 {
  background-color: #c7d2fe;
}

.bg-indigo-300 {
  background-color: #a5b4fc;
}

.bg-indigo-400 {
  background-color: #818cf8;
}

.bg-indigo-500 {
  background-color: #6366f1;
}

.bg-indigo-600 {
  background-color: #4f46e5;
}

.bg-indigo-700 {
  background-color: #4338ca;
}

.bg-indigo-800 {
  background-color: #3730a3;
}

.bg-indigo-900 {
  background-color: #312e81;
}

.bg-purple-transparent {
  background: transparent;
}

.bg-purple-current {
  background: currentColor;
}

.bg-purple-50 {
  background-color: #f5f3ff;
}

.bg-purple-100 {
  background-color: #ede9fe;
}

.bg-purple-200 {
  background-color: #ddd6fe;
}

.bg-purple-300 {
  background-color: #c4b5fd;
}

.bg-purple-400 {
  background-color: #a78bfa;
}

.bg-purple-500 {
  background-color: #8b5cf6;
}

.bg-purple-600 {
  background-color: #7c3aed;
}

.bg-purple-700 {
  background-color: #6d28d9;
}

.bg-purple-800 {
  background-color: #5b21b6;
}

.bg-purple-900 {
  background-color: #4c1d95;
}

.bg-pink-transparent {
  background: transparent;
}

.bg-pink-current {
  background: currentColor;
}

.bg-pink-50 {
  background-color: #fdf2f8;
}

.bg-pink-100 {
  background-color: #fce7f3;
}

.bg-pink-200 {
  background-color: #fbcfe8;
}

.bg-pink-300 {
  background-color: #f9a8d4;
}

.bg-pink-400 {
  background-color: #f472b6;
}

.bg-pink-500 {
  background-color: #ec4899;
}

.bg-pink-600 {
  background-color: #db2777;
}

.bg-pink-700 {
  background-color: #be185d;
}

.bg-pink-800 {
  background-color: #9d174d;
}

.bg-pink-900 {
  background-color: #831843;
}

.hover\:bg-transparent:hover {
  background: transparent;
}

.hover\:bg-none:hover {
  background: none !important;
}

.hover\:bg-transparent:hover {
  background: transparent;
}

.hover\:bg-current:hover {
  background: currentColor;
}

.hover\:bg-black:hover {
  background-color: #000;
}

.hover\:bg-white:hover {
  background-color: #fff;
}

.hover\:bg-primary:hover {
  background-color: #007bff;
}

.hover\:bg-secondary:hover {
  background-color: #6c757d;
}

.hover\:bg-success:hover {
  background-color: #28a745;
}

.hover\:bg-info:hover {
  background-color: #17a2b8;
}

.hover\:bg-warning:hover {
  background-color: #fad733;
}

.hover\:bg-danger:hover {
  background-color: #dc3545;
}

.hover\:bg-light:hover {
  background-color: #f8f9fa;
}

.hover\:bg-dark:hover {
  background-color: #343a40;
}

.hover\:bg-gray-transparent:hover {
  background: transparent;
}

.hover\:bg-gray-current:hover {
  background: currentColor;
}

.hover\:bg-gray-50:hover {
  background-color: #f9fafb;
}

.hover\:bg-gray-100:hover {
  background-color: #f3f4f6;
}

.hover\:bg-gray-200:hover {
  background-color: #e5e7eb;
}

.hover\:bg-gray-300:hover {
  background-color: #d1d5db;
}

.hover\:bg-gray-400:hover {
  background-color: #9ca3af;
}

.hover\:bg-gray-500:hover {
  background-color: #6b7280;
}

.hover\:bg-gray-600:hover {
  background-color: #4b5563;
}

.hover\:bg-gray-700:hover {
  background-color: #374151;
}

.hover\:bg-gray-800:hover {
  background-color: #1f2937;
}

.hover\:bg-gray-900:hover {
  background-color: #111827;
}

.hover\:bg-red-transparent:hover {
  background: transparent;
}

.hover\:bg-red-current:hover {
  background: currentColor;
}

.hover\:bg-red-50:hover {
  background-color: #fef2f2;
}

.hover\:bg-red-100:hover {
  background-color: #fee2e2;
}

.hover\:bg-red-200:hover {
  background-color: #fecaca;
}

.hover\:bg-red-300:hover {
  background-color: #fca5a5;
}

.hover\:bg-red-400:hover {
  background-color: #f87171;
}

.hover\:bg-red-500:hover {
  background-color: #ef4444;
}

.hover\:bg-red-600:hover {
  background-color: #dc2626;
}

.hover\:bg-red-700:hover {
  background-color: #b91c1c;
}

.hover\:bg-red-800:hover {
  background-color: #991b1b;
}

.hover\:bg-red-900:hover {
  background-color: #7f1d1d;
}

.hover\:bg-yellow-transparent:hover {
  background: transparent;
}

.hover\:bg-yellow-current:hover {
  background: currentColor;
}

.hover\:bg-yellow-50:hover {
  background-color: #fffbeb;
}

.hover\:bg-yellow-100:hover {
  background-color: #fef3c7;
}

.hover\:bg-yellow-200:hover {
  background-color: #fde68a;
}

.hover\:bg-yellow-300:hover {
  background-color: #fcd34d;
}

.hover\:bg-yellow-400:hover {
  background-color: #fbbf24;
}

.hover\:bg-yellow-500:hover {
  background-color: #f59e0b;
}

.hover\:bg-yellow-600:hover {
  background-color: #d97706;
}

.hover\:bg-yellow-700:hover {
  background-color: #b45309;
}

.hover\:bg-yellow-800:hover {
  background-color: #92400e;
}

.hover\:bg-yellow-900:hover {
  background-color: #78350f;
}

.hover\:bg-green-transparent:hover {
  background: transparent;
}

.hover\:bg-green-current:hover {
  background: currentColor;
}

.hover\:bg-green-50:hover {
  background-color: #ecfdf5;
}

.hover\:bg-green-100:hover {
  background-color: #d1fae5;
}

.hover\:bg-green-200:hover {
  background-color: #a7f3d0;
}

.hover\:bg-green-300:hover {
  background-color: #6ee7b7;
}

.hover\:bg-green-400:hover {
  background-color: #34d399;
}

.hover\:bg-green-500:hover {
  background-color: #10b981;
}

.hover\:bg-green-600:hover {
  background-color: #059669;
}

.hover\:bg-green-700:hover {
  background-color: #047857;
}

.hover\:bg-green-800:hover {
  background-color: #065f46;
}

.hover\:bg-green-900:hover {
  background-color: #064e3b;
}

.hover\:bg-blue-transparent:hover {
  background: transparent;
}

.hover\:bg-blue-current:hover {
  background: currentColor;
}

.hover\:bg-blue-50:hover {
  background-color: #eff6ff;
}

.hover\:bg-blue-100:hover {
  background-color: #dbeafe;
}

.hover\:bg-blue-200:hover {
  background-color: #bfdbfe;
}

.hover\:bg-blue-300:hover {
  background-color: #93c5fd;
}

.hover\:bg-blue-400:hover {
  background-color: #60a5fa;
}

.hover\:bg-blue-500:hover {
  background-color: #3b82f6;
}

.hover\:bg-blue-600:hover {
  background-color: #2563eb;
}

.hover\:bg-blue-700:hover {
  background-color: #1d4ed8;
}

.hover\:bg-blue-800:hover {
  background-color: #1e40af;
}

.hover\:bg-blue-900:hover {
  background-color: #1e3a8a;
}

.hover\:bg-cyan-transparent:hover {
  background: transparent;
}

.hover\:bg-cyan-current:hover {
  background: currentColor;
}

.hover\:bg-cyan-50:hover {
  background-color: #ecfeff;
}

.hover\:bg-cyan-100:hover {
  background-color: #cffafe;
}

.hover\:bg-cyan-200:hover {
  background-color: #a5f3fc;
}

.hover\:bg-cyan-300:hover {
  background-color: #67e8f9;
}

.hover\:bg-cyan-400:hover {
  background-color: #22d3ee;
}

.hover\:bg-cyan-500:hover {
  background-color: #06b6d4;
}

.hover\:bg-cyan-600:hover {
  background-color: #0891b2;
}

.hover\:bg-cyan-700:hover {
  background-color: #0e7490;
}

.hover\:bg-cyan-800:hover {
  background-color: #155e75;
}

.hover\:bg-cyan-900:hover {
  background-color: #164e63;
}

.hover\:bg-indigo-transparent:hover {
  background: transparent;
}

.hover\:bg-indigo-current:hover {
  background: currentColor;
}

.hover\:bg-indigo-50:hover {
  background-color: #eef2ff;
}

.hover\:bg-indigo-100:hover {
  background-color: #e0e7ff;
}

.hover\:bg-indigo-200:hover {
  background-color: #c7d2fe;
}

.hover\:bg-indigo-300:hover {
  background-color: #a5b4fc;
}

.hover\:bg-indigo-400:hover {
  background-color: #818cf8;
}

.hover\:bg-indigo-500:hover {
  background-color: #6366f1;
}

.hover\:bg-indigo-600:hover {
  background-color: #4f46e5;
}

.hover\:bg-indigo-700:hover {
  background-color: #4338ca;
}

.hover\:bg-indigo-800:hover {
  background-color: #3730a3;
}

.hover\:bg-indigo-900:hover {
  background-color: #312e81;
}

.hover\:bg-purple-transparent:hover {
  background: transparent;
}

.hover\:bg-purple-current:hover {
  background: currentColor;
}

.hover\:bg-purple-50:hover {
  background-color: #f5f3ff;
}

.hover\:bg-purple-100:hover {
  background-color: #ede9fe;
}

.hover\:bg-purple-200:hover {
  background-color: #ddd6fe;
}

.hover\:bg-purple-300:hover {
  background-color: #c4b5fd;
}

.hover\:bg-purple-400:hover {
  background-color: #a78bfa;
}

.hover\:bg-purple-500:hover {
  background-color: #8b5cf6;
}

.hover\:bg-purple-600:hover {
  background-color: #7c3aed;
}

.hover\:bg-purple-700:hover {
  background-color: #6d28d9;
}

.hover\:bg-purple-800:hover {
  background-color: #5b21b6;
}

.hover\:bg-purple-900:hover {
  background-color: #4c1d95;
}

.hover\:bg-pink-transparent:hover {
  background: transparent;
}

.hover\:bg-pink-current:hover {
  background: currentColor;
}

.hover\:bg-pink-50:hover {
  background-color: #fdf2f8;
}

.hover\:bg-pink-100:hover {
  background-color: #fce7f3;
}

.hover\:bg-pink-200:hover {
  background-color: #fbcfe8;
}

.hover\:bg-pink-300:hover {
  background-color: #f9a8d4;
}

.hover\:bg-pink-400:hover {
  background-color: #f472b6;
}

.hover\:bg-pink-500:hover {
  background-color: #ec4899;
}

.hover\:bg-pink-600:hover {
  background-color: #db2777;
}

.hover\:bg-pink-700:hover {
  background-color: #be185d;
}

.hover\:bg-pink-800:hover {
  background-color: #9d174d;
}

.hover\:bg-pink-900:hover {
  background-color: #831843;
}

.active\:bg-transparent.is-active {
  background: transparent;
}

.active\:bg-none.is-active {
  background: none !important;
}

.active\:bg-transparent.is-active {
  background: transparent;
}

.active\:bg-current.is-active {
  background: currentColor;
}

.active\:bg-black.is-active,
.active\:bg-black:active {
  background-color: #000;
}

.active\:bg-white.is-active,
.active\:bg-white:active {
  background-color: #fff;
}

.active\:bg-primary.is-active,
.active\:bg-primary:active {
  background-color: #007bff;
}

.active\:bg-secondary.is-active,
.active\:bg-secondary:active {
  background-color: #6c757d;
}

.active\:bg-success.is-active,
.active\:bg-success:active {
  background-color: #28a745;
}

.active\:bg-info.is-active,
.active\:bg-info:active {
  background-color: #17a2b8;
}

.active\:bg-warning.is-active,
.active\:bg-warning:active {
  background-color: #fad733;
}

.active\:bg-danger.is-active,
.active\:bg-danger:active {
  background-color: #dc3545;
}

.active\:bg-light.is-active,
.active\:bg-light:active {
  background-color: #f8f9fa;
}

.active\:bg-dark.is-active,
.active\:bg-dark:active {
  background-color: #343a40;
}

.active\:bg-gray-transparent.is-active {
  background: transparent;
}

.active\:bg-gray-current.is-active {
  background: currentColor;
}

.active\:bg-gray-50.is-active,
.active\:bg-gray-50:active {
  background-color: #f9fafb;
}

.active\:bg-gray-100.is-active,
.active\:bg-gray-100:active {
  background-color: #f3f4f6;
}

.active\:bg-gray-200.is-active,
.active\:bg-gray-200:active {
  background-color: #e5e7eb;
}

.active\:bg-gray-300.is-active,
.active\:bg-gray-300:active {
  background-color: #d1d5db;
}

.active\:bg-gray-400.is-active,
.active\:bg-gray-400:active {
  background-color: #9ca3af;
}

.active\:bg-gray-500.is-active,
.active\:bg-gray-500:active {
  background-color: #6b7280;
}

.active\:bg-gray-600.is-active,
.active\:bg-gray-600:active {
  background-color: #4b5563;
}

.active\:bg-gray-700.is-active,
.active\:bg-gray-700:active {
  background-color: #374151;
}

.active\:bg-gray-800.is-active,
.active\:bg-gray-800:active {
  background-color: #1f2937;
}

.active\:bg-gray-900.is-active,
.active\:bg-gray-900:active {
  background-color: #111827;
}

.active\:bg-red-transparent.is-active {
  background: transparent;
}

.active\:bg-red-current.is-active {
  background: currentColor;
}

.active\:bg-red-50.is-active,
.active\:bg-red-50:active {
  background-color: #fef2f2;
}

.active\:bg-red-100.is-active,
.active\:bg-red-100:active {
  background-color: #fee2e2;
}

.active\:bg-red-200.is-active,
.active\:bg-red-200:active {
  background-color: #fecaca;
}

.active\:bg-red-300.is-active,
.active\:bg-red-300:active {
  background-color: #fca5a5;
}

.active\:bg-red-400.is-active,
.active\:bg-red-400:active {
  background-color: #f87171;
}

.active\:bg-red-500.is-active,
.active\:bg-red-500:active {
  background-color: #ef4444;
}

.active\:bg-red-600.is-active,
.active\:bg-red-600:active {
  background-color: #dc2626;
}

.active\:bg-red-700.is-active,
.active\:bg-red-700:active {
  background-color: #b91c1c;
}

.active\:bg-red-800.is-active,
.active\:bg-red-800:active {
  background-color: #991b1b;
}

.active\:bg-red-900.is-active,
.active\:bg-red-900:active {
  background-color: #7f1d1d;
}

.active\:bg-yellow-transparent.is-active {
  background: transparent;
}

.active\:bg-yellow-current.is-active {
  background: currentColor;
}

.active\:bg-yellow-50.is-active,
.active\:bg-yellow-50:active {
  background-color: #fffbeb;
}

.active\:bg-yellow-100.is-active,
.active\:bg-yellow-100:active {
  background-color: #fef3c7;
}

.active\:bg-yellow-200.is-active,
.active\:bg-yellow-200:active {
  background-color: #fde68a;
}

.active\:bg-yellow-300.is-active,
.active\:bg-yellow-300:active {
  background-color: #fcd34d;
}

.active\:bg-yellow-400.is-active,
.active\:bg-yellow-400:active {
  background-color: #fbbf24;
}

.active\:bg-yellow-500.is-active,
.active\:bg-yellow-500:active {
  background-color: #f59e0b;
}

.active\:bg-yellow-600.is-active,
.active\:bg-yellow-600:active {
  background-color: #d97706;
}

.active\:bg-yellow-700.is-active,
.active\:bg-yellow-700:active {
  background-color: #b45309;
}

.active\:bg-yellow-800.is-active,
.active\:bg-yellow-800:active {
  background-color: #92400e;
}

.active\:bg-yellow-900.is-active,
.active\:bg-yellow-900:active {
  background-color: #78350f;
}

.active\:bg-green-transparent.is-active {
  background: transparent;
}

.active\:bg-green-current.is-active {
  background: currentColor;
}

.active\:bg-green-50.is-active,
.active\:bg-green-50:active {
  background-color: #ecfdf5;
}

.active\:bg-green-100.is-active,
.active\:bg-green-100:active {
  background-color: #d1fae5;
}

.active\:bg-green-200.is-active,
.active\:bg-green-200:active {
  background-color: #a7f3d0;
}

.active\:bg-green-300.is-active,
.active\:bg-green-300:active {
  background-color: #6ee7b7;
}

.active\:bg-green-400.is-active,
.active\:bg-green-400:active {
  background-color: #34d399;
}

.active\:bg-green-500.is-active,
.active\:bg-green-500:active {
  background-color: #10b981;
}

.active\:bg-green-600.is-active,
.active\:bg-green-600:active {
  background-color: #059669;
}

.active\:bg-green-700.is-active,
.active\:bg-green-700:active {
  background-color: #047857;
}

.active\:bg-green-800.is-active,
.active\:bg-green-800:active {
  background-color: #065f46;
}

.active\:bg-green-900.is-active,
.active\:bg-green-900:active {
  background-color: #064e3b;
}

.active\:bg-blue-transparent.is-active {
  background: transparent;
}

.active\:bg-blue-current.is-active {
  background: currentColor;
}

.active\:bg-blue-50.is-active,
.active\:bg-blue-50:active {
  background-color: #eff6ff;
}

.active\:bg-blue-100.is-active,
.active\:bg-blue-100:active {
  background-color: #dbeafe;
}

.active\:bg-blue-200.is-active,
.active\:bg-blue-200:active {
  background-color: #bfdbfe;
}

.active\:bg-blue-300.is-active,
.active\:bg-blue-300:active {
  background-color: #93c5fd;
}

.active\:bg-blue-400.is-active,
.active\:bg-blue-400:active {
  background-color: #60a5fa;
}

.active\:bg-blue-500.is-active,
.active\:bg-blue-500:active {
  background-color: #3b82f6;
}

.active\:bg-blue-600.is-active,
.active\:bg-blue-600:active {
  background-color: #2563eb;
}

.active\:bg-blue-700.is-active,
.active\:bg-blue-700:active {
  background-color: #1d4ed8;
}

.active\:bg-blue-800.is-active,
.active\:bg-blue-800:active {
  background-color: #1e40af;
}

.active\:bg-blue-900.is-active,
.active\:bg-blue-900:active {
  background-color: #1e3a8a;
}

.active\:bg-cyan-transparent.is-active {
  background: transparent;
}

.active\:bg-cyan-current.is-active {
  background: currentColor;
}

.active\:bg-cyan-50.is-active,
.active\:bg-cyan-50:active {
  background-color: #ecfeff;
}

.active\:bg-cyan-100.is-active,
.active\:bg-cyan-100:active {
  background-color: #cffafe;
}

.active\:bg-cyan-200.is-active,
.active\:bg-cyan-200:active {
  background-color: #a5f3fc;
}

.active\:bg-cyan-300.is-active,
.active\:bg-cyan-300:active {
  background-color: #67e8f9;
}

.active\:bg-cyan-400.is-active,
.active\:bg-cyan-400:active {
  background-color: #22d3ee;
}

.active\:bg-cyan-500.is-active,
.active\:bg-cyan-500:active {
  background-color: #06b6d4;
}

.active\:bg-cyan-600.is-active,
.active\:bg-cyan-600:active {
  background-color: #0891b2;
}

.active\:bg-cyan-700.is-active,
.active\:bg-cyan-700:active {
  background-color: #0e7490;
}

.active\:bg-cyan-800.is-active,
.active\:bg-cyan-800:active {
  background-color: #155e75;
}

.active\:bg-cyan-900.is-active,
.active\:bg-cyan-900:active {
  background-color: #164e63;
}

.active\:bg-indigo-transparent.is-active {
  background: transparent;
}

.active\:bg-indigo-current.is-active {
  background: currentColor;
}

.active\:bg-indigo-50.is-active,
.active\:bg-indigo-50:active {
  background-color: #eef2ff;
}

.active\:bg-indigo-100.is-active,
.active\:bg-indigo-100:active {
  background-color: #e0e7ff;
}

.active\:bg-indigo-200.is-active,
.active\:bg-indigo-200:active {
  background-color: #c7d2fe;
}

.active\:bg-indigo-300.is-active,
.active\:bg-indigo-300:active {
  background-color: #a5b4fc;
}

.active\:bg-indigo-400.is-active,
.active\:bg-indigo-400:active {
  background-color: #818cf8;
}

.active\:bg-indigo-500.is-active,
.active\:bg-indigo-500:active {
  background-color: #6366f1;
}

.active\:bg-indigo-600.is-active,
.active\:bg-indigo-600:active {
  background-color: #4f46e5;
}

.active\:bg-indigo-700.is-active,
.active\:bg-indigo-700:active {
  background-color: #4338ca;
}

.active\:bg-indigo-800.is-active,
.active\:bg-indigo-800:active {
  background-color: #3730a3;
}

.active\:bg-indigo-900.is-active,
.active\:bg-indigo-900:active {
  background-color: #312e81;
}

.active\:bg-purple-transparent.is-active {
  background: transparent;
}

.active\:bg-purple-current.is-active {
  background: currentColor;
}

.active\:bg-purple-50.is-active,
.active\:bg-purple-50:active {
  background-color: #f5f3ff;
}

.active\:bg-purple-100.is-active,
.active\:bg-purple-100:active {
  background-color: #ede9fe;
}

.active\:bg-purple-200.is-active,
.active\:bg-purple-200:active {
  background-color: #ddd6fe;
}

.active\:bg-purple-300.is-active,
.active\:bg-purple-300:active {
  background-color: #c4b5fd;
}

.active\:bg-purple-400.is-active,
.active\:bg-purple-400:active {
  background-color: #a78bfa;
}

.active\:bg-purple-500.is-active,
.active\:bg-purple-500:active {
  background-color: #8b5cf6;
}

.active\:bg-purple-600.is-active,
.active\:bg-purple-600:active {
  background-color: #7c3aed;
}

.active\:bg-purple-700.is-active,
.active\:bg-purple-700:active {
  background-color: #6d28d9;
}

.active\:bg-purple-800.is-active,
.active\:bg-purple-800:active {
  background-color: #5b21b6;
}

.active\:bg-purple-900.is-active,
.active\:bg-purple-900:active {
  background-color: #4c1d95;
}

.active\:bg-pink-transparent.is-active {
  background: transparent;
}

.active\:bg-pink-current.is-active {
  background: currentColor;
}

.active\:bg-pink-50.is-active,
.active\:bg-pink-50:active {
  background-color: #fdf2f8;
}

.active\:bg-pink-100.is-active,
.active\:bg-pink-100:active {
  background-color: #fce7f3;
}

.active\:bg-pink-200.is-active,
.active\:bg-pink-200:active {
  background-color: #fbcfe8;
}

.active\:bg-pink-300.is-active,
.active\:bg-pink-300:active {
  background-color: #f9a8d4;
}

.active\:bg-pink-400.is-active,
.active\:bg-pink-400:active {
  background-color: #f472b6;
}

.active\:bg-pink-500.is-active,
.active\:bg-pink-500:active {
  background-color: #ec4899;
}

.active\:bg-pink-600.is-active,
.active\:bg-pink-600:active {
  background-color: #db2777;
}

.active\:bg-pink-700.is-active,
.active\:bg-pink-700:active {
  background-color: #be185d;
}

.active\:bg-pink-800.is-active,
.active\:bg-pink-800:active {
  background-color: #9d174d;
}

.active\:bg-pink-900.is-active,
.active\:bg-pink-900:active {
  background-color: #831843;
}

.focus\:bg-transparent:focus {
  background: transparent;
}

.focus\:bg-none:focus {
  background: none !important;
}

.focus\:bg-transparent:focus {
  background: transparent;
}

.focus\:bg-current:focus {
  background: currentColor;
}

.focus\:bg-black:focus {
  background-color: #000;
}

.focus\:bg-white:focus {
  background-color: #fff;
}

.focus\:bg-primary:focus {
  background-color: #007bff;
}

.focus\:bg-secondary:focus {
  background-color: #6c757d;
}

.focus\:bg-success:focus {
  background-color: #28a745;
}

.focus\:bg-info:focus {
  background-color: #17a2b8;
}

.focus\:bg-warning:focus {
  background-color: #fad733;
}

.focus\:bg-danger:focus {
  background-color: #dc3545;
}

.focus\:bg-light:focus {
  background-color: #f8f9fa;
}

.focus\:bg-dark:focus {
  background-color: #343a40;
}

.focus\:bg-gray-transparent:focus {
  background: transparent;
}

.focus\:bg-gray-current:focus {
  background: currentColor;
}

.focus\:bg-gray-50:focus {
  background-color: #f9fafb;
}

.focus\:bg-gray-100:focus {
  background-color: #f3f4f6;
}

.focus\:bg-gray-200:focus {
  background-color: #e5e7eb;
}

.focus\:bg-gray-300:focus {
  background-color: #d1d5db;
}

.focus\:bg-gray-400:focus {
  background-color: #9ca3af;
}

.focus\:bg-gray-500:focus {
  background-color: #6b7280;
}

.focus\:bg-gray-600:focus {
  background-color: #4b5563;
}

.focus\:bg-gray-700:focus {
  background-color: #374151;
}

.focus\:bg-gray-800:focus {
  background-color: #1f2937;
}

.focus\:bg-gray-900:focus {
  background-color: #111827;
}

.focus\:bg-red-transparent:focus {
  background: transparent;
}

.focus\:bg-red-current:focus {
  background: currentColor;
}

.focus\:bg-red-50:focus {
  background-color: #fef2f2;
}

.focus\:bg-red-100:focus {
  background-color: #fee2e2;
}

.focus\:bg-red-200:focus {
  background-color: #fecaca;
}

.focus\:bg-red-300:focus {
  background-color: #fca5a5;
}

.focus\:bg-red-400:focus {
  background-color: #f87171;
}

.focus\:bg-red-500:focus {
  background-color: #ef4444;
}

.focus\:bg-red-600:focus {
  background-color: #dc2626;
}

.focus\:bg-red-700:focus {
  background-color: #b91c1c;
}

.focus\:bg-red-800:focus {
  background-color: #991b1b;
}

.focus\:bg-red-900:focus {
  background-color: #7f1d1d;
}

.focus\:bg-yellow-transparent:focus {
  background: transparent;
}

.focus\:bg-yellow-current:focus {
  background: currentColor;
}

.focus\:bg-yellow-50:focus {
  background-color: #fffbeb;
}

.focus\:bg-yellow-100:focus {
  background-color: #fef3c7;
}

.focus\:bg-yellow-200:focus {
  background-color: #fde68a;
}

.focus\:bg-yellow-300:focus {
  background-color: #fcd34d;
}

.focus\:bg-yellow-400:focus {
  background-color: #fbbf24;
}

.focus\:bg-yellow-500:focus {
  background-color: #f59e0b;
}

.focus\:bg-yellow-600:focus {
  background-color: #d97706;
}

.focus\:bg-yellow-700:focus {
  background-color: #b45309;
}

.focus\:bg-yellow-800:focus {
  background-color: #92400e;
}

.focus\:bg-yellow-900:focus {
  background-color: #78350f;
}

.focus\:bg-green-transparent:focus {
  background: transparent;
}

.focus\:bg-green-current:focus {
  background: currentColor;
}

.focus\:bg-green-50:focus {
  background-color: #ecfdf5;
}

.focus\:bg-green-100:focus {
  background-color: #d1fae5;
}

.focus\:bg-green-200:focus {
  background-color: #a7f3d0;
}

.focus\:bg-green-300:focus {
  background-color: #6ee7b7;
}

.focus\:bg-green-400:focus {
  background-color: #34d399;
}

.focus\:bg-green-500:focus {
  background-color: #10b981;
}

.focus\:bg-green-600:focus {
  background-color: #059669;
}

.focus\:bg-green-700:focus {
  background-color: #047857;
}

.focus\:bg-green-800:focus {
  background-color: #065f46;
}

.focus\:bg-green-900:focus {
  background-color: #064e3b;
}

.focus\:bg-blue-transparent:focus {
  background: transparent;
}

.focus\:bg-blue-current:focus {
  background: currentColor;
}

.focus\:bg-blue-50:focus {
  background-color: #eff6ff;
}

.focus\:bg-blue-100:focus {
  background-color: #dbeafe;
}

.focus\:bg-blue-200:focus {
  background-color: #bfdbfe;
}

.focus\:bg-blue-300:focus {
  background-color: #93c5fd;
}

.focus\:bg-blue-400:focus {
  background-color: #60a5fa;
}

.focus\:bg-blue-500:focus {
  background-color: #3b82f6;
}

.focus\:bg-blue-600:focus {
  background-color: #2563eb;
}

.focus\:bg-blue-700:focus {
  background-color: #1d4ed8;
}

.focus\:bg-blue-800:focus {
  background-color: #1e40af;
}

.focus\:bg-blue-900:focus {
  background-color: #1e3a8a;
}

.focus\:bg-cyan-transparent:focus {
  background: transparent;
}

.focus\:bg-cyan-current:focus {
  background: currentColor;
}

.focus\:bg-cyan-50:focus {
  background-color: #ecfeff;
}

.focus\:bg-cyan-100:focus {
  background-color: #cffafe;
}

.focus\:bg-cyan-200:focus {
  background-color: #a5f3fc;
}

.focus\:bg-cyan-300:focus {
  background-color: #67e8f9;
}

.focus\:bg-cyan-400:focus {
  background-color: #22d3ee;
}

.focus\:bg-cyan-500:focus {
  background-color: #06b6d4;
}

.focus\:bg-cyan-600:focus {
  background-color: #0891b2;
}

.focus\:bg-cyan-700:focus {
  background-color: #0e7490;
}

.focus\:bg-cyan-800:focus {
  background-color: #155e75;
}

.focus\:bg-cyan-900:focus {
  background-color: #164e63;
}

.focus\:bg-indigo-transparent:focus {
  background: transparent;
}

.focus\:bg-indigo-current:focus {
  background: currentColor;
}

.focus\:bg-indigo-50:focus {
  background-color: #eef2ff;
}

.focus\:bg-indigo-100:focus {
  background-color: #e0e7ff;
}

.focus\:bg-indigo-200:focus {
  background-color: #c7d2fe;
}

.focus\:bg-indigo-300:focus {
  background-color: #a5b4fc;
}

.focus\:bg-indigo-400:focus {
  background-color: #818cf8;
}

.focus\:bg-indigo-500:focus {
  background-color: #6366f1;
}

.focus\:bg-indigo-600:focus {
  background-color: #4f46e5;
}

.focus\:bg-indigo-700:focus {
  background-color: #4338ca;
}

.focus\:bg-indigo-800:focus {
  background-color: #3730a3;
}

.focus\:bg-indigo-900:focus {
  background-color: #312e81;
}

.focus\:bg-purple-transparent:focus {
  background: transparent;
}

.focus\:bg-purple-current:focus {
  background: currentColor;
}

.focus\:bg-purple-50:focus {
  background-color: #f5f3ff;
}

.focus\:bg-purple-100:focus {
  background-color: #ede9fe;
}

.focus\:bg-purple-200:focus {
  background-color: #ddd6fe;
}

.focus\:bg-purple-300:focus {
  background-color: #c4b5fd;
}

.focus\:bg-purple-400:focus {
  background-color: #a78bfa;
}

.focus\:bg-purple-500:focus {
  background-color: #8b5cf6;
}

.focus\:bg-purple-600:focus {
  background-color: #7c3aed;
}

.focus\:bg-purple-700:focus {
  background-color: #6d28d9;
}

.focus\:bg-purple-800:focus {
  background-color: #5b21b6;
}

.focus\:bg-purple-900:focus {
  background-color: #4c1d95;
}

.focus\:bg-pink-transparent:focus {
  background: transparent;
}

.focus\:bg-pink-current:focus {
  background: currentColor;
}

.focus\:bg-pink-50:focus {
  background-color: #fdf2f8;
}

.focus\:bg-pink-100:focus {
  background-color: #fce7f3;
}

.focus\:bg-pink-200:focus {
  background-color: #fbcfe8;
}

.focus\:bg-pink-300:focus {
  background-color: #f9a8d4;
}

.focus\:bg-pink-400:focus {
  background-color: #f472b6;
}

.focus\:bg-pink-500:focus {
  background-color: #ec4899;
}

.focus\:bg-pink-600:focus {
  background-color: #db2777;
}

.focus\:bg-pink-700:focus {
  background-color: #be185d;
}

.focus\:bg-pink-800:focus {
  background-color: #9d174d;
}

.focus\:bg-pink-900:focus {
  background-color: #831843;
}

.disabled\:bg-transparent.is-disabled {
  background: transparent;
}

.disabled\:bg-none.is-disabled {
  background: none !important;
}

.disabled\:bg-transparent.is-disabled {
  background: transparent;
}

.disabled\:bg-current.is-disabled {
  background: currentColor;
}

.disabled\:bg-black.is-disabled,
.disabled\:bg-black:disabled {
  background-color: #000;
}

.disabled\:bg-white.is-disabled,
.disabled\:bg-white:disabled {
  background-color: #fff;
}

.disabled\:bg-primary.is-disabled,
.disabled\:bg-primary:disabled {
  background-color: #007bff;
}

.disabled\:bg-secondary.is-disabled,
.disabled\:bg-secondary:disabled {
  background-color: #6c757d;
}

.disabled\:bg-success.is-disabled,
.disabled\:bg-success:disabled {
  background-color: #28a745;
}

.disabled\:bg-info.is-disabled,
.disabled\:bg-info:disabled {
  background-color: #17a2b8;
}

.disabled\:bg-warning.is-disabled,
.disabled\:bg-warning:disabled {
  background-color: #fad733;
}

.disabled\:bg-danger.is-disabled,
.disabled\:bg-danger:disabled {
  background-color: #dc3545;
}

.disabled\:bg-light.is-disabled,
.disabled\:bg-light:disabled {
  background-color: #f8f9fa;
}

.disabled\:bg-dark.is-disabled,
.disabled\:bg-dark:disabled {
  background-color: #343a40;
}

.disabled\:bg-gray-transparent.is-disabled {
  background: transparent;
}

.disabled\:bg-gray-current.is-disabled {
  background: currentColor;
}

.disabled\:bg-gray-50.is-disabled,
.disabled\:bg-gray-50:disabled {
  background-color: #f9fafb;
}

.disabled\:bg-gray-100.is-disabled,
.disabled\:bg-gray-100:disabled {
  background-color: #f3f4f6;
}

.disabled\:bg-gray-200.is-disabled,
.disabled\:bg-gray-200:disabled {
  background-color: #e5e7eb;
}

.disabled\:bg-gray-300.is-disabled,
.disabled\:bg-gray-300:disabled {
  background-color: #d1d5db;
}

.disabled\:bg-gray-400.is-disabled,
.disabled\:bg-gray-400:disabled {
  background-color: #9ca3af;
}

.disabled\:bg-gray-500.is-disabled,
.disabled\:bg-gray-500:disabled {
  background-color: #6b7280;
}

.disabled\:bg-gray-600.is-disabled,
.disabled\:bg-gray-600:disabled {
  background-color: #4b5563;
}

.disabled\:bg-gray-700.is-disabled,
.disabled\:bg-gray-700:disabled {
  background-color: #374151;
}

.disabled\:bg-gray-800.is-disabled,
.disabled\:bg-gray-800:disabled {
  background-color: #1f2937;
}

.disabled\:bg-gray-900.is-disabled,
.disabled\:bg-gray-900:disabled {
  background-color: #111827;
}

.disabled\:bg-red-transparent.is-disabled {
  background: transparent;
}

.disabled\:bg-red-current.is-disabled {
  background: currentColor;
}

.disabled\:bg-red-50.is-disabled,
.disabled\:bg-red-50:disabled {
  background-color: #fef2f2;
}

.disabled\:bg-red-100.is-disabled,
.disabled\:bg-red-100:disabled {
  background-color: #fee2e2;
}

.disabled\:bg-red-200.is-disabled,
.disabled\:bg-red-200:disabled {
  background-color: #fecaca;
}

.disabled\:bg-red-300.is-disabled,
.disabled\:bg-red-300:disabled {
  background-color: #fca5a5;
}

.disabled\:bg-red-400.is-disabled,
.disabled\:bg-red-400:disabled {
  background-color: #f87171;
}

.disabled\:bg-red-500.is-disabled,
.disabled\:bg-red-500:disabled {
  background-color: #ef4444;
}

.disabled\:bg-red-600.is-disabled,
.disabled\:bg-red-600:disabled {
  background-color: #dc2626;
}

.disabled\:bg-red-700.is-disabled,
.disabled\:bg-red-700:disabled {
  background-color: #b91c1c;
}

.disabled\:bg-red-800.is-disabled,
.disabled\:bg-red-800:disabled {
  background-color: #991b1b;
}

.disabled\:bg-red-900.is-disabled,
.disabled\:bg-red-900:disabled {
  background-color: #7f1d1d;
}

.disabled\:bg-yellow-transparent.is-disabled {
  background: transparent;
}

.disabled\:bg-yellow-current.is-disabled {
  background: currentColor;
}

.disabled\:bg-yellow-50.is-disabled,
.disabled\:bg-yellow-50:disabled {
  background-color: #fffbeb;
}

.disabled\:bg-yellow-100.is-disabled,
.disabled\:bg-yellow-100:disabled {
  background-color: #fef3c7;
}

.disabled\:bg-yellow-200.is-disabled,
.disabled\:bg-yellow-200:disabled {
  background-color: #fde68a;
}

.disabled\:bg-yellow-300.is-disabled,
.disabled\:bg-yellow-300:disabled {
  background-color: #fcd34d;
}

.disabled\:bg-yellow-400.is-disabled,
.disabled\:bg-yellow-400:disabled {
  background-color: #fbbf24;
}

.disabled\:bg-yellow-500.is-disabled,
.disabled\:bg-yellow-500:disabled {
  background-color: #f59e0b;
}

.disabled\:bg-yellow-600.is-disabled,
.disabled\:bg-yellow-600:disabled {
  background-color: #d97706;
}

.disabled\:bg-yellow-700.is-disabled,
.disabled\:bg-yellow-700:disabled {
  background-color: #b45309;
}

.disabled\:bg-yellow-800.is-disabled,
.disabled\:bg-yellow-800:disabled {
  background-color: #92400e;
}

.disabled\:bg-yellow-900.is-disabled,
.disabled\:bg-yellow-900:disabled {
  background-color: #78350f;
}

.disabled\:bg-green-transparent.is-disabled {
  background: transparent;
}

.disabled\:bg-green-current.is-disabled {
  background: currentColor;
}

.disabled\:bg-green-50.is-disabled,
.disabled\:bg-green-50:disabled {
  background-color: #ecfdf5;
}

.disabled\:bg-green-100.is-disabled,
.disabled\:bg-green-100:disabled {
  background-color: #d1fae5;
}

.disabled\:bg-green-200.is-disabled,
.disabled\:bg-green-200:disabled {
  background-color: #a7f3d0;
}

.disabled\:bg-green-300.is-disabled,
.disabled\:bg-green-300:disabled {
  background-color: #6ee7b7;
}

.disabled\:bg-green-400.is-disabled,
.disabled\:bg-green-400:disabled {
  background-color: #34d399;
}

.disabled\:bg-green-500.is-disabled,
.disabled\:bg-green-500:disabled {
  background-color: #10b981;
}

.disabled\:bg-green-600.is-disabled,
.disabled\:bg-green-600:disabled {
  background-color: #059669;
}

.disabled\:bg-green-700.is-disabled,
.disabled\:bg-green-700:disabled {
  background-color: #047857;
}

.disabled\:bg-green-800.is-disabled,
.disabled\:bg-green-800:disabled {
  background-color: #065f46;
}

.disabled\:bg-green-900.is-disabled,
.disabled\:bg-green-900:disabled {
  background-color: #064e3b;
}

.disabled\:bg-blue-transparent.is-disabled {
  background: transparent;
}

.disabled\:bg-blue-current.is-disabled {
  background: currentColor;
}

.disabled\:bg-blue-50.is-disabled,
.disabled\:bg-blue-50:disabled {
  background-color: #eff6ff;
}

.disabled\:bg-blue-100.is-disabled,
.disabled\:bg-blue-100:disabled {
  background-color: #dbeafe;
}

.disabled\:bg-blue-200.is-disabled,
.disabled\:bg-blue-200:disabled {
  background-color: #bfdbfe;
}

.disabled\:bg-blue-300.is-disabled,
.disabled\:bg-blue-300:disabled {
  background-color: #93c5fd;
}

.disabled\:bg-blue-400.is-disabled,
.disabled\:bg-blue-400:disabled {
  background-color: #60a5fa;
}

.disabled\:bg-blue-500.is-disabled,
.disabled\:bg-blue-500:disabled {
  background-color: #3b82f6;
}

.disabled\:bg-blue-600.is-disabled,
.disabled\:bg-blue-600:disabled {
  background-color: #2563eb;
}

.disabled\:bg-blue-700.is-disabled,
.disabled\:bg-blue-700:disabled {
  background-color: #1d4ed8;
}

.disabled\:bg-blue-800.is-disabled,
.disabled\:bg-blue-800:disabled {
  background-color: #1e40af;
}

.disabled\:bg-blue-900.is-disabled,
.disabled\:bg-blue-900:disabled {
  background-color: #1e3a8a;
}

.disabled\:bg-cyan-transparent.is-disabled {
  background: transparent;
}

.disabled\:bg-cyan-current.is-disabled {
  background: currentColor;
}

.disabled\:bg-cyan-50.is-disabled,
.disabled\:bg-cyan-50:disabled {
  background-color: #ecfeff;
}

.disabled\:bg-cyan-100.is-disabled,
.disabled\:bg-cyan-100:disabled {
  background-color: #cffafe;
}

.disabled\:bg-cyan-200.is-disabled,
.disabled\:bg-cyan-200:disabled {
  background-color: #a5f3fc;
}

.disabled\:bg-cyan-300.is-disabled,
.disabled\:bg-cyan-300:disabled {
  background-color: #67e8f9;
}

.disabled\:bg-cyan-400.is-disabled,
.disabled\:bg-cyan-400:disabled {
  background-color: #22d3ee;
}

.disabled\:bg-cyan-500.is-disabled,
.disabled\:bg-cyan-500:disabled {
  background-color: #06b6d4;
}

.disabled\:bg-cyan-600.is-disabled,
.disabled\:bg-cyan-600:disabled {
  background-color: #0891b2;
}

.disabled\:bg-cyan-700.is-disabled,
.disabled\:bg-cyan-700:disabled {
  background-color: #0e7490;
}

.disabled\:bg-cyan-800.is-disabled,
.disabled\:bg-cyan-800:disabled {
  background-color: #155e75;
}

.disabled\:bg-cyan-900.is-disabled,
.disabled\:bg-cyan-900:disabled {
  background-color: #164e63;
}

.disabled\:bg-indigo-transparent.is-disabled {
  background: transparent;
}

.disabled\:bg-indigo-current.is-disabled {
  background: currentColor;
}

.disabled\:bg-indigo-50.is-disabled,
.disabled\:bg-indigo-50:disabled {
  background-color: #eef2ff;
}

.disabled\:bg-indigo-100.is-disabled,
.disabled\:bg-indigo-100:disabled {
  background-color: #e0e7ff;
}

.disabled\:bg-indigo-200.is-disabled,
.disabled\:bg-indigo-200:disabled {
  background-color: #c7d2fe;
}

.disabled\:bg-indigo-300.is-disabled,
.disabled\:bg-indigo-300:disabled {
  background-color: #a5b4fc;
}

.disabled\:bg-indigo-400.is-disabled,
.disabled\:bg-indigo-400:disabled {
  background-color: #818cf8;
}

.disabled\:bg-indigo-500.is-disabled,
.disabled\:bg-indigo-500:disabled {
  background-color: #6366f1;
}

.disabled\:bg-indigo-600.is-disabled,
.disabled\:bg-indigo-600:disabled {
  background-color: #4f46e5;
}

.disabled\:bg-indigo-700.is-disabled,
.disabled\:bg-indigo-700:disabled {
  background-color: #4338ca;
}

.disabled\:bg-indigo-800.is-disabled,
.disabled\:bg-indigo-800:disabled {
  background-color: #3730a3;
}

.disabled\:bg-indigo-900.is-disabled,
.disabled\:bg-indigo-900:disabled {
  background-color: #312e81;
}

.disabled\:bg-purple-transparent.is-disabled {
  background: transparent;
}

.disabled\:bg-purple-current.is-disabled {
  background: currentColor;
}

.disabled\:bg-purple-50.is-disabled,
.disabled\:bg-purple-50:disabled {
  background-color: #f5f3ff;
}

.disabled\:bg-purple-100.is-disabled,
.disabled\:bg-purple-100:disabled {
  background-color: #ede9fe;
}

.disabled\:bg-purple-200.is-disabled,
.disabled\:bg-purple-200:disabled {
  background-color: #ddd6fe;
}

.disabled\:bg-purple-300.is-disabled,
.disabled\:bg-purple-300:disabled {
  background-color: #c4b5fd;
}

.disabled\:bg-purple-400.is-disabled,
.disabled\:bg-purple-400:disabled {
  background-color: #a78bfa;
}

.disabled\:bg-purple-500.is-disabled,
.disabled\:bg-purple-500:disabled {
  background-color: #8b5cf6;
}

.disabled\:bg-purple-600.is-disabled,
.disabled\:bg-purple-600:disabled {
  background-color: #7c3aed;
}

.disabled\:bg-purple-700.is-disabled,
.disabled\:bg-purple-700:disabled {
  background-color: #6d28d9;
}

.disabled\:bg-purple-800.is-disabled,
.disabled\:bg-purple-800:disabled {
  background-color: #5b21b6;
}

.disabled\:bg-purple-900.is-disabled,
.disabled\:bg-purple-900:disabled {
  background-color: #4c1d95;
}

.disabled\:bg-pink-transparent.is-disabled {
  background: transparent;
}

.disabled\:bg-pink-current.is-disabled {
  background: currentColor;
}

.disabled\:bg-pink-50.is-disabled,
.disabled\:bg-pink-50:disabled {
  background-color: #fdf2f8;
}

.disabled\:bg-pink-100.is-disabled,
.disabled\:bg-pink-100:disabled {
  background-color: #fce7f3;
}

.disabled\:bg-pink-200.is-disabled,
.disabled\:bg-pink-200:disabled {
  background-color: #fbcfe8;
}

.disabled\:bg-pink-300.is-disabled,
.disabled\:bg-pink-300:disabled {
  background-color: #f9a8d4;
}

.disabled\:bg-pink-400.is-disabled,
.disabled\:bg-pink-400:disabled {
  background-color: #f472b6;
}

.disabled\:bg-pink-500.is-disabled,
.disabled\:bg-pink-500:disabled {
  background-color: #ec4899;
}

.disabled\:bg-pink-600.is-disabled,
.disabled\:bg-pink-600:disabled {
  background-color: #db2777;
}

.disabled\:bg-pink-700.is-disabled,
.disabled\:bg-pink-700:disabled {
  background-color: #be185d;
}

.disabled\:bg-pink-800.is-disabled,
.disabled\:bg-pink-800:disabled {
  background-color: #9d174d;
}

.disabled\:bg-pink-900.is-disabled,
.disabled\:bg-pink-900:disabled {
  background-color: #831843;
}

.group:hover .group-hover\:bg-transparent {
  background: transparent;
}

.group:hover .group-hover\:bg-none {
  background: none !important;
}

.group:hover .group-hover\:bg-transparent {
  background: transparent;
}

.group:hover .group-hover\:bg-current {
  background: currentColor;
}

.group:hover .group-hover\:bg-black {
  background-color: #000;
}

.group:hover .group-hover\:bg-white {
  background-color: #fff;
}

.group:hover .group-hover\:bg-primary {
  background-color: #007bff;
}

.group:hover .group-hover\:bg-secondary {
  background-color: #6c757d;
}

.group:hover .group-hover\:bg-success {
  background-color: #28a745;
}

.group:hover .group-hover\:bg-info {
  background-color: #17a2b8;
}

.group:hover .group-hover\:bg-warning {
  background-color: #fad733;
}

.group:hover .group-hover\:bg-danger {
  background-color: #dc3545;
}

.group:hover .group-hover\:bg-light {
  background-color: #f8f9fa;
}

.group:hover .group-hover\:bg-dark {
  background-color: #343a40;
}

.group:hover .group-hover\:bg-gray-transparent {
  background: transparent;
}

.group:hover .group-hover\:bg-gray-current {
  background: currentColor;
}

.group:hover .group-hover\:bg-gray-50 {
  background-color: #f9fafb;
}

.group:hover .group-hover\:bg-gray-100 {
  background-color: #f3f4f6;
}

.group:hover .group-hover\:bg-gray-200 {
  background-color: #e5e7eb;
}

.group:hover .group-hover\:bg-gray-300 {
  background-color: #d1d5db;
}

.group:hover .group-hover\:bg-gray-400 {
  background-color: #9ca3af;
}

.group:hover .group-hover\:bg-gray-500 {
  background-color: #6b7280;
}

.group:hover .group-hover\:bg-gray-600 {
  background-color: #4b5563;
}

.group:hover .group-hover\:bg-gray-700 {
  background-color: #374151;
}

.group:hover .group-hover\:bg-gray-800 {
  background-color: #1f2937;
}

.group:hover .group-hover\:bg-gray-900 {
  background-color: #111827;
}

.group:hover .group-hover\:bg-red-transparent {
  background: transparent;
}

.group:hover .group-hover\:bg-red-current {
  background: currentColor;
}

.group:hover .group-hover\:bg-red-50 {
  background-color: #fef2f2;
}

.group:hover .group-hover\:bg-red-100 {
  background-color: #fee2e2;
}

.group:hover .group-hover\:bg-red-200 {
  background-color: #fecaca;
}

.group:hover .group-hover\:bg-red-300 {
  background-color: #fca5a5;
}

.group:hover .group-hover\:bg-red-400 {
  background-color: #f87171;
}

.group:hover .group-hover\:bg-red-500 {
  background-color: #ef4444;
}

.group:hover .group-hover\:bg-red-600 {
  background-color: #dc2626;
}

.group:hover .group-hover\:bg-red-700 {
  background-color: #b91c1c;
}

.group:hover .group-hover\:bg-red-800 {
  background-color: #991b1b;
}

.group:hover .group-hover\:bg-red-900 {
  background-color: #7f1d1d;
}

.group:hover .group-hover\:bg-yellow-transparent {
  background: transparent;
}

.group:hover .group-hover\:bg-yellow-current {
  background: currentColor;
}

.group:hover .group-hover\:bg-yellow-50 {
  background-color: #fffbeb;
}

.group:hover .group-hover\:bg-yellow-100 {
  background-color: #fef3c7;
}

.group:hover .group-hover\:bg-yellow-200 {
  background-color: #fde68a;
}

.group:hover .group-hover\:bg-yellow-300 {
  background-color: #fcd34d;
}

.group:hover .group-hover\:bg-yellow-400 {
  background-color: #fbbf24;
}

.group:hover .group-hover\:bg-yellow-500 {
  background-color: #f59e0b;
}

.group:hover .group-hover\:bg-yellow-600 {
  background-color: #d97706;
}

.group:hover .group-hover\:bg-yellow-700 {
  background-color: #b45309;
}

.group:hover .group-hover\:bg-yellow-800 {
  background-color: #92400e;
}

.group:hover .group-hover\:bg-yellow-900 {
  background-color: #78350f;
}

.group:hover .group-hover\:bg-green-transparent {
  background: transparent;
}

.group:hover .group-hover\:bg-green-current {
  background: currentColor;
}

.group:hover .group-hover\:bg-green-50 {
  background-color: #ecfdf5;
}

.group:hover .group-hover\:bg-green-100 {
  background-color: #d1fae5;
}

.group:hover .group-hover\:bg-green-200 {
  background-color: #a7f3d0;
}

.group:hover .group-hover\:bg-green-300 {
  background-color: #6ee7b7;
}

.group:hover .group-hover\:bg-green-400 {
  background-color: #34d399;
}

.group:hover .group-hover\:bg-green-500 {
  background-color: #10b981;
}

.group:hover .group-hover\:bg-green-600 {
  background-color: #059669;
}

.group:hover .group-hover\:bg-green-700 {
  background-color: #047857;
}

.group:hover .group-hover\:bg-green-800 {
  background-color: #065f46;
}

.group:hover .group-hover\:bg-green-900 {
  background-color: #064e3b;
}

.group:hover .group-hover\:bg-blue-transparent {
  background: transparent;
}

.group:hover .group-hover\:bg-blue-current {
  background: currentColor;
}

.group:hover .group-hover\:bg-blue-50 {
  background-color: #eff6ff;
}

.group:hover .group-hover\:bg-blue-100 {
  background-color: #dbeafe;
}

.group:hover .group-hover\:bg-blue-200 {
  background-color: #bfdbfe;
}

.group:hover .group-hover\:bg-blue-300 {
  background-color: #93c5fd;
}

.group:hover .group-hover\:bg-blue-400 {
  background-color: #60a5fa;
}

.group:hover .group-hover\:bg-blue-500 {
  background-color: #3b82f6;
}

.group:hover .group-hover\:bg-blue-600 {
  background-color: #2563eb;
}

.group:hover .group-hover\:bg-blue-700 {
  background-color: #1d4ed8;
}

.group:hover .group-hover\:bg-blue-800 {
  background-color: #1e40af;
}

.group:hover .group-hover\:bg-blue-900 {
  background-color: #1e3a8a;
}

.group:hover .group-hover\:bg-cyan-transparent {
  background: transparent;
}

.group:hover .group-hover\:bg-cyan-current {
  background: currentColor;
}

.group:hover .group-hover\:bg-cyan-50 {
  background-color: #ecfeff;
}

.group:hover .group-hover\:bg-cyan-100 {
  background-color: #cffafe;
}

.group:hover .group-hover\:bg-cyan-200 {
  background-color: #a5f3fc;
}

.group:hover .group-hover\:bg-cyan-300 {
  background-color: #67e8f9;
}

.group:hover .group-hover\:bg-cyan-400 {
  background-color: #22d3ee;
}

.group:hover .group-hover\:bg-cyan-500 {
  background-color: #06b6d4;
}

.group:hover .group-hover\:bg-cyan-600 {
  background-color: #0891b2;
}

.group:hover .group-hover\:bg-cyan-700 {
  background-color: #0e7490;
}

.group:hover .group-hover\:bg-cyan-800 {
  background-color: #155e75;
}

.group:hover .group-hover\:bg-cyan-900 {
  background-color: #164e63;
}

.group:hover .group-hover\:bg-indigo-transparent {
  background: transparent;
}

.group:hover .group-hover\:bg-indigo-current {
  background: currentColor;
}

.group:hover .group-hover\:bg-indigo-50 {
  background-color: #eef2ff;
}

.group:hover .group-hover\:bg-indigo-100 {
  background-color: #e0e7ff;
}

.group:hover .group-hover\:bg-indigo-200 {
  background-color: #c7d2fe;
}

.group:hover .group-hover\:bg-indigo-300 {
  background-color: #a5b4fc;
}

.group:hover .group-hover\:bg-indigo-400 {
  background-color: #818cf8;
}

.group:hover .group-hover\:bg-indigo-500 {
  background-color: #6366f1;
}

.group:hover .group-hover\:bg-indigo-600 {
  background-color: #4f46e5;
}

.group:hover .group-hover\:bg-indigo-700 {
  background-color: #4338ca;
}

.group:hover .group-hover\:bg-indigo-800 {
  background-color: #3730a3;
}

.group:hover .group-hover\:bg-indigo-900 {
  background-color: #312e81;
}

.group:hover .group-hover\:bg-purple-transparent {
  background: transparent;
}

.group:hover .group-hover\:bg-purple-current {
  background: currentColor;
}

.group:hover .group-hover\:bg-purple-50 {
  background-color: #f5f3ff;
}

.group:hover .group-hover\:bg-purple-100 {
  background-color: #ede9fe;
}

.group:hover .group-hover\:bg-purple-200 {
  background-color: #ddd6fe;
}

.group:hover .group-hover\:bg-purple-300 {
  background-color: #c4b5fd;
}

.group:hover .group-hover\:bg-purple-400 {
  background-color: #a78bfa;
}

.group:hover .group-hover\:bg-purple-500 {
  background-color: #8b5cf6;
}

.group:hover .group-hover\:bg-purple-600 {
  background-color: #7c3aed;
}

.group:hover .group-hover\:bg-purple-700 {
  background-color: #6d28d9;
}

.group:hover .group-hover\:bg-purple-800 {
  background-color: #5b21b6;
}

.group:hover .group-hover\:bg-purple-900 {
  background-color: #4c1d95;
}

.group:hover .group-hover\:bg-pink-transparent {
  background: transparent;
}

.group:hover .group-hover\:bg-pink-current {
  background: currentColor;
}

.group:hover .group-hover\:bg-pink-50 {
  background-color: #fdf2f8;
}

.group:hover .group-hover\:bg-pink-100 {
  background-color: #fce7f3;
}

.group:hover .group-hover\:bg-pink-200 {
  background-color: #fbcfe8;
}

.group:hover .group-hover\:bg-pink-300 {
  background-color: #f9a8d4;
}

.group:hover .group-hover\:bg-pink-400 {
  background-color: #f472b6;
}

.group:hover .group-hover\:bg-pink-500 {
  background-color: #ec4899;
}

.group:hover .group-hover\:bg-pink-600 {
  background-color: #db2777;
}

.group:hover .group-hover\:bg-pink-700 {
  background-color: #be185d;
}

.group:hover .group-hover\:bg-pink-800 {
  background-color: #9d174d;
}

.group:hover .group-hover\:bg-pink-900 {
  background-color: #831843;
}

@media (max-width: 768px) {
  .m\:bg-transparent {
    background: transparent;
  }

  .m\:bg-none {
    background: none !important;
  }

  .m\:bg-transparent {
    background: transparent;
  }

  .m\:bg-current {
    background: currentColor;
  }

  .m\:bg-black {
    background-color: #000;
  }

  .m\:bg-white {
    background-color: #fff;
  }

  .m\:bg-primary {
    background-color: #007bff;
  }

  .m\:bg-secondary {
    background-color: #6c757d;
  }

  .m\:bg-success {
    background-color: #28a745;
  }

  .m\:bg-info {
    background-color: #17a2b8;
  }

  .m\:bg-warning {
    background-color: #fad733;
  }

  .m\:bg-danger {
    background-color: #dc3545;
  }

  .m\:bg-light {
    background-color: #f8f9fa;
  }

  .m\:bg-dark {
    background-color: #343a40;
  }

  .m\:bg-gray-transparent {
    background: transparent;
  }

  .m\:bg-gray-current {
    background: currentColor;
  }

  .m\:bg-gray-50 {
    background-color: #f9fafb;
  }

  .m\:bg-gray-100 {
    background-color: #f3f4f6;
  }

  .m\:bg-gray-200 {
    background-color: #e5e7eb;
  }

  .m\:bg-gray-300 {
    background-color: #d1d5db;
  }

  .m\:bg-gray-400 {
    background-color: #9ca3af;
  }

  .m\:bg-gray-500 {
    background-color: #6b7280;
  }

  .m\:bg-gray-600 {
    background-color: #4b5563;
  }

  .m\:bg-gray-700 {
    background-color: #374151;
  }

  .m\:bg-gray-800 {
    background-color: #1f2937;
  }

  .m\:bg-gray-900 {
    background-color: #111827;
  }

  .m\:bg-red-transparent {
    background: transparent;
  }

  .m\:bg-red-current {
    background: currentColor;
  }

  .m\:bg-red-50 {
    background-color: #fef2f2;
  }

  .m\:bg-red-100 {
    background-color: #fee2e2;
  }

  .m\:bg-red-200 {
    background-color: #fecaca;
  }

  .m\:bg-red-300 {
    background-color: #fca5a5;
  }

  .m\:bg-red-400 {
    background-color: #f87171;
  }

  .m\:bg-red-500 {
    background-color: #ef4444;
  }

  .m\:bg-red-600 {
    background-color: #dc2626;
  }

  .m\:bg-red-700 {
    background-color: #b91c1c;
  }

  .m\:bg-red-800 {
    background-color: #991b1b;
  }

  .m\:bg-red-900 {
    background-color: #7f1d1d;
  }

  .m\:bg-yellow-transparent {
    background: transparent;
  }

  .m\:bg-yellow-current {
    background: currentColor;
  }

  .m\:bg-yellow-50 {
    background-color: #fffbeb;
  }

  .m\:bg-yellow-100 {
    background-color: #fef3c7;
  }

  .m\:bg-yellow-200 {
    background-color: #fde68a;
  }

  .m\:bg-yellow-300 {
    background-color: #fcd34d;
  }

  .m\:bg-yellow-400 {
    background-color: #fbbf24;
  }

  .m\:bg-yellow-500 {
    background-color: #f59e0b;
  }

  .m\:bg-yellow-600 {
    background-color: #d97706;
  }

  .m\:bg-yellow-700 {
    background-color: #b45309;
  }

  .m\:bg-yellow-800 {
    background-color: #92400e;
  }

  .m\:bg-yellow-900 {
    background-color: #78350f;
  }

  .m\:bg-green-transparent {
    background: transparent;
  }

  .m\:bg-green-current {
    background: currentColor;
  }

  .m\:bg-green-50 {
    background-color: #ecfdf5;
  }

  .m\:bg-green-100 {
    background-color: #d1fae5;
  }

  .m\:bg-green-200 {
    background-color: #a7f3d0;
  }

  .m\:bg-green-300 {
    background-color: #6ee7b7;
  }

  .m\:bg-green-400 {
    background-color: #34d399;
  }

  .m\:bg-green-500 {
    background-color: #10b981;
  }

  .m\:bg-green-600 {
    background-color: #059669;
  }

  .m\:bg-green-700 {
    background-color: #047857;
  }

  .m\:bg-green-800 {
    background-color: #065f46;
  }

  .m\:bg-green-900 {
    background-color: #064e3b;
  }

  .m\:bg-blue-transparent {
    background: transparent;
  }

  .m\:bg-blue-current {
    background: currentColor;
  }

  .m\:bg-blue-50 {
    background-color: #eff6ff;
  }

  .m\:bg-blue-100 {
    background-color: #dbeafe;
  }

  .m\:bg-blue-200 {
    background-color: #bfdbfe;
  }

  .m\:bg-blue-300 {
    background-color: #93c5fd;
  }

  .m\:bg-blue-400 {
    background-color: #60a5fa;
  }

  .m\:bg-blue-500 {
    background-color: #3b82f6;
  }

  .m\:bg-blue-600 {
    background-color: #2563eb;
  }

  .m\:bg-blue-700 {
    background-color: #1d4ed8;
  }

  .m\:bg-blue-800 {
    background-color: #1e40af;
  }

  .m\:bg-blue-900 {
    background-color: #1e3a8a;
  }

  .m\:bg-cyan-transparent {
    background: transparent;
  }

  .m\:bg-cyan-current {
    background: currentColor;
  }

  .m\:bg-cyan-50 {
    background-color: #ecfeff;
  }

  .m\:bg-cyan-100 {
    background-color: #cffafe;
  }

  .m\:bg-cyan-200 {
    background-color: #a5f3fc;
  }

  .m\:bg-cyan-300 {
    background-color: #67e8f9;
  }

  .m\:bg-cyan-400 {
    background-color: #22d3ee;
  }

  .m\:bg-cyan-500 {
    background-color: #06b6d4;
  }

  .m\:bg-cyan-600 {
    background-color: #0891b2;
  }

  .m\:bg-cyan-700 {
    background-color: #0e7490;
  }

  .m\:bg-cyan-800 {
    background-color: #155e75;
  }

  .m\:bg-cyan-900 {
    background-color: #164e63;
  }

  .m\:bg-indigo-transparent {
    background: transparent;
  }

  .m\:bg-indigo-current {
    background: currentColor;
  }

  .m\:bg-indigo-50 {
    background-color: #eef2ff;
  }

  .m\:bg-indigo-100 {
    background-color: #e0e7ff;
  }

  .m\:bg-indigo-200 {
    background-color: #c7d2fe;
  }

  .m\:bg-indigo-300 {
    background-color: #a5b4fc;
  }

  .m\:bg-indigo-400 {
    background-color: #818cf8;
  }

  .m\:bg-indigo-500 {
    background-color: #6366f1;
  }

  .m\:bg-indigo-600 {
    background-color: #4f46e5;
  }

  .m\:bg-indigo-700 {
    background-color: #4338ca;
  }

  .m\:bg-indigo-800 {
    background-color: #3730a3;
  }

  .m\:bg-indigo-900 {
    background-color: #312e81;
  }

  .m\:bg-purple-transparent {
    background: transparent;
  }

  .m\:bg-purple-current {
    background: currentColor;
  }

  .m\:bg-purple-50 {
    background-color: #f5f3ff;
  }

  .m\:bg-purple-100 {
    background-color: #ede9fe;
  }

  .m\:bg-purple-200 {
    background-color: #ddd6fe;
  }

  .m\:bg-purple-300 {
    background-color: #c4b5fd;
  }

  .m\:bg-purple-400 {
    background-color: #a78bfa;
  }

  .m\:bg-purple-500 {
    background-color: #8b5cf6;
  }

  .m\:bg-purple-600 {
    background-color: #7c3aed;
  }

  .m\:bg-purple-700 {
    background-color: #6d28d9;
  }

  .m\:bg-purple-800 {
    background-color: #5b21b6;
  }

  .m\:bg-purple-900 {
    background-color: #4c1d95;
  }

  .m\:bg-pink-transparent {
    background: transparent;
  }

  .m\:bg-pink-current {
    background: currentColor;
  }

  .m\:bg-pink-50 {
    background-color: #fdf2f8;
  }

  .m\:bg-pink-100 {
    background-color: #fce7f3;
  }

  .m\:bg-pink-200 {
    background-color: #fbcfe8;
  }

  .m\:bg-pink-300 {
    background-color: #f9a8d4;
  }

  .m\:bg-pink-400 {
    background-color: #f472b6;
  }

  .m\:bg-pink-500 {
    background-color: #ec4899;
  }

  .m\:bg-pink-600 {
    background-color: #db2777;
  }

  .m\:bg-pink-700 {
    background-color: #be185d;
  }

  .m\:bg-pink-800 {
    background-color: #9d174d;
  }

  .m\:bg-pink-900 {
    background-color: #831843;
  }

  .m\:hover\:bg-transparent:hover {
    background: transparent;
  }

  .m\:hover\:bg-none:hover {
    background: none !important;
  }

  .m\:hover\:bg-transparent:hover {
    background: transparent;
  }

  .m\:hover\:bg-current:hover {
    background: currentColor;
  }

  .m\:hover\:bg-black:hover {
    background-color: #000;
  }

  .m\:hover\:bg-white:hover {
    background-color: #fff;
  }

  .m\:hover\:bg-primary:hover {
    background-color: #007bff;
  }

  .m\:hover\:bg-secondary:hover {
    background-color: #6c757d;
  }

  .m\:hover\:bg-success:hover {
    background-color: #28a745;
  }

  .m\:hover\:bg-info:hover {
    background-color: #17a2b8;
  }

  .m\:hover\:bg-warning:hover {
    background-color: #fad733;
  }

  .m\:hover\:bg-danger:hover {
    background-color: #dc3545;
  }

  .m\:hover\:bg-light:hover {
    background-color: #f8f9fa;
  }

  .m\:hover\:bg-dark:hover {
    background-color: #343a40;
  }

  .m\:hover\:bg-gray-transparent:hover {
    background: transparent;
  }

  .m\:hover\:bg-gray-current:hover {
    background: currentColor;
  }

  .m\:hover\:bg-gray-50:hover {
    background-color: #f9fafb;
  }

  .m\:hover\:bg-gray-100:hover {
    background-color: #f3f4f6;
  }

  .m\:hover\:bg-gray-200:hover {
    background-color: #e5e7eb;
  }

  .m\:hover\:bg-gray-300:hover {
    background-color: #d1d5db;
  }

  .m\:hover\:bg-gray-400:hover {
    background-color: #9ca3af;
  }

  .m\:hover\:bg-gray-500:hover {
    background-color: #6b7280;
  }

  .m\:hover\:bg-gray-600:hover {
    background-color: #4b5563;
  }

  .m\:hover\:bg-gray-700:hover {
    background-color: #374151;
  }

  .m\:hover\:bg-gray-800:hover {
    background-color: #1f2937;
  }

  .m\:hover\:bg-gray-900:hover {
    background-color: #111827;
  }

  .m\:hover\:bg-red-transparent:hover {
    background: transparent;
  }

  .m\:hover\:bg-red-current:hover {
    background: currentColor;
  }

  .m\:hover\:bg-red-50:hover {
    background-color: #fef2f2;
  }

  .m\:hover\:bg-red-100:hover {
    background-color: #fee2e2;
  }

  .m\:hover\:bg-red-200:hover {
    background-color: #fecaca;
  }

  .m\:hover\:bg-red-300:hover {
    background-color: #fca5a5;
  }

  .m\:hover\:bg-red-400:hover {
    background-color: #f87171;
  }

  .m\:hover\:bg-red-500:hover {
    background-color: #ef4444;
  }

  .m\:hover\:bg-red-600:hover {
    background-color: #dc2626;
  }

  .m\:hover\:bg-red-700:hover {
    background-color: #b91c1c;
  }

  .m\:hover\:bg-red-800:hover {
    background-color: #991b1b;
  }

  .m\:hover\:bg-red-900:hover {
    background-color: #7f1d1d;
  }

  .m\:hover\:bg-yellow-transparent:hover {
    background: transparent;
  }

  .m\:hover\:bg-yellow-current:hover {
    background: currentColor;
  }

  .m\:hover\:bg-yellow-50:hover {
    background-color: #fffbeb;
  }

  .m\:hover\:bg-yellow-100:hover {
    background-color: #fef3c7;
  }

  .m\:hover\:bg-yellow-200:hover {
    background-color: #fde68a;
  }

  .m\:hover\:bg-yellow-300:hover {
    background-color: #fcd34d;
  }

  .m\:hover\:bg-yellow-400:hover {
    background-color: #fbbf24;
  }

  .m\:hover\:bg-yellow-500:hover {
    background-color: #f59e0b;
  }

  .m\:hover\:bg-yellow-600:hover {
    background-color: #d97706;
  }

  .m\:hover\:bg-yellow-700:hover {
    background-color: #b45309;
  }

  .m\:hover\:bg-yellow-800:hover {
    background-color: #92400e;
  }

  .m\:hover\:bg-yellow-900:hover {
    background-color: #78350f;
  }

  .m\:hover\:bg-green-transparent:hover {
    background: transparent;
  }

  .m\:hover\:bg-green-current:hover {
    background: currentColor;
  }

  .m\:hover\:bg-green-50:hover {
    background-color: #ecfdf5;
  }

  .m\:hover\:bg-green-100:hover {
    background-color: #d1fae5;
  }

  .m\:hover\:bg-green-200:hover {
    background-color: #a7f3d0;
  }

  .m\:hover\:bg-green-300:hover {
    background-color: #6ee7b7;
  }

  .m\:hover\:bg-green-400:hover {
    background-color: #34d399;
  }

  .m\:hover\:bg-green-500:hover {
    background-color: #10b981;
  }

  .m\:hover\:bg-green-600:hover {
    background-color: #059669;
  }

  .m\:hover\:bg-green-700:hover {
    background-color: #047857;
  }

  .m\:hover\:bg-green-800:hover {
    background-color: #065f46;
  }

  .m\:hover\:bg-green-900:hover {
    background-color: #064e3b;
  }

  .m\:hover\:bg-blue-transparent:hover {
    background: transparent;
  }

  .m\:hover\:bg-blue-current:hover {
    background: currentColor;
  }

  .m\:hover\:bg-blue-50:hover {
    background-color: #eff6ff;
  }

  .m\:hover\:bg-blue-100:hover {
    background-color: #dbeafe;
  }

  .m\:hover\:bg-blue-200:hover {
    background-color: #bfdbfe;
  }

  .m\:hover\:bg-blue-300:hover {
    background-color: #93c5fd;
  }

  .m\:hover\:bg-blue-400:hover {
    background-color: #60a5fa;
  }

  .m\:hover\:bg-blue-500:hover {
    background-color: #3b82f6;
  }

  .m\:hover\:bg-blue-600:hover {
    background-color: #2563eb;
  }

  .m\:hover\:bg-blue-700:hover {
    background-color: #1d4ed8;
  }

  .m\:hover\:bg-blue-800:hover {
    background-color: #1e40af;
  }

  .m\:hover\:bg-blue-900:hover {
    background-color: #1e3a8a;
  }

  .m\:hover\:bg-cyan-transparent:hover {
    background: transparent;
  }

  .m\:hover\:bg-cyan-current:hover {
    background: currentColor;
  }

  .m\:hover\:bg-cyan-50:hover {
    background-color: #ecfeff;
  }

  .m\:hover\:bg-cyan-100:hover {
    background-color: #cffafe;
  }

  .m\:hover\:bg-cyan-200:hover {
    background-color: #a5f3fc;
  }

  .m\:hover\:bg-cyan-300:hover {
    background-color: #67e8f9;
  }

  .m\:hover\:bg-cyan-400:hover {
    background-color: #22d3ee;
  }

  .m\:hover\:bg-cyan-500:hover {
    background-color: #06b6d4;
  }

  .m\:hover\:bg-cyan-600:hover {
    background-color: #0891b2;
  }

  .m\:hover\:bg-cyan-700:hover {
    background-color: #0e7490;
  }

  .m\:hover\:bg-cyan-800:hover {
    background-color: #155e75;
  }

  .m\:hover\:bg-cyan-900:hover {
    background-color: #164e63;
  }

  .m\:hover\:bg-indigo-transparent:hover {
    background: transparent;
  }

  .m\:hover\:bg-indigo-current:hover {
    background: currentColor;
  }

  .m\:hover\:bg-indigo-50:hover {
    background-color: #eef2ff;
  }

  .m\:hover\:bg-indigo-100:hover {
    background-color: #e0e7ff;
  }

  .m\:hover\:bg-indigo-200:hover {
    background-color: #c7d2fe;
  }

  .m\:hover\:bg-indigo-300:hover {
    background-color: #a5b4fc;
  }

  .m\:hover\:bg-indigo-400:hover {
    background-color: #818cf8;
  }

  .m\:hover\:bg-indigo-500:hover {
    background-color: #6366f1;
  }

  .m\:hover\:bg-indigo-600:hover {
    background-color: #4f46e5;
  }

  .m\:hover\:bg-indigo-700:hover {
    background-color: #4338ca;
  }

  .m\:hover\:bg-indigo-800:hover {
    background-color: #3730a3;
  }

  .m\:hover\:bg-indigo-900:hover {
    background-color: #312e81;
  }

  .m\:hover\:bg-purple-transparent:hover {
    background: transparent;
  }

  .m\:hover\:bg-purple-current:hover {
    background: currentColor;
  }

  .m\:hover\:bg-purple-50:hover {
    background-color: #f5f3ff;
  }

  .m\:hover\:bg-purple-100:hover {
    background-color: #ede9fe;
  }

  .m\:hover\:bg-purple-200:hover {
    background-color: #ddd6fe;
  }

  .m\:hover\:bg-purple-300:hover {
    background-color: #c4b5fd;
  }

  .m\:hover\:bg-purple-400:hover {
    background-color: #a78bfa;
  }

  .m\:hover\:bg-purple-500:hover {
    background-color: #8b5cf6;
  }

  .m\:hover\:bg-purple-600:hover {
    background-color: #7c3aed;
  }

  .m\:hover\:bg-purple-700:hover {
    background-color: #6d28d9;
  }

  .m\:hover\:bg-purple-800:hover {
    background-color: #5b21b6;
  }

  .m\:hover\:bg-purple-900:hover {
    background-color: #4c1d95;
  }

  .m\:hover\:bg-pink-transparent:hover {
    background: transparent;
  }

  .m\:hover\:bg-pink-current:hover {
    background: currentColor;
  }

  .m\:hover\:bg-pink-50:hover {
    background-color: #fdf2f8;
  }

  .m\:hover\:bg-pink-100:hover {
    background-color: #fce7f3;
  }

  .m\:hover\:bg-pink-200:hover {
    background-color: #fbcfe8;
  }

  .m\:hover\:bg-pink-300:hover {
    background-color: #f9a8d4;
  }

  .m\:hover\:bg-pink-400:hover {
    background-color: #f472b6;
  }

  .m\:hover\:bg-pink-500:hover {
    background-color: #ec4899;
  }

  .m\:hover\:bg-pink-600:hover {
    background-color: #db2777;
  }

  .m\:hover\:bg-pink-700:hover {
    background-color: #be185d;
  }

  .m\:hover\:bg-pink-800:hover {
    background-color: #9d174d;
  }

  .m\:hover\:bg-pink-900:hover {
    background-color: #831843;
  }

  .m\:active\:bg-transparent.is-active {
    background: transparent;
  }

  .m\:active\:bg-none.is-active {
    background: none !important;
  }

  .m\:active\:bg-transparent.is-active {
    background: transparent;
  }

  .m\:active\:bg-current.is-active {
    background: currentColor;
  }

  .m\:active\:bg-black.is-active,
.m\:active\:bg-black:active {
    background-color: #000;
  }

  .m\:active\:bg-white.is-active,
.m\:active\:bg-white:active {
    background-color: #fff;
  }

  .m\:active\:bg-primary.is-active,
.m\:active\:bg-primary:active {
    background-color: #007bff;
  }

  .m\:active\:bg-secondary.is-active,
.m\:active\:bg-secondary:active {
    background-color: #6c757d;
  }

  .m\:active\:bg-success.is-active,
.m\:active\:bg-success:active {
    background-color: #28a745;
  }

  .m\:active\:bg-info.is-active,
.m\:active\:bg-info:active {
    background-color: #17a2b8;
  }

  .m\:active\:bg-warning.is-active,
.m\:active\:bg-warning:active {
    background-color: #fad733;
  }

  .m\:active\:bg-danger.is-active,
.m\:active\:bg-danger:active {
    background-color: #dc3545;
  }

  .m\:active\:bg-light.is-active,
.m\:active\:bg-light:active {
    background-color: #f8f9fa;
  }

  .m\:active\:bg-dark.is-active,
.m\:active\:bg-dark:active {
    background-color: #343a40;
  }

  .m\:active\:bg-gray-transparent.is-active {
    background: transparent;
  }

  .m\:active\:bg-gray-current.is-active {
    background: currentColor;
  }

  .m\:active\:bg-gray-50.is-active,
.m\:active\:bg-gray-50:active {
    background-color: #f9fafb;
  }

  .m\:active\:bg-gray-100.is-active,
.m\:active\:bg-gray-100:active {
    background-color: #f3f4f6;
  }

  .m\:active\:bg-gray-200.is-active,
.m\:active\:bg-gray-200:active {
    background-color: #e5e7eb;
  }

  .m\:active\:bg-gray-300.is-active,
.m\:active\:bg-gray-300:active {
    background-color: #d1d5db;
  }

  .m\:active\:bg-gray-400.is-active,
.m\:active\:bg-gray-400:active {
    background-color: #9ca3af;
  }

  .m\:active\:bg-gray-500.is-active,
.m\:active\:bg-gray-500:active {
    background-color: #6b7280;
  }

  .m\:active\:bg-gray-600.is-active,
.m\:active\:bg-gray-600:active {
    background-color: #4b5563;
  }

  .m\:active\:bg-gray-700.is-active,
.m\:active\:bg-gray-700:active {
    background-color: #374151;
  }

  .m\:active\:bg-gray-800.is-active,
.m\:active\:bg-gray-800:active {
    background-color: #1f2937;
  }

  .m\:active\:bg-gray-900.is-active,
.m\:active\:bg-gray-900:active {
    background-color: #111827;
  }

  .m\:active\:bg-red-transparent.is-active {
    background: transparent;
  }

  .m\:active\:bg-red-current.is-active {
    background: currentColor;
  }

  .m\:active\:bg-red-50.is-active,
.m\:active\:bg-red-50:active {
    background-color: #fef2f2;
  }

  .m\:active\:bg-red-100.is-active,
.m\:active\:bg-red-100:active {
    background-color: #fee2e2;
  }

  .m\:active\:bg-red-200.is-active,
.m\:active\:bg-red-200:active {
    background-color: #fecaca;
  }

  .m\:active\:bg-red-300.is-active,
.m\:active\:bg-red-300:active {
    background-color: #fca5a5;
  }

  .m\:active\:bg-red-400.is-active,
.m\:active\:bg-red-400:active {
    background-color: #f87171;
  }

  .m\:active\:bg-red-500.is-active,
.m\:active\:bg-red-500:active {
    background-color: #ef4444;
  }

  .m\:active\:bg-red-600.is-active,
.m\:active\:bg-red-600:active {
    background-color: #dc2626;
  }

  .m\:active\:bg-red-700.is-active,
.m\:active\:bg-red-700:active {
    background-color: #b91c1c;
  }

  .m\:active\:bg-red-800.is-active,
.m\:active\:bg-red-800:active {
    background-color: #991b1b;
  }

  .m\:active\:bg-red-900.is-active,
.m\:active\:bg-red-900:active {
    background-color: #7f1d1d;
  }

  .m\:active\:bg-yellow-transparent.is-active {
    background: transparent;
  }

  .m\:active\:bg-yellow-current.is-active {
    background: currentColor;
  }

  .m\:active\:bg-yellow-50.is-active,
.m\:active\:bg-yellow-50:active {
    background-color: #fffbeb;
  }

  .m\:active\:bg-yellow-100.is-active,
.m\:active\:bg-yellow-100:active {
    background-color: #fef3c7;
  }

  .m\:active\:bg-yellow-200.is-active,
.m\:active\:bg-yellow-200:active {
    background-color: #fde68a;
  }

  .m\:active\:bg-yellow-300.is-active,
.m\:active\:bg-yellow-300:active {
    background-color: #fcd34d;
  }

  .m\:active\:bg-yellow-400.is-active,
.m\:active\:bg-yellow-400:active {
    background-color: #fbbf24;
  }

  .m\:active\:bg-yellow-500.is-active,
.m\:active\:bg-yellow-500:active {
    background-color: #f59e0b;
  }

  .m\:active\:bg-yellow-600.is-active,
.m\:active\:bg-yellow-600:active {
    background-color: #d97706;
  }

  .m\:active\:bg-yellow-700.is-active,
.m\:active\:bg-yellow-700:active {
    background-color: #b45309;
  }

  .m\:active\:bg-yellow-800.is-active,
.m\:active\:bg-yellow-800:active {
    background-color: #92400e;
  }

  .m\:active\:bg-yellow-900.is-active,
.m\:active\:bg-yellow-900:active {
    background-color: #78350f;
  }

  .m\:active\:bg-green-transparent.is-active {
    background: transparent;
  }

  .m\:active\:bg-green-current.is-active {
    background: currentColor;
  }

  .m\:active\:bg-green-50.is-active,
.m\:active\:bg-green-50:active {
    background-color: #ecfdf5;
  }

  .m\:active\:bg-green-100.is-active,
.m\:active\:bg-green-100:active {
    background-color: #d1fae5;
  }

  .m\:active\:bg-green-200.is-active,
.m\:active\:bg-green-200:active {
    background-color: #a7f3d0;
  }

  .m\:active\:bg-green-300.is-active,
.m\:active\:bg-green-300:active {
    background-color: #6ee7b7;
  }

  .m\:active\:bg-green-400.is-active,
.m\:active\:bg-green-400:active {
    background-color: #34d399;
  }

  .m\:active\:bg-green-500.is-active,
.m\:active\:bg-green-500:active {
    background-color: #10b981;
  }

  .m\:active\:bg-green-600.is-active,
.m\:active\:bg-green-600:active {
    background-color: #059669;
  }

  .m\:active\:bg-green-700.is-active,
.m\:active\:bg-green-700:active {
    background-color: #047857;
  }

  .m\:active\:bg-green-800.is-active,
.m\:active\:bg-green-800:active {
    background-color: #065f46;
  }

  .m\:active\:bg-green-900.is-active,
.m\:active\:bg-green-900:active {
    background-color: #064e3b;
  }

  .m\:active\:bg-blue-transparent.is-active {
    background: transparent;
  }

  .m\:active\:bg-blue-current.is-active {
    background: currentColor;
  }

  .m\:active\:bg-blue-50.is-active,
.m\:active\:bg-blue-50:active {
    background-color: #eff6ff;
  }

  .m\:active\:bg-blue-100.is-active,
.m\:active\:bg-blue-100:active {
    background-color: #dbeafe;
  }

  .m\:active\:bg-blue-200.is-active,
.m\:active\:bg-blue-200:active {
    background-color: #bfdbfe;
  }

  .m\:active\:bg-blue-300.is-active,
.m\:active\:bg-blue-300:active {
    background-color: #93c5fd;
  }

  .m\:active\:bg-blue-400.is-active,
.m\:active\:bg-blue-400:active {
    background-color: #60a5fa;
  }

  .m\:active\:bg-blue-500.is-active,
.m\:active\:bg-blue-500:active {
    background-color: #3b82f6;
  }

  .m\:active\:bg-blue-600.is-active,
.m\:active\:bg-blue-600:active {
    background-color: #2563eb;
  }

  .m\:active\:bg-blue-700.is-active,
.m\:active\:bg-blue-700:active {
    background-color: #1d4ed8;
  }

  .m\:active\:bg-blue-800.is-active,
.m\:active\:bg-blue-800:active {
    background-color: #1e40af;
  }

  .m\:active\:bg-blue-900.is-active,
.m\:active\:bg-blue-900:active {
    background-color: #1e3a8a;
  }

  .m\:active\:bg-cyan-transparent.is-active {
    background: transparent;
  }

  .m\:active\:bg-cyan-current.is-active {
    background: currentColor;
  }

  .m\:active\:bg-cyan-50.is-active,
.m\:active\:bg-cyan-50:active {
    background-color: #ecfeff;
  }

  .m\:active\:bg-cyan-100.is-active,
.m\:active\:bg-cyan-100:active {
    background-color: #cffafe;
  }

  .m\:active\:bg-cyan-200.is-active,
.m\:active\:bg-cyan-200:active {
    background-color: #a5f3fc;
  }

  .m\:active\:bg-cyan-300.is-active,
.m\:active\:bg-cyan-300:active {
    background-color: #67e8f9;
  }

  .m\:active\:bg-cyan-400.is-active,
.m\:active\:bg-cyan-400:active {
    background-color: #22d3ee;
  }

  .m\:active\:bg-cyan-500.is-active,
.m\:active\:bg-cyan-500:active {
    background-color: #06b6d4;
  }

  .m\:active\:bg-cyan-600.is-active,
.m\:active\:bg-cyan-600:active {
    background-color: #0891b2;
  }

  .m\:active\:bg-cyan-700.is-active,
.m\:active\:bg-cyan-700:active {
    background-color: #0e7490;
  }

  .m\:active\:bg-cyan-800.is-active,
.m\:active\:bg-cyan-800:active {
    background-color: #155e75;
  }

  .m\:active\:bg-cyan-900.is-active,
.m\:active\:bg-cyan-900:active {
    background-color: #164e63;
  }

  .m\:active\:bg-indigo-transparent.is-active {
    background: transparent;
  }

  .m\:active\:bg-indigo-current.is-active {
    background: currentColor;
  }

  .m\:active\:bg-indigo-50.is-active,
.m\:active\:bg-indigo-50:active {
    background-color: #eef2ff;
  }

  .m\:active\:bg-indigo-100.is-active,
.m\:active\:bg-indigo-100:active {
    background-color: #e0e7ff;
  }

  .m\:active\:bg-indigo-200.is-active,
.m\:active\:bg-indigo-200:active {
    background-color: #c7d2fe;
  }

  .m\:active\:bg-indigo-300.is-active,
.m\:active\:bg-indigo-300:active {
    background-color: #a5b4fc;
  }

  .m\:active\:bg-indigo-400.is-active,
.m\:active\:bg-indigo-400:active {
    background-color: #818cf8;
  }

  .m\:active\:bg-indigo-500.is-active,
.m\:active\:bg-indigo-500:active {
    background-color: #6366f1;
  }

  .m\:active\:bg-indigo-600.is-active,
.m\:active\:bg-indigo-600:active {
    background-color: #4f46e5;
  }

  .m\:active\:bg-indigo-700.is-active,
.m\:active\:bg-indigo-700:active {
    background-color: #4338ca;
  }

  .m\:active\:bg-indigo-800.is-active,
.m\:active\:bg-indigo-800:active {
    background-color: #3730a3;
  }

  .m\:active\:bg-indigo-900.is-active,
.m\:active\:bg-indigo-900:active {
    background-color: #312e81;
  }

  .m\:active\:bg-purple-transparent.is-active {
    background: transparent;
  }

  .m\:active\:bg-purple-current.is-active {
    background: currentColor;
  }

  .m\:active\:bg-purple-50.is-active,
.m\:active\:bg-purple-50:active {
    background-color: #f5f3ff;
  }

  .m\:active\:bg-purple-100.is-active,
.m\:active\:bg-purple-100:active {
    background-color: #ede9fe;
  }

  .m\:active\:bg-purple-200.is-active,
.m\:active\:bg-purple-200:active {
    background-color: #ddd6fe;
  }

  .m\:active\:bg-purple-300.is-active,
.m\:active\:bg-purple-300:active {
    background-color: #c4b5fd;
  }

  .m\:active\:bg-purple-400.is-active,
.m\:active\:bg-purple-400:active {
    background-color: #a78bfa;
  }

  .m\:active\:bg-purple-500.is-active,
.m\:active\:bg-purple-500:active {
    background-color: #8b5cf6;
  }

  .m\:active\:bg-purple-600.is-active,
.m\:active\:bg-purple-600:active {
    background-color: #7c3aed;
  }

  .m\:active\:bg-purple-700.is-active,
.m\:active\:bg-purple-700:active {
    background-color: #6d28d9;
  }

  .m\:active\:bg-purple-800.is-active,
.m\:active\:bg-purple-800:active {
    background-color: #5b21b6;
  }

  .m\:active\:bg-purple-900.is-active,
.m\:active\:bg-purple-900:active {
    background-color: #4c1d95;
  }

  .m\:active\:bg-pink-transparent.is-active {
    background: transparent;
  }

  .m\:active\:bg-pink-current.is-active {
    background: currentColor;
  }

  .m\:active\:bg-pink-50.is-active,
.m\:active\:bg-pink-50:active {
    background-color: #fdf2f8;
  }

  .m\:active\:bg-pink-100.is-active,
.m\:active\:bg-pink-100:active {
    background-color: #fce7f3;
  }

  .m\:active\:bg-pink-200.is-active,
.m\:active\:bg-pink-200:active {
    background-color: #fbcfe8;
  }

  .m\:active\:bg-pink-300.is-active,
.m\:active\:bg-pink-300:active {
    background-color: #f9a8d4;
  }

  .m\:active\:bg-pink-400.is-active,
.m\:active\:bg-pink-400:active {
    background-color: #f472b6;
  }

  .m\:active\:bg-pink-500.is-active,
.m\:active\:bg-pink-500:active {
    background-color: #ec4899;
  }

  .m\:active\:bg-pink-600.is-active,
.m\:active\:bg-pink-600:active {
    background-color: #db2777;
  }

  .m\:active\:bg-pink-700.is-active,
.m\:active\:bg-pink-700:active {
    background-color: #be185d;
  }

  .m\:active\:bg-pink-800.is-active,
.m\:active\:bg-pink-800:active {
    background-color: #9d174d;
  }

  .m\:active\:bg-pink-900.is-active,
.m\:active\:bg-pink-900:active {
    background-color: #831843;
  }

  .m\:focus\:bg-transparent:focus {
    background: transparent;
  }

  .m\:focus\:bg-none:focus {
    background: none !important;
  }

  .m\:focus\:bg-transparent:focus {
    background: transparent;
  }

  .m\:focus\:bg-current:focus {
    background: currentColor;
  }

  .m\:focus\:bg-black:focus {
    background-color: #000;
  }

  .m\:focus\:bg-white:focus {
    background-color: #fff;
  }

  .m\:focus\:bg-primary:focus {
    background-color: #007bff;
  }

  .m\:focus\:bg-secondary:focus {
    background-color: #6c757d;
  }

  .m\:focus\:bg-success:focus {
    background-color: #28a745;
  }

  .m\:focus\:bg-info:focus {
    background-color: #17a2b8;
  }

  .m\:focus\:bg-warning:focus {
    background-color: #fad733;
  }

  .m\:focus\:bg-danger:focus {
    background-color: #dc3545;
  }

  .m\:focus\:bg-light:focus {
    background-color: #f8f9fa;
  }

  .m\:focus\:bg-dark:focus {
    background-color: #343a40;
  }

  .m\:focus\:bg-gray-transparent:focus {
    background: transparent;
  }

  .m\:focus\:bg-gray-current:focus {
    background: currentColor;
  }

  .m\:focus\:bg-gray-50:focus {
    background-color: #f9fafb;
  }

  .m\:focus\:bg-gray-100:focus {
    background-color: #f3f4f6;
  }

  .m\:focus\:bg-gray-200:focus {
    background-color: #e5e7eb;
  }

  .m\:focus\:bg-gray-300:focus {
    background-color: #d1d5db;
  }

  .m\:focus\:bg-gray-400:focus {
    background-color: #9ca3af;
  }

  .m\:focus\:bg-gray-500:focus {
    background-color: #6b7280;
  }

  .m\:focus\:bg-gray-600:focus {
    background-color: #4b5563;
  }

  .m\:focus\:bg-gray-700:focus {
    background-color: #374151;
  }

  .m\:focus\:bg-gray-800:focus {
    background-color: #1f2937;
  }

  .m\:focus\:bg-gray-900:focus {
    background-color: #111827;
  }

  .m\:focus\:bg-red-transparent:focus {
    background: transparent;
  }

  .m\:focus\:bg-red-current:focus {
    background: currentColor;
  }

  .m\:focus\:bg-red-50:focus {
    background-color: #fef2f2;
  }

  .m\:focus\:bg-red-100:focus {
    background-color: #fee2e2;
  }

  .m\:focus\:bg-red-200:focus {
    background-color: #fecaca;
  }

  .m\:focus\:bg-red-300:focus {
    background-color: #fca5a5;
  }

  .m\:focus\:bg-red-400:focus {
    background-color: #f87171;
  }

  .m\:focus\:bg-red-500:focus {
    background-color: #ef4444;
  }

  .m\:focus\:bg-red-600:focus {
    background-color: #dc2626;
  }

  .m\:focus\:bg-red-700:focus {
    background-color: #b91c1c;
  }

  .m\:focus\:bg-red-800:focus {
    background-color: #991b1b;
  }

  .m\:focus\:bg-red-900:focus {
    background-color: #7f1d1d;
  }

  .m\:focus\:bg-yellow-transparent:focus {
    background: transparent;
  }

  .m\:focus\:bg-yellow-current:focus {
    background: currentColor;
  }

  .m\:focus\:bg-yellow-50:focus {
    background-color: #fffbeb;
  }

  .m\:focus\:bg-yellow-100:focus {
    background-color: #fef3c7;
  }

  .m\:focus\:bg-yellow-200:focus {
    background-color: #fde68a;
  }

  .m\:focus\:bg-yellow-300:focus {
    background-color: #fcd34d;
  }

  .m\:focus\:bg-yellow-400:focus {
    background-color: #fbbf24;
  }

  .m\:focus\:bg-yellow-500:focus {
    background-color: #f59e0b;
  }

  .m\:focus\:bg-yellow-600:focus {
    background-color: #d97706;
  }

  .m\:focus\:bg-yellow-700:focus {
    background-color: #b45309;
  }

  .m\:focus\:bg-yellow-800:focus {
    background-color: #92400e;
  }

  .m\:focus\:bg-yellow-900:focus {
    background-color: #78350f;
  }

  .m\:focus\:bg-green-transparent:focus {
    background: transparent;
  }

  .m\:focus\:bg-green-current:focus {
    background: currentColor;
  }

  .m\:focus\:bg-green-50:focus {
    background-color: #ecfdf5;
  }

  .m\:focus\:bg-green-100:focus {
    background-color: #d1fae5;
  }

  .m\:focus\:bg-green-200:focus {
    background-color: #a7f3d0;
  }

  .m\:focus\:bg-green-300:focus {
    background-color: #6ee7b7;
  }

  .m\:focus\:bg-green-400:focus {
    background-color: #34d399;
  }

  .m\:focus\:bg-green-500:focus {
    background-color: #10b981;
  }

  .m\:focus\:bg-green-600:focus {
    background-color: #059669;
  }

  .m\:focus\:bg-green-700:focus {
    background-color: #047857;
  }

  .m\:focus\:bg-green-800:focus {
    background-color: #065f46;
  }

  .m\:focus\:bg-green-900:focus {
    background-color: #064e3b;
  }

  .m\:focus\:bg-blue-transparent:focus {
    background: transparent;
  }

  .m\:focus\:bg-blue-current:focus {
    background: currentColor;
  }

  .m\:focus\:bg-blue-50:focus {
    background-color: #eff6ff;
  }

  .m\:focus\:bg-blue-100:focus {
    background-color: #dbeafe;
  }

  .m\:focus\:bg-blue-200:focus {
    background-color: #bfdbfe;
  }

  .m\:focus\:bg-blue-300:focus {
    background-color: #93c5fd;
  }

  .m\:focus\:bg-blue-400:focus {
    background-color: #60a5fa;
  }

  .m\:focus\:bg-blue-500:focus {
    background-color: #3b82f6;
  }

  .m\:focus\:bg-blue-600:focus {
    background-color: #2563eb;
  }

  .m\:focus\:bg-blue-700:focus {
    background-color: #1d4ed8;
  }

  .m\:focus\:bg-blue-800:focus {
    background-color: #1e40af;
  }

  .m\:focus\:bg-blue-900:focus {
    background-color: #1e3a8a;
  }

  .m\:focus\:bg-cyan-transparent:focus {
    background: transparent;
  }

  .m\:focus\:bg-cyan-current:focus {
    background: currentColor;
  }

  .m\:focus\:bg-cyan-50:focus {
    background-color: #ecfeff;
  }

  .m\:focus\:bg-cyan-100:focus {
    background-color: #cffafe;
  }

  .m\:focus\:bg-cyan-200:focus {
    background-color: #a5f3fc;
  }

  .m\:focus\:bg-cyan-300:focus {
    background-color: #67e8f9;
  }

  .m\:focus\:bg-cyan-400:focus {
    background-color: #22d3ee;
  }

  .m\:focus\:bg-cyan-500:focus {
    background-color: #06b6d4;
  }

  .m\:focus\:bg-cyan-600:focus {
    background-color: #0891b2;
  }

  .m\:focus\:bg-cyan-700:focus {
    background-color: #0e7490;
  }

  .m\:focus\:bg-cyan-800:focus {
    background-color: #155e75;
  }

  .m\:focus\:bg-cyan-900:focus {
    background-color: #164e63;
  }

  .m\:focus\:bg-indigo-transparent:focus {
    background: transparent;
  }

  .m\:focus\:bg-indigo-current:focus {
    background: currentColor;
  }

  .m\:focus\:bg-indigo-50:focus {
    background-color: #eef2ff;
  }

  .m\:focus\:bg-indigo-100:focus {
    background-color: #e0e7ff;
  }

  .m\:focus\:bg-indigo-200:focus {
    background-color: #c7d2fe;
  }

  .m\:focus\:bg-indigo-300:focus {
    background-color: #a5b4fc;
  }

  .m\:focus\:bg-indigo-400:focus {
    background-color: #818cf8;
  }

  .m\:focus\:bg-indigo-500:focus {
    background-color: #6366f1;
  }

  .m\:focus\:bg-indigo-600:focus {
    background-color: #4f46e5;
  }

  .m\:focus\:bg-indigo-700:focus {
    background-color: #4338ca;
  }

  .m\:focus\:bg-indigo-800:focus {
    background-color: #3730a3;
  }

  .m\:focus\:bg-indigo-900:focus {
    background-color: #312e81;
  }

  .m\:focus\:bg-purple-transparent:focus {
    background: transparent;
  }

  .m\:focus\:bg-purple-current:focus {
    background: currentColor;
  }

  .m\:focus\:bg-purple-50:focus {
    background-color: #f5f3ff;
  }

  .m\:focus\:bg-purple-100:focus {
    background-color: #ede9fe;
  }

  .m\:focus\:bg-purple-200:focus {
    background-color: #ddd6fe;
  }

  .m\:focus\:bg-purple-300:focus {
    background-color: #c4b5fd;
  }

  .m\:focus\:bg-purple-400:focus {
    background-color: #a78bfa;
  }

  .m\:focus\:bg-purple-500:focus {
    background-color: #8b5cf6;
  }

  .m\:focus\:bg-purple-600:focus {
    background-color: #7c3aed;
  }

  .m\:focus\:bg-purple-700:focus {
    background-color: #6d28d9;
  }

  .m\:focus\:bg-purple-800:focus {
    background-color: #5b21b6;
  }

  .m\:focus\:bg-purple-900:focus {
    background-color: #4c1d95;
  }

  .m\:focus\:bg-pink-transparent:focus {
    background: transparent;
  }

  .m\:focus\:bg-pink-current:focus {
    background: currentColor;
  }

  .m\:focus\:bg-pink-50:focus {
    background-color: #fdf2f8;
  }

  .m\:focus\:bg-pink-100:focus {
    background-color: #fce7f3;
  }

  .m\:focus\:bg-pink-200:focus {
    background-color: #fbcfe8;
  }

  .m\:focus\:bg-pink-300:focus {
    background-color: #f9a8d4;
  }

  .m\:focus\:bg-pink-400:focus {
    background-color: #f472b6;
  }

  .m\:focus\:bg-pink-500:focus {
    background-color: #ec4899;
  }

  .m\:focus\:bg-pink-600:focus {
    background-color: #db2777;
  }

  .m\:focus\:bg-pink-700:focus {
    background-color: #be185d;
  }

  .m\:focus\:bg-pink-800:focus {
    background-color: #9d174d;
  }

  .m\:focus\:bg-pink-900:focus {
    background-color: #831843;
  }

  .m\:disabled\:bg-transparent.is-disabled {
    background: transparent;
  }

  .m\:disabled\:bg-none.is-disabled {
    background: none !important;
  }

  .m\:disabled\:bg-transparent.is-disabled {
    background: transparent;
  }

  .m\:disabled\:bg-current.is-disabled {
    background: currentColor;
  }

  .m\:disabled\:bg-black.is-disabled,
.m\:disabled\:bg-black:disabled {
    background-color: #000;
  }

  .m\:disabled\:bg-white.is-disabled,
.m\:disabled\:bg-white:disabled {
    background-color: #fff;
  }

  .m\:disabled\:bg-primary.is-disabled,
.m\:disabled\:bg-primary:disabled {
    background-color: #007bff;
  }

  .m\:disabled\:bg-secondary.is-disabled,
.m\:disabled\:bg-secondary:disabled {
    background-color: #6c757d;
  }

  .m\:disabled\:bg-success.is-disabled,
.m\:disabled\:bg-success:disabled {
    background-color: #28a745;
  }

  .m\:disabled\:bg-info.is-disabled,
.m\:disabled\:bg-info:disabled {
    background-color: #17a2b8;
  }

  .m\:disabled\:bg-warning.is-disabled,
.m\:disabled\:bg-warning:disabled {
    background-color: #fad733;
  }

  .m\:disabled\:bg-danger.is-disabled,
.m\:disabled\:bg-danger:disabled {
    background-color: #dc3545;
  }

  .m\:disabled\:bg-light.is-disabled,
.m\:disabled\:bg-light:disabled {
    background-color: #f8f9fa;
  }

  .m\:disabled\:bg-dark.is-disabled,
.m\:disabled\:bg-dark:disabled {
    background-color: #343a40;
  }

  .m\:disabled\:bg-gray-transparent.is-disabled {
    background: transparent;
  }

  .m\:disabled\:bg-gray-current.is-disabled {
    background: currentColor;
  }

  .m\:disabled\:bg-gray-50.is-disabled,
.m\:disabled\:bg-gray-50:disabled {
    background-color: #f9fafb;
  }

  .m\:disabled\:bg-gray-100.is-disabled,
.m\:disabled\:bg-gray-100:disabled {
    background-color: #f3f4f6;
  }

  .m\:disabled\:bg-gray-200.is-disabled,
.m\:disabled\:bg-gray-200:disabled {
    background-color: #e5e7eb;
  }

  .m\:disabled\:bg-gray-300.is-disabled,
.m\:disabled\:bg-gray-300:disabled {
    background-color: #d1d5db;
  }

  .m\:disabled\:bg-gray-400.is-disabled,
.m\:disabled\:bg-gray-400:disabled {
    background-color: #9ca3af;
  }

  .m\:disabled\:bg-gray-500.is-disabled,
.m\:disabled\:bg-gray-500:disabled {
    background-color: #6b7280;
  }

  .m\:disabled\:bg-gray-600.is-disabled,
.m\:disabled\:bg-gray-600:disabled {
    background-color: #4b5563;
  }

  .m\:disabled\:bg-gray-700.is-disabled,
.m\:disabled\:bg-gray-700:disabled {
    background-color: #374151;
  }

  .m\:disabled\:bg-gray-800.is-disabled,
.m\:disabled\:bg-gray-800:disabled {
    background-color: #1f2937;
  }

  .m\:disabled\:bg-gray-900.is-disabled,
.m\:disabled\:bg-gray-900:disabled {
    background-color: #111827;
  }

  .m\:disabled\:bg-red-transparent.is-disabled {
    background: transparent;
  }

  .m\:disabled\:bg-red-current.is-disabled {
    background: currentColor;
  }

  .m\:disabled\:bg-red-50.is-disabled,
.m\:disabled\:bg-red-50:disabled {
    background-color: #fef2f2;
  }

  .m\:disabled\:bg-red-100.is-disabled,
.m\:disabled\:bg-red-100:disabled {
    background-color: #fee2e2;
  }

  .m\:disabled\:bg-red-200.is-disabled,
.m\:disabled\:bg-red-200:disabled {
    background-color: #fecaca;
  }

  .m\:disabled\:bg-red-300.is-disabled,
.m\:disabled\:bg-red-300:disabled {
    background-color: #fca5a5;
  }

  .m\:disabled\:bg-red-400.is-disabled,
.m\:disabled\:bg-red-400:disabled {
    background-color: #f87171;
  }

  .m\:disabled\:bg-red-500.is-disabled,
.m\:disabled\:bg-red-500:disabled {
    background-color: #ef4444;
  }

  .m\:disabled\:bg-red-600.is-disabled,
.m\:disabled\:bg-red-600:disabled {
    background-color: #dc2626;
  }

  .m\:disabled\:bg-red-700.is-disabled,
.m\:disabled\:bg-red-700:disabled {
    background-color: #b91c1c;
  }

  .m\:disabled\:bg-red-800.is-disabled,
.m\:disabled\:bg-red-800:disabled {
    background-color: #991b1b;
  }

  .m\:disabled\:bg-red-900.is-disabled,
.m\:disabled\:bg-red-900:disabled {
    background-color: #7f1d1d;
  }

  .m\:disabled\:bg-yellow-transparent.is-disabled {
    background: transparent;
  }

  .m\:disabled\:bg-yellow-current.is-disabled {
    background: currentColor;
  }

  .m\:disabled\:bg-yellow-50.is-disabled,
.m\:disabled\:bg-yellow-50:disabled {
    background-color: #fffbeb;
  }

  .m\:disabled\:bg-yellow-100.is-disabled,
.m\:disabled\:bg-yellow-100:disabled {
    background-color: #fef3c7;
  }

  .m\:disabled\:bg-yellow-200.is-disabled,
.m\:disabled\:bg-yellow-200:disabled {
    background-color: #fde68a;
  }

  .m\:disabled\:bg-yellow-300.is-disabled,
.m\:disabled\:bg-yellow-300:disabled {
    background-color: #fcd34d;
  }

  .m\:disabled\:bg-yellow-400.is-disabled,
.m\:disabled\:bg-yellow-400:disabled {
    background-color: #fbbf24;
  }

  .m\:disabled\:bg-yellow-500.is-disabled,
.m\:disabled\:bg-yellow-500:disabled {
    background-color: #f59e0b;
  }

  .m\:disabled\:bg-yellow-600.is-disabled,
.m\:disabled\:bg-yellow-600:disabled {
    background-color: #d97706;
  }

  .m\:disabled\:bg-yellow-700.is-disabled,
.m\:disabled\:bg-yellow-700:disabled {
    background-color: #b45309;
  }

  .m\:disabled\:bg-yellow-800.is-disabled,
.m\:disabled\:bg-yellow-800:disabled {
    background-color: #92400e;
  }

  .m\:disabled\:bg-yellow-900.is-disabled,
.m\:disabled\:bg-yellow-900:disabled {
    background-color: #78350f;
  }

  .m\:disabled\:bg-green-transparent.is-disabled {
    background: transparent;
  }

  .m\:disabled\:bg-green-current.is-disabled {
    background: currentColor;
  }

  .m\:disabled\:bg-green-50.is-disabled,
.m\:disabled\:bg-green-50:disabled {
    background-color: #ecfdf5;
  }

  .m\:disabled\:bg-green-100.is-disabled,
.m\:disabled\:bg-green-100:disabled {
    background-color: #d1fae5;
  }

  .m\:disabled\:bg-green-200.is-disabled,
.m\:disabled\:bg-green-200:disabled {
    background-color: #a7f3d0;
  }

  .m\:disabled\:bg-green-300.is-disabled,
.m\:disabled\:bg-green-300:disabled {
    background-color: #6ee7b7;
  }

  .m\:disabled\:bg-green-400.is-disabled,
.m\:disabled\:bg-green-400:disabled {
    background-color: #34d399;
  }

  .m\:disabled\:bg-green-500.is-disabled,
.m\:disabled\:bg-green-500:disabled {
    background-color: #10b981;
  }

  .m\:disabled\:bg-green-600.is-disabled,
.m\:disabled\:bg-green-600:disabled {
    background-color: #059669;
  }

  .m\:disabled\:bg-green-700.is-disabled,
.m\:disabled\:bg-green-700:disabled {
    background-color: #047857;
  }

  .m\:disabled\:bg-green-800.is-disabled,
.m\:disabled\:bg-green-800:disabled {
    background-color: #065f46;
  }

  .m\:disabled\:bg-green-900.is-disabled,
.m\:disabled\:bg-green-900:disabled {
    background-color: #064e3b;
  }

  .m\:disabled\:bg-blue-transparent.is-disabled {
    background: transparent;
  }

  .m\:disabled\:bg-blue-current.is-disabled {
    background: currentColor;
  }

  .m\:disabled\:bg-blue-50.is-disabled,
.m\:disabled\:bg-blue-50:disabled {
    background-color: #eff6ff;
  }

  .m\:disabled\:bg-blue-100.is-disabled,
.m\:disabled\:bg-blue-100:disabled {
    background-color: #dbeafe;
  }

  .m\:disabled\:bg-blue-200.is-disabled,
.m\:disabled\:bg-blue-200:disabled {
    background-color: #bfdbfe;
  }

  .m\:disabled\:bg-blue-300.is-disabled,
.m\:disabled\:bg-blue-300:disabled {
    background-color: #93c5fd;
  }

  .m\:disabled\:bg-blue-400.is-disabled,
.m\:disabled\:bg-blue-400:disabled {
    background-color: #60a5fa;
  }

  .m\:disabled\:bg-blue-500.is-disabled,
.m\:disabled\:bg-blue-500:disabled {
    background-color: #3b82f6;
  }

  .m\:disabled\:bg-blue-600.is-disabled,
.m\:disabled\:bg-blue-600:disabled {
    background-color: #2563eb;
  }

  .m\:disabled\:bg-blue-700.is-disabled,
.m\:disabled\:bg-blue-700:disabled {
    background-color: #1d4ed8;
  }

  .m\:disabled\:bg-blue-800.is-disabled,
.m\:disabled\:bg-blue-800:disabled {
    background-color: #1e40af;
  }

  .m\:disabled\:bg-blue-900.is-disabled,
.m\:disabled\:bg-blue-900:disabled {
    background-color: #1e3a8a;
  }

  .m\:disabled\:bg-cyan-transparent.is-disabled {
    background: transparent;
  }

  .m\:disabled\:bg-cyan-current.is-disabled {
    background: currentColor;
  }

  .m\:disabled\:bg-cyan-50.is-disabled,
.m\:disabled\:bg-cyan-50:disabled {
    background-color: #ecfeff;
  }

  .m\:disabled\:bg-cyan-100.is-disabled,
.m\:disabled\:bg-cyan-100:disabled {
    background-color: #cffafe;
  }

  .m\:disabled\:bg-cyan-200.is-disabled,
.m\:disabled\:bg-cyan-200:disabled {
    background-color: #a5f3fc;
  }

  .m\:disabled\:bg-cyan-300.is-disabled,
.m\:disabled\:bg-cyan-300:disabled {
    background-color: #67e8f9;
  }

  .m\:disabled\:bg-cyan-400.is-disabled,
.m\:disabled\:bg-cyan-400:disabled {
    background-color: #22d3ee;
  }

  .m\:disabled\:bg-cyan-500.is-disabled,
.m\:disabled\:bg-cyan-500:disabled {
    background-color: #06b6d4;
  }

  .m\:disabled\:bg-cyan-600.is-disabled,
.m\:disabled\:bg-cyan-600:disabled {
    background-color: #0891b2;
  }

  .m\:disabled\:bg-cyan-700.is-disabled,
.m\:disabled\:bg-cyan-700:disabled {
    background-color: #0e7490;
  }

  .m\:disabled\:bg-cyan-800.is-disabled,
.m\:disabled\:bg-cyan-800:disabled {
    background-color: #155e75;
  }

  .m\:disabled\:bg-cyan-900.is-disabled,
.m\:disabled\:bg-cyan-900:disabled {
    background-color: #164e63;
  }

  .m\:disabled\:bg-indigo-transparent.is-disabled {
    background: transparent;
  }

  .m\:disabled\:bg-indigo-current.is-disabled {
    background: currentColor;
  }

  .m\:disabled\:bg-indigo-50.is-disabled,
.m\:disabled\:bg-indigo-50:disabled {
    background-color: #eef2ff;
  }

  .m\:disabled\:bg-indigo-100.is-disabled,
.m\:disabled\:bg-indigo-100:disabled {
    background-color: #e0e7ff;
  }

  .m\:disabled\:bg-indigo-200.is-disabled,
.m\:disabled\:bg-indigo-200:disabled {
    background-color: #c7d2fe;
  }

  .m\:disabled\:bg-indigo-300.is-disabled,
.m\:disabled\:bg-indigo-300:disabled {
    background-color: #a5b4fc;
  }

  .m\:disabled\:bg-indigo-400.is-disabled,
.m\:disabled\:bg-indigo-400:disabled {
    background-color: #818cf8;
  }

  .m\:disabled\:bg-indigo-500.is-disabled,
.m\:disabled\:bg-indigo-500:disabled {
    background-color: #6366f1;
  }

  .m\:disabled\:bg-indigo-600.is-disabled,
.m\:disabled\:bg-indigo-600:disabled {
    background-color: #4f46e5;
  }

  .m\:disabled\:bg-indigo-700.is-disabled,
.m\:disabled\:bg-indigo-700:disabled {
    background-color: #4338ca;
  }

  .m\:disabled\:bg-indigo-800.is-disabled,
.m\:disabled\:bg-indigo-800:disabled {
    background-color: #3730a3;
  }

  .m\:disabled\:bg-indigo-900.is-disabled,
.m\:disabled\:bg-indigo-900:disabled {
    background-color: #312e81;
  }

  .m\:disabled\:bg-purple-transparent.is-disabled {
    background: transparent;
  }

  .m\:disabled\:bg-purple-current.is-disabled {
    background: currentColor;
  }

  .m\:disabled\:bg-purple-50.is-disabled,
.m\:disabled\:bg-purple-50:disabled {
    background-color: #f5f3ff;
  }

  .m\:disabled\:bg-purple-100.is-disabled,
.m\:disabled\:bg-purple-100:disabled {
    background-color: #ede9fe;
  }

  .m\:disabled\:bg-purple-200.is-disabled,
.m\:disabled\:bg-purple-200:disabled {
    background-color: #ddd6fe;
  }

  .m\:disabled\:bg-purple-300.is-disabled,
.m\:disabled\:bg-purple-300:disabled {
    background-color: #c4b5fd;
  }

  .m\:disabled\:bg-purple-400.is-disabled,
.m\:disabled\:bg-purple-400:disabled {
    background-color: #a78bfa;
  }

  .m\:disabled\:bg-purple-500.is-disabled,
.m\:disabled\:bg-purple-500:disabled {
    background-color: #8b5cf6;
  }

  .m\:disabled\:bg-purple-600.is-disabled,
.m\:disabled\:bg-purple-600:disabled {
    background-color: #7c3aed;
  }

  .m\:disabled\:bg-purple-700.is-disabled,
.m\:disabled\:bg-purple-700:disabled {
    background-color: #6d28d9;
  }

  .m\:disabled\:bg-purple-800.is-disabled,
.m\:disabled\:bg-purple-800:disabled {
    background-color: #5b21b6;
  }

  .m\:disabled\:bg-purple-900.is-disabled,
.m\:disabled\:bg-purple-900:disabled {
    background-color: #4c1d95;
  }

  .m\:disabled\:bg-pink-transparent.is-disabled {
    background: transparent;
  }

  .m\:disabled\:bg-pink-current.is-disabled {
    background: currentColor;
  }

  .m\:disabled\:bg-pink-50.is-disabled,
.m\:disabled\:bg-pink-50:disabled {
    background-color: #fdf2f8;
  }

  .m\:disabled\:bg-pink-100.is-disabled,
.m\:disabled\:bg-pink-100:disabled {
    background-color: #fce7f3;
  }

  .m\:disabled\:bg-pink-200.is-disabled,
.m\:disabled\:bg-pink-200:disabled {
    background-color: #fbcfe8;
  }

  .m\:disabled\:bg-pink-300.is-disabled,
.m\:disabled\:bg-pink-300:disabled {
    background-color: #f9a8d4;
  }

  .m\:disabled\:bg-pink-400.is-disabled,
.m\:disabled\:bg-pink-400:disabled {
    background-color: #f472b6;
  }

  .m\:disabled\:bg-pink-500.is-disabled,
.m\:disabled\:bg-pink-500:disabled {
    background-color: #ec4899;
  }

  .m\:disabled\:bg-pink-600.is-disabled,
.m\:disabled\:bg-pink-600:disabled {
    background-color: #db2777;
  }

  .m\:disabled\:bg-pink-700.is-disabled,
.m\:disabled\:bg-pink-700:disabled {
    background-color: #be185d;
  }

  .m\:disabled\:bg-pink-800.is-disabled,
.m\:disabled\:bg-pink-800:disabled {
    background-color: #9d174d;
  }

  .m\:disabled\:bg-pink-900.is-disabled,
.m\:disabled\:bg-pink-900:disabled {
    background-color: #831843;
  }

  .group:hover .m\:group-hover\:bg-transparent {
    background: transparent;
  }

  .group:hover .m\:group-hover\:bg-none {
    background: none !important;
  }

  .group:hover .m\:group-hover\:bg-transparent {
    background: transparent;
  }

  .group:hover .m\:group-hover\:bg-current {
    background: currentColor;
  }

  .group:hover .m\:group-hover\:bg-black {
    background-color: #000;
  }

  .group:hover .m\:group-hover\:bg-white {
    background-color: #fff;
  }

  .group:hover .m\:group-hover\:bg-primary {
    background-color: #007bff;
  }

  .group:hover .m\:group-hover\:bg-secondary {
    background-color: #6c757d;
  }

  .group:hover .m\:group-hover\:bg-success {
    background-color: #28a745;
  }

  .group:hover .m\:group-hover\:bg-info {
    background-color: #17a2b8;
  }

  .group:hover .m\:group-hover\:bg-warning {
    background-color: #fad733;
  }

  .group:hover .m\:group-hover\:bg-danger {
    background-color: #dc3545;
  }

  .group:hover .m\:group-hover\:bg-light {
    background-color: #f8f9fa;
  }

  .group:hover .m\:group-hover\:bg-dark {
    background-color: #343a40;
  }

  .group:hover .m\:group-hover\:bg-gray-transparent {
    background: transparent;
  }

  .group:hover .m\:group-hover\:bg-gray-current {
    background: currentColor;
  }

  .group:hover .m\:group-hover\:bg-gray-50 {
    background-color: #f9fafb;
  }

  .group:hover .m\:group-hover\:bg-gray-100 {
    background-color: #f3f4f6;
  }

  .group:hover .m\:group-hover\:bg-gray-200 {
    background-color: #e5e7eb;
  }

  .group:hover .m\:group-hover\:bg-gray-300 {
    background-color: #d1d5db;
  }

  .group:hover .m\:group-hover\:bg-gray-400 {
    background-color: #9ca3af;
  }

  .group:hover .m\:group-hover\:bg-gray-500 {
    background-color: #6b7280;
  }

  .group:hover .m\:group-hover\:bg-gray-600 {
    background-color: #4b5563;
  }

  .group:hover .m\:group-hover\:bg-gray-700 {
    background-color: #374151;
  }

  .group:hover .m\:group-hover\:bg-gray-800 {
    background-color: #1f2937;
  }

  .group:hover .m\:group-hover\:bg-gray-900 {
    background-color: #111827;
  }

  .group:hover .m\:group-hover\:bg-red-transparent {
    background: transparent;
  }

  .group:hover .m\:group-hover\:bg-red-current {
    background: currentColor;
  }

  .group:hover .m\:group-hover\:bg-red-50 {
    background-color: #fef2f2;
  }

  .group:hover .m\:group-hover\:bg-red-100 {
    background-color: #fee2e2;
  }

  .group:hover .m\:group-hover\:bg-red-200 {
    background-color: #fecaca;
  }

  .group:hover .m\:group-hover\:bg-red-300 {
    background-color: #fca5a5;
  }

  .group:hover .m\:group-hover\:bg-red-400 {
    background-color: #f87171;
  }

  .group:hover .m\:group-hover\:bg-red-500 {
    background-color: #ef4444;
  }

  .group:hover .m\:group-hover\:bg-red-600 {
    background-color: #dc2626;
  }

  .group:hover .m\:group-hover\:bg-red-700 {
    background-color: #b91c1c;
  }

  .group:hover .m\:group-hover\:bg-red-800 {
    background-color: #991b1b;
  }

  .group:hover .m\:group-hover\:bg-red-900 {
    background-color: #7f1d1d;
  }

  .group:hover .m\:group-hover\:bg-yellow-transparent {
    background: transparent;
  }

  .group:hover .m\:group-hover\:bg-yellow-current {
    background: currentColor;
  }

  .group:hover .m\:group-hover\:bg-yellow-50 {
    background-color: #fffbeb;
  }

  .group:hover .m\:group-hover\:bg-yellow-100 {
    background-color: #fef3c7;
  }

  .group:hover .m\:group-hover\:bg-yellow-200 {
    background-color: #fde68a;
  }

  .group:hover .m\:group-hover\:bg-yellow-300 {
    background-color: #fcd34d;
  }

  .group:hover .m\:group-hover\:bg-yellow-400 {
    background-color: #fbbf24;
  }

  .group:hover .m\:group-hover\:bg-yellow-500 {
    background-color: #f59e0b;
  }

  .group:hover .m\:group-hover\:bg-yellow-600 {
    background-color: #d97706;
  }

  .group:hover .m\:group-hover\:bg-yellow-700 {
    background-color: #b45309;
  }

  .group:hover .m\:group-hover\:bg-yellow-800 {
    background-color: #92400e;
  }

  .group:hover .m\:group-hover\:bg-yellow-900 {
    background-color: #78350f;
  }

  .group:hover .m\:group-hover\:bg-green-transparent {
    background: transparent;
  }

  .group:hover .m\:group-hover\:bg-green-current {
    background: currentColor;
  }

  .group:hover .m\:group-hover\:bg-green-50 {
    background-color: #ecfdf5;
  }

  .group:hover .m\:group-hover\:bg-green-100 {
    background-color: #d1fae5;
  }

  .group:hover .m\:group-hover\:bg-green-200 {
    background-color: #a7f3d0;
  }

  .group:hover .m\:group-hover\:bg-green-300 {
    background-color: #6ee7b7;
  }

  .group:hover .m\:group-hover\:bg-green-400 {
    background-color: #34d399;
  }

  .group:hover .m\:group-hover\:bg-green-500 {
    background-color: #10b981;
  }

  .group:hover .m\:group-hover\:bg-green-600 {
    background-color: #059669;
  }

  .group:hover .m\:group-hover\:bg-green-700 {
    background-color: #047857;
  }

  .group:hover .m\:group-hover\:bg-green-800 {
    background-color: #065f46;
  }

  .group:hover .m\:group-hover\:bg-green-900 {
    background-color: #064e3b;
  }

  .group:hover .m\:group-hover\:bg-blue-transparent {
    background: transparent;
  }

  .group:hover .m\:group-hover\:bg-blue-current {
    background: currentColor;
  }

  .group:hover .m\:group-hover\:bg-blue-50 {
    background-color: #eff6ff;
  }

  .group:hover .m\:group-hover\:bg-blue-100 {
    background-color: #dbeafe;
  }

  .group:hover .m\:group-hover\:bg-blue-200 {
    background-color: #bfdbfe;
  }

  .group:hover .m\:group-hover\:bg-blue-300 {
    background-color: #93c5fd;
  }

  .group:hover .m\:group-hover\:bg-blue-400 {
    background-color: #60a5fa;
  }

  .group:hover .m\:group-hover\:bg-blue-500 {
    background-color: #3b82f6;
  }

  .group:hover .m\:group-hover\:bg-blue-600 {
    background-color: #2563eb;
  }

  .group:hover .m\:group-hover\:bg-blue-700 {
    background-color: #1d4ed8;
  }

  .group:hover .m\:group-hover\:bg-blue-800 {
    background-color: #1e40af;
  }

  .group:hover .m\:group-hover\:bg-blue-900 {
    background-color: #1e3a8a;
  }

  .group:hover .m\:group-hover\:bg-cyan-transparent {
    background: transparent;
  }

  .group:hover .m\:group-hover\:bg-cyan-current {
    background: currentColor;
  }

  .group:hover .m\:group-hover\:bg-cyan-50 {
    background-color: #ecfeff;
  }

  .group:hover .m\:group-hover\:bg-cyan-100 {
    background-color: #cffafe;
  }

  .group:hover .m\:group-hover\:bg-cyan-200 {
    background-color: #a5f3fc;
  }

  .group:hover .m\:group-hover\:bg-cyan-300 {
    background-color: #67e8f9;
  }

  .group:hover .m\:group-hover\:bg-cyan-400 {
    background-color: #22d3ee;
  }

  .group:hover .m\:group-hover\:bg-cyan-500 {
    background-color: #06b6d4;
  }

  .group:hover .m\:group-hover\:bg-cyan-600 {
    background-color: #0891b2;
  }

  .group:hover .m\:group-hover\:bg-cyan-700 {
    background-color: #0e7490;
  }

  .group:hover .m\:group-hover\:bg-cyan-800 {
    background-color: #155e75;
  }

  .group:hover .m\:group-hover\:bg-cyan-900 {
    background-color: #164e63;
  }

  .group:hover .m\:group-hover\:bg-indigo-transparent {
    background: transparent;
  }

  .group:hover .m\:group-hover\:bg-indigo-current {
    background: currentColor;
  }

  .group:hover .m\:group-hover\:bg-indigo-50 {
    background-color: #eef2ff;
  }

  .group:hover .m\:group-hover\:bg-indigo-100 {
    background-color: #e0e7ff;
  }

  .group:hover .m\:group-hover\:bg-indigo-200 {
    background-color: #c7d2fe;
  }

  .group:hover .m\:group-hover\:bg-indigo-300 {
    background-color: #a5b4fc;
  }

  .group:hover .m\:group-hover\:bg-indigo-400 {
    background-color: #818cf8;
  }

  .group:hover .m\:group-hover\:bg-indigo-500 {
    background-color: #6366f1;
  }

  .group:hover .m\:group-hover\:bg-indigo-600 {
    background-color: #4f46e5;
  }

  .group:hover .m\:group-hover\:bg-indigo-700 {
    background-color: #4338ca;
  }

  .group:hover .m\:group-hover\:bg-indigo-800 {
    background-color: #3730a3;
  }

  .group:hover .m\:group-hover\:bg-indigo-900 {
    background-color: #312e81;
  }

  .group:hover .m\:group-hover\:bg-purple-transparent {
    background: transparent;
  }

  .group:hover .m\:group-hover\:bg-purple-current {
    background: currentColor;
  }

  .group:hover .m\:group-hover\:bg-purple-50 {
    background-color: #f5f3ff;
  }

  .group:hover .m\:group-hover\:bg-purple-100 {
    background-color: #ede9fe;
  }

  .group:hover .m\:group-hover\:bg-purple-200 {
    background-color: #ddd6fe;
  }

  .group:hover .m\:group-hover\:bg-purple-300 {
    background-color: #c4b5fd;
  }

  .group:hover .m\:group-hover\:bg-purple-400 {
    background-color: #a78bfa;
  }

  .group:hover .m\:group-hover\:bg-purple-500 {
    background-color: #8b5cf6;
  }

  .group:hover .m\:group-hover\:bg-purple-600 {
    background-color: #7c3aed;
  }

  .group:hover .m\:group-hover\:bg-purple-700 {
    background-color: #6d28d9;
  }

  .group:hover .m\:group-hover\:bg-purple-800 {
    background-color: #5b21b6;
  }

  .group:hover .m\:group-hover\:bg-purple-900 {
    background-color: #4c1d95;
  }

  .group:hover .m\:group-hover\:bg-pink-transparent {
    background: transparent;
  }

  .group:hover .m\:group-hover\:bg-pink-current {
    background: currentColor;
  }

  .group:hover .m\:group-hover\:bg-pink-50 {
    background-color: #fdf2f8;
  }

  .group:hover .m\:group-hover\:bg-pink-100 {
    background-color: #fce7f3;
  }

  .group:hover .m\:group-hover\:bg-pink-200 {
    background-color: #fbcfe8;
  }

  .group:hover .m\:group-hover\:bg-pink-300 {
    background-color: #f9a8d4;
  }

  .group:hover .m\:group-hover\:bg-pink-400 {
    background-color: #f472b6;
  }

  .group:hover .m\:group-hover\:bg-pink-500 {
    background-color: #ec4899;
  }

  .group:hover .m\:group-hover\:bg-pink-600 {
    background-color: #db2777;
  }

  .group:hover .m\:group-hover\:bg-pink-700 {
    background-color: #be185d;
  }

  .group:hover .m\:group-hover\:bg-pink-800 {
    background-color: #9d174d;
  }

  .group:hover .m\:group-hover\:bg-pink-900 {
    background-color: #831843;
  }
}
@media (min-width: 769px) {
  .pc\:bg-transparent {
    background: transparent;
  }

  .pc\:bg-none {
    background: none !important;
  }

  .pc\:bg-transparent {
    background: transparent;
  }

  .pc\:bg-current {
    background: currentColor;
  }

  .pc\:bg-black {
    background-color: #000;
  }

  .pc\:bg-white {
    background-color: #fff;
  }

  .pc\:bg-primary {
    background-color: #007bff;
  }

  .pc\:bg-secondary {
    background-color: #6c757d;
  }

  .pc\:bg-success {
    background-color: #28a745;
  }

  .pc\:bg-info {
    background-color: #17a2b8;
  }

  .pc\:bg-warning {
    background-color: #fad733;
  }

  .pc\:bg-danger {
    background-color: #dc3545;
  }

  .pc\:bg-light {
    background-color: #f8f9fa;
  }

  .pc\:bg-dark {
    background-color: #343a40;
  }

  .pc\:bg-gray-transparent {
    background: transparent;
  }

  .pc\:bg-gray-current {
    background: currentColor;
  }

  .pc\:bg-gray-50 {
    background-color: #f9fafb;
  }

  .pc\:bg-gray-100 {
    background-color: #f3f4f6;
  }

  .pc\:bg-gray-200 {
    background-color: #e5e7eb;
  }

  .pc\:bg-gray-300 {
    background-color: #d1d5db;
  }

  .pc\:bg-gray-400 {
    background-color: #9ca3af;
  }

  .pc\:bg-gray-500 {
    background-color: #6b7280;
  }

  .pc\:bg-gray-600 {
    background-color: #4b5563;
  }

  .pc\:bg-gray-700 {
    background-color: #374151;
  }

  .pc\:bg-gray-800 {
    background-color: #1f2937;
  }

  .pc\:bg-gray-900 {
    background-color: #111827;
  }

  .pc\:bg-red-transparent {
    background: transparent;
  }

  .pc\:bg-red-current {
    background: currentColor;
  }

  .pc\:bg-red-50 {
    background-color: #fef2f2;
  }

  .pc\:bg-red-100 {
    background-color: #fee2e2;
  }

  .pc\:bg-red-200 {
    background-color: #fecaca;
  }

  .pc\:bg-red-300 {
    background-color: #fca5a5;
  }

  .pc\:bg-red-400 {
    background-color: #f87171;
  }

  .pc\:bg-red-500 {
    background-color: #ef4444;
  }

  .pc\:bg-red-600 {
    background-color: #dc2626;
  }

  .pc\:bg-red-700 {
    background-color: #b91c1c;
  }

  .pc\:bg-red-800 {
    background-color: #991b1b;
  }

  .pc\:bg-red-900 {
    background-color: #7f1d1d;
  }

  .pc\:bg-yellow-transparent {
    background: transparent;
  }

  .pc\:bg-yellow-current {
    background: currentColor;
  }

  .pc\:bg-yellow-50 {
    background-color: #fffbeb;
  }

  .pc\:bg-yellow-100 {
    background-color: #fef3c7;
  }

  .pc\:bg-yellow-200 {
    background-color: #fde68a;
  }

  .pc\:bg-yellow-300 {
    background-color: #fcd34d;
  }

  .pc\:bg-yellow-400 {
    background-color: #fbbf24;
  }

  .pc\:bg-yellow-500 {
    background-color: #f59e0b;
  }

  .pc\:bg-yellow-600 {
    background-color: #d97706;
  }

  .pc\:bg-yellow-700 {
    background-color: #b45309;
  }

  .pc\:bg-yellow-800 {
    background-color: #92400e;
  }

  .pc\:bg-yellow-900 {
    background-color: #78350f;
  }

  .pc\:bg-green-transparent {
    background: transparent;
  }

  .pc\:bg-green-current {
    background: currentColor;
  }

  .pc\:bg-green-50 {
    background-color: #ecfdf5;
  }

  .pc\:bg-green-100 {
    background-color: #d1fae5;
  }

  .pc\:bg-green-200 {
    background-color: #a7f3d0;
  }

  .pc\:bg-green-300 {
    background-color: #6ee7b7;
  }

  .pc\:bg-green-400 {
    background-color: #34d399;
  }

  .pc\:bg-green-500 {
    background-color: #10b981;
  }

  .pc\:bg-green-600 {
    background-color: #059669;
  }

  .pc\:bg-green-700 {
    background-color: #047857;
  }

  .pc\:bg-green-800 {
    background-color: #065f46;
  }

  .pc\:bg-green-900 {
    background-color: #064e3b;
  }

  .pc\:bg-blue-transparent {
    background: transparent;
  }

  .pc\:bg-blue-current {
    background: currentColor;
  }

  .pc\:bg-blue-50 {
    background-color: #eff6ff;
  }

  .pc\:bg-blue-100 {
    background-color: #dbeafe;
  }

  .pc\:bg-blue-200 {
    background-color: #bfdbfe;
  }

  .pc\:bg-blue-300 {
    background-color: #93c5fd;
  }

  .pc\:bg-blue-400 {
    background-color: #60a5fa;
  }

  .pc\:bg-blue-500 {
    background-color: #3b82f6;
  }

  .pc\:bg-blue-600 {
    background-color: #2563eb;
  }

  .pc\:bg-blue-700 {
    background-color: #1d4ed8;
  }

  .pc\:bg-blue-800 {
    background-color: #1e40af;
  }

  .pc\:bg-blue-900 {
    background-color: #1e3a8a;
  }

  .pc\:bg-cyan-transparent {
    background: transparent;
  }

  .pc\:bg-cyan-current {
    background: currentColor;
  }

  .pc\:bg-cyan-50 {
    background-color: #ecfeff;
  }

  .pc\:bg-cyan-100 {
    background-color: #cffafe;
  }

  .pc\:bg-cyan-200 {
    background-color: #a5f3fc;
  }

  .pc\:bg-cyan-300 {
    background-color: #67e8f9;
  }

  .pc\:bg-cyan-400 {
    background-color: #22d3ee;
  }

  .pc\:bg-cyan-500 {
    background-color: #06b6d4;
  }

  .pc\:bg-cyan-600 {
    background-color: #0891b2;
  }

  .pc\:bg-cyan-700 {
    background-color: #0e7490;
  }

  .pc\:bg-cyan-800 {
    background-color: #155e75;
  }

  .pc\:bg-cyan-900 {
    background-color: #164e63;
  }

  .pc\:bg-indigo-transparent {
    background: transparent;
  }

  .pc\:bg-indigo-current {
    background: currentColor;
  }

  .pc\:bg-indigo-50 {
    background-color: #eef2ff;
  }

  .pc\:bg-indigo-100 {
    background-color: #e0e7ff;
  }

  .pc\:bg-indigo-200 {
    background-color: #c7d2fe;
  }

  .pc\:bg-indigo-300 {
    background-color: #a5b4fc;
  }

  .pc\:bg-indigo-400 {
    background-color: #818cf8;
  }

  .pc\:bg-indigo-500 {
    background-color: #6366f1;
  }

  .pc\:bg-indigo-600 {
    background-color: #4f46e5;
  }

  .pc\:bg-indigo-700 {
    background-color: #4338ca;
  }

  .pc\:bg-indigo-800 {
    background-color: #3730a3;
  }

  .pc\:bg-indigo-900 {
    background-color: #312e81;
  }

  .pc\:bg-purple-transparent {
    background: transparent;
  }

  .pc\:bg-purple-current {
    background: currentColor;
  }

  .pc\:bg-purple-50 {
    background-color: #f5f3ff;
  }

  .pc\:bg-purple-100 {
    background-color: #ede9fe;
  }

  .pc\:bg-purple-200 {
    background-color: #ddd6fe;
  }

  .pc\:bg-purple-300 {
    background-color: #c4b5fd;
  }

  .pc\:bg-purple-400 {
    background-color: #a78bfa;
  }

  .pc\:bg-purple-500 {
    background-color: #8b5cf6;
  }

  .pc\:bg-purple-600 {
    background-color: #7c3aed;
  }

  .pc\:bg-purple-700 {
    background-color: #6d28d9;
  }

  .pc\:bg-purple-800 {
    background-color: #5b21b6;
  }

  .pc\:bg-purple-900 {
    background-color: #4c1d95;
  }

  .pc\:bg-pink-transparent {
    background: transparent;
  }

  .pc\:bg-pink-current {
    background: currentColor;
  }

  .pc\:bg-pink-50 {
    background-color: #fdf2f8;
  }

  .pc\:bg-pink-100 {
    background-color: #fce7f3;
  }

  .pc\:bg-pink-200 {
    background-color: #fbcfe8;
  }

  .pc\:bg-pink-300 {
    background-color: #f9a8d4;
  }

  .pc\:bg-pink-400 {
    background-color: #f472b6;
  }

  .pc\:bg-pink-500 {
    background-color: #ec4899;
  }

  .pc\:bg-pink-600 {
    background-color: #db2777;
  }

  .pc\:bg-pink-700 {
    background-color: #be185d;
  }

  .pc\:bg-pink-800 {
    background-color: #9d174d;
  }

  .pc\:bg-pink-900 {
    background-color: #831843;
  }

  .pc\:hover\:bg-transparent:hover {
    background: transparent;
  }

  .pc\:hover\:bg-none:hover {
    background: none !important;
  }

  .pc\:hover\:bg-transparent:hover {
    background: transparent;
  }

  .pc\:hover\:bg-current:hover {
    background: currentColor;
  }

  .pc\:hover\:bg-black:hover {
    background-color: #000;
  }

  .pc\:hover\:bg-white:hover {
    background-color: #fff;
  }

  .pc\:hover\:bg-primary:hover {
    background-color: #007bff;
  }

  .pc\:hover\:bg-secondary:hover {
    background-color: #6c757d;
  }

  .pc\:hover\:bg-success:hover {
    background-color: #28a745;
  }

  .pc\:hover\:bg-info:hover {
    background-color: #17a2b8;
  }

  .pc\:hover\:bg-warning:hover {
    background-color: #fad733;
  }

  .pc\:hover\:bg-danger:hover {
    background-color: #dc3545;
  }

  .pc\:hover\:bg-light:hover {
    background-color: #f8f9fa;
  }

  .pc\:hover\:bg-dark:hover {
    background-color: #343a40;
  }

  .pc\:hover\:bg-gray-transparent:hover {
    background: transparent;
  }

  .pc\:hover\:bg-gray-current:hover {
    background: currentColor;
  }

  .pc\:hover\:bg-gray-50:hover {
    background-color: #f9fafb;
  }

  .pc\:hover\:bg-gray-100:hover {
    background-color: #f3f4f6;
  }

  .pc\:hover\:bg-gray-200:hover {
    background-color: #e5e7eb;
  }

  .pc\:hover\:bg-gray-300:hover {
    background-color: #d1d5db;
  }

  .pc\:hover\:bg-gray-400:hover {
    background-color: #9ca3af;
  }

  .pc\:hover\:bg-gray-500:hover {
    background-color: #6b7280;
  }

  .pc\:hover\:bg-gray-600:hover {
    background-color: #4b5563;
  }

  .pc\:hover\:bg-gray-700:hover {
    background-color: #374151;
  }

  .pc\:hover\:bg-gray-800:hover {
    background-color: #1f2937;
  }

  .pc\:hover\:bg-gray-900:hover {
    background-color: #111827;
  }

  .pc\:hover\:bg-red-transparent:hover {
    background: transparent;
  }

  .pc\:hover\:bg-red-current:hover {
    background: currentColor;
  }

  .pc\:hover\:bg-red-50:hover {
    background-color: #fef2f2;
  }

  .pc\:hover\:bg-red-100:hover {
    background-color: #fee2e2;
  }

  .pc\:hover\:bg-red-200:hover {
    background-color: #fecaca;
  }

  .pc\:hover\:bg-red-300:hover {
    background-color: #fca5a5;
  }

  .pc\:hover\:bg-red-400:hover {
    background-color: #f87171;
  }

  .pc\:hover\:bg-red-500:hover {
    background-color: #ef4444;
  }

  .pc\:hover\:bg-red-600:hover {
    background-color: #dc2626;
  }

  .pc\:hover\:bg-red-700:hover {
    background-color: #b91c1c;
  }

  .pc\:hover\:bg-red-800:hover {
    background-color: #991b1b;
  }

  .pc\:hover\:bg-red-900:hover {
    background-color: #7f1d1d;
  }

  .pc\:hover\:bg-yellow-transparent:hover {
    background: transparent;
  }

  .pc\:hover\:bg-yellow-current:hover {
    background: currentColor;
  }

  .pc\:hover\:bg-yellow-50:hover {
    background-color: #fffbeb;
  }

  .pc\:hover\:bg-yellow-100:hover {
    background-color: #fef3c7;
  }

  .pc\:hover\:bg-yellow-200:hover {
    background-color: #fde68a;
  }

  .pc\:hover\:bg-yellow-300:hover {
    background-color: #fcd34d;
  }

  .pc\:hover\:bg-yellow-400:hover {
    background-color: #fbbf24;
  }

  .pc\:hover\:bg-yellow-500:hover {
    background-color: #f59e0b;
  }

  .pc\:hover\:bg-yellow-600:hover {
    background-color: #d97706;
  }

  .pc\:hover\:bg-yellow-700:hover {
    background-color: #b45309;
  }

  .pc\:hover\:bg-yellow-800:hover {
    background-color: #92400e;
  }

  .pc\:hover\:bg-yellow-900:hover {
    background-color: #78350f;
  }

  .pc\:hover\:bg-green-transparent:hover {
    background: transparent;
  }

  .pc\:hover\:bg-green-current:hover {
    background: currentColor;
  }

  .pc\:hover\:bg-green-50:hover {
    background-color: #ecfdf5;
  }

  .pc\:hover\:bg-green-100:hover {
    background-color: #d1fae5;
  }

  .pc\:hover\:bg-green-200:hover {
    background-color: #a7f3d0;
  }

  .pc\:hover\:bg-green-300:hover {
    background-color: #6ee7b7;
  }

  .pc\:hover\:bg-green-400:hover {
    background-color: #34d399;
  }

  .pc\:hover\:bg-green-500:hover {
    background-color: #10b981;
  }

  .pc\:hover\:bg-green-600:hover {
    background-color: #059669;
  }

  .pc\:hover\:bg-green-700:hover {
    background-color: #047857;
  }

  .pc\:hover\:bg-green-800:hover {
    background-color: #065f46;
  }

  .pc\:hover\:bg-green-900:hover {
    background-color: #064e3b;
  }

  .pc\:hover\:bg-blue-transparent:hover {
    background: transparent;
  }

  .pc\:hover\:bg-blue-current:hover {
    background: currentColor;
  }

  .pc\:hover\:bg-blue-50:hover {
    background-color: #eff6ff;
  }

  .pc\:hover\:bg-blue-100:hover {
    background-color: #dbeafe;
  }

  .pc\:hover\:bg-blue-200:hover {
    background-color: #bfdbfe;
  }

  .pc\:hover\:bg-blue-300:hover {
    background-color: #93c5fd;
  }

  .pc\:hover\:bg-blue-400:hover {
    background-color: #60a5fa;
  }

  .pc\:hover\:bg-blue-500:hover {
    background-color: #3b82f6;
  }

  .pc\:hover\:bg-blue-600:hover {
    background-color: #2563eb;
  }

  .pc\:hover\:bg-blue-700:hover {
    background-color: #1d4ed8;
  }

  .pc\:hover\:bg-blue-800:hover {
    background-color: #1e40af;
  }

  .pc\:hover\:bg-blue-900:hover {
    background-color: #1e3a8a;
  }

  .pc\:hover\:bg-cyan-transparent:hover {
    background: transparent;
  }

  .pc\:hover\:bg-cyan-current:hover {
    background: currentColor;
  }

  .pc\:hover\:bg-cyan-50:hover {
    background-color: #ecfeff;
  }

  .pc\:hover\:bg-cyan-100:hover {
    background-color: #cffafe;
  }

  .pc\:hover\:bg-cyan-200:hover {
    background-color: #a5f3fc;
  }

  .pc\:hover\:bg-cyan-300:hover {
    background-color: #67e8f9;
  }

  .pc\:hover\:bg-cyan-400:hover {
    background-color: #22d3ee;
  }

  .pc\:hover\:bg-cyan-500:hover {
    background-color: #06b6d4;
  }

  .pc\:hover\:bg-cyan-600:hover {
    background-color: #0891b2;
  }

  .pc\:hover\:bg-cyan-700:hover {
    background-color: #0e7490;
  }

  .pc\:hover\:bg-cyan-800:hover {
    background-color: #155e75;
  }

  .pc\:hover\:bg-cyan-900:hover {
    background-color: #164e63;
  }

  .pc\:hover\:bg-indigo-transparent:hover {
    background: transparent;
  }

  .pc\:hover\:bg-indigo-current:hover {
    background: currentColor;
  }

  .pc\:hover\:bg-indigo-50:hover {
    background-color: #eef2ff;
  }

  .pc\:hover\:bg-indigo-100:hover {
    background-color: #e0e7ff;
  }

  .pc\:hover\:bg-indigo-200:hover {
    background-color: #c7d2fe;
  }

  .pc\:hover\:bg-indigo-300:hover {
    background-color: #a5b4fc;
  }

  .pc\:hover\:bg-indigo-400:hover {
    background-color: #818cf8;
  }

  .pc\:hover\:bg-indigo-500:hover {
    background-color: #6366f1;
  }

  .pc\:hover\:bg-indigo-600:hover {
    background-color: #4f46e5;
  }

  .pc\:hover\:bg-indigo-700:hover {
    background-color: #4338ca;
  }

  .pc\:hover\:bg-indigo-800:hover {
    background-color: #3730a3;
  }

  .pc\:hover\:bg-indigo-900:hover {
    background-color: #312e81;
  }

  .pc\:hover\:bg-purple-transparent:hover {
    background: transparent;
  }

  .pc\:hover\:bg-purple-current:hover {
    background: currentColor;
  }

  .pc\:hover\:bg-purple-50:hover {
    background-color: #f5f3ff;
  }

  .pc\:hover\:bg-purple-100:hover {
    background-color: #ede9fe;
  }

  .pc\:hover\:bg-purple-200:hover {
    background-color: #ddd6fe;
  }

  .pc\:hover\:bg-purple-300:hover {
    background-color: #c4b5fd;
  }

  .pc\:hover\:bg-purple-400:hover {
    background-color: #a78bfa;
  }

  .pc\:hover\:bg-purple-500:hover {
    background-color: #8b5cf6;
  }

  .pc\:hover\:bg-purple-600:hover {
    background-color: #7c3aed;
  }

  .pc\:hover\:bg-purple-700:hover {
    background-color: #6d28d9;
  }

  .pc\:hover\:bg-purple-800:hover {
    background-color: #5b21b6;
  }

  .pc\:hover\:bg-purple-900:hover {
    background-color: #4c1d95;
  }

  .pc\:hover\:bg-pink-transparent:hover {
    background: transparent;
  }

  .pc\:hover\:bg-pink-current:hover {
    background: currentColor;
  }

  .pc\:hover\:bg-pink-50:hover {
    background-color: #fdf2f8;
  }

  .pc\:hover\:bg-pink-100:hover {
    background-color: #fce7f3;
  }

  .pc\:hover\:bg-pink-200:hover {
    background-color: #fbcfe8;
  }

  .pc\:hover\:bg-pink-300:hover {
    background-color: #f9a8d4;
  }

  .pc\:hover\:bg-pink-400:hover {
    background-color: #f472b6;
  }

  .pc\:hover\:bg-pink-500:hover {
    background-color: #ec4899;
  }

  .pc\:hover\:bg-pink-600:hover {
    background-color: #db2777;
  }

  .pc\:hover\:bg-pink-700:hover {
    background-color: #be185d;
  }

  .pc\:hover\:bg-pink-800:hover {
    background-color: #9d174d;
  }

  .pc\:hover\:bg-pink-900:hover {
    background-color: #831843;
  }

  .pc\:active\:bg-transparent.is-active {
    background: transparent;
  }

  .pc\:active\:bg-none.is-active {
    background: none !important;
  }

  .pc\:active\:bg-transparent.is-active {
    background: transparent;
  }

  .pc\:active\:bg-current.is-active {
    background: currentColor;
  }

  .pc\:active\:bg-black.is-active,
.pc\:active\:bg-black:active {
    background-color: #000;
  }

  .pc\:active\:bg-white.is-active,
.pc\:active\:bg-white:active {
    background-color: #fff;
  }

  .pc\:active\:bg-primary.is-active,
.pc\:active\:bg-primary:active {
    background-color: #007bff;
  }

  .pc\:active\:bg-secondary.is-active,
.pc\:active\:bg-secondary:active {
    background-color: #6c757d;
  }

  .pc\:active\:bg-success.is-active,
.pc\:active\:bg-success:active {
    background-color: #28a745;
  }

  .pc\:active\:bg-info.is-active,
.pc\:active\:bg-info:active {
    background-color: #17a2b8;
  }

  .pc\:active\:bg-warning.is-active,
.pc\:active\:bg-warning:active {
    background-color: #fad733;
  }

  .pc\:active\:bg-danger.is-active,
.pc\:active\:bg-danger:active {
    background-color: #dc3545;
  }

  .pc\:active\:bg-light.is-active,
.pc\:active\:bg-light:active {
    background-color: #f8f9fa;
  }

  .pc\:active\:bg-dark.is-active,
.pc\:active\:bg-dark:active {
    background-color: #343a40;
  }

  .pc\:active\:bg-gray-transparent.is-active {
    background: transparent;
  }

  .pc\:active\:bg-gray-current.is-active {
    background: currentColor;
  }

  .pc\:active\:bg-gray-50.is-active,
.pc\:active\:bg-gray-50:active {
    background-color: #f9fafb;
  }

  .pc\:active\:bg-gray-100.is-active,
.pc\:active\:bg-gray-100:active {
    background-color: #f3f4f6;
  }

  .pc\:active\:bg-gray-200.is-active,
.pc\:active\:bg-gray-200:active {
    background-color: #e5e7eb;
  }

  .pc\:active\:bg-gray-300.is-active,
.pc\:active\:bg-gray-300:active {
    background-color: #d1d5db;
  }

  .pc\:active\:bg-gray-400.is-active,
.pc\:active\:bg-gray-400:active {
    background-color: #9ca3af;
  }

  .pc\:active\:bg-gray-500.is-active,
.pc\:active\:bg-gray-500:active {
    background-color: #6b7280;
  }

  .pc\:active\:bg-gray-600.is-active,
.pc\:active\:bg-gray-600:active {
    background-color: #4b5563;
  }

  .pc\:active\:bg-gray-700.is-active,
.pc\:active\:bg-gray-700:active {
    background-color: #374151;
  }

  .pc\:active\:bg-gray-800.is-active,
.pc\:active\:bg-gray-800:active {
    background-color: #1f2937;
  }

  .pc\:active\:bg-gray-900.is-active,
.pc\:active\:bg-gray-900:active {
    background-color: #111827;
  }

  .pc\:active\:bg-red-transparent.is-active {
    background: transparent;
  }

  .pc\:active\:bg-red-current.is-active {
    background: currentColor;
  }

  .pc\:active\:bg-red-50.is-active,
.pc\:active\:bg-red-50:active {
    background-color: #fef2f2;
  }

  .pc\:active\:bg-red-100.is-active,
.pc\:active\:bg-red-100:active {
    background-color: #fee2e2;
  }

  .pc\:active\:bg-red-200.is-active,
.pc\:active\:bg-red-200:active {
    background-color: #fecaca;
  }

  .pc\:active\:bg-red-300.is-active,
.pc\:active\:bg-red-300:active {
    background-color: #fca5a5;
  }

  .pc\:active\:bg-red-400.is-active,
.pc\:active\:bg-red-400:active {
    background-color: #f87171;
  }

  .pc\:active\:bg-red-500.is-active,
.pc\:active\:bg-red-500:active {
    background-color: #ef4444;
  }

  .pc\:active\:bg-red-600.is-active,
.pc\:active\:bg-red-600:active {
    background-color: #dc2626;
  }

  .pc\:active\:bg-red-700.is-active,
.pc\:active\:bg-red-700:active {
    background-color: #b91c1c;
  }

  .pc\:active\:bg-red-800.is-active,
.pc\:active\:bg-red-800:active {
    background-color: #991b1b;
  }

  .pc\:active\:bg-red-900.is-active,
.pc\:active\:bg-red-900:active {
    background-color: #7f1d1d;
  }

  .pc\:active\:bg-yellow-transparent.is-active {
    background: transparent;
  }

  .pc\:active\:bg-yellow-current.is-active {
    background: currentColor;
  }

  .pc\:active\:bg-yellow-50.is-active,
.pc\:active\:bg-yellow-50:active {
    background-color: #fffbeb;
  }

  .pc\:active\:bg-yellow-100.is-active,
.pc\:active\:bg-yellow-100:active {
    background-color: #fef3c7;
  }

  .pc\:active\:bg-yellow-200.is-active,
.pc\:active\:bg-yellow-200:active {
    background-color: #fde68a;
  }

  .pc\:active\:bg-yellow-300.is-active,
.pc\:active\:bg-yellow-300:active {
    background-color: #fcd34d;
  }

  .pc\:active\:bg-yellow-400.is-active,
.pc\:active\:bg-yellow-400:active {
    background-color: #fbbf24;
  }

  .pc\:active\:bg-yellow-500.is-active,
.pc\:active\:bg-yellow-500:active {
    background-color: #f59e0b;
  }

  .pc\:active\:bg-yellow-600.is-active,
.pc\:active\:bg-yellow-600:active {
    background-color: #d97706;
  }

  .pc\:active\:bg-yellow-700.is-active,
.pc\:active\:bg-yellow-700:active {
    background-color: #b45309;
  }

  .pc\:active\:bg-yellow-800.is-active,
.pc\:active\:bg-yellow-800:active {
    background-color: #92400e;
  }

  .pc\:active\:bg-yellow-900.is-active,
.pc\:active\:bg-yellow-900:active {
    background-color: #78350f;
  }

  .pc\:active\:bg-green-transparent.is-active {
    background: transparent;
  }

  .pc\:active\:bg-green-current.is-active {
    background: currentColor;
  }

  .pc\:active\:bg-green-50.is-active,
.pc\:active\:bg-green-50:active {
    background-color: #ecfdf5;
  }

  .pc\:active\:bg-green-100.is-active,
.pc\:active\:bg-green-100:active {
    background-color: #d1fae5;
  }

  .pc\:active\:bg-green-200.is-active,
.pc\:active\:bg-green-200:active {
    background-color: #a7f3d0;
  }

  .pc\:active\:bg-green-300.is-active,
.pc\:active\:bg-green-300:active {
    background-color: #6ee7b7;
  }

  .pc\:active\:bg-green-400.is-active,
.pc\:active\:bg-green-400:active {
    background-color: #34d399;
  }

  .pc\:active\:bg-green-500.is-active,
.pc\:active\:bg-green-500:active {
    background-color: #10b981;
  }

  .pc\:active\:bg-green-600.is-active,
.pc\:active\:bg-green-600:active {
    background-color: #059669;
  }

  .pc\:active\:bg-green-700.is-active,
.pc\:active\:bg-green-700:active {
    background-color: #047857;
  }

  .pc\:active\:bg-green-800.is-active,
.pc\:active\:bg-green-800:active {
    background-color: #065f46;
  }

  .pc\:active\:bg-green-900.is-active,
.pc\:active\:bg-green-900:active {
    background-color: #064e3b;
  }

  .pc\:active\:bg-blue-transparent.is-active {
    background: transparent;
  }

  .pc\:active\:bg-blue-current.is-active {
    background: currentColor;
  }

  .pc\:active\:bg-blue-50.is-active,
.pc\:active\:bg-blue-50:active {
    background-color: #eff6ff;
  }

  .pc\:active\:bg-blue-100.is-active,
.pc\:active\:bg-blue-100:active {
    background-color: #dbeafe;
  }

  .pc\:active\:bg-blue-200.is-active,
.pc\:active\:bg-blue-200:active {
    background-color: #bfdbfe;
  }

  .pc\:active\:bg-blue-300.is-active,
.pc\:active\:bg-blue-300:active {
    background-color: #93c5fd;
  }

  .pc\:active\:bg-blue-400.is-active,
.pc\:active\:bg-blue-400:active {
    background-color: #60a5fa;
  }

  .pc\:active\:bg-blue-500.is-active,
.pc\:active\:bg-blue-500:active {
    background-color: #3b82f6;
  }

  .pc\:active\:bg-blue-600.is-active,
.pc\:active\:bg-blue-600:active {
    background-color: #2563eb;
  }

  .pc\:active\:bg-blue-700.is-active,
.pc\:active\:bg-blue-700:active {
    background-color: #1d4ed8;
  }

  .pc\:active\:bg-blue-800.is-active,
.pc\:active\:bg-blue-800:active {
    background-color: #1e40af;
  }

  .pc\:active\:bg-blue-900.is-active,
.pc\:active\:bg-blue-900:active {
    background-color: #1e3a8a;
  }

  .pc\:active\:bg-cyan-transparent.is-active {
    background: transparent;
  }

  .pc\:active\:bg-cyan-current.is-active {
    background: currentColor;
  }

  .pc\:active\:bg-cyan-50.is-active,
.pc\:active\:bg-cyan-50:active {
    background-color: #ecfeff;
  }

  .pc\:active\:bg-cyan-100.is-active,
.pc\:active\:bg-cyan-100:active {
    background-color: #cffafe;
  }

  .pc\:active\:bg-cyan-200.is-active,
.pc\:active\:bg-cyan-200:active {
    background-color: #a5f3fc;
  }

  .pc\:active\:bg-cyan-300.is-active,
.pc\:active\:bg-cyan-300:active {
    background-color: #67e8f9;
  }

  .pc\:active\:bg-cyan-400.is-active,
.pc\:active\:bg-cyan-400:active {
    background-color: #22d3ee;
  }

  .pc\:active\:bg-cyan-500.is-active,
.pc\:active\:bg-cyan-500:active {
    background-color: #06b6d4;
  }

  .pc\:active\:bg-cyan-600.is-active,
.pc\:active\:bg-cyan-600:active {
    background-color: #0891b2;
  }

  .pc\:active\:bg-cyan-700.is-active,
.pc\:active\:bg-cyan-700:active {
    background-color: #0e7490;
  }

  .pc\:active\:bg-cyan-800.is-active,
.pc\:active\:bg-cyan-800:active {
    background-color: #155e75;
  }

  .pc\:active\:bg-cyan-900.is-active,
.pc\:active\:bg-cyan-900:active {
    background-color: #164e63;
  }

  .pc\:active\:bg-indigo-transparent.is-active {
    background: transparent;
  }

  .pc\:active\:bg-indigo-current.is-active {
    background: currentColor;
  }

  .pc\:active\:bg-indigo-50.is-active,
.pc\:active\:bg-indigo-50:active {
    background-color: #eef2ff;
  }

  .pc\:active\:bg-indigo-100.is-active,
.pc\:active\:bg-indigo-100:active {
    background-color: #e0e7ff;
  }

  .pc\:active\:bg-indigo-200.is-active,
.pc\:active\:bg-indigo-200:active {
    background-color: #c7d2fe;
  }

  .pc\:active\:bg-indigo-300.is-active,
.pc\:active\:bg-indigo-300:active {
    background-color: #a5b4fc;
  }

  .pc\:active\:bg-indigo-400.is-active,
.pc\:active\:bg-indigo-400:active {
    background-color: #818cf8;
  }

  .pc\:active\:bg-indigo-500.is-active,
.pc\:active\:bg-indigo-500:active {
    background-color: #6366f1;
  }

  .pc\:active\:bg-indigo-600.is-active,
.pc\:active\:bg-indigo-600:active {
    background-color: #4f46e5;
  }

  .pc\:active\:bg-indigo-700.is-active,
.pc\:active\:bg-indigo-700:active {
    background-color: #4338ca;
  }

  .pc\:active\:bg-indigo-800.is-active,
.pc\:active\:bg-indigo-800:active {
    background-color: #3730a3;
  }

  .pc\:active\:bg-indigo-900.is-active,
.pc\:active\:bg-indigo-900:active {
    background-color: #312e81;
  }

  .pc\:active\:bg-purple-transparent.is-active {
    background: transparent;
  }

  .pc\:active\:bg-purple-current.is-active {
    background: currentColor;
  }

  .pc\:active\:bg-purple-50.is-active,
.pc\:active\:bg-purple-50:active {
    background-color: #f5f3ff;
  }

  .pc\:active\:bg-purple-100.is-active,
.pc\:active\:bg-purple-100:active {
    background-color: #ede9fe;
  }

  .pc\:active\:bg-purple-200.is-active,
.pc\:active\:bg-purple-200:active {
    background-color: #ddd6fe;
  }

  .pc\:active\:bg-purple-300.is-active,
.pc\:active\:bg-purple-300:active {
    background-color: #c4b5fd;
  }

  .pc\:active\:bg-purple-400.is-active,
.pc\:active\:bg-purple-400:active {
    background-color: #a78bfa;
  }

  .pc\:active\:bg-purple-500.is-active,
.pc\:active\:bg-purple-500:active {
    background-color: #8b5cf6;
  }

  .pc\:active\:bg-purple-600.is-active,
.pc\:active\:bg-purple-600:active {
    background-color: #7c3aed;
  }

  .pc\:active\:bg-purple-700.is-active,
.pc\:active\:bg-purple-700:active {
    background-color: #6d28d9;
  }

  .pc\:active\:bg-purple-800.is-active,
.pc\:active\:bg-purple-800:active {
    background-color: #5b21b6;
  }

  .pc\:active\:bg-purple-900.is-active,
.pc\:active\:bg-purple-900:active {
    background-color: #4c1d95;
  }

  .pc\:active\:bg-pink-transparent.is-active {
    background: transparent;
  }

  .pc\:active\:bg-pink-current.is-active {
    background: currentColor;
  }

  .pc\:active\:bg-pink-50.is-active,
.pc\:active\:bg-pink-50:active {
    background-color: #fdf2f8;
  }

  .pc\:active\:bg-pink-100.is-active,
.pc\:active\:bg-pink-100:active {
    background-color: #fce7f3;
  }

  .pc\:active\:bg-pink-200.is-active,
.pc\:active\:bg-pink-200:active {
    background-color: #fbcfe8;
  }

  .pc\:active\:bg-pink-300.is-active,
.pc\:active\:bg-pink-300:active {
    background-color: #f9a8d4;
  }

  .pc\:active\:bg-pink-400.is-active,
.pc\:active\:bg-pink-400:active {
    background-color: #f472b6;
  }

  .pc\:active\:bg-pink-500.is-active,
.pc\:active\:bg-pink-500:active {
    background-color: #ec4899;
  }

  .pc\:active\:bg-pink-600.is-active,
.pc\:active\:bg-pink-600:active {
    background-color: #db2777;
  }

  .pc\:active\:bg-pink-700.is-active,
.pc\:active\:bg-pink-700:active {
    background-color: #be185d;
  }

  .pc\:active\:bg-pink-800.is-active,
.pc\:active\:bg-pink-800:active {
    background-color: #9d174d;
  }

  .pc\:active\:bg-pink-900.is-active,
.pc\:active\:bg-pink-900:active {
    background-color: #831843;
  }

  .pc\:focus\:bg-transparent:focus {
    background: transparent;
  }

  .pc\:focus\:bg-none:focus {
    background: none !important;
  }

  .pc\:focus\:bg-transparent:focus {
    background: transparent;
  }

  .pc\:focus\:bg-current:focus {
    background: currentColor;
  }

  .pc\:focus\:bg-black:focus {
    background-color: #000;
  }

  .pc\:focus\:bg-white:focus {
    background-color: #fff;
  }

  .pc\:focus\:bg-primary:focus {
    background-color: #007bff;
  }

  .pc\:focus\:bg-secondary:focus {
    background-color: #6c757d;
  }

  .pc\:focus\:bg-success:focus {
    background-color: #28a745;
  }

  .pc\:focus\:bg-info:focus {
    background-color: #17a2b8;
  }

  .pc\:focus\:bg-warning:focus {
    background-color: #fad733;
  }

  .pc\:focus\:bg-danger:focus {
    background-color: #dc3545;
  }

  .pc\:focus\:bg-light:focus {
    background-color: #f8f9fa;
  }

  .pc\:focus\:bg-dark:focus {
    background-color: #343a40;
  }

  .pc\:focus\:bg-gray-transparent:focus {
    background: transparent;
  }

  .pc\:focus\:bg-gray-current:focus {
    background: currentColor;
  }

  .pc\:focus\:bg-gray-50:focus {
    background-color: #f9fafb;
  }

  .pc\:focus\:bg-gray-100:focus {
    background-color: #f3f4f6;
  }

  .pc\:focus\:bg-gray-200:focus {
    background-color: #e5e7eb;
  }

  .pc\:focus\:bg-gray-300:focus {
    background-color: #d1d5db;
  }

  .pc\:focus\:bg-gray-400:focus {
    background-color: #9ca3af;
  }

  .pc\:focus\:bg-gray-500:focus {
    background-color: #6b7280;
  }

  .pc\:focus\:bg-gray-600:focus {
    background-color: #4b5563;
  }

  .pc\:focus\:bg-gray-700:focus {
    background-color: #374151;
  }

  .pc\:focus\:bg-gray-800:focus {
    background-color: #1f2937;
  }

  .pc\:focus\:bg-gray-900:focus {
    background-color: #111827;
  }

  .pc\:focus\:bg-red-transparent:focus {
    background: transparent;
  }

  .pc\:focus\:bg-red-current:focus {
    background: currentColor;
  }

  .pc\:focus\:bg-red-50:focus {
    background-color: #fef2f2;
  }

  .pc\:focus\:bg-red-100:focus {
    background-color: #fee2e2;
  }

  .pc\:focus\:bg-red-200:focus {
    background-color: #fecaca;
  }

  .pc\:focus\:bg-red-300:focus {
    background-color: #fca5a5;
  }

  .pc\:focus\:bg-red-400:focus {
    background-color: #f87171;
  }

  .pc\:focus\:bg-red-500:focus {
    background-color: #ef4444;
  }

  .pc\:focus\:bg-red-600:focus {
    background-color: #dc2626;
  }

  .pc\:focus\:bg-red-700:focus {
    background-color: #b91c1c;
  }

  .pc\:focus\:bg-red-800:focus {
    background-color: #991b1b;
  }

  .pc\:focus\:bg-red-900:focus {
    background-color: #7f1d1d;
  }

  .pc\:focus\:bg-yellow-transparent:focus {
    background: transparent;
  }

  .pc\:focus\:bg-yellow-current:focus {
    background: currentColor;
  }

  .pc\:focus\:bg-yellow-50:focus {
    background-color: #fffbeb;
  }

  .pc\:focus\:bg-yellow-100:focus {
    background-color: #fef3c7;
  }

  .pc\:focus\:bg-yellow-200:focus {
    background-color: #fde68a;
  }

  .pc\:focus\:bg-yellow-300:focus {
    background-color: #fcd34d;
  }

  .pc\:focus\:bg-yellow-400:focus {
    background-color: #fbbf24;
  }

  .pc\:focus\:bg-yellow-500:focus {
    background-color: #f59e0b;
  }

  .pc\:focus\:bg-yellow-600:focus {
    background-color: #d97706;
  }

  .pc\:focus\:bg-yellow-700:focus {
    background-color: #b45309;
  }

  .pc\:focus\:bg-yellow-800:focus {
    background-color: #92400e;
  }

  .pc\:focus\:bg-yellow-900:focus {
    background-color: #78350f;
  }

  .pc\:focus\:bg-green-transparent:focus {
    background: transparent;
  }

  .pc\:focus\:bg-green-current:focus {
    background: currentColor;
  }

  .pc\:focus\:bg-green-50:focus {
    background-color: #ecfdf5;
  }

  .pc\:focus\:bg-green-100:focus {
    background-color: #d1fae5;
  }

  .pc\:focus\:bg-green-200:focus {
    background-color: #a7f3d0;
  }

  .pc\:focus\:bg-green-300:focus {
    background-color: #6ee7b7;
  }

  .pc\:focus\:bg-green-400:focus {
    background-color: #34d399;
  }

  .pc\:focus\:bg-green-500:focus {
    background-color: #10b981;
  }

  .pc\:focus\:bg-green-600:focus {
    background-color: #059669;
  }

  .pc\:focus\:bg-green-700:focus {
    background-color: #047857;
  }

  .pc\:focus\:bg-green-800:focus {
    background-color: #065f46;
  }

  .pc\:focus\:bg-green-900:focus {
    background-color: #064e3b;
  }

  .pc\:focus\:bg-blue-transparent:focus {
    background: transparent;
  }

  .pc\:focus\:bg-blue-current:focus {
    background: currentColor;
  }

  .pc\:focus\:bg-blue-50:focus {
    background-color: #eff6ff;
  }

  .pc\:focus\:bg-blue-100:focus {
    background-color: #dbeafe;
  }

  .pc\:focus\:bg-blue-200:focus {
    background-color: #bfdbfe;
  }

  .pc\:focus\:bg-blue-300:focus {
    background-color: #93c5fd;
  }

  .pc\:focus\:bg-blue-400:focus {
    background-color: #60a5fa;
  }

  .pc\:focus\:bg-blue-500:focus {
    background-color: #3b82f6;
  }

  .pc\:focus\:bg-blue-600:focus {
    background-color: #2563eb;
  }

  .pc\:focus\:bg-blue-700:focus {
    background-color: #1d4ed8;
  }

  .pc\:focus\:bg-blue-800:focus {
    background-color: #1e40af;
  }

  .pc\:focus\:bg-blue-900:focus {
    background-color: #1e3a8a;
  }

  .pc\:focus\:bg-cyan-transparent:focus {
    background: transparent;
  }

  .pc\:focus\:bg-cyan-current:focus {
    background: currentColor;
  }

  .pc\:focus\:bg-cyan-50:focus {
    background-color: #ecfeff;
  }

  .pc\:focus\:bg-cyan-100:focus {
    background-color: #cffafe;
  }

  .pc\:focus\:bg-cyan-200:focus {
    background-color: #a5f3fc;
  }

  .pc\:focus\:bg-cyan-300:focus {
    background-color: #67e8f9;
  }

  .pc\:focus\:bg-cyan-400:focus {
    background-color: #22d3ee;
  }

  .pc\:focus\:bg-cyan-500:focus {
    background-color: #06b6d4;
  }

  .pc\:focus\:bg-cyan-600:focus {
    background-color: #0891b2;
  }

  .pc\:focus\:bg-cyan-700:focus {
    background-color: #0e7490;
  }

  .pc\:focus\:bg-cyan-800:focus {
    background-color: #155e75;
  }

  .pc\:focus\:bg-cyan-900:focus {
    background-color: #164e63;
  }

  .pc\:focus\:bg-indigo-transparent:focus {
    background: transparent;
  }

  .pc\:focus\:bg-indigo-current:focus {
    background: currentColor;
  }

  .pc\:focus\:bg-indigo-50:focus {
    background-color: #eef2ff;
  }

  .pc\:focus\:bg-indigo-100:focus {
    background-color: #e0e7ff;
  }

  .pc\:focus\:bg-indigo-200:focus {
    background-color: #c7d2fe;
  }

  .pc\:focus\:bg-indigo-300:focus {
    background-color: #a5b4fc;
  }

  .pc\:focus\:bg-indigo-400:focus {
    background-color: #818cf8;
  }

  .pc\:focus\:bg-indigo-500:focus {
    background-color: #6366f1;
  }

  .pc\:focus\:bg-indigo-600:focus {
    background-color: #4f46e5;
  }

  .pc\:focus\:bg-indigo-700:focus {
    background-color: #4338ca;
  }

  .pc\:focus\:bg-indigo-800:focus {
    background-color: #3730a3;
  }

  .pc\:focus\:bg-indigo-900:focus {
    background-color: #312e81;
  }

  .pc\:focus\:bg-purple-transparent:focus {
    background: transparent;
  }

  .pc\:focus\:bg-purple-current:focus {
    background: currentColor;
  }

  .pc\:focus\:bg-purple-50:focus {
    background-color: #f5f3ff;
  }

  .pc\:focus\:bg-purple-100:focus {
    background-color: #ede9fe;
  }

  .pc\:focus\:bg-purple-200:focus {
    background-color: #ddd6fe;
  }

  .pc\:focus\:bg-purple-300:focus {
    background-color: #c4b5fd;
  }

  .pc\:focus\:bg-purple-400:focus {
    background-color: #a78bfa;
  }

  .pc\:focus\:bg-purple-500:focus {
    background-color: #8b5cf6;
  }

  .pc\:focus\:bg-purple-600:focus {
    background-color: #7c3aed;
  }

  .pc\:focus\:bg-purple-700:focus {
    background-color: #6d28d9;
  }

  .pc\:focus\:bg-purple-800:focus {
    background-color: #5b21b6;
  }

  .pc\:focus\:bg-purple-900:focus {
    background-color: #4c1d95;
  }

  .pc\:focus\:bg-pink-transparent:focus {
    background: transparent;
  }

  .pc\:focus\:bg-pink-current:focus {
    background: currentColor;
  }

  .pc\:focus\:bg-pink-50:focus {
    background-color: #fdf2f8;
  }

  .pc\:focus\:bg-pink-100:focus {
    background-color: #fce7f3;
  }

  .pc\:focus\:bg-pink-200:focus {
    background-color: #fbcfe8;
  }

  .pc\:focus\:bg-pink-300:focus {
    background-color: #f9a8d4;
  }

  .pc\:focus\:bg-pink-400:focus {
    background-color: #f472b6;
  }

  .pc\:focus\:bg-pink-500:focus {
    background-color: #ec4899;
  }

  .pc\:focus\:bg-pink-600:focus {
    background-color: #db2777;
  }

  .pc\:focus\:bg-pink-700:focus {
    background-color: #be185d;
  }

  .pc\:focus\:bg-pink-800:focus {
    background-color: #9d174d;
  }

  .pc\:focus\:bg-pink-900:focus {
    background-color: #831843;
  }

  .pc\:disabled\:bg-transparent.is-disabled {
    background: transparent;
  }

  .pc\:disabled\:bg-none.is-disabled {
    background: none !important;
  }

  .pc\:disabled\:bg-transparent.is-disabled {
    background: transparent;
  }

  .pc\:disabled\:bg-current.is-disabled {
    background: currentColor;
  }

  .pc\:disabled\:bg-black.is-disabled,
.pc\:disabled\:bg-black:disabled {
    background-color: #000;
  }

  .pc\:disabled\:bg-white.is-disabled,
.pc\:disabled\:bg-white:disabled {
    background-color: #fff;
  }

  .pc\:disabled\:bg-primary.is-disabled,
.pc\:disabled\:bg-primary:disabled {
    background-color: #007bff;
  }

  .pc\:disabled\:bg-secondary.is-disabled,
.pc\:disabled\:bg-secondary:disabled {
    background-color: #6c757d;
  }

  .pc\:disabled\:bg-success.is-disabled,
.pc\:disabled\:bg-success:disabled {
    background-color: #28a745;
  }

  .pc\:disabled\:bg-info.is-disabled,
.pc\:disabled\:bg-info:disabled {
    background-color: #17a2b8;
  }

  .pc\:disabled\:bg-warning.is-disabled,
.pc\:disabled\:bg-warning:disabled {
    background-color: #fad733;
  }

  .pc\:disabled\:bg-danger.is-disabled,
.pc\:disabled\:bg-danger:disabled {
    background-color: #dc3545;
  }

  .pc\:disabled\:bg-light.is-disabled,
.pc\:disabled\:bg-light:disabled {
    background-color: #f8f9fa;
  }

  .pc\:disabled\:bg-dark.is-disabled,
.pc\:disabled\:bg-dark:disabled {
    background-color: #343a40;
  }

  .pc\:disabled\:bg-gray-transparent.is-disabled {
    background: transparent;
  }

  .pc\:disabled\:bg-gray-current.is-disabled {
    background: currentColor;
  }

  .pc\:disabled\:bg-gray-50.is-disabled,
.pc\:disabled\:bg-gray-50:disabled {
    background-color: #f9fafb;
  }

  .pc\:disabled\:bg-gray-100.is-disabled,
.pc\:disabled\:bg-gray-100:disabled {
    background-color: #f3f4f6;
  }

  .pc\:disabled\:bg-gray-200.is-disabled,
.pc\:disabled\:bg-gray-200:disabled {
    background-color: #e5e7eb;
  }

  .pc\:disabled\:bg-gray-300.is-disabled,
.pc\:disabled\:bg-gray-300:disabled {
    background-color: #d1d5db;
  }

  .pc\:disabled\:bg-gray-400.is-disabled,
.pc\:disabled\:bg-gray-400:disabled {
    background-color: #9ca3af;
  }

  .pc\:disabled\:bg-gray-500.is-disabled,
.pc\:disabled\:bg-gray-500:disabled {
    background-color: #6b7280;
  }

  .pc\:disabled\:bg-gray-600.is-disabled,
.pc\:disabled\:bg-gray-600:disabled {
    background-color: #4b5563;
  }

  .pc\:disabled\:bg-gray-700.is-disabled,
.pc\:disabled\:bg-gray-700:disabled {
    background-color: #374151;
  }

  .pc\:disabled\:bg-gray-800.is-disabled,
.pc\:disabled\:bg-gray-800:disabled {
    background-color: #1f2937;
  }

  .pc\:disabled\:bg-gray-900.is-disabled,
.pc\:disabled\:bg-gray-900:disabled {
    background-color: #111827;
  }

  .pc\:disabled\:bg-red-transparent.is-disabled {
    background: transparent;
  }

  .pc\:disabled\:bg-red-current.is-disabled {
    background: currentColor;
  }

  .pc\:disabled\:bg-red-50.is-disabled,
.pc\:disabled\:bg-red-50:disabled {
    background-color: #fef2f2;
  }

  .pc\:disabled\:bg-red-100.is-disabled,
.pc\:disabled\:bg-red-100:disabled {
    background-color: #fee2e2;
  }

  .pc\:disabled\:bg-red-200.is-disabled,
.pc\:disabled\:bg-red-200:disabled {
    background-color: #fecaca;
  }

  .pc\:disabled\:bg-red-300.is-disabled,
.pc\:disabled\:bg-red-300:disabled {
    background-color: #fca5a5;
  }

  .pc\:disabled\:bg-red-400.is-disabled,
.pc\:disabled\:bg-red-400:disabled {
    background-color: #f87171;
  }

  .pc\:disabled\:bg-red-500.is-disabled,
.pc\:disabled\:bg-red-500:disabled {
    background-color: #ef4444;
  }

  .pc\:disabled\:bg-red-600.is-disabled,
.pc\:disabled\:bg-red-600:disabled {
    background-color: #dc2626;
  }

  .pc\:disabled\:bg-red-700.is-disabled,
.pc\:disabled\:bg-red-700:disabled {
    background-color: #b91c1c;
  }

  .pc\:disabled\:bg-red-800.is-disabled,
.pc\:disabled\:bg-red-800:disabled {
    background-color: #991b1b;
  }

  .pc\:disabled\:bg-red-900.is-disabled,
.pc\:disabled\:bg-red-900:disabled {
    background-color: #7f1d1d;
  }

  .pc\:disabled\:bg-yellow-transparent.is-disabled {
    background: transparent;
  }

  .pc\:disabled\:bg-yellow-current.is-disabled {
    background: currentColor;
  }

  .pc\:disabled\:bg-yellow-50.is-disabled,
.pc\:disabled\:bg-yellow-50:disabled {
    background-color: #fffbeb;
  }

  .pc\:disabled\:bg-yellow-100.is-disabled,
.pc\:disabled\:bg-yellow-100:disabled {
    background-color: #fef3c7;
  }

  .pc\:disabled\:bg-yellow-200.is-disabled,
.pc\:disabled\:bg-yellow-200:disabled {
    background-color: #fde68a;
  }

  .pc\:disabled\:bg-yellow-300.is-disabled,
.pc\:disabled\:bg-yellow-300:disabled {
    background-color: #fcd34d;
  }

  .pc\:disabled\:bg-yellow-400.is-disabled,
.pc\:disabled\:bg-yellow-400:disabled {
    background-color: #fbbf24;
  }

  .pc\:disabled\:bg-yellow-500.is-disabled,
.pc\:disabled\:bg-yellow-500:disabled {
    background-color: #f59e0b;
  }

  .pc\:disabled\:bg-yellow-600.is-disabled,
.pc\:disabled\:bg-yellow-600:disabled {
    background-color: #d97706;
  }

  .pc\:disabled\:bg-yellow-700.is-disabled,
.pc\:disabled\:bg-yellow-700:disabled {
    background-color: #b45309;
  }

  .pc\:disabled\:bg-yellow-800.is-disabled,
.pc\:disabled\:bg-yellow-800:disabled {
    background-color: #92400e;
  }

  .pc\:disabled\:bg-yellow-900.is-disabled,
.pc\:disabled\:bg-yellow-900:disabled {
    background-color: #78350f;
  }

  .pc\:disabled\:bg-green-transparent.is-disabled {
    background: transparent;
  }

  .pc\:disabled\:bg-green-current.is-disabled {
    background: currentColor;
  }

  .pc\:disabled\:bg-green-50.is-disabled,
.pc\:disabled\:bg-green-50:disabled {
    background-color: #ecfdf5;
  }

  .pc\:disabled\:bg-green-100.is-disabled,
.pc\:disabled\:bg-green-100:disabled {
    background-color: #d1fae5;
  }

  .pc\:disabled\:bg-green-200.is-disabled,
.pc\:disabled\:bg-green-200:disabled {
    background-color: #a7f3d0;
  }

  .pc\:disabled\:bg-green-300.is-disabled,
.pc\:disabled\:bg-green-300:disabled {
    background-color: #6ee7b7;
  }

  .pc\:disabled\:bg-green-400.is-disabled,
.pc\:disabled\:bg-green-400:disabled {
    background-color: #34d399;
  }

  .pc\:disabled\:bg-green-500.is-disabled,
.pc\:disabled\:bg-green-500:disabled {
    background-color: #10b981;
  }

  .pc\:disabled\:bg-green-600.is-disabled,
.pc\:disabled\:bg-green-600:disabled {
    background-color: #059669;
  }

  .pc\:disabled\:bg-green-700.is-disabled,
.pc\:disabled\:bg-green-700:disabled {
    background-color: #047857;
  }

  .pc\:disabled\:bg-green-800.is-disabled,
.pc\:disabled\:bg-green-800:disabled {
    background-color: #065f46;
  }

  .pc\:disabled\:bg-green-900.is-disabled,
.pc\:disabled\:bg-green-900:disabled {
    background-color: #064e3b;
  }

  .pc\:disabled\:bg-blue-transparent.is-disabled {
    background: transparent;
  }

  .pc\:disabled\:bg-blue-current.is-disabled {
    background: currentColor;
  }

  .pc\:disabled\:bg-blue-50.is-disabled,
.pc\:disabled\:bg-blue-50:disabled {
    background-color: #eff6ff;
  }

  .pc\:disabled\:bg-blue-100.is-disabled,
.pc\:disabled\:bg-blue-100:disabled {
    background-color: #dbeafe;
  }

  .pc\:disabled\:bg-blue-200.is-disabled,
.pc\:disabled\:bg-blue-200:disabled {
    background-color: #bfdbfe;
  }

  .pc\:disabled\:bg-blue-300.is-disabled,
.pc\:disabled\:bg-blue-300:disabled {
    background-color: #93c5fd;
  }

  .pc\:disabled\:bg-blue-400.is-disabled,
.pc\:disabled\:bg-blue-400:disabled {
    background-color: #60a5fa;
  }

  .pc\:disabled\:bg-blue-500.is-disabled,
.pc\:disabled\:bg-blue-500:disabled {
    background-color: #3b82f6;
  }

  .pc\:disabled\:bg-blue-600.is-disabled,
.pc\:disabled\:bg-blue-600:disabled {
    background-color: #2563eb;
  }

  .pc\:disabled\:bg-blue-700.is-disabled,
.pc\:disabled\:bg-blue-700:disabled {
    background-color: #1d4ed8;
  }

  .pc\:disabled\:bg-blue-800.is-disabled,
.pc\:disabled\:bg-blue-800:disabled {
    background-color: #1e40af;
  }

  .pc\:disabled\:bg-blue-900.is-disabled,
.pc\:disabled\:bg-blue-900:disabled {
    background-color: #1e3a8a;
  }

  .pc\:disabled\:bg-cyan-transparent.is-disabled {
    background: transparent;
  }

  .pc\:disabled\:bg-cyan-current.is-disabled {
    background: currentColor;
  }

  .pc\:disabled\:bg-cyan-50.is-disabled,
.pc\:disabled\:bg-cyan-50:disabled {
    background-color: #ecfeff;
  }

  .pc\:disabled\:bg-cyan-100.is-disabled,
.pc\:disabled\:bg-cyan-100:disabled {
    background-color: #cffafe;
  }

  .pc\:disabled\:bg-cyan-200.is-disabled,
.pc\:disabled\:bg-cyan-200:disabled {
    background-color: #a5f3fc;
  }

  .pc\:disabled\:bg-cyan-300.is-disabled,
.pc\:disabled\:bg-cyan-300:disabled {
    background-color: #67e8f9;
  }

  .pc\:disabled\:bg-cyan-400.is-disabled,
.pc\:disabled\:bg-cyan-400:disabled {
    background-color: #22d3ee;
  }

  .pc\:disabled\:bg-cyan-500.is-disabled,
.pc\:disabled\:bg-cyan-500:disabled {
    background-color: #06b6d4;
  }

  .pc\:disabled\:bg-cyan-600.is-disabled,
.pc\:disabled\:bg-cyan-600:disabled {
    background-color: #0891b2;
  }

  .pc\:disabled\:bg-cyan-700.is-disabled,
.pc\:disabled\:bg-cyan-700:disabled {
    background-color: #0e7490;
  }

  .pc\:disabled\:bg-cyan-800.is-disabled,
.pc\:disabled\:bg-cyan-800:disabled {
    background-color: #155e75;
  }

  .pc\:disabled\:bg-cyan-900.is-disabled,
.pc\:disabled\:bg-cyan-900:disabled {
    background-color: #164e63;
  }

  .pc\:disabled\:bg-indigo-transparent.is-disabled {
    background: transparent;
  }

  .pc\:disabled\:bg-indigo-current.is-disabled {
    background: currentColor;
  }

  .pc\:disabled\:bg-indigo-50.is-disabled,
.pc\:disabled\:bg-indigo-50:disabled {
    background-color: #eef2ff;
  }

  .pc\:disabled\:bg-indigo-100.is-disabled,
.pc\:disabled\:bg-indigo-100:disabled {
    background-color: #e0e7ff;
  }

  .pc\:disabled\:bg-indigo-200.is-disabled,
.pc\:disabled\:bg-indigo-200:disabled {
    background-color: #c7d2fe;
  }

  .pc\:disabled\:bg-indigo-300.is-disabled,
.pc\:disabled\:bg-indigo-300:disabled {
    background-color: #a5b4fc;
  }

  .pc\:disabled\:bg-indigo-400.is-disabled,
.pc\:disabled\:bg-indigo-400:disabled {
    background-color: #818cf8;
  }

  .pc\:disabled\:bg-indigo-500.is-disabled,
.pc\:disabled\:bg-indigo-500:disabled {
    background-color: #6366f1;
  }

  .pc\:disabled\:bg-indigo-600.is-disabled,
.pc\:disabled\:bg-indigo-600:disabled {
    background-color: #4f46e5;
  }

  .pc\:disabled\:bg-indigo-700.is-disabled,
.pc\:disabled\:bg-indigo-700:disabled {
    background-color: #4338ca;
  }

  .pc\:disabled\:bg-indigo-800.is-disabled,
.pc\:disabled\:bg-indigo-800:disabled {
    background-color: #3730a3;
  }

  .pc\:disabled\:bg-indigo-900.is-disabled,
.pc\:disabled\:bg-indigo-900:disabled {
    background-color: #312e81;
  }

  .pc\:disabled\:bg-purple-transparent.is-disabled {
    background: transparent;
  }

  .pc\:disabled\:bg-purple-current.is-disabled {
    background: currentColor;
  }

  .pc\:disabled\:bg-purple-50.is-disabled,
.pc\:disabled\:bg-purple-50:disabled {
    background-color: #f5f3ff;
  }

  .pc\:disabled\:bg-purple-100.is-disabled,
.pc\:disabled\:bg-purple-100:disabled {
    background-color: #ede9fe;
  }

  .pc\:disabled\:bg-purple-200.is-disabled,
.pc\:disabled\:bg-purple-200:disabled {
    background-color: #ddd6fe;
  }

  .pc\:disabled\:bg-purple-300.is-disabled,
.pc\:disabled\:bg-purple-300:disabled {
    background-color: #c4b5fd;
  }

  .pc\:disabled\:bg-purple-400.is-disabled,
.pc\:disabled\:bg-purple-400:disabled {
    background-color: #a78bfa;
  }

  .pc\:disabled\:bg-purple-500.is-disabled,
.pc\:disabled\:bg-purple-500:disabled {
    background-color: #8b5cf6;
  }

  .pc\:disabled\:bg-purple-600.is-disabled,
.pc\:disabled\:bg-purple-600:disabled {
    background-color: #7c3aed;
  }

  .pc\:disabled\:bg-purple-700.is-disabled,
.pc\:disabled\:bg-purple-700:disabled {
    background-color: #6d28d9;
  }

  .pc\:disabled\:bg-purple-800.is-disabled,
.pc\:disabled\:bg-purple-800:disabled {
    background-color: #5b21b6;
  }

  .pc\:disabled\:bg-purple-900.is-disabled,
.pc\:disabled\:bg-purple-900:disabled {
    background-color: #4c1d95;
  }

  .pc\:disabled\:bg-pink-transparent.is-disabled {
    background: transparent;
  }

  .pc\:disabled\:bg-pink-current.is-disabled {
    background: currentColor;
  }

  .pc\:disabled\:bg-pink-50.is-disabled,
.pc\:disabled\:bg-pink-50:disabled {
    background-color: #fdf2f8;
  }

  .pc\:disabled\:bg-pink-100.is-disabled,
.pc\:disabled\:bg-pink-100:disabled {
    background-color: #fce7f3;
  }

  .pc\:disabled\:bg-pink-200.is-disabled,
.pc\:disabled\:bg-pink-200:disabled {
    background-color: #fbcfe8;
  }

  .pc\:disabled\:bg-pink-300.is-disabled,
.pc\:disabled\:bg-pink-300:disabled {
    background-color: #f9a8d4;
  }

  .pc\:disabled\:bg-pink-400.is-disabled,
.pc\:disabled\:bg-pink-400:disabled {
    background-color: #f472b6;
  }

  .pc\:disabled\:bg-pink-500.is-disabled,
.pc\:disabled\:bg-pink-500:disabled {
    background-color: #ec4899;
  }

  .pc\:disabled\:bg-pink-600.is-disabled,
.pc\:disabled\:bg-pink-600:disabled {
    background-color: #db2777;
  }

  .pc\:disabled\:bg-pink-700.is-disabled,
.pc\:disabled\:bg-pink-700:disabled {
    background-color: #be185d;
  }

  .pc\:disabled\:bg-pink-800.is-disabled,
.pc\:disabled\:bg-pink-800:disabled {
    background-color: #9d174d;
  }

  .pc\:disabled\:bg-pink-900.is-disabled,
.pc\:disabled\:bg-pink-900:disabled {
    background-color: #831843;
  }

  .group:hover .pc\:group-hover\:bg-transparent {
    background: transparent;
  }

  .group:hover .pc\:group-hover\:bg-none {
    background: none !important;
  }

  .group:hover .pc\:group-hover\:bg-transparent {
    background: transparent;
  }

  .group:hover .pc\:group-hover\:bg-current {
    background: currentColor;
  }

  .group:hover .pc\:group-hover\:bg-black {
    background-color: #000;
  }

  .group:hover .pc\:group-hover\:bg-white {
    background-color: #fff;
  }

  .group:hover .pc\:group-hover\:bg-primary {
    background-color: #007bff;
  }

  .group:hover .pc\:group-hover\:bg-secondary {
    background-color: #6c757d;
  }

  .group:hover .pc\:group-hover\:bg-success {
    background-color: #28a745;
  }

  .group:hover .pc\:group-hover\:bg-info {
    background-color: #17a2b8;
  }

  .group:hover .pc\:group-hover\:bg-warning {
    background-color: #fad733;
  }

  .group:hover .pc\:group-hover\:bg-danger {
    background-color: #dc3545;
  }

  .group:hover .pc\:group-hover\:bg-light {
    background-color: #f8f9fa;
  }

  .group:hover .pc\:group-hover\:bg-dark {
    background-color: #343a40;
  }

  .group:hover .pc\:group-hover\:bg-gray-transparent {
    background: transparent;
  }

  .group:hover .pc\:group-hover\:bg-gray-current {
    background: currentColor;
  }

  .group:hover .pc\:group-hover\:bg-gray-50 {
    background-color: #f9fafb;
  }

  .group:hover .pc\:group-hover\:bg-gray-100 {
    background-color: #f3f4f6;
  }

  .group:hover .pc\:group-hover\:bg-gray-200 {
    background-color: #e5e7eb;
  }

  .group:hover .pc\:group-hover\:bg-gray-300 {
    background-color: #d1d5db;
  }

  .group:hover .pc\:group-hover\:bg-gray-400 {
    background-color: #9ca3af;
  }

  .group:hover .pc\:group-hover\:bg-gray-500 {
    background-color: #6b7280;
  }

  .group:hover .pc\:group-hover\:bg-gray-600 {
    background-color: #4b5563;
  }

  .group:hover .pc\:group-hover\:bg-gray-700 {
    background-color: #374151;
  }

  .group:hover .pc\:group-hover\:bg-gray-800 {
    background-color: #1f2937;
  }

  .group:hover .pc\:group-hover\:bg-gray-900 {
    background-color: #111827;
  }

  .group:hover .pc\:group-hover\:bg-red-transparent {
    background: transparent;
  }

  .group:hover .pc\:group-hover\:bg-red-current {
    background: currentColor;
  }

  .group:hover .pc\:group-hover\:bg-red-50 {
    background-color: #fef2f2;
  }

  .group:hover .pc\:group-hover\:bg-red-100 {
    background-color: #fee2e2;
  }

  .group:hover .pc\:group-hover\:bg-red-200 {
    background-color: #fecaca;
  }

  .group:hover .pc\:group-hover\:bg-red-300 {
    background-color: #fca5a5;
  }

  .group:hover .pc\:group-hover\:bg-red-400 {
    background-color: #f87171;
  }

  .group:hover .pc\:group-hover\:bg-red-500 {
    background-color: #ef4444;
  }

  .group:hover .pc\:group-hover\:bg-red-600 {
    background-color: #dc2626;
  }

  .group:hover .pc\:group-hover\:bg-red-700 {
    background-color: #b91c1c;
  }

  .group:hover .pc\:group-hover\:bg-red-800 {
    background-color: #991b1b;
  }

  .group:hover .pc\:group-hover\:bg-red-900 {
    background-color: #7f1d1d;
  }

  .group:hover .pc\:group-hover\:bg-yellow-transparent {
    background: transparent;
  }

  .group:hover .pc\:group-hover\:bg-yellow-current {
    background: currentColor;
  }

  .group:hover .pc\:group-hover\:bg-yellow-50 {
    background-color: #fffbeb;
  }

  .group:hover .pc\:group-hover\:bg-yellow-100 {
    background-color: #fef3c7;
  }

  .group:hover .pc\:group-hover\:bg-yellow-200 {
    background-color: #fde68a;
  }

  .group:hover .pc\:group-hover\:bg-yellow-300 {
    background-color: #fcd34d;
  }

  .group:hover .pc\:group-hover\:bg-yellow-400 {
    background-color: #fbbf24;
  }

  .group:hover .pc\:group-hover\:bg-yellow-500 {
    background-color: #f59e0b;
  }

  .group:hover .pc\:group-hover\:bg-yellow-600 {
    background-color: #d97706;
  }

  .group:hover .pc\:group-hover\:bg-yellow-700 {
    background-color: #b45309;
  }

  .group:hover .pc\:group-hover\:bg-yellow-800 {
    background-color: #92400e;
  }

  .group:hover .pc\:group-hover\:bg-yellow-900 {
    background-color: #78350f;
  }

  .group:hover .pc\:group-hover\:bg-green-transparent {
    background: transparent;
  }

  .group:hover .pc\:group-hover\:bg-green-current {
    background: currentColor;
  }

  .group:hover .pc\:group-hover\:bg-green-50 {
    background-color: #ecfdf5;
  }

  .group:hover .pc\:group-hover\:bg-green-100 {
    background-color: #d1fae5;
  }

  .group:hover .pc\:group-hover\:bg-green-200 {
    background-color: #a7f3d0;
  }

  .group:hover .pc\:group-hover\:bg-green-300 {
    background-color: #6ee7b7;
  }

  .group:hover .pc\:group-hover\:bg-green-400 {
    background-color: #34d399;
  }

  .group:hover .pc\:group-hover\:bg-green-500 {
    background-color: #10b981;
  }

  .group:hover .pc\:group-hover\:bg-green-600 {
    background-color: #059669;
  }

  .group:hover .pc\:group-hover\:bg-green-700 {
    background-color: #047857;
  }

  .group:hover .pc\:group-hover\:bg-green-800 {
    background-color: #065f46;
  }

  .group:hover .pc\:group-hover\:bg-green-900 {
    background-color: #064e3b;
  }

  .group:hover .pc\:group-hover\:bg-blue-transparent {
    background: transparent;
  }

  .group:hover .pc\:group-hover\:bg-blue-current {
    background: currentColor;
  }

  .group:hover .pc\:group-hover\:bg-blue-50 {
    background-color: #eff6ff;
  }

  .group:hover .pc\:group-hover\:bg-blue-100 {
    background-color: #dbeafe;
  }

  .group:hover .pc\:group-hover\:bg-blue-200 {
    background-color: #bfdbfe;
  }

  .group:hover .pc\:group-hover\:bg-blue-300 {
    background-color: #93c5fd;
  }

  .group:hover .pc\:group-hover\:bg-blue-400 {
    background-color: #60a5fa;
  }

  .group:hover .pc\:group-hover\:bg-blue-500 {
    background-color: #3b82f6;
  }

  .group:hover .pc\:group-hover\:bg-blue-600 {
    background-color: #2563eb;
  }

  .group:hover .pc\:group-hover\:bg-blue-700 {
    background-color: #1d4ed8;
  }

  .group:hover .pc\:group-hover\:bg-blue-800 {
    background-color: #1e40af;
  }

  .group:hover .pc\:group-hover\:bg-blue-900 {
    background-color: #1e3a8a;
  }

  .group:hover .pc\:group-hover\:bg-cyan-transparent {
    background: transparent;
  }

  .group:hover .pc\:group-hover\:bg-cyan-current {
    background: currentColor;
  }

  .group:hover .pc\:group-hover\:bg-cyan-50 {
    background-color: #ecfeff;
  }

  .group:hover .pc\:group-hover\:bg-cyan-100 {
    background-color: #cffafe;
  }

  .group:hover .pc\:group-hover\:bg-cyan-200 {
    background-color: #a5f3fc;
  }

  .group:hover .pc\:group-hover\:bg-cyan-300 {
    background-color: #67e8f9;
  }

  .group:hover .pc\:group-hover\:bg-cyan-400 {
    background-color: #22d3ee;
  }

  .group:hover .pc\:group-hover\:bg-cyan-500 {
    background-color: #06b6d4;
  }

  .group:hover .pc\:group-hover\:bg-cyan-600 {
    background-color: #0891b2;
  }

  .group:hover .pc\:group-hover\:bg-cyan-700 {
    background-color: #0e7490;
  }

  .group:hover .pc\:group-hover\:bg-cyan-800 {
    background-color: #155e75;
  }

  .group:hover .pc\:group-hover\:bg-cyan-900 {
    background-color: #164e63;
  }

  .group:hover .pc\:group-hover\:bg-indigo-transparent {
    background: transparent;
  }

  .group:hover .pc\:group-hover\:bg-indigo-current {
    background: currentColor;
  }

  .group:hover .pc\:group-hover\:bg-indigo-50 {
    background-color: #eef2ff;
  }

  .group:hover .pc\:group-hover\:bg-indigo-100 {
    background-color: #e0e7ff;
  }

  .group:hover .pc\:group-hover\:bg-indigo-200 {
    background-color: #c7d2fe;
  }

  .group:hover .pc\:group-hover\:bg-indigo-300 {
    background-color: #a5b4fc;
  }

  .group:hover .pc\:group-hover\:bg-indigo-400 {
    background-color: #818cf8;
  }

  .group:hover .pc\:group-hover\:bg-indigo-500 {
    background-color: #6366f1;
  }

  .group:hover .pc\:group-hover\:bg-indigo-600 {
    background-color: #4f46e5;
  }

  .group:hover .pc\:group-hover\:bg-indigo-700 {
    background-color: #4338ca;
  }

  .group:hover .pc\:group-hover\:bg-indigo-800 {
    background-color: #3730a3;
  }

  .group:hover .pc\:group-hover\:bg-indigo-900 {
    background-color: #312e81;
  }

  .group:hover .pc\:group-hover\:bg-purple-transparent {
    background: transparent;
  }

  .group:hover .pc\:group-hover\:bg-purple-current {
    background: currentColor;
  }

  .group:hover .pc\:group-hover\:bg-purple-50 {
    background-color: #f5f3ff;
  }

  .group:hover .pc\:group-hover\:bg-purple-100 {
    background-color: #ede9fe;
  }

  .group:hover .pc\:group-hover\:bg-purple-200 {
    background-color: #ddd6fe;
  }

  .group:hover .pc\:group-hover\:bg-purple-300 {
    background-color: #c4b5fd;
  }

  .group:hover .pc\:group-hover\:bg-purple-400 {
    background-color: #a78bfa;
  }

  .group:hover .pc\:group-hover\:bg-purple-500 {
    background-color: #8b5cf6;
  }

  .group:hover .pc\:group-hover\:bg-purple-600 {
    background-color: #7c3aed;
  }

  .group:hover .pc\:group-hover\:bg-purple-700 {
    background-color: #6d28d9;
  }

  .group:hover .pc\:group-hover\:bg-purple-800 {
    background-color: #5b21b6;
  }

  .group:hover .pc\:group-hover\:bg-purple-900 {
    background-color: #4c1d95;
  }

  .group:hover .pc\:group-hover\:bg-pink-transparent {
    background: transparent;
  }

  .group:hover .pc\:group-hover\:bg-pink-current {
    background: currentColor;
  }

  .group:hover .pc\:group-hover\:bg-pink-50 {
    background-color: #fdf2f8;
  }

  .group:hover .pc\:group-hover\:bg-pink-100 {
    background-color: #fce7f3;
  }

  .group:hover .pc\:group-hover\:bg-pink-200 {
    background-color: #fbcfe8;
  }

  .group:hover .pc\:group-hover\:bg-pink-300 {
    background-color: #f9a8d4;
  }

  .group:hover .pc\:group-hover\:bg-pink-400 {
    background-color: #f472b6;
  }

  .group:hover .pc\:group-hover\:bg-pink-500 {
    background-color: #ec4899;
  }

  .group:hover .pc\:group-hover\:bg-pink-600 {
    background-color: #db2777;
  }

  .group:hover .pc\:group-hover\:bg-pink-700 {
    background-color: #be185d;
  }

  .group:hover .pc\:group-hover\:bg-pink-800 {
    background-color: #9d174d;
  }

  .group:hover .pc\:group-hover\:bg-pink-900 {
    background-color: #831843;
  }
}
/*!markdown

---
title: 边框颜色
---

| Class       | Properties               |
| ----------- | ------------------------ |
| border-black | border-color: #000 |
| border-white | border-color: #fff |
| border-primary | border-color: #007bff |
| border-secondary | border-color: #6c757d |
| border-success | border-color: #28a745 |
| border-info | border-color: #17a2b8 |
| border-warning | border-color: #28a745 |
| border-danger | border-color: #dc3545 |
| border-light | border-color: #f8f9fa |
| border-dark | border-color: #343a40 |
| border-gray-50 | border-color: #f9fafb |
| border-gray-100 | border-color: #f3f4f6 |
| border-gray-200 | border-color: #e5e7eb |
| border-gray-300 | border-color: #d1d5db |
| border-gray-400 | border-color: #9ca3af |
| border-gray-500 | border-color: #6b7280 |
| border-gray-600 | border-color: #4b5563 |
| border-gray-700 | border-color: #374151 |
| border-gray-800 | border-color: #1f2937 |
| border-gray-900 | border-color: #111827 |
| border-red-50 | border-color: #fef2f2 |
| border-red-100 | border-color: #fee2e2 |
| border-red-200 | border-color: #fecaca |
| border-red-300 | border-color: #fca5a5 |
| border-red-400 | border-color: #f87171 |
| border-red-500 | border-color: #ef4444 |
| border-red-600 | border-color: #dc2626 |
| border-red-700 | border-color: #b91c1c |
| border-red-800 | border-color: #991b1b |
| border-red-900 | border-color: #7f1d1d |
| border-yellow-50 | border-color: #fffbeb |
| border-yellow-100 | border-color: #fef3c7 |
| border-yellow-200 | border-color: #fde68a |
| border-yellow-300 | border-color: #fcd34d |
| border-yellow-400 | border-color: #fbbf24 |
| border-yellow-500 | border-color: #f59e0b |
| border-yellow-600 | border-color: #d97706 |
| border-yellow-700 | border-color: #b45309 |
| border-yellow-800 | border-color: #92400e |
| border-yellow-900 | border-color: #78350f |
| border-green-50 | border-color: #ecfdf5 |
| border-green-100 | border-color: #d1fae5 |
| border-green-200 | border-color: #a7f3d0 |
| border-green-300 | border-color: #6ee7b7 |
| border-green-400 | border-color: #34d399 |
| border-green-500 | border-color: #10b981 |
| border-green-600 | border-color: #059669 |
| border-green-700 | border-color: #047857 |
| border-green-800 | border-color: #065f46 |
| border-green-900 | border-color: #064e3b |
| border-blue-50 | border-color: #eff6ff |
| border-blue-100 | border-color: #dbeafe |
| border-blue-200 | border-color: #bfdbfe |
| border-blue-300 | border-color: #93c5fd |
| border-blue-400 | border-color: #60a5fa |
| border-blue-500 | border-color: #3b82f6 |
| border-blue-600 | border-color: #2563eb |
| border-blue-700 | border-color: #1d4ed8 |
| border-blue-800 | border-color: #1e40af |
| border-blue-900 | border-color: #1e3a8a |
| border-cyan-50 | border-color: #ecfeff |
| border-cyan-100 | border-color: #cffafe |
| border-cyan-200 | border-color: #a5f3fc |
| border-cyan-300 | border-color: #67e8f9 |
| border-cyan-400 | border-color: #22d3ee |
| border-cyan-500 | border-color: #06b6d4 |
| border-cyan-600 | border-color: #0891b2 |
| border-cyan-700 | border-color: #0e7490 |
| border-cyan-800 | border-color: #155e75 |
| border-cyan-900 | border-color: #164e63 |
| border-indigo-50 | border-color: #eef2ff |
| border-indigo-100 | border-color: #e0e7ff |
| border-indigo-200 | border-color: #c7d2fe |
| border-indigo-300 | border-color: #a5b4fc |
| border-indigo-400 | border-color: #818cf8 |
| border-indigo-500 | border-color: #6366f1 |
| border-indigo-600 | border-color: #4f46e5 |
| border-indigo-700 | border-color: #4338ca |
| border-indigo-800 | border-color: #3730a3 |
| border-indigo-900 | border-color: #312e81 |
| border-purple-50 | border-color: #f5f3ff |
| border-purple-100 | border-color: #ede9fe |
| border-purple-200 | border-color: #ddd6fe |
| border-purple-300 | border-color: #c4b5fd |
| border-purple-400 | border-color: #a78bfa |
| border-purple-500 | border-color: #8b5cf6 |
| border-purple-600 | border-color: #7c3aed |
| border-purple-700 | border-color: #6d28d9 |
| border-purple-800 | border-color: #5b21b6 |
| border-purple-900 | border-color: #4c1d95 |
| border-pink-50 | border-color: #fdf2f8 |
| border-pink-100 | border-color: #fce7f3 |
| border-pink-200 | border-color: #fbcfe8 |
| border-pink-300 | border-color: #f9a8d4 |
| border-pink-400 | border-color: #f472b6 |
| border-pink-500 | border-color: #ec4899 |
| border-pink-600 | border-color: #db2777 |
| border-pink-700 | border-color: #be185d |
| border-pink-800 | border-color: #9d174d |
| border-pink-900 | border-color: #831843 |


还有 hover、active、focus、disabled 扩展，比如 `hover:border-black`

*/
.border-black {
  border-color: #000;
}

.border-white {
  border-color: #fff;
}

.border-primary {
  border-color: #007bff;
}

.border-secondary {
  border-color: #6c757d;
}

.border-success {
  border-color: #28a745;
}

.border-info {
  border-color: #17a2b8;
}

.border-warning {
  border-color: #fad733;
}

.border-danger {
  border-color: #dc3545;
}

.border-light {
  border-color: #f8f9fa;
}

.border-dark {
  border-color: #343a40;
}

.border-gray-50 {
  border-color: #f9fafb;
}

.border-gray-100 {
  border-color: #f3f4f6;
}

.border-gray-200 {
  border-color: #e5e7eb;
}

.border-gray-300 {
  border-color: #d1d5db;
}

.border-gray-400 {
  border-color: #9ca3af;
}

.border-gray-500 {
  border-color: #6b7280;
}

.border-gray-600 {
  border-color: #4b5563;
}

.border-gray-700 {
  border-color: #374151;
}

.border-gray-800 {
  border-color: #1f2937;
}

.border-gray-900 {
  border-color: #111827;
}

.border-red-50 {
  border-color: #fef2f2;
}

.border-red-100 {
  border-color: #fee2e2;
}

.border-red-200 {
  border-color: #fecaca;
}

.border-red-300 {
  border-color: #fca5a5;
}

.border-red-400 {
  border-color: #f87171;
}

.border-red-500 {
  border-color: #ef4444;
}

.border-red-600 {
  border-color: #dc2626;
}

.border-red-700 {
  border-color: #b91c1c;
}

.border-red-800 {
  border-color: #991b1b;
}

.border-red-900 {
  border-color: #7f1d1d;
}

.border-yellow-50 {
  border-color: #fffbeb;
}

.border-yellow-100 {
  border-color: #fef3c7;
}

.border-yellow-200 {
  border-color: #fde68a;
}

.border-yellow-300 {
  border-color: #fcd34d;
}

.border-yellow-400 {
  border-color: #fbbf24;
}

.border-yellow-500 {
  border-color: #f59e0b;
}

.border-yellow-600 {
  border-color: #d97706;
}

.border-yellow-700 {
  border-color: #b45309;
}

.border-yellow-800 {
  border-color: #92400e;
}

.border-yellow-900 {
  border-color: #78350f;
}

.border-green-50 {
  border-color: #ecfdf5;
}

.border-green-100 {
  border-color: #d1fae5;
}

.border-green-200 {
  border-color: #a7f3d0;
}

.border-green-300 {
  border-color: #6ee7b7;
}

.border-green-400 {
  border-color: #34d399;
}

.border-green-500 {
  border-color: #10b981;
}

.border-green-600 {
  border-color: #059669;
}

.border-green-700 {
  border-color: #047857;
}

.border-green-800 {
  border-color: #065f46;
}

.border-green-900 {
  border-color: #064e3b;
}

.border-blue-50 {
  border-color: #eff6ff;
}

.border-blue-100 {
  border-color: #dbeafe;
}

.border-blue-200 {
  border-color: #bfdbfe;
}

.border-blue-300 {
  border-color: #93c5fd;
}

.border-blue-400 {
  border-color: #60a5fa;
}

.border-blue-500 {
  border-color: #3b82f6;
}

.border-blue-600 {
  border-color: #2563eb;
}

.border-blue-700 {
  border-color: #1d4ed8;
}

.border-blue-800 {
  border-color: #1e40af;
}

.border-blue-900 {
  border-color: #1e3a8a;
}

.border-cyan-50 {
  border-color: #ecfeff;
}

.border-cyan-100 {
  border-color: #cffafe;
}

.border-cyan-200 {
  border-color: #a5f3fc;
}

.border-cyan-300 {
  border-color: #67e8f9;
}

.border-cyan-400 {
  border-color: #22d3ee;
}

.border-cyan-500 {
  border-color: #06b6d4;
}

.border-cyan-600 {
  border-color: #0891b2;
}

.border-cyan-700 {
  border-color: #0e7490;
}

.border-cyan-800 {
  border-color: #155e75;
}

.border-cyan-900 {
  border-color: #164e63;
}

.border-indigo-50 {
  border-color: #eef2ff;
}

.border-indigo-100 {
  border-color: #e0e7ff;
}

.border-indigo-200 {
  border-color: #c7d2fe;
}

.border-indigo-300 {
  border-color: #a5b4fc;
}

.border-indigo-400 {
  border-color: #818cf8;
}

.border-indigo-500 {
  border-color: #6366f1;
}

.border-indigo-600 {
  border-color: #4f46e5;
}

.border-indigo-700 {
  border-color: #4338ca;
}

.border-indigo-800 {
  border-color: #3730a3;
}

.border-indigo-900 {
  border-color: #312e81;
}

.border-purple-50 {
  border-color: #f5f3ff;
}

.border-purple-100 {
  border-color: #ede9fe;
}

.border-purple-200 {
  border-color: #ddd6fe;
}

.border-purple-300 {
  border-color: #c4b5fd;
}

.border-purple-400 {
  border-color: #a78bfa;
}

.border-purple-500 {
  border-color: #8b5cf6;
}

.border-purple-600 {
  border-color: #7c3aed;
}

.border-purple-700 {
  border-color: #6d28d9;
}

.border-purple-800 {
  border-color: #5b21b6;
}

.border-purple-900 {
  border-color: #4c1d95;
}

.border-pink-50 {
  border-color: #fdf2f8;
}

.border-pink-100 {
  border-color: #fce7f3;
}

.border-pink-200 {
  border-color: #fbcfe8;
}

.border-pink-300 {
  border-color: #f9a8d4;
}

.border-pink-400 {
  border-color: #f472b6;
}

.border-pink-500 {
  border-color: #ec4899;
}

.border-pink-600 {
  border-color: #db2777;
}

.border-pink-700 {
  border-color: #be185d;
}

.border-pink-800 {
  border-color: #9d174d;
}

.border-pink-900 {
  border-color: #831843;
}

.hover\:border-black:hover {
  border-color: #000;
}

.hover\:border-white:hover {
  border-color: #fff;
}

.hover\:border-primary:hover {
  border-color: #007bff;
}

.hover\:border-secondary:hover {
  border-color: #6c757d;
}

.hover\:border-success:hover {
  border-color: #28a745;
}

.hover\:border-info:hover {
  border-color: #17a2b8;
}

.hover\:border-warning:hover {
  border-color: #fad733;
}

.hover\:border-danger:hover {
  border-color: #dc3545;
}

.hover\:border-light:hover {
  border-color: #f8f9fa;
}

.hover\:border-dark:hover {
  border-color: #343a40;
}

.hover\:border-gray-50:hover {
  border-color: #f9fafb;
}

.hover\:border-gray-100:hover {
  border-color: #f3f4f6;
}

.hover\:border-gray-200:hover {
  border-color: #e5e7eb;
}

.hover\:border-gray-300:hover {
  border-color: #d1d5db;
}

.hover\:border-gray-400:hover {
  border-color: #9ca3af;
}

.hover\:border-gray-500:hover {
  border-color: #6b7280;
}

.hover\:border-gray-600:hover {
  border-color: #4b5563;
}

.hover\:border-gray-700:hover {
  border-color: #374151;
}

.hover\:border-gray-800:hover {
  border-color: #1f2937;
}

.hover\:border-gray-900:hover {
  border-color: #111827;
}

.hover\:border-red-50:hover {
  border-color: #fef2f2;
}

.hover\:border-red-100:hover {
  border-color: #fee2e2;
}

.hover\:border-red-200:hover {
  border-color: #fecaca;
}

.hover\:border-red-300:hover {
  border-color: #fca5a5;
}

.hover\:border-red-400:hover {
  border-color: #f87171;
}

.hover\:border-red-500:hover {
  border-color: #ef4444;
}

.hover\:border-red-600:hover {
  border-color: #dc2626;
}

.hover\:border-red-700:hover {
  border-color: #b91c1c;
}

.hover\:border-red-800:hover {
  border-color: #991b1b;
}

.hover\:border-red-900:hover {
  border-color: #7f1d1d;
}

.hover\:border-yellow-50:hover {
  border-color: #fffbeb;
}

.hover\:border-yellow-100:hover {
  border-color: #fef3c7;
}

.hover\:border-yellow-200:hover {
  border-color: #fde68a;
}

.hover\:border-yellow-300:hover {
  border-color: #fcd34d;
}

.hover\:border-yellow-400:hover {
  border-color: #fbbf24;
}

.hover\:border-yellow-500:hover {
  border-color: #f59e0b;
}

.hover\:border-yellow-600:hover {
  border-color: #d97706;
}

.hover\:border-yellow-700:hover {
  border-color: #b45309;
}

.hover\:border-yellow-800:hover {
  border-color: #92400e;
}

.hover\:border-yellow-900:hover {
  border-color: #78350f;
}

.hover\:border-green-50:hover {
  border-color: #ecfdf5;
}

.hover\:border-green-100:hover {
  border-color: #d1fae5;
}

.hover\:border-green-200:hover {
  border-color: #a7f3d0;
}

.hover\:border-green-300:hover {
  border-color: #6ee7b7;
}

.hover\:border-green-400:hover {
  border-color: #34d399;
}

.hover\:border-green-500:hover {
  border-color: #10b981;
}

.hover\:border-green-600:hover {
  border-color: #059669;
}

.hover\:border-green-700:hover {
  border-color: #047857;
}

.hover\:border-green-800:hover {
  border-color: #065f46;
}

.hover\:border-green-900:hover {
  border-color: #064e3b;
}

.hover\:border-blue-50:hover {
  border-color: #eff6ff;
}

.hover\:border-blue-100:hover {
  border-color: #dbeafe;
}

.hover\:border-blue-200:hover {
  border-color: #bfdbfe;
}

.hover\:border-blue-300:hover {
  border-color: #93c5fd;
}

.hover\:border-blue-400:hover {
  border-color: #60a5fa;
}

.hover\:border-blue-500:hover {
  border-color: #3b82f6;
}

.hover\:border-blue-600:hover {
  border-color: #2563eb;
}

.hover\:border-blue-700:hover {
  border-color: #1d4ed8;
}

.hover\:border-blue-800:hover {
  border-color: #1e40af;
}

.hover\:border-blue-900:hover {
  border-color: #1e3a8a;
}

.hover\:border-cyan-50:hover {
  border-color: #ecfeff;
}

.hover\:border-cyan-100:hover {
  border-color: #cffafe;
}

.hover\:border-cyan-200:hover {
  border-color: #a5f3fc;
}

.hover\:border-cyan-300:hover {
  border-color: #67e8f9;
}

.hover\:border-cyan-400:hover {
  border-color: #22d3ee;
}

.hover\:border-cyan-500:hover {
  border-color: #06b6d4;
}

.hover\:border-cyan-600:hover {
  border-color: #0891b2;
}

.hover\:border-cyan-700:hover {
  border-color: #0e7490;
}

.hover\:border-cyan-800:hover {
  border-color: #155e75;
}

.hover\:border-cyan-900:hover {
  border-color: #164e63;
}

.hover\:border-indigo-50:hover {
  border-color: #eef2ff;
}

.hover\:border-indigo-100:hover {
  border-color: #e0e7ff;
}

.hover\:border-indigo-200:hover {
  border-color: #c7d2fe;
}

.hover\:border-indigo-300:hover {
  border-color: #a5b4fc;
}

.hover\:border-indigo-400:hover {
  border-color: #818cf8;
}

.hover\:border-indigo-500:hover {
  border-color: #6366f1;
}

.hover\:border-indigo-600:hover {
  border-color: #4f46e5;
}

.hover\:border-indigo-700:hover {
  border-color: #4338ca;
}

.hover\:border-indigo-800:hover {
  border-color: #3730a3;
}

.hover\:border-indigo-900:hover {
  border-color: #312e81;
}

.hover\:border-purple-50:hover {
  border-color: #f5f3ff;
}

.hover\:border-purple-100:hover {
  border-color: #ede9fe;
}

.hover\:border-purple-200:hover {
  border-color: #ddd6fe;
}

.hover\:border-purple-300:hover {
  border-color: #c4b5fd;
}

.hover\:border-purple-400:hover {
  border-color: #a78bfa;
}

.hover\:border-purple-500:hover {
  border-color: #8b5cf6;
}

.hover\:border-purple-600:hover {
  border-color: #7c3aed;
}

.hover\:border-purple-700:hover {
  border-color: #6d28d9;
}

.hover\:border-purple-800:hover {
  border-color: #5b21b6;
}

.hover\:border-purple-900:hover {
  border-color: #4c1d95;
}

.hover\:border-pink-50:hover {
  border-color: #fdf2f8;
}

.hover\:border-pink-100:hover {
  border-color: #fce7f3;
}

.hover\:border-pink-200:hover {
  border-color: #fbcfe8;
}

.hover\:border-pink-300:hover {
  border-color: #f9a8d4;
}

.hover\:border-pink-400:hover {
  border-color: #f472b6;
}

.hover\:border-pink-500:hover {
  border-color: #ec4899;
}

.hover\:border-pink-600:hover {
  border-color: #db2777;
}

.hover\:border-pink-700:hover {
  border-color: #be185d;
}

.hover\:border-pink-800:hover {
  border-color: #9d174d;
}

.hover\:border-pink-900:hover {
  border-color: #831843;
}

.active\:border-black.is-active,
.active\:border-black:active {
  border-color: #000;
}

.active\:border-white.is-active,
.active\:border-white:active {
  border-color: #fff;
}

.active\:border-primary.is-active,
.active\:border-primary:active {
  border-color: #007bff;
}

.active\:border-secondary.is-active,
.active\:border-secondary:active {
  border-color: #6c757d;
}

.active\:border-success.is-active,
.active\:border-success:active {
  border-color: #28a745;
}

.active\:border-info.is-active,
.active\:border-info:active {
  border-color: #17a2b8;
}

.active\:border-warning.is-active,
.active\:border-warning:active {
  border-color: #fad733;
}

.active\:border-danger.is-active,
.active\:border-danger:active {
  border-color: #dc3545;
}

.active\:border-light.is-active,
.active\:border-light:active {
  border-color: #f8f9fa;
}

.active\:border-dark.is-active,
.active\:border-dark:active {
  border-color: #343a40;
}

.active\:border-gray-50.is-active,
.active\:border-gray-50:active {
  border-color: #f9fafb;
}

.active\:border-gray-100.is-active,
.active\:border-gray-100:active {
  border-color: #f3f4f6;
}

.active\:border-gray-200.is-active,
.active\:border-gray-200:active {
  border-color: #e5e7eb;
}

.active\:border-gray-300.is-active,
.active\:border-gray-300:active {
  border-color: #d1d5db;
}

.active\:border-gray-400.is-active,
.active\:border-gray-400:active {
  border-color: #9ca3af;
}

.active\:border-gray-500.is-active,
.active\:border-gray-500:active {
  border-color: #6b7280;
}

.active\:border-gray-600.is-active,
.active\:border-gray-600:active {
  border-color: #4b5563;
}

.active\:border-gray-700.is-active,
.active\:border-gray-700:active {
  border-color: #374151;
}

.active\:border-gray-800.is-active,
.active\:border-gray-800:active {
  border-color: #1f2937;
}

.active\:border-gray-900.is-active,
.active\:border-gray-900:active {
  border-color: #111827;
}

.active\:border-red-50.is-active,
.active\:border-red-50:active {
  border-color: #fef2f2;
}

.active\:border-red-100.is-active,
.active\:border-red-100:active {
  border-color: #fee2e2;
}

.active\:border-red-200.is-active,
.active\:border-red-200:active {
  border-color: #fecaca;
}

.active\:border-red-300.is-active,
.active\:border-red-300:active {
  border-color: #fca5a5;
}

.active\:border-red-400.is-active,
.active\:border-red-400:active {
  border-color: #f87171;
}

.active\:border-red-500.is-active,
.active\:border-red-500:active {
  border-color: #ef4444;
}

.active\:border-red-600.is-active,
.active\:border-red-600:active {
  border-color: #dc2626;
}

.active\:border-red-700.is-active,
.active\:border-red-700:active {
  border-color: #b91c1c;
}

.active\:border-red-800.is-active,
.active\:border-red-800:active {
  border-color: #991b1b;
}

.active\:border-red-900.is-active,
.active\:border-red-900:active {
  border-color: #7f1d1d;
}

.active\:border-yellow-50.is-active,
.active\:border-yellow-50:active {
  border-color: #fffbeb;
}

.active\:border-yellow-100.is-active,
.active\:border-yellow-100:active {
  border-color: #fef3c7;
}

.active\:border-yellow-200.is-active,
.active\:border-yellow-200:active {
  border-color: #fde68a;
}

.active\:border-yellow-300.is-active,
.active\:border-yellow-300:active {
  border-color: #fcd34d;
}

.active\:border-yellow-400.is-active,
.active\:border-yellow-400:active {
  border-color: #fbbf24;
}

.active\:border-yellow-500.is-active,
.active\:border-yellow-500:active {
  border-color: #f59e0b;
}

.active\:border-yellow-600.is-active,
.active\:border-yellow-600:active {
  border-color: #d97706;
}

.active\:border-yellow-700.is-active,
.active\:border-yellow-700:active {
  border-color: #b45309;
}

.active\:border-yellow-800.is-active,
.active\:border-yellow-800:active {
  border-color: #92400e;
}

.active\:border-yellow-900.is-active,
.active\:border-yellow-900:active {
  border-color: #78350f;
}

.active\:border-green-50.is-active,
.active\:border-green-50:active {
  border-color: #ecfdf5;
}

.active\:border-green-100.is-active,
.active\:border-green-100:active {
  border-color: #d1fae5;
}

.active\:border-green-200.is-active,
.active\:border-green-200:active {
  border-color: #a7f3d0;
}

.active\:border-green-300.is-active,
.active\:border-green-300:active {
  border-color: #6ee7b7;
}

.active\:border-green-400.is-active,
.active\:border-green-400:active {
  border-color: #34d399;
}

.active\:border-green-500.is-active,
.active\:border-green-500:active {
  border-color: #10b981;
}

.active\:border-green-600.is-active,
.active\:border-green-600:active {
  border-color: #059669;
}

.active\:border-green-700.is-active,
.active\:border-green-700:active {
  border-color: #047857;
}

.active\:border-green-800.is-active,
.active\:border-green-800:active {
  border-color: #065f46;
}

.active\:border-green-900.is-active,
.active\:border-green-900:active {
  border-color: #064e3b;
}

.active\:border-blue-50.is-active,
.active\:border-blue-50:active {
  border-color: #eff6ff;
}

.active\:border-blue-100.is-active,
.active\:border-blue-100:active {
  border-color: #dbeafe;
}

.active\:border-blue-200.is-active,
.active\:border-blue-200:active {
  border-color: #bfdbfe;
}

.active\:border-blue-300.is-active,
.active\:border-blue-300:active {
  border-color: #93c5fd;
}

.active\:border-blue-400.is-active,
.active\:border-blue-400:active {
  border-color: #60a5fa;
}

.active\:border-blue-500.is-active,
.active\:border-blue-500:active {
  border-color: #3b82f6;
}

.active\:border-blue-600.is-active,
.active\:border-blue-600:active {
  border-color: #2563eb;
}

.active\:border-blue-700.is-active,
.active\:border-blue-700:active {
  border-color: #1d4ed8;
}

.active\:border-blue-800.is-active,
.active\:border-blue-800:active {
  border-color: #1e40af;
}

.active\:border-blue-900.is-active,
.active\:border-blue-900:active {
  border-color: #1e3a8a;
}

.active\:border-cyan-50.is-active,
.active\:border-cyan-50:active {
  border-color: #ecfeff;
}

.active\:border-cyan-100.is-active,
.active\:border-cyan-100:active {
  border-color: #cffafe;
}

.active\:border-cyan-200.is-active,
.active\:border-cyan-200:active {
  border-color: #a5f3fc;
}

.active\:border-cyan-300.is-active,
.active\:border-cyan-300:active {
  border-color: #67e8f9;
}

.active\:border-cyan-400.is-active,
.active\:border-cyan-400:active {
  border-color: #22d3ee;
}

.active\:border-cyan-500.is-active,
.active\:border-cyan-500:active {
  border-color: #06b6d4;
}

.active\:border-cyan-600.is-active,
.active\:border-cyan-600:active {
  border-color: #0891b2;
}

.active\:border-cyan-700.is-active,
.active\:border-cyan-700:active {
  border-color: #0e7490;
}

.active\:border-cyan-800.is-active,
.active\:border-cyan-800:active {
  border-color: #155e75;
}

.active\:border-cyan-900.is-active,
.active\:border-cyan-900:active {
  border-color: #164e63;
}

.active\:border-indigo-50.is-active,
.active\:border-indigo-50:active {
  border-color: #eef2ff;
}

.active\:border-indigo-100.is-active,
.active\:border-indigo-100:active {
  border-color: #e0e7ff;
}

.active\:border-indigo-200.is-active,
.active\:border-indigo-200:active {
  border-color: #c7d2fe;
}

.active\:border-indigo-300.is-active,
.active\:border-indigo-300:active {
  border-color: #a5b4fc;
}

.active\:border-indigo-400.is-active,
.active\:border-indigo-400:active {
  border-color: #818cf8;
}

.active\:border-indigo-500.is-active,
.active\:border-indigo-500:active {
  border-color: #6366f1;
}

.active\:border-indigo-600.is-active,
.active\:border-indigo-600:active {
  border-color: #4f46e5;
}

.active\:border-indigo-700.is-active,
.active\:border-indigo-700:active {
  border-color: #4338ca;
}

.active\:border-indigo-800.is-active,
.active\:border-indigo-800:active {
  border-color: #3730a3;
}

.active\:border-indigo-900.is-active,
.active\:border-indigo-900:active {
  border-color: #312e81;
}

.active\:border-purple-50.is-active,
.active\:border-purple-50:active {
  border-color: #f5f3ff;
}

.active\:border-purple-100.is-active,
.active\:border-purple-100:active {
  border-color: #ede9fe;
}

.active\:border-purple-200.is-active,
.active\:border-purple-200:active {
  border-color: #ddd6fe;
}

.active\:border-purple-300.is-active,
.active\:border-purple-300:active {
  border-color: #c4b5fd;
}

.active\:border-purple-400.is-active,
.active\:border-purple-400:active {
  border-color: #a78bfa;
}

.active\:border-purple-500.is-active,
.active\:border-purple-500:active {
  border-color: #8b5cf6;
}

.active\:border-purple-600.is-active,
.active\:border-purple-600:active {
  border-color: #7c3aed;
}

.active\:border-purple-700.is-active,
.active\:border-purple-700:active {
  border-color: #6d28d9;
}

.active\:border-purple-800.is-active,
.active\:border-purple-800:active {
  border-color: #5b21b6;
}

.active\:border-purple-900.is-active,
.active\:border-purple-900:active {
  border-color: #4c1d95;
}

.active\:border-pink-50.is-active,
.active\:border-pink-50:active {
  border-color: #fdf2f8;
}

.active\:border-pink-100.is-active,
.active\:border-pink-100:active {
  border-color: #fce7f3;
}

.active\:border-pink-200.is-active,
.active\:border-pink-200:active {
  border-color: #fbcfe8;
}

.active\:border-pink-300.is-active,
.active\:border-pink-300:active {
  border-color: #f9a8d4;
}

.active\:border-pink-400.is-active,
.active\:border-pink-400:active {
  border-color: #f472b6;
}

.active\:border-pink-500.is-active,
.active\:border-pink-500:active {
  border-color: #ec4899;
}

.active\:border-pink-600.is-active,
.active\:border-pink-600:active {
  border-color: #db2777;
}

.active\:border-pink-700.is-active,
.active\:border-pink-700:active {
  border-color: #be185d;
}

.active\:border-pink-800.is-active,
.active\:border-pink-800:active {
  border-color: #9d174d;
}

.active\:border-pink-900.is-active,
.active\:border-pink-900:active {
  border-color: #831843;
}

.focus\:border-black:focus {
  border-color: #000;
}

.focus\:border-white:focus {
  border-color: #fff;
}

.focus\:border-primary:focus {
  border-color: #007bff;
}

.focus\:border-secondary:focus {
  border-color: #6c757d;
}

.focus\:border-success:focus {
  border-color: #28a745;
}

.focus\:border-info:focus {
  border-color: #17a2b8;
}

.focus\:border-warning:focus {
  border-color: #fad733;
}

.focus\:border-danger:focus {
  border-color: #dc3545;
}

.focus\:border-light:focus {
  border-color: #f8f9fa;
}

.focus\:border-dark:focus {
  border-color: #343a40;
}

.focus\:border-gray-50:focus {
  border-color: #f9fafb;
}

.focus\:border-gray-100:focus {
  border-color: #f3f4f6;
}

.focus\:border-gray-200:focus {
  border-color: #e5e7eb;
}

.focus\:border-gray-300:focus {
  border-color: #d1d5db;
}

.focus\:border-gray-400:focus {
  border-color: #9ca3af;
}

.focus\:border-gray-500:focus {
  border-color: #6b7280;
}

.focus\:border-gray-600:focus {
  border-color: #4b5563;
}

.focus\:border-gray-700:focus {
  border-color: #374151;
}

.focus\:border-gray-800:focus {
  border-color: #1f2937;
}

.focus\:border-gray-900:focus {
  border-color: #111827;
}

.focus\:border-red-50:focus {
  border-color: #fef2f2;
}

.focus\:border-red-100:focus {
  border-color: #fee2e2;
}

.focus\:border-red-200:focus {
  border-color: #fecaca;
}

.focus\:border-red-300:focus {
  border-color: #fca5a5;
}

.focus\:border-red-400:focus {
  border-color: #f87171;
}

.focus\:border-red-500:focus {
  border-color: #ef4444;
}

.focus\:border-red-600:focus {
  border-color: #dc2626;
}

.focus\:border-red-700:focus {
  border-color: #b91c1c;
}

.focus\:border-red-800:focus {
  border-color: #991b1b;
}

.focus\:border-red-900:focus {
  border-color: #7f1d1d;
}

.focus\:border-yellow-50:focus {
  border-color: #fffbeb;
}

.focus\:border-yellow-100:focus {
  border-color: #fef3c7;
}

.focus\:border-yellow-200:focus {
  border-color: #fde68a;
}

.focus\:border-yellow-300:focus {
  border-color: #fcd34d;
}

.focus\:border-yellow-400:focus {
  border-color: #fbbf24;
}

.focus\:border-yellow-500:focus {
  border-color: #f59e0b;
}

.focus\:border-yellow-600:focus {
  border-color: #d97706;
}

.focus\:border-yellow-700:focus {
  border-color: #b45309;
}

.focus\:border-yellow-800:focus {
  border-color: #92400e;
}

.focus\:border-yellow-900:focus {
  border-color: #78350f;
}

.focus\:border-green-50:focus {
  border-color: #ecfdf5;
}

.focus\:border-green-100:focus {
  border-color: #d1fae5;
}

.focus\:border-green-200:focus {
  border-color: #a7f3d0;
}

.focus\:border-green-300:focus {
  border-color: #6ee7b7;
}

.focus\:border-green-400:focus {
  border-color: #34d399;
}

.focus\:border-green-500:focus {
  border-color: #10b981;
}

.focus\:border-green-600:focus {
  border-color: #059669;
}

.focus\:border-green-700:focus {
  border-color: #047857;
}

.focus\:border-green-800:focus {
  border-color: #065f46;
}

.focus\:border-green-900:focus {
  border-color: #064e3b;
}

.focus\:border-blue-50:focus {
  border-color: #eff6ff;
}

.focus\:border-blue-100:focus {
  border-color: #dbeafe;
}

.focus\:border-blue-200:focus {
  border-color: #bfdbfe;
}

.focus\:border-blue-300:focus {
  border-color: #93c5fd;
}

.focus\:border-blue-400:focus {
  border-color: #60a5fa;
}

.focus\:border-blue-500:focus {
  border-color: #3b82f6;
}

.focus\:border-blue-600:focus {
  border-color: #2563eb;
}

.focus\:border-blue-700:focus {
  border-color: #1d4ed8;
}

.focus\:border-blue-800:focus {
  border-color: #1e40af;
}

.focus\:border-blue-900:focus {
  border-color: #1e3a8a;
}

.focus\:border-cyan-50:focus {
  border-color: #ecfeff;
}

.focus\:border-cyan-100:focus {
  border-color: #cffafe;
}

.focus\:border-cyan-200:focus {
  border-color: #a5f3fc;
}

.focus\:border-cyan-300:focus {
  border-color: #67e8f9;
}

.focus\:border-cyan-400:focus {
  border-color: #22d3ee;
}

.focus\:border-cyan-500:focus {
  border-color: #06b6d4;
}

.focus\:border-cyan-600:focus {
  border-color: #0891b2;
}

.focus\:border-cyan-700:focus {
  border-color: #0e7490;
}

.focus\:border-cyan-800:focus {
  border-color: #155e75;
}

.focus\:border-cyan-900:focus {
  border-color: #164e63;
}

.focus\:border-indigo-50:focus {
  border-color: #eef2ff;
}

.focus\:border-indigo-100:focus {
  border-color: #e0e7ff;
}

.focus\:border-indigo-200:focus {
  border-color: #c7d2fe;
}

.focus\:border-indigo-300:focus {
  border-color: #a5b4fc;
}

.focus\:border-indigo-400:focus {
  border-color: #818cf8;
}

.focus\:border-indigo-500:focus {
  border-color: #6366f1;
}

.focus\:border-indigo-600:focus {
  border-color: #4f46e5;
}

.focus\:border-indigo-700:focus {
  border-color: #4338ca;
}

.focus\:border-indigo-800:focus {
  border-color: #3730a3;
}

.focus\:border-indigo-900:focus {
  border-color: #312e81;
}

.focus\:border-purple-50:focus {
  border-color: #f5f3ff;
}

.focus\:border-purple-100:focus {
  border-color: #ede9fe;
}

.focus\:border-purple-200:focus {
  border-color: #ddd6fe;
}

.focus\:border-purple-300:focus {
  border-color: #c4b5fd;
}

.focus\:border-purple-400:focus {
  border-color: #a78bfa;
}

.focus\:border-purple-500:focus {
  border-color: #8b5cf6;
}

.focus\:border-purple-600:focus {
  border-color: #7c3aed;
}

.focus\:border-purple-700:focus {
  border-color: #6d28d9;
}

.focus\:border-purple-800:focus {
  border-color: #5b21b6;
}

.focus\:border-purple-900:focus {
  border-color: #4c1d95;
}

.focus\:border-pink-50:focus {
  border-color: #fdf2f8;
}

.focus\:border-pink-100:focus {
  border-color: #fce7f3;
}

.focus\:border-pink-200:focus {
  border-color: #fbcfe8;
}

.focus\:border-pink-300:focus {
  border-color: #f9a8d4;
}

.focus\:border-pink-400:focus {
  border-color: #f472b6;
}

.focus\:border-pink-500:focus {
  border-color: #ec4899;
}

.focus\:border-pink-600:focus {
  border-color: #db2777;
}

.focus\:border-pink-700:focus {
  border-color: #be185d;
}

.focus\:border-pink-800:focus {
  border-color: #9d174d;
}

.focus\:border-pink-900:focus {
  border-color: #831843;
}

.disabled\:border-black.is-disabled,
.disabled\:border-black:disabled {
  border-color: #000;
}

.disabled\:border-white.is-disabled,
.disabled\:border-white:disabled {
  border-color: #fff;
}

.disabled\:border-primary.is-disabled,
.disabled\:border-primary:disabled {
  border-color: #007bff;
}

.disabled\:border-secondary.is-disabled,
.disabled\:border-secondary:disabled {
  border-color: #6c757d;
}

.disabled\:border-success.is-disabled,
.disabled\:border-success:disabled {
  border-color: #28a745;
}

.disabled\:border-info.is-disabled,
.disabled\:border-info:disabled {
  border-color: #17a2b8;
}

.disabled\:border-warning.is-disabled,
.disabled\:border-warning:disabled {
  border-color: #fad733;
}

.disabled\:border-danger.is-disabled,
.disabled\:border-danger:disabled {
  border-color: #dc3545;
}

.disabled\:border-light.is-disabled,
.disabled\:border-light:disabled {
  border-color: #f8f9fa;
}

.disabled\:border-dark.is-disabled,
.disabled\:border-dark:disabled {
  border-color: #343a40;
}

.disabled\:border-gray-50.is-disabled,
.disabled\:border-gray-50:disabled {
  border-color: #f9fafb;
}

.disabled\:border-gray-100.is-disabled,
.disabled\:border-gray-100:disabled {
  border-color: #f3f4f6;
}

.disabled\:border-gray-200.is-disabled,
.disabled\:border-gray-200:disabled {
  border-color: #e5e7eb;
}

.disabled\:border-gray-300.is-disabled,
.disabled\:border-gray-300:disabled {
  border-color: #d1d5db;
}

.disabled\:border-gray-400.is-disabled,
.disabled\:border-gray-400:disabled {
  border-color: #9ca3af;
}

.disabled\:border-gray-500.is-disabled,
.disabled\:border-gray-500:disabled {
  border-color: #6b7280;
}

.disabled\:border-gray-600.is-disabled,
.disabled\:border-gray-600:disabled {
  border-color: #4b5563;
}

.disabled\:border-gray-700.is-disabled,
.disabled\:border-gray-700:disabled {
  border-color: #374151;
}

.disabled\:border-gray-800.is-disabled,
.disabled\:border-gray-800:disabled {
  border-color: #1f2937;
}

.disabled\:border-gray-900.is-disabled,
.disabled\:border-gray-900:disabled {
  border-color: #111827;
}

.disabled\:border-red-50.is-disabled,
.disabled\:border-red-50:disabled {
  border-color: #fef2f2;
}

.disabled\:border-red-100.is-disabled,
.disabled\:border-red-100:disabled {
  border-color: #fee2e2;
}

.disabled\:border-red-200.is-disabled,
.disabled\:border-red-200:disabled {
  border-color: #fecaca;
}

.disabled\:border-red-300.is-disabled,
.disabled\:border-red-300:disabled {
  border-color: #fca5a5;
}

.disabled\:border-red-400.is-disabled,
.disabled\:border-red-400:disabled {
  border-color: #f87171;
}

.disabled\:border-red-500.is-disabled,
.disabled\:border-red-500:disabled {
  border-color: #ef4444;
}

.disabled\:border-red-600.is-disabled,
.disabled\:border-red-600:disabled {
  border-color: #dc2626;
}

.disabled\:border-red-700.is-disabled,
.disabled\:border-red-700:disabled {
  border-color: #b91c1c;
}

.disabled\:border-red-800.is-disabled,
.disabled\:border-red-800:disabled {
  border-color: #991b1b;
}

.disabled\:border-red-900.is-disabled,
.disabled\:border-red-900:disabled {
  border-color: #7f1d1d;
}

.disabled\:border-yellow-50.is-disabled,
.disabled\:border-yellow-50:disabled {
  border-color: #fffbeb;
}

.disabled\:border-yellow-100.is-disabled,
.disabled\:border-yellow-100:disabled {
  border-color: #fef3c7;
}

.disabled\:border-yellow-200.is-disabled,
.disabled\:border-yellow-200:disabled {
  border-color: #fde68a;
}

.disabled\:border-yellow-300.is-disabled,
.disabled\:border-yellow-300:disabled {
  border-color: #fcd34d;
}

.disabled\:border-yellow-400.is-disabled,
.disabled\:border-yellow-400:disabled {
  border-color: #fbbf24;
}

.disabled\:border-yellow-500.is-disabled,
.disabled\:border-yellow-500:disabled {
  border-color: #f59e0b;
}

.disabled\:border-yellow-600.is-disabled,
.disabled\:border-yellow-600:disabled {
  border-color: #d97706;
}

.disabled\:border-yellow-700.is-disabled,
.disabled\:border-yellow-700:disabled {
  border-color: #b45309;
}

.disabled\:border-yellow-800.is-disabled,
.disabled\:border-yellow-800:disabled {
  border-color: #92400e;
}

.disabled\:border-yellow-900.is-disabled,
.disabled\:border-yellow-900:disabled {
  border-color: #78350f;
}

.disabled\:border-green-50.is-disabled,
.disabled\:border-green-50:disabled {
  border-color: #ecfdf5;
}

.disabled\:border-green-100.is-disabled,
.disabled\:border-green-100:disabled {
  border-color: #d1fae5;
}

.disabled\:border-green-200.is-disabled,
.disabled\:border-green-200:disabled {
  border-color: #a7f3d0;
}

.disabled\:border-green-300.is-disabled,
.disabled\:border-green-300:disabled {
  border-color: #6ee7b7;
}

.disabled\:border-green-400.is-disabled,
.disabled\:border-green-400:disabled {
  border-color: #34d399;
}

.disabled\:border-green-500.is-disabled,
.disabled\:border-green-500:disabled {
  border-color: #10b981;
}

.disabled\:border-green-600.is-disabled,
.disabled\:border-green-600:disabled {
  border-color: #059669;
}

.disabled\:border-green-700.is-disabled,
.disabled\:border-green-700:disabled {
  border-color: #047857;
}

.disabled\:border-green-800.is-disabled,
.disabled\:border-green-800:disabled {
  border-color: #065f46;
}

.disabled\:border-green-900.is-disabled,
.disabled\:border-green-900:disabled {
  border-color: #064e3b;
}

.disabled\:border-blue-50.is-disabled,
.disabled\:border-blue-50:disabled {
  border-color: #eff6ff;
}

.disabled\:border-blue-100.is-disabled,
.disabled\:border-blue-100:disabled {
  border-color: #dbeafe;
}

.disabled\:border-blue-200.is-disabled,
.disabled\:border-blue-200:disabled {
  border-color: #bfdbfe;
}

.disabled\:border-blue-300.is-disabled,
.disabled\:border-blue-300:disabled {
  border-color: #93c5fd;
}

.disabled\:border-blue-400.is-disabled,
.disabled\:border-blue-400:disabled {
  border-color: #60a5fa;
}

.disabled\:border-blue-500.is-disabled,
.disabled\:border-blue-500:disabled {
  border-color: #3b82f6;
}

.disabled\:border-blue-600.is-disabled,
.disabled\:border-blue-600:disabled {
  border-color: #2563eb;
}

.disabled\:border-blue-700.is-disabled,
.disabled\:border-blue-700:disabled {
  border-color: #1d4ed8;
}

.disabled\:border-blue-800.is-disabled,
.disabled\:border-blue-800:disabled {
  border-color: #1e40af;
}

.disabled\:border-blue-900.is-disabled,
.disabled\:border-blue-900:disabled {
  border-color: #1e3a8a;
}

.disabled\:border-cyan-50.is-disabled,
.disabled\:border-cyan-50:disabled {
  border-color: #ecfeff;
}

.disabled\:border-cyan-100.is-disabled,
.disabled\:border-cyan-100:disabled {
  border-color: #cffafe;
}

.disabled\:border-cyan-200.is-disabled,
.disabled\:border-cyan-200:disabled {
  border-color: #a5f3fc;
}

.disabled\:border-cyan-300.is-disabled,
.disabled\:border-cyan-300:disabled {
  border-color: #67e8f9;
}

.disabled\:border-cyan-400.is-disabled,
.disabled\:border-cyan-400:disabled {
  border-color: #22d3ee;
}

.disabled\:border-cyan-500.is-disabled,
.disabled\:border-cyan-500:disabled {
  border-color: #06b6d4;
}

.disabled\:border-cyan-600.is-disabled,
.disabled\:border-cyan-600:disabled {
  border-color: #0891b2;
}

.disabled\:border-cyan-700.is-disabled,
.disabled\:border-cyan-700:disabled {
  border-color: #0e7490;
}

.disabled\:border-cyan-800.is-disabled,
.disabled\:border-cyan-800:disabled {
  border-color: #155e75;
}

.disabled\:border-cyan-900.is-disabled,
.disabled\:border-cyan-900:disabled {
  border-color: #164e63;
}

.disabled\:border-indigo-50.is-disabled,
.disabled\:border-indigo-50:disabled {
  border-color: #eef2ff;
}

.disabled\:border-indigo-100.is-disabled,
.disabled\:border-indigo-100:disabled {
  border-color: #e0e7ff;
}

.disabled\:border-indigo-200.is-disabled,
.disabled\:border-indigo-200:disabled {
  border-color: #c7d2fe;
}

.disabled\:border-indigo-300.is-disabled,
.disabled\:border-indigo-300:disabled {
  border-color: #a5b4fc;
}

.disabled\:border-indigo-400.is-disabled,
.disabled\:border-indigo-400:disabled {
  border-color: #818cf8;
}

.disabled\:border-indigo-500.is-disabled,
.disabled\:border-indigo-500:disabled {
  border-color: #6366f1;
}

.disabled\:border-indigo-600.is-disabled,
.disabled\:border-indigo-600:disabled {
  border-color: #4f46e5;
}

.disabled\:border-indigo-700.is-disabled,
.disabled\:border-indigo-700:disabled {
  border-color: #4338ca;
}

.disabled\:border-indigo-800.is-disabled,
.disabled\:border-indigo-800:disabled {
  border-color: #3730a3;
}

.disabled\:border-indigo-900.is-disabled,
.disabled\:border-indigo-900:disabled {
  border-color: #312e81;
}

.disabled\:border-purple-50.is-disabled,
.disabled\:border-purple-50:disabled {
  border-color: #f5f3ff;
}

.disabled\:border-purple-100.is-disabled,
.disabled\:border-purple-100:disabled {
  border-color: #ede9fe;
}

.disabled\:border-purple-200.is-disabled,
.disabled\:border-purple-200:disabled {
  border-color: #ddd6fe;
}

.disabled\:border-purple-300.is-disabled,
.disabled\:border-purple-300:disabled {
  border-color: #c4b5fd;
}

.disabled\:border-purple-400.is-disabled,
.disabled\:border-purple-400:disabled {
  border-color: #a78bfa;
}

.disabled\:border-purple-500.is-disabled,
.disabled\:border-purple-500:disabled {
  border-color: #8b5cf6;
}

.disabled\:border-purple-600.is-disabled,
.disabled\:border-purple-600:disabled {
  border-color: #7c3aed;
}

.disabled\:border-purple-700.is-disabled,
.disabled\:border-purple-700:disabled {
  border-color: #6d28d9;
}

.disabled\:border-purple-800.is-disabled,
.disabled\:border-purple-800:disabled {
  border-color: #5b21b6;
}

.disabled\:border-purple-900.is-disabled,
.disabled\:border-purple-900:disabled {
  border-color: #4c1d95;
}

.disabled\:border-pink-50.is-disabled,
.disabled\:border-pink-50:disabled {
  border-color: #fdf2f8;
}

.disabled\:border-pink-100.is-disabled,
.disabled\:border-pink-100:disabled {
  border-color: #fce7f3;
}

.disabled\:border-pink-200.is-disabled,
.disabled\:border-pink-200:disabled {
  border-color: #fbcfe8;
}

.disabled\:border-pink-300.is-disabled,
.disabled\:border-pink-300:disabled {
  border-color: #f9a8d4;
}

.disabled\:border-pink-400.is-disabled,
.disabled\:border-pink-400:disabled {
  border-color: #f472b6;
}

.disabled\:border-pink-500.is-disabled,
.disabled\:border-pink-500:disabled {
  border-color: #ec4899;
}

.disabled\:border-pink-600.is-disabled,
.disabled\:border-pink-600:disabled {
  border-color: #db2777;
}

.disabled\:border-pink-700.is-disabled,
.disabled\:border-pink-700:disabled {
  border-color: #be185d;
}

.disabled\:border-pink-800.is-disabled,
.disabled\:border-pink-800:disabled {
  border-color: #9d174d;
}

.disabled\:border-pink-900.is-disabled,
.disabled\:border-pink-900:disabled {
  border-color: #831843;
}

.group:hover .group-hover\:border-black {
  border-color: #000;
}

.group:hover .group-hover\:border-white {
  border-color: #fff;
}

.group:hover .group-hover\:border-primary {
  border-color: #007bff;
}

.group:hover .group-hover\:border-secondary {
  border-color: #6c757d;
}

.group:hover .group-hover\:border-success {
  border-color: #28a745;
}

.group:hover .group-hover\:border-info {
  border-color: #17a2b8;
}

.group:hover .group-hover\:border-warning {
  border-color: #fad733;
}

.group:hover .group-hover\:border-danger {
  border-color: #dc3545;
}

.group:hover .group-hover\:border-light {
  border-color: #f8f9fa;
}

.group:hover .group-hover\:border-dark {
  border-color: #343a40;
}

.group:hover .group-hover\:border-gray-50 {
  border-color: #f9fafb;
}

.group:hover .group-hover\:border-gray-100 {
  border-color: #f3f4f6;
}

.group:hover .group-hover\:border-gray-200 {
  border-color: #e5e7eb;
}

.group:hover .group-hover\:border-gray-300 {
  border-color: #d1d5db;
}

.group:hover .group-hover\:border-gray-400 {
  border-color: #9ca3af;
}

.group:hover .group-hover\:border-gray-500 {
  border-color: #6b7280;
}

.group:hover .group-hover\:border-gray-600 {
  border-color: #4b5563;
}

.group:hover .group-hover\:border-gray-700 {
  border-color: #374151;
}

.group:hover .group-hover\:border-gray-800 {
  border-color: #1f2937;
}

.group:hover .group-hover\:border-gray-900 {
  border-color: #111827;
}

.group:hover .group-hover\:border-red-50 {
  border-color: #fef2f2;
}

.group:hover .group-hover\:border-red-100 {
  border-color: #fee2e2;
}

.group:hover .group-hover\:border-red-200 {
  border-color: #fecaca;
}

.group:hover .group-hover\:border-red-300 {
  border-color: #fca5a5;
}

.group:hover .group-hover\:border-red-400 {
  border-color: #f87171;
}

.group:hover .group-hover\:border-red-500 {
  border-color: #ef4444;
}

.group:hover .group-hover\:border-red-600 {
  border-color: #dc2626;
}

.group:hover .group-hover\:border-red-700 {
  border-color: #b91c1c;
}

.group:hover .group-hover\:border-red-800 {
  border-color: #991b1b;
}

.group:hover .group-hover\:border-red-900 {
  border-color: #7f1d1d;
}

.group:hover .group-hover\:border-yellow-50 {
  border-color: #fffbeb;
}

.group:hover .group-hover\:border-yellow-100 {
  border-color: #fef3c7;
}

.group:hover .group-hover\:border-yellow-200 {
  border-color: #fde68a;
}

.group:hover .group-hover\:border-yellow-300 {
  border-color: #fcd34d;
}

.group:hover .group-hover\:border-yellow-400 {
  border-color: #fbbf24;
}

.group:hover .group-hover\:border-yellow-500 {
  border-color: #f59e0b;
}

.group:hover .group-hover\:border-yellow-600 {
  border-color: #d97706;
}

.group:hover .group-hover\:border-yellow-700 {
  border-color: #b45309;
}

.group:hover .group-hover\:border-yellow-800 {
  border-color: #92400e;
}

.group:hover .group-hover\:border-yellow-900 {
  border-color: #78350f;
}

.group:hover .group-hover\:border-green-50 {
  border-color: #ecfdf5;
}

.group:hover .group-hover\:border-green-100 {
  border-color: #d1fae5;
}

.group:hover .group-hover\:border-green-200 {
  border-color: #a7f3d0;
}

.group:hover .group-hover\:border-green-300 {
  border-color: #6ee7b7;
}

.group:hover .group-hover\:border-green-400 {
  border-color: #34d399;
}

.group:hover .group-hover\:border-green-500 {
  border-color: #10b981;
}

.group:hover .group-hover\:border-green-600 {
  border-color: #059669;
}

.group:hover .group-hover\:border-green-700 {
  border-color: #047857;
}

.group:hover .group-hover\:border-green-800 {
  border-color: #065f46;
}

.group:hover .group-hover\:border-green-900 {
  border-color: #064e3b;
}

.group:hover .group-hover\:border-blue-50 {
  border-color: #eff6ff;
}

.group:hover .group-hover\:border-blue-100 {
  border-color: #dbeafe;
}

.group:hover .group-hover\:border-blue-200 {
  border-color: #bfdbfe;
}

.group:hover .group-hover\:border-blue-300 {
  border-color: #93c5fd;
}

.group:hover .group-hover\:border-blue-400 {
  border-color: #60a5fa;
}

.group:hover .group-hover\:border-blue-500 {
  border-color: #3b82f6;
}

.group:hover .group-hover\:border-blue-600 {
  border-color: #2563eb;
}

.group:hover .group-hover\:border-blue-700 {
  border-color: #1d4ed8;
}

.group:hover .group-hover\:border-blue-800 {
  border-color: #1e40af;
}

.group:hover .group-hover\:border-blue-900 {
  border-color: #1e3a8a;
}

.group:hover .group-hover\:border-cyan-50 {
  border-color: #ecfeff;
}

.group:hover .group-hover\:border-cyan-100 {
  border-color: #cffafe;
}

.group:hover .group-hover\:border-cyan-200 {
  border-color: #a5f3fc;
}

.group:hover .group-hover\:border-cyan-300 {
  border-color: #67e8f9;
}

.group:hover .group-hover\:border-cyan-400 {
  border-color: #22d3ee;
}

.group:hover .group-hover\:border-cyan-500 {
  border-color: #06b6d4;
}

.group:hover .group-hover\:border-cyan-600 {
  border-color: #0891b2;
}

.group:hover .group-hover\:border-cyan-700 {
  border-color: #0e7490;
}

.group:hover .group-hover\:border-cyan-800 {
  border-color: #155e75;
}

.group:hover .group-hover\:border-cyan-900 {
  border-color: #164e63;
}

.group:hover .group-hover\:border-indigo-50 {
  border-color: #eef2ff;
}

.group:hover .group-hover\:border-indigo-100 {
  border-color: #e0e7ff;
}

.group:hover .group-hover\:border-indigo-200 {
  border-color: #c7d2fe;
}

.group:hover .group-hover\:border-indigo-300 {
  border-color: #a5b4fc;
}

.group:hover .group-hover\:border-indigo-400 {
  border-color: #818cf8;
}

.group:hover .group-hover\:border-indigo-500 {
  border-color: #6366f1;
}

.group:hover .group-hover\:border-indigo-600 {
  border-color: #4f46e5;
}

.group:hover .group-hover\:border-indigo-700 {
  border-color: #4338ca;
}

.group:hover .group-hover\:border-indigo-800 {
  border-color: #3730a3;
}

.group:hover .group-hover\:border-indigo-900 {
  border-color: #312e81;
}

.group:hover .group-hover\:border-purple-50 {
  border-color: #f5f3ff;
}

.group:hover .group-hover\:border-purple-100 {
  border-color: #ede9fe;
}

.group:hover .group-hover\:border-purple-200 {
  border-color: #ddd6fe;
}

.group:hover .group-hover\:border-purple-300 {
  border-color: #c4b5fd;
}

.group:hover .group-hover\:border-purple-400 {
  border-color: #a78bfa;
}

.group:hover .group-hover\:border-purple-500 {
  border-color: #8b5cf6;
}

.group:hover .group-hover\:border-purple-600 {
  border-color: #7c3aed;
}

.group:hover .group-hover\:border-purple-700 {
  border-color: #6d28d9;
}

.group:hover .group-hover\:border-purple-800 {
  border-color: #5b21b6;
}

.group:hover .group-hover\:border-purple-900 {
  border-color: #4c1d95;
}

.group:hover .group-hover\:border-pink-50 {
  border-color: #fdf2f8;
}

.group:hover .group-hover\:border-pink-100 {
  border-color: #fce7f3;
}

.group:hover .group-hover\:border-pink-200 {
  border-color: #fbcfe8;
}

.group:hover .group-hover\:border-pink-300 {
  border-color: #f9a8d4;
}

.group:hover .group-hover\:border-pink-400 {
  border-color: #f472b6;
}

.group:hover .group-hover\:border-pink-500 {
  border-color: #ec4899;
}

.group:hover .group-hover\:border-pink-600 {
  border-color: #db2777;
}

.group:hover .group-hover\:border-pink-700 {
  border-color: #be185d;
}

.group:hover .group-hover\:border-pink-800 {
  border-color: #9d174d;
}

.group:hover .group-hover\:border-pink-900 {
  border-color: #831843;
}

@media (max-width: 768px) {
  .m\:border-black {
    border-color: #000;
  }

  .m\:border-white {
    border-color: #fff;
  }

  .m\:border-primary {
    border-color: #007bff;
  }

  .m\:border-secondary {
    border-color: #6c757d;
  }

  .m\:border-success {
    border-color: #28a745;
  }

  .m\:border-info {
    border-color: #17a2b8;
  }

  .m\:border-warning {
    border-color: #fad733;
  }

  .m\:border-danger {
    border-color: #dc3545;
  }

  .m\:border-light {
    border-color: #f8f9fa;
  }

  .m\:border-dark {
    border-color: #343a40;
  }

  .m\:border-gray-50 {
    border-color: #f9fafb;
  }

  .m\:border-gray-100 {
    border-color: #f3f4f6;
  }

  .m\:border-gray-200 {
    border-color: #e5e7eb;
  }

  .m\:border-gray-300 {
    border-color: #d1d5db;
  }

  .m\:border-gray-400 {
    border-color: #9ca3af;
  }

  .m\:border-gray-500 {
    border-color: #6b7280;
  }

  .m\:border-gray-600 {
    border-color: #4b5563;
  }

  .m\:border-gray-700 {
    border-color: #374151;
  }

  .m\:border-gray-800 {
    border-color: #1f2937;
  }

  .m\:border-gray-900 {
    border-color: #111827;
  }

  .m\:border-red-50 {
    border-color: #fef2f2;
  }

  .m\:border-red-100 {
    border-color: #fee2e2;
  }

  .m\:border-red-200 {
    border-color: #fecaca;
  }

  .m\:border-red-300 {
    border-color: #fca5a5;
  }

  .m\:border-red-400 {
    border-color: #f87171;
  }

  .m\:border-red-500 {
    border-color: #ef4444;
  }

  .m\:border-red-600 {
    border-color: #dc2626;
  }

  .m\:border-red-700 {
    border-color: #b91c1c;
  }

  .m\:border-red-800 {
    border-color: #991b1b;
  }

  .m\:border-red-900 {
    border-color: #7f1d1d;
  }

  .m\:border-yellow-50 {
    border-color: #fffbeb;
  }

  .m\:border-yellow-100 {
    border-color: #fef3c7;
  }

  .m\:border-yellow-200 {
    border-color: #fde68a;
  }

  .m\:border-yellow-300 {
    border-color: #fcd34d;
  }

  .m\:border-yellow-400 {
    border-color: #fbbf24;
  }

  .m\:border-yellow-500 {
    border-color: #f59e0b;
  }

  .m\:border-yellow-600 {
    border-color: #d97706;
  }

  .m\:border-yellow-700 {
    border-color: #b45309;
  }

  .m\:border-yellow-800 {
    border-color: #92400e;
  }

  .m\:border-yellow-900 {
    border-color: #78350f;
  }

  .m\:border-green-50 {
    border-color: #ecfdf5;
  }

  .m\:border-green-100 {
    border-color: #d1fae5;
  }

  .m\:border-green-200 {
    border-color: #a7f3d0;
  }

  .m\:border-green-300 {
    border-color: #6ee7b7;
  }

  .m\:border-green-400 {
    border-color: #34d399;
  }

  .m\:border-green-500 {
    border-color: #10b981;
  }

  .m\:border-green-600 {
    border-color: #059669;
  }

  .m\:border-green-700 {
    border-color: #047857;
  }

  .m\:border-green-800 {
    border-color: #065f46;
  }

  .m\:border-green-900 {
    border-color: #064e3b;
  }

  .m\:border-blue-50 {
    border-color: #eff6ff;
  }

  .m\:border-blue-100 {
    border-color: #dbeafe;
  }

  .m\:border-blue-200 {
    border-color: #bfdbfe;
  }

  .m\:border-blue-300 {
    border-color: #93c5fd;
  }

  .m\:border-blue-400 {
    border-color: #60a5fa;
  }

  .m\:border-blue-500 {
    border-color: #3b82f6;
  }

  .m\:border-blue-600 {
    border-color: #2563eb;
  }

  .m\:border-blue-700 {
    border-color: #1d4ed8;
  }

  .m\:border-blue-800 {
    border-color: #1e40af;
  }

  .m\:border-blue-900 {
    border-color: #1e3a8a;
  }

  .m\:border-cyan-50 {
    border-color: #ecfeff;
  }

  .m\:border-cyan-100 {
    border-color: #cffafe;
  }

  .m\:border-cyan-200 {
    border-color: #a5f3fc;
  }

  .m\:border-cyan-300 {
    border-color: #67e8f9;
  }

  .m\:border-cyan-400 {
    border-color: #22d3ee;
  }

  .m\:border-cyan-500 {
    border-color: #06b6d4;
  }

  .m\:border-cyan-600 {
    border-color: #0891b2;
  }

  .m\:border-cyan-700 {
    border-color: #0e7490;
  }

  .m\:border-cyan-800 {
    border-color: #155e75;
  }

  .m\:border-cyan-900 {
    border-color: #164e63;
  }

  .m\:border-indigo-50 {
    border-color: #eef2ff;
  }

  .m\:border-indigo-100 {
    border-color: #e0e7ff;
  }

  .m\:border-indigo-200 {
    border-color: #c7d2fe;
  }

  .m\:border-indigo-300 {
    border-color: #a5b4fc;
  }

  .m\:border-indigo-400 {
    border-color: #818cf8;
  }

  .m\:border-indigo-500 {
    border-color: #6366f1;
  }

  .m\:border-indigo-600 {
    border-color: #4f46e5;
  }

  .m\:border-indigo-700 {
    border-color: #4338ca;
  }

  .m\:border-indigo-800 {
    border-color: #3730a3;
  }

  .m\:border-indigo-900 {
    border-color: #312e81;
  }

  .m\:border-purple-50 {
    border-color: #f5f3ff;
  }

  .m\:border-purple-100 {
    border-color: #ede9fe;
  }

  .m\:border-purple-200 {
    border-color: #ddd6fe;
  }

  .m\:border-purple-300 {
    border-color: #c4b5fd;
  }

  .m\:border-purple-400 {
    border-color: #a78bfa;
  }

  .m\:border-purple-500 {
    border-color: #8b5cf6;
  }

  .m\:border-purple-600 {
    border-color: #7c3aed;
  }

  .m\:border-purple-700 {
    border-color: #6d28d9;
  }

  .m\:border-purple-800 {
    border-color: #5b21b6;
  }

  .m\:border-purple-900 {
    border-color: #4c1d95;
  }

  .m\:border-pink-50 {
    border-color: #fdf2f8;
  }

  .m\:border-pink-100 {
    border-color: #fce7f3;
  }

  .m\:border-pink-200 {
    border-color: #fbcfe8;
  }

  .m\:border-pink-300 {
    border-color: #f9a8d4;
  }

  .m\:border-pink-400 {
    border-color: #f472b6;
  }

  .m\:border-pink-500 {
    border-color: #ec4899;
  }

  .m\:border-pink-600 {
    border-color: #db2777;
  }

  .m\:border-pink-700 {
    border-color: #be185d;
  }

  .m\:border-pink-800 {
    border-color: #9d174d;
  }

  .m\:border-pink-900 {
    border-color: #831843;
  }

  .m\:hover\:border-black:hover {
    border-color: #000;
  }

  .m\:hover\:border-white:hover {
    border-color: #fff;
  }

  .m\:hover\:border-primary:hover {
    border-color: #007bff;
  }

  .m\:hover\:border-secondary:hover {
    border-color: #6c757d;
  }

  .m\:hover\:border-success:hover {
    border-color: #28a745;
  }

  .m\:hover\:border-info:hover {
    border-color: #17a2b8;
  }

  .m\:hover\:border-warning:hover {
    border-color: #fad733;
  }

  .m\:hover\:border-danger:hover {
    border-color: #dc3545;
  }

  .m\:hover\:border-light:hover {
    border-color: #f8f9fa;
  }

  .m\:hover\:border-dark:hover {
    border-color: #343a40;
  }

  .m\:hover\:border-gray-50:hover {
    border-color: #f9fafb;
  }

  .m\:hover\:border-gray-100:hover {
    border-color: #f3f4f6;
  }

  .m\:hover\:border-gray-200:hover {
    border-color: #e5e7eb;
  }

  .m\:hover\:border-gray-300:hover {
    border-color: #d1d5db;
  }

  .m\:hover\:border-gray-400:hover {
    border-color: #9ca3af;
  }

  .m\:hover\:border-gray-500:hover {
    border-color: #6b7280;
  }

  .m\:hover\:border-gray-600:hover {
    border-color: #4b5563;
  }

  .m\:hover\:border-gray-700:hover {
    border-color: #374151;
  }

  .m\:hover\:border-gray-800:hover {
    border-color: #1f2937;
  }

  .m\:hover\:border-gray-900:hover {
    border-color: #111827;
  }

  .m\:hover\:border-red-50:hover {
    border-color: #fef2f2;
  }

  .m\:hover\:border-red-100:hover {
    border-color: #fee2e2;
  }

  .m\:hover\:border-red-200:hover {
    border-color: #fecaca;
  }

  .m\:hover\:border-red-300:hover {
    border-color: #fca5a5;
  }

  .m\:hover\:border-red-400:hover {
    border-color: #f87171;
  }

  .m\:hover\:border-red-500:hover {
    border-color: #ef4444;
  }

  .m\:hover\:border-red-600:hover {
    border-color: #dc2626;
  }

  .m\:hover\:border-red-700:hover {
    border-color: #b91c1c;
  }

  .m\:hover\:border-red-800:hover {
    border-color: #991b1b;
  }

  .m\:hover\:border-red-900:hover {
    border-color: #7f1d1d;
  }

  .m\:hover\:border-yellow-50:hover {
    border-color: #fffbeb;
  }

  .m\:hover\:border-yellow-100:hover {
    border-color: #fef3c7;
  }

  .m\:hover\:border-yellow-200:hover {
    border-color: #fde68a;
  }

  .m\:hover\:border-yellow-300:hover {
    border-color: #fcd34d;
  }

  .m\:hover\:border-yellow-400:hover {
    border-color: #fbbf24;
  }

  .m\:hover\:border-yellow-500:hover {
    border-color: #f59e0b;
  }

  .m\:hover\:border-yellow-600:hover {
    border-color: #d97706;
  }

  .m\:hover\:border-yellow-700:hover {
    border-color: #b45309;
  }

  .m\:hover\:border-yellow-800:hover {
    border-color: #92400e;
  }

  .m\:hover\:border-yellow-900:hover {
    border-color: #78350f;
  }

  .m\:hover\:border-green-50:hover {
    border-color: #ecfdf5;
  }

  .m\:hover\:border-green-100:hover {
    border-color: #d1fae5;
  }

  .m\:hover\:border-green-200:hover {
    border-color: #a7f3d0;
  }

  .m\:hover\:border-green-300:hover {
    border-color: #6ee7b7;
  }

  .m\:hover\:border-green-400:hover {
    border-color: #34d399;
  }

  .m\:hover\:border-green-500:hover {
    border-color: #10b981;
  }

  .m\:hover\:border-green-600:hover {
    border-color: #059669;
  }

  .m\:hover\:border-green-700:hover {
    border-color: #047857;
  }

  .m\:hover\:border-green-800:hover {
    border-color: #065f46;
  }

  .m\:hover\:border-green-900:hover {
    border-color: #064e3b;
  }

  .m\:hover\:border-blue-50:hover {
    border-color: #eff6ff;
  }

  .m\:hover\:border-blue-100:hover {
    border-color: #dbeafe;
  }

  .m\:hover\:border-blue-200:hover {
    border-color: #bfdbfe;
  }

  .m\:hover\:border-blue-300:hover {
    border-color: #93c5fd;
  }

  .m\:hover\:border-blue-400:hover {
    border-color: #60a5fa;
  }

  .m\:hover\:border-blue-500:hover {
    border-color: #3b82f6;
  }

  .m\:hover\:border-blue-600:hover {
    border-color: #2563eb;
  }

  .m\:hover\:border-blue-700:hover {
    border-color: #1d4ed8;
  }

  .m\:hover\:border-blue-800:hover {
    border-color: #1e40af;
  }

  .m\:hover\:border-blue-900:hover {
    border-color: #1e3a8a;
  }

  .m\:hover\:border-cyan-50:hover {
    border-color: #ecfeff;
  }

  .m\:hover\:border-cyan-100:hover {
    border-color: #cffafe;
  }

  .m\:hover\:border-cyan-200:hover {
    border-color: #a5f3fc;
  }

  .m\:hover\:border-cyan-300:hover {
    border-color: #67e8f9;
  }

  .m\:hover\:border-cyan-400:hover {
    border-color: #22d3ee;
  }

  .m\:hover\:border-cyan-500:hover {
    border-color: #06b6d4;
  }

  .m\:hover\:border-cyan-600:hover {
    border-color: #0891b2;
  }

  .m\:hover\:border-cyan-700:hover {
    border-color: #0e7490;
  }

  .m\:hover\:border-cyan-800:hover {
    border-color: #155e75;
  }

  .m\:hover\:border-cyan-900:hover {
    border-color: #164e63;
  }

  .m\:hover\:border-indigo-50:hover {
    border-color: #eef2ff;
  }

  .m\:hover\:border-indigo-100:hover {
    border-color: #e0e7ff;
  }

  .m\:hover\:border-indigo-200:hover {
    border-color: #c7d2fe;
  }

  .m\:hover\:border-indigo-300:hover {
    border-color: #a5b4fc;
  }

  .m\:hover\:border-indigo-400:hover {
    border-color: #818cf8;
  }

  .m\:hover\:border-indigo-500:hover {
    border-color: #6366f1;
  }

  .m\:hover\:border-indigo-600:hover {
    border-color: #4f46e5;
  }

  .m\:hover\:border-indigo-700:hover {
    border-color: #4338ca;
  }

  .m\:hover\:border-indigo-800:hover {
    border-color: #3730a3;
  }

  .m\:hover\:border-indigo-900:hover {
    border-color: #312e81;
  }

  .m\:hover\:border-purple-50:hover {
    border-color: #f5f3ff;
  }

  .m\:hover\:border-purple-100:hover {
    border-color: #ede9fe;
  }

  .m\:hover\:border-purple-200:hover {
    border-color: #ddd6fe;
  }

  .m\:hover\:border-purple-300:hover {
    border-color: #c4b5fd;
  }

  .m\:hover\:border-purple-400:hover {
    border-color: #a78bfa;
  }

  .m\:hover\:border-purple-500:hover {
    border-color: #8b5cf6;
  }

  .m\:hover\:border-purple-600:hover {
    border-color: #7c3aed;
  }

  .m\:hover\:border-purple-700:hover {
    border-color: #6d28d9;
  }

  .m\:hover\:border-purple-800:hover {
    border-color: #5b21b6;
  }

  .m\:hover\:border-purple-900:hover {
    border-color: #4c1d95;
  }

  .m\:hover\:border-pink-50:hover {
    border-color: #fdf2f8;
  }

  .m\:hover\:border-pink-100:hover {
    border-color: #fce7f3;
  }

  .m\:hover\:border-pink-200:hover {
    border-color: #fbcfe8;
  }

  .m\:hover\:border-pink-300:hover {
    border-color: #f9a8d4;
  }

  .m\:hover\:border-pink-400:hover {
    border-color: #f472b6;
  }

  .m\:hover\:border-pink-500:hover {
    border-color: #ec4899;
  }

  .m\:hover\:border-pink-600:hover {
    border-color: #db2777;
  }

  .m\:hover\:border-pink-700:hover {
    border-color: #be185d;
  }

  .m\:hover\:border-pink-800:hover {
    border-color: #9d174d;
  }

  .m\:hover\:border-pink-900:hover {
    border-color: #831843;
  }

  .m\:active\:border-black.is-active,
.m\:active\:border-black:active {
    border-color: #000;
  }

  .m\:active\:border-white.is-active,
.m\:active\:border-white:active {
    border-color: #fff;
  }

  .m\:active\:border-primary.is-active,
.m\:active\:border-primary:active {
    border-color: #007bff;
  }

  .m\:active\:border-secondary.is-active,
.m\:active\:border-secondary:active {
    border-color: #6c757d;
  }

  .m\:active\:border-success.is-active,
.m\:active\:border-success:active {
    border-color: #28a745;
  }

  .m\:active\:border-info.is-active,
.m\:active\:border-info:active {
    border-color: #17a2b8;
  }

  .m\:active\:border-warning.is-active,
.m\:active\:border-warning:active {
    border-color: #fad733;
  }

  .m\:active\:border-danger.is-active,
.m\:active\:border-danger:active {
    border-color: #dc3545;
  }

  .m\:active\:border-light.is-active,
.m\:active\:border-light:active {
    border-color: #f8f9fa;
  }

  .m\:active\:border-dark.is-active,
.m\:active\:border-dark:active {
    border-color: #343a40;
  }

  .m\:active\:border-gray-50.is-active,
.m\:active\:border-gray-50:active {
    border-color: #f9fafb;
  }

  .m\:active\:border-gray-100.is-active,
.m\:active\:border-gray-100:active {
    border-color: #f3f4f6;
  }

  .m\:active\:border-gray-200.is-active,
.m\:active\:border-gray-200:active {
    border-color: #e5e7eb;
  }

  .m\:active\:border-gray-300.is-active,
.m\:active\:border-gray-300:active {
    border-color: #d1d5db;
  }

  .m\:active\:border-gray-400.is-active,
.m\:active\:border-gray-400:active {
    border-color: #9ca3af;
  }

  .m\:active\:border-gray-500.is-active,
.m\:active\:border-gray-500:active {
    border-color: #6b7280;
  }

  .m\:active\:border-gray-600.is-active,
.m\:active\:border-gray-600:active {
    border-color: #4b5563;
  }

  .m\:active\:border-gray-700.is-active,
.m\:active\:border-gray-700:active {
    border-color: #374151;
  }

  .m\:active\:border-gray-800.is-active,
.m\:active\:border-gray-800:active {
    border-color: #1f2937;
  }

  .m\:active\:border-gray-900.is-active,
.m\:active\:border-gray-900:active {
    border-color: #111827;
  }

  .m\:active\:border-red-50.is-active,
.m\:active\:border-red-50:active {
    border-color: #fef2f2;
  }

  .m\:active\:border-red-100.is-active,
.m\:active\:border-red-100:active {
    border-color: #fee2e2;
  }

  .m\:active\:border-red-200.is-active,
.m\:active\:border-red-200:active {
    border-color: #fecaca;
  }

  .m\:active\:border-red-300.is-active,
.m\:active\:border-red-300:active {
    border-color: #fca5a5;
  }

  .m\:active\:border-red-400.is-active,
.m\:active\:border-red-400:active {
    border-color: #f87171;
  }

  .m\:active\:border-red-500.is-active,
.m\:active\:border-red-500:active {
    border-color: #ef4444;
  }

  .m\:active\:border-red-600.is-active,
.m\:active\:border-red-600:active {
    border-color: #dc2626;
  }

  .m\:active\:border-red-700.is-active,
.m\:active\:border-red-700:active {
    border-color: #b91c1c;
  }

  .m\:active\:border-red-800.is-active,
.m\:active\:border-red-800:active {
    border-color: #991b1b;
  }

  .m\:active\:border-red-900.is-active,
.m\:active\:border-red-900:active {
    border-color: #7f1d1d;
  }

  .m\:active\:border-yellow-50.is-active,
.m\:active\:border-yellow-50:active {
    border-color: #fffbeb;
  }

  .m\:active\:border-yellow-100.is-active,
.m\:active\:border-yellow-100:active {
    border-color: #fef3c7;
  }

  .m\:active\:border-yellow-200.is-active,
.m\:active\:border-yellow-200:active {
    border-color: #fde68a;
  }

  .m\:active\:border-yellow-300.is-active,
.m\:active\:border-yellow-300:active {
    border-color: #fcd34d;
  }

  .m\:active\:border-yellow-400.is-active,
.m\:active\:border-yellow-400:active {
    border-color: #fbbf24;
  }

  .m\:active\:border-yellow-500.is-active,
.m\:active\:border-yellow-500:active {
    border-color: #f59e0b;
  }

  .m\:active\:border-yellow-600.is-active,
.m\:active\:border-yellow-600:active {
    border-color: #d97706;
  }

  .m\:active\:border-yellow-700.is-active,
.m\:active\:border-yellow-700:active {
    border-color: #b45309;
  }

  .m\:active\:border-yellow-800.is-active,
.m\:active\:border-yellow-800:active {
    border-color: #92400e;
  }

  .m\:active\:border-yellow-900.is-active,
.m\:active\:border-yellow-900:active {
    border-color: #78350f;
  }

  .m\:active\:border-green-50.is-active,
.m\:active\:border-green-50:active {
    border-color: #ecfdf5;
  }

  .m\:active\:border-green-100.is-active,
.m\:active\:border-green-100:active {
    border-color: #d1fae5;
  }

  .m\:active\:border-green-200.is-active,
.m\:active\:border-green-200:active {
    border-color: #a7f3d0;
  }

  .m\:active\:border-green-300.is-active,
.m\:active\:border-green-300:active {
    border-color: #6ee7b7;
  }

  .m\:active\:border-green-400.is-active,
.m\:active\:border-green-400:active {
    border-color: #34d399;
  }

  .m\:active\:border-green-500.is-active,
.m\:active\:border-green-500:active {
    border-color: #10b981;
  }

  .m\:active\:border-green-600.is-active,
.m\:active\:border-green-600:active {
    border-color: #059669;
  }

  .m\:active\:border-green-700.is-active,
.m\:active\:border-green-700:active {
    border-color: #047857;
  }

  .m\:active\:border-green-800.is-active,
.m\:active\:border-green-800:active {
    border-color: #065f46;
  }

  .m\:active\:border-green-900.is-active,
.m\:active\:border-green-900:active {
    border-color: #064e3b;
  }

  .m\:active\:border-blue-50.is-active,
.m\:active\:border-blue-50:active {
    border-color: #eff6ff;
  }

  .m\:active\:border-blue-100.is-active,
.m\:active\:border-blue-100:active {
    border-color: #dbeafe;
  }

  .m\:active\:border-blue-200.is-active,
.m\:active\:border-blue-200:active {
    border-color: #bfdbfe;
  }

  .m\:active\:border-blue-300.is-active,
.m\:active\:border-blue-300:active {
    border-color: #93c5fd;
  }

  .m\:active\:border-blue-400.is-active,
.m\:active\:border-blue-400:active {
    border-color: #60a5fa;
  }

  .m\:active\:border-blue-500.is-active,
.m\:active\:border-blue-500:active {
    border-color: #3b82f6;
  }

  .m\:active\:border-blue-600.is-active,
.m\:active\:border-blue-600:active {
    border-color: #2563eb;
  }

  .m\:active\:border-blue-700.is-active,
.m\:active\:border-blue-700:active {
    border-color: #1d4ed8;
  }

  .m\:active\:border-blue-800.is-active,
.m\:active\:border-blue-800:active {
    border-color: #1e40af;
  }

  .m\:active\:border-blue-900.is-active,
.m\:active\:border-blue-900:active {
    border-color: #1e3a8a;
  }

  .m\:active\:border-cyan-50.is-active,
.m\:active\:border-cyan-50:active {
    border-color: #ecfeff;
  }

  .m\:active\:border-cyan-100.is-active,
.m\:active\:border-cyan-100:active {
    border-color: #cffafe;
  }

  .m\:active\:border-cyan-200.is-active,
.m\:active\:border-cyan-200:active {
    border-color: #a5f3fc;
  }

  .m\:active\:border-cyan-300.is-active,
.m\:active\:border-cyan-300:active {
    border-color: #67e8f9;
  }

  .m\:active\:border-cyan-400.is-active,
.m\:active\:border-cyan-400:active {
    border-color: #22d3ee;
  }

  .m\:active\:border-cyan-500.is-active,
.m\:active\:border-cyan-500:active {
    border-color: #06b6d4;
  }

  .m\:active\:border-cyan-600.is-active,
.m\:active\:border-cyan-600:active {
    border-color: #0891b2;
  }

  .m\:active\:border-cyan-700.is-active,
.m\:active\:border-cyan-700:active {
    border-color: #0e7490;
  }

  .m\:active\:border-cyan-800.is-active,
.m\:active\:border-cyan-800:active {
    border-color: #155e75;
  }

  .m\:active\:border-cyan-900.is-active,
.m\:active\:border-cyan-900:active {
    border-color: #164e63;
  }

  .m\:active\:border-indigo-50.is-active,
.m\:active\:border-indigo-50:active {
    border-color: #eef2ff;
  }

  .m\:active\:border-indigo-100.is-active,
.m\:active\:border-indigo-100:active {
    border-color: #e0e7ff;
  }

  .m\:active\:border-indigo-200.is-active,
.m\:active\:border-indigo-200:active {
    border-color: #c7d2fe;
  }

  .m\:active\:border-indigo-300.is-active,
.m\:active\:border-indigo-300:active {
    border-color: #a5b4fc;
  }

  .m\:active\:border-indigo-400.is-active,
.m\:active\:border-indigo-400:active {
    border-color: #818cf8;
  }

  .m\:active\:border-indigo-500.is-active,
.m\:active\:border-indigo-500:active {
    border-color: #6366f1;
  }

  .m\:active\:border-indigo-600.is-active,
.m\:active\:border-indigo-600:active {
    border-color: #4f46e5;
  }

  .m\:active\:border-indigo-700.is-active,
.m\:active\:border-indigo-700:active {
    border-color: #4338ca;
  }

  .m\:active\:border-indigo-800.is-active,
.m\:active\:border-indigo-800:active {
    border-color: #3730a3;
  }

  .m\:active\:border-indigo-900.is-active,
.m\:active\:border-indigo-900:active {
    border-color: #312e81;
  }

  .m\:active\:border-purple-50.is-active,
.m\:active\:border-purple-50:active {
    border-color: #f5f3ff;
  }

  .m\:active\:border-purple-100.is-active,
.m\:active\:border-purple-100:active {
    border-color: #ede9fe;
  }

  .m\:active\:border-purple-200.is-active,
.m\:active\:border-purple-200:active {
    border-color: #ddd6fe;
  }

  .m\:active\:border-purple-300.is-active,
.m\:active\:border-purple-300:active {
    border-color: #c4b5fd;
  }

  .m\:active\:border-purple-400.is-active,
.m\:active\:border-purple-400:active {
    border-color: #a78bfa;
  }

  .m\:active\:border-purple-500.is-active,
.m\:active\:border-purple-500:active {
    border-color: #8b5cf6;
  }

  .m\:active\:border-purple-600.is-active,
.m\:active\:border-purple-600:active {
    border-color: #7c3aed;
  }

  .m\:active\:border-purple-700.is-active,
.m\:active\:border-purple-700:active {
    border-color: #6d28d9;
  }

  .m\:active\:border-purple-800.is-active,
.m\:active\:border-purple-800:active {
    border-color: #5b21b6;
  }

  .m\:active\:border-purple-900.is-active,
.m\:active\:border-purple-900:active {
    border-color: #4c1d95;
  }

  .m\:active\:border-pink-50.is-active,
.m\:active\:border-pink-50:active {
    border-color: #fdf2f8;
  }

  .m\:active\:border-pink-100.is-active,
.m\:active\:border-pink-100:active {
    border-color: #fce7f3;
  }

  .m\:active\:border-pink-200.is-active,
.m\:active\:border-pink-200:active {
    border-color: #fbcfe8;
  }

  .m\:active\:border-pink-300.is-active,
.m\:active\:border-pink-300:active {
    border-color: #f9a8d4;
  }

  .m\:active\:border-pink-400.is-active,
.m\:active\:border-pink-400:active {
    border-color: #f472b6;
  }

  .m\:active\:border-pink-500.is-active,
.m\:active\:border-pink-500:active {
    border-color: #ec4899;
  }

  .m\:active\:border-pink-600.is-active,
.m\:active\:border-pink-600:active {
    border-color: #db2777;
  }

  .m\:active\:border-pink-700.is-active,
.m\:active\:border-pink-700:active {
    border-color: #be185d;
  }

  .m\:active\:border-pink-800.is-active,
.m\:active\:border-pink-800:active {
    border-color: #9d174d;
  }

  .m\:active\:border-pink-900.is-active,
.m\:active\:border-pink-900:active {
    border-color: #831843;
  }

  .m\:focus\:border-black:focus {
    border-color: #000;
  }

  .m\:focus\:border-white:focus {
    border-color: #fff;
  }

  .m\:focus\:border-primary:focus {
    border-color: #007bff;
  }

  .m\:focus\:border-secondary:focus {
    border-color: #6c757d;
  }

  .m\:focus\:border-success:focus {
    border-color: #28a745;
  }

  .m\:focus\:border-info:focus {
    border-color: #17a2b8;
  }

  .m\:focus\:border-warning:focus {
    border-color: #fad733;
  }

  .m\:focus\:border-danger:focus {
    border-color: #dc3545;
  }

  .m\:focus\:border-light:focus {
    border-color: #f8f9fa;
  }

  .m\:focus\:border-dark:focus {
    border-color: #343a40;
  }

  .m\:focus\:border-gray-50:focus {
    border-color: #f9fafb;
  }

  .m\:focus\:border-gray-100:focus {
    border-color: #f3f4f6;
  }

  .m\:focus\:border-gray-200:focus {
    border-color: #e5e7eb;
  }

  .m\:focus\:border-gray-300:focus {
    border-color: #d1d5db;
  }

  .m\:focus\:border-gray-400:focus {
    border-color: #9ca3af;
  }

  .m\:focus\:border-gray-500:focus {
    border-color: #6b7280;
  }

  .m\:focus\:border-gray-600:focus {
    border-color: #4b5563;
  }

  .m\:focus\:border-gray-700:focus {
    border-color: #374151;
  }

  .m\:focus\:border-gray-800:focus {
    border-color: #1f2937;
  }

  .m\:focus\:border-gray-900:focus {
    border-color: #111827;
  }

  .m\:focus\:border-red-50:focus {
    border-color: #fef2f2;
  }

  .m\:focus\:border-red-100:focus {
    border-color: #fee2e2;
  }

  .m\:focus\:border-red-200:focus {
    border-color: #fecaca;
  }

  .m\:focus\:border-red-300:focus {
    border-color: #fca5a5;
  }

  .m\:focus\:border-red-400:focus {
    border-color: #f87171;
  }

  .m\:focus\:border-red-500:focus {
    border-color: #ef4444;
  }

  .m\:focus\:border-red-600:focus {
    border-color: #dc2626;
  }

  .m\:focus\:border-red-700:focus {
    border-color: #b91c1c;
  }

  .m\:focus\:border-red-800:focus {
    border-color: #991b1b;
  }

  .m\:focus\:border-red-900:focus {
    border-color: #7f1d1d;
  }

  .m\:focus\:border-yellow-50:focus {
    border-color: #fffbeb;
  }

  .m\:focus\:border-yellow-100:focus {
    border-color: #fef3c7;
  }

  .m\:focus\:border-yellow-200:focus {
    border-color: #fde68a;
  }

  .m\:focus\:border-yellow-300:focus {
    border-color: #fcd34d;
  }

  .m\:focus\:border-yellow-400:focus {
    border-color: #fbbf24;
  }

  .m\:focus\:border-yellow-500:focus {
    border-color: #f59e0b;
  }

  .m\:focus\:border-yellow-600:focus {
    border-color: #d97706;
  }

  .m\:focus\:border-yellow-700:focus {
    border-color: #b45309;
  }

  .m\:focus\:border-yellow-800:focus {
    border-color: #92400e;
  }

  .m\:focus\:border-yellow-900:focus {
    border-color: #78350f;
  }

  .m\:focus\:border-green-50:focus {
    border-color: #ecfdf5;
  }

  .m\:focus\:border-green-100:focus {
    border-color: #d1fae5;
  }

  .m\:focus\:border-green-200:focus {
    border-color: #a7f3d0;
  }

  .m\:focus\:border-green-300:focus {
    border-color: #6ee7b7;
  }

  .m\:focus\:border-green-400:focus {
    border-color: #34d399;
  }

  .m\:focus\:border-green-500:focus {
    border-color: #10b981;
  }

  .m\:focus\:border-green-600:focus {
    border-color: #059669;
  }

  .m\:focus\:border-green-700:focus {
    border-color: #047857;
  }

  .m\:focus\:border-green-800:focus {
    border-color: #065f46;
  }

  .m\:focus\:border-green-900:focus {
    border-color: #064e3b;
  }

  .m\:focus\:border-blue-50:focus {
    border-color: #eff6ff;
  }

  .m\:focus\:border-blue-100:focus {
    border-color: #dbeafe;
  }

  .m\:focus\:border-blue-200:focus {
    border-color: #bfdbfe;
  }

  .m\:focus\:border-blue-300:focus {
    border-color: #93c5fd;
  }

  .m\:focus\:border-blue-400:focus {
    border-color: #60a5fa;
  }

  .m\:focus\:border-blue-500:focus {
    border-color: #3b82f6;
  }

  .m\:focus\:border-blue-600:focus {
    border-color: #2563eb;
  }

  .m\:focus\:border-blue-700:focus {
    border-color: #1d4ed8;
  }

  .m\:focus\:border-blue-800:focus {
    border-color: #1e40af;
  }

  .m\:focus\:border-blue-900:focus {
    border-color: #1e3a8a;
  }

  .m\:focus\:border-cyan-50:focus {
    border-color: #ecfeff;
  }

  .m\:focus\:border-cyan-100:focus {
    border-color: #cffafe;
  }

  .m\:focus\:border-cyan-200:focus {
    border-color: #a5f3fc;
  }

  .m\:focus\:border-cyan-300:focus {
    border-color: #67e8f9;
  }

  .m\:focus\:border-cyan-400:focus {
    border-color: #22d3ee;
  }

  .m\:focus\:border-cyan-500:focus {
    border-color: #06b6d4;
  }

  .m\:focus\:border-cyan-600:focus {
    border-color: #0891b2;
  }

  .m\:focus\:border-cyan-700:focus {
    border-color: #0e7490;
  }

  .m\:focus\:border-cyan-800:focus {
    border-color: #155e75;
  }

  .m\:focus\:border-cyan-900:focus {
    border-color: #164e63;
  }

  .m\:focus\:border-indigo-50:focus {
    border-color: #eef2ff;
  }

  .m\:focus\:border-indigo-100:focus {
    border-color: #e0e7ff;
  }

  .m\:focus\:border-indigo-200:focus {
    border-color: #c7d2fe;
  }

  .m\:focus\:border-indigo-300:focus {
    border-color: #a5b4fc;
  }

  .m\:focus\:border-indigo-400:focus {
    border-color: #818cf8;
  }

  .m\:focus\:border-indigo-500:focus {
    border-color: #6366f1;
  }

  .m\:focus\:border-indigo-600:focus {
    border-color: #4f46e5;
  }

  .m\:focus\:border-indigo-700:focus {
    border-color: #4338ca;
  }

  .m\:focus\:border-indigo-800:focus {
    border-color: #3730a3;
  }

  .m\:focus\:border-indigo-900:focus {
    border-color: #312e81;
  }

  .m\:focus\:border-purple-50:focus {
    border-color: #f5f3ff;
  }

  .m\:focus\:border-purple-100:focus {
    border-color: #ede9fe;
  }

  .m\:focus\:border-purple-200:focus {
    border-color: #ddd6fe;
  }

  .m\:focus\:border-purple-300:focus {
    border-color: #c4b5fd;
  }

  .m\:focus\:border-purple-400:focus {
    border-color: #a78bfa;
  }

  .m\:focus\:border-purple-500:focus {
    border-color: #8b5cf6;
  }

  .m\:focus\:border-purple-600:focus {
    border-color: #7c3aed;
  }

  .m\:focus\:border-purple-700:focus {
    border-color: #6d28d9;
  }

  .m\:focus\:border-purple-800:focus {
    border-color: #5b21b6;
  }

  .m\:focus\:border-purple-900:focus {
    border-color: #4c1d95;
  }

  .m\:focus\:border-pink-50:focus {
    border-color: #fdf2f8;
  }

  .m\:focus\:border-pink-100:focus {
    border-color: #fce7f3;
  }

  .m\:focus\:border-pink-200:focus {
    border-color: #fbcfe8;
  }

  .m\:focus\:border-pink-300:focus {
    border-color: #f9a8d4;
  }

  .m\:focus\:border-pink-400:focus {
    border-color: #f472b6;
  }

  .m\:focus\:border-pink-500:focus {
    border-color: #ec4899;
  }

  .m\:focus\:border-pink-600:focus {
    border-color: #db2777;
  }

  .m\:focus\:border-pink-700:focus {
    border-color: #be185d;
  }

  .m\:focus\:border-pink-800:focus {
    border-color: #9d174d;
  }

  .m\:focus\:border-pink-900:focus {
    border-color: #831843;
  }

  .m\:disabled\:border-black.is-disabled,
.m\:disabled\:border-black:disabled {
    border-color: #000;
  }

  .m\:disabled\:border-white.is-disabled,
.m\:disabled\:border-white:disabled {
    border-color: #fff;
  }

  .m\:disabled\:border-primary.is-disabled,
.m\:disabled\:border-primary:disabled {
    border-color: #007bff;
  }

  .m\:disabled\:border-secondary.is-disabled,
.m\:disabled\:border-secondary:disabled {
    border-color: #6c757d;
  }

  .m\:disabled\:border-success.is-disabled,
.m\:disabled\:border-success:disabled {
    border-color: #28a745;
  }

  .m\:disabled\:border-info.is-disabled,
.m\:disabled\:border-info:disabled {
    border-color: #17a2b8;
  }

  .m\:disabled\:border-warning.is-disabled,
.m\:disabled\:border-warning:disabled {
    border-color: #fad733;
  }

  .m\:disabled\:border-danger.is-disabled,
.m\:disabled\:border-danger:disabled {
    border-color: #dc3545;
  }

  .m\:disabled\:border-light.is-disabled,
.m\:disabled\:border-light:disabled {
    border-color: #f8f9fa;
  }

  .m\:disabled\:border-dark.is-disabled,
.m\:disabled\:border-dark:disabled {
    border-color: #343a40;
  }

  .m\:disabled\:border-gray-50.is-disabled,
.m\:disabled\:border-gray-50:disabled {
    border-color: #f9fafb;
  }

  .m\:disabled\:border-gray-100.is-disabled,
.m\:disabled\:border-gray-100:disabled {
    border-color: #f3f4f6;
  }

  .m\:disabled\:border-gray-200.is-disabled,
.m\:disabled\:border-gray-200:disabled {
    border-color: #e5e7eb;
  }

  .m\:disabled\:border-gray-300.is-disabled,
.m\:disabled\:border-gray-300:disabled {
    border-color: #d1d5db;
  }

  .m\:disabled\:border-gray-400.is-disabled,
.m\:disabled\:border-gray-400:disabled {
    border-color: #9ca3af;
  }

  .m\:disabled\:border-gray-500.is-disabled,
.m\:disabled\:border-gray-500:disabled {
    border-color: #6b7280;
  }

  .m\:disabled\:border-gray-600.is-disabled,
.m\:disabled\:border-gray-600:disabled {
    border-color: #4b5563;
  }

  .m\:disabled\:border-gray-700.is-disabled,
.m\:disabled\:border-gray-700:disabled {
    border-color: #374151;
  }

  .m\:disabled\:border-gray-800.is-disabled,
.m\:disabled\:border-gray-800:disabled {
    border-color: #1f2937;
  }

  .m\:disabled\:border-gray-900.is-disabled,
.m\:disabled\:border-gray-900:disabled {
    border-color: #111827;
  }

  .m\:disabled\:border-red-50.is-disabled,
.m\:disabled\:border-red-50:disabled {
    border-color: #fef2f2;
  }

  .m\:disabled\:border-red-100.is-disabled,
.m\:disabled\:border-red-100:disabled {
    border-color: #fee2e2;
  }

  .m\:disabled\:border-red-200.is-disabled,
.m\:disabled\:border-red-200:disabled {
    border-color: #fecaca;
  }

  .m\:disabled\:border-red-300.is-disabled,
.m\:disabled\:border-red-300:disabled {
    border-color: #fca5a5;
  }

  .m\:disabled\:border-red-400.is-disabled,
.m\:disabled\:border-red-400:disabled {
    border-color: #f87171;
  }

  .m\:disabled\:border-red-500.is-disabled,
.m\:disabled\:border-red-500:disabled {
    border-color: #ef4444;
  }

  .m\:disabled\:border-red-600.is-disabled,
.m\:disabled\:border-red-600:disabled {
    border-color: #dc2626;
  }

  .m\:disabled\:border-red-700.is-disabled,
.m\:disabled\:border-red-700:disabled {
    border-color: #b91c1c;
  }

  .m\:disabled\:border-red-800.is-disabled,
.m\:disabled\:border-red-800:disabled {
    border-color: #991b1b;
  }

  .m\:disabled\:border-red-900.is-disabled,
.m\:disabled\:border-red-900:disabled {
    border-color: #7f1d1d;
  }

  .m\:disabled\:border-yellow-50.is-disabled,
.m\:disabled\:border-yellow-50:disabled {
    border-color: #fffbeb;
  }

  .m\:disabled\:border-yellow-100.is-disabled,
.m\:disabled\:border-yellow-100:disabled {
    border-color: #fef3c7;
  }

  .m\:disabled\:border-yellow-200.is-disabled,
.m\:disabled\:border-yellow-200:disabled {
    border-color: #fde68a;
  }

  .m\:disabled\:border-yellow-300.is-disabled,
.m\:disabled\:border-yellow-300:disabled {
    border-color: #fcd34d;
  }

  .m\:disabled\:border-yellow-400.is-disabled,
.m\:disabled\:border-yellow-400:disabled {
    border-color: #fbbf24;
  }

  .m\:disabled\:border-yellow-500.is-disabled,
.m\:disabled\:border-yellow-500:disabled {
    border-color: #f59e0b;
  }

  .m\:disabled\:border-yellow-600.is-disabled,
.m\:disabled\:border-yellow-600:disabled {
    border-color: #d97706;
  }

  .m\:disabled\:border-yellow-700.is-disabled,
.m\:disabled\:border-yellow-700:disabled {
    border-color: #b45309;
  }

  .m\:disabled\:border-yellow-800.is-disabled,
.m\:disabled\:border-yellow-800:disabled {
    border-color: #92400e;
  }

  .m\:disabled\:border-yellow-900.is-disabled,
.m\:disabled\:border-yellow-900:disabled {
    border-color: #78350f;
  }

  .m\:disabled\:border-green-50.is-disabled,
.m\:disabled\:border-green-50:disabled {
    border-color: #ecfdf5;
  }

  .m\:disabled\:border-green-100.is-disabled,
.m\:disabled\:border-green-100:disabled {
    border-color: #d1fae5;
  }

  .m\:disabled\:border-green-200.is-disabled,
.m\:disabled\:border-green-200:disabled {
    border-color: #a7f3d0;
  }

  .m\:disabled\:border-green-300.is-disabled,
.m\:disabled\:border-green-300:disabled {
    border-color: #6ee7b7;
  }

  .m\:disabled\:border-green-400.is-disabled,
.m\:disabled\:border-green-400:disabled {
    border-color: #34d399;
  }

  .m\:disabled\:border-green-500.is-disabled,
.m\:disabled\:border-green-500:disabled {
    border-color: #10b981;
  }

  .m\:disabled\:border-green-600.is-disabled,
.m\:disabled\:border-green-600:disabled {
    border-color: #059669;
  }

  .m\:disabled\:border-green-700.is-disabled,
.m\:disabled\:border-green-700:disabled {
    border-color: #047857;
  }

  .m\:disabled\:border-green-800.is-disabled,
.m\:disabled\:border-green-800:disabled {
    border-color: #065f46;
  }

  .m\:disabled\:border-green-900.is-disabled,
.m\:disabled\:border-green-900:disabled {
    border-color: #064e3b;
  }

  .m\:disabled\:border-blue-50.is-disabled,
.m\:disabled\:border-blue-50:disabled {
    border-color: #eff6ff;
  }

  .m\:disabled\:border-blue-100.is-disabled,
.m\:disabled\:border-blue-100:disabled {
    border-color: #dbeafe;
  }

  .m\:disabled\:border-blue-200.is-disabled,
.m\:disabled\:border-blue-200:disabled {
    border-color: #bfdbfe;
  }

  .m\:disabled\:border-blue-300.is-disabled,
.m\:disabled\:border-blue-300:disabled {
    border-color: #93c5fd;
  }

  .m\:disabled\:border-blue-400.is-disabled,
.m\:disabled\:border-blue-400:disabled {
    border-color: #60a5fa;
  }

  .m\:disabled\:border-blue-500.is-disabled,
.m\:disabled\:border-blue-500:disabled {
    border-color: #3b82f6;
  }

  .m\:disabled\:border-blue-600.is-disabled,
.m\:disabled\:border-blue-600:disabled {
    border-color: #2563eb;
  }

  .m\:disabled\:border-blue-700.is-disabled,
.m\:disabled\:border-blue-700:disabled {
    border-color: #1d4ed8;
  }

  .m\:disabled\:border-blue-800.is-disabled,
.m\:disabled\:border-blue-800:disabled {
    border-color: #1e40af;
  }

  .m\:disabled\:border-blue-900.is-disabled,
.m\:disabled\:border-blue-900:disabled {
    border-color: #1e3a8a;
  }

  .m\:disabled\:border-cyan-50.is-disabled,
.m\:disabled\:border-cyan-50:disabled {
    border-color: #ecfeff;
  }

  .m\:disabled\:border-cyan-100.is-disabled,
.m\:disabled\:border-cyan-100:disabled {
    border-color: #cffafe;
  }

  .m\:disabled\:border-cyan-200.is-disabled,
.m\:disabled\:border-cyan-200:disabled {
    border-color: #a5f3fc;
  }

  .m\:disabled\:border-cyan-300.is-disabled,
.m\:disabled\:border-cyan-300:disabled {
    border-color: #67e8f9;
  }

  .m\:disabled\:border-cyan-400.is-disabled,
.m\:disabled\:border-cyan-400:disabled {
    border-color: #22d3ee;
  }

  .m\:disabled\:border-cyan-500.is-disabled,
.m\:disabled\:border-cyan-500:disabled {
    border-color: #06b6d4;
  }

  .m\:disabled\:border-cyan-600.is-disabled,
.m\:disabled\:border-cyan-600:disabled {
    border-color: #0891b2;
  }

  .m\:disabled\:border-cyan-700.is-disabled,
.m\:disabled\:border-cyan-700:disabled {
    border-color: #0e7490;
  }

  .m\:disabled\:border-cyan-800.is-disabled,
.m\:disabled\:border-cyan-800:disabled {
    border-color: #155e75;
  }

  .m\:disabled\:border-cyan-900.is-disabled,
.m\:disabled\:border-cyan-900:disabled {
    border-color: #164e63;
  }

  .m\:disabled\:border-indigo-50.is-disabled,
.m\:disabled\:border-indigo-50:disabled {
    border-color: #eef2ff;
  }

  .m\:disabled\:border-indigo-100.is-disabled,
.m\:disabled\:border-indigo-100:disabled {
    border-color: #e0e7ff;
  }

  .m\:disabled\:border-indigo-200.is-disabled,
.m\:disabled\:border-indigo-200:disabled {
    border-color: #c7d2fe;
  }

  .m\:disabled\:border-indigo-300.is-disabled,
.m\:disabled\:border-indigo-300:disabled {
    border-color: #a5b4fc;
  }

  .m\:disabled\:border-indigo-400.is-disabled,
.m\:disabled\:border-indigo-400:disabled {
    border-color: #818cf8;
  }

  .m\:disabled\:border-indigo-500.is-disabled,
.m\:disabled\:border-indigo-500:disabled {
    border-color: #6366f1;
  }

  .m\:disabled\:border-indigo-600.is-disabled,
.m\:disabled\:border-indigo-600:disabled {
    border-color: #4f46e5;
  }

  .m\:disabled\:border-indigo-700.is-disabled,
.m\:disabled\:border-indigo-700:disabled {
    border-color: #4338ca;
  }

  .m\:disabled\:border-indigo-800.is-disabled,
.m\:disabled\:border-indigo-800:disabled {
    border-color: #3730a3;
  }

  .m\:disabled\:border-indigo-900.is-disabled,
.m\:disabled\:border-indigo-900:disabled {
    border-color: #312e81;
  }

  .m\:disabled\:border-purple-50.is-disabled,
.m\:disabled\:border-purple-50:disabled {
    border-color: #f5f3ff;
  }

  .m\:disabled\:border-purple-100.is-disabled,
.m\:disabled\:border-purple-100:disabled {
    border-color: #ede9fe;
  }

  .m\:disabled\:border-purple-200.is-disabled,
.m\:disabled\:border-purple-200:disabled {
    border-color: #ddd6fe;
  }

  .m\:disabled\:border-purple-300.is-disabled,
.m\:disabled\:border-purple-300:disabled {
    border-color: #c4b5fd;
  }

  .m\:disabled\:border-purple-400.is-disabled,
.m\:disabled\:border-purple-400:disabled {
    border-color: #a78bfa;
  }

  .m\:disabled\:border-purple-500.is-disabled,
.m\:disabled\:border-purple-500:disabled {
    border-color: #8b5cf6;
  }

  .m\:disabled\:border-purple-600.is-disabled,
.m\:disabled\:border-purple-600:disabled {
    border-color: #7c3aed;
  }

  .m\:disabled\:border-purple-700.is-disabled,
.m\:disabled\:border-purple-700:disabled {
    border-color: #6d28d9;
  }

  .m\:disabled\:border-purple-800.is-disabled,
.m\:disabled\:border-purple-800:disabled {
    border-color: #5b21b6;
  }

  .m\:disabled\:border-purple-900.is-disabled,
.m\:disabled\:border-purple-900:disabled {
    border-color: #4c1d95;
  }

  .m\:disabled\:border-pink-50.is-disabled,
.m\:disabled\:border-pink-50:disabled {
    border-color: #fdf2f8;
  }

  .m\:disabled\:border-pink-100.is-disabled,
.m\:disabled\:border-pink-100:disabled {
    border-color: #fce7f3;
  }

  .m\:disabled\:border-pink-200.is-disabled,
.m\:disabled\:border-pink-200:disabled {
    border-color: #fbcfe8;
  }

  .m\:disabled\:border-pink-300.is-disabled,
.m\:disabled\:border-pink-300:disabled {
    border-color: #f9a8d4;
  }

  .m\:disabled\:border-pink-400.is-disabled,
.m\:disabled\:border-pink-400:disabled {
    border-color: #f472b6;
  }

  .m\:disabled\:border-pink-500.is-disabled,
.m\:disabled\:border-pink-500:disabled {
    border-color: #ec4899;
  }

  .m\:disabled\:border-pink-600.is-disabled,
.m\:disabled\:border-pink-600:disabled {
    border-color: #db2777;
  }

  .m\:disabled\:border-pink-700.is-disabled,
.m\:disabled\:border-pink-700:disabled {
    border-color: #be185d;
  }

  .m\:disabled\:border-pink-800.is-disabled,
.m\:disabled\:border-pink-800:disabled {
    border-color: #9d174d;
  }

  .m\:disabled\:border-pink-900.is-disabled,
.m\:disabled\:border-pink-900:disabled {
    border-color: #831843;
  }

  .group:hover .m\:group-hover\:border-black {
    border-color: #000;
  }

  .group:hover .m\:group-hover\:border-white {
    border-color: #fff;
  }

  .group:hover .m\:group-hover\:border-primary {
    border-color: #007bff;
  }

  .group:hover .m\:group-hover\:border-secondary {
    border-color: #6c757d;
  }

  .group:hover .m\:group-hover\:border-success {
    border-color: #28a745;
  }

  .group:hover .m\:group-hover\:border-info {
    border-color: #17a2b8;
  }

  .group:hover .m\:group-hover\:border-warning {
    border-color: #fad733;
  }

  .group:hover .m\:group-hover\:border-danger {
    border-color: #dc3545;
  }

  .group:hover .m\:group-hover\:border-light {
    border-color: #f8f9fa;
  }

  .group:hover .m\:group-hover\:border-dark {
    border-color: #343a40;
  }

  .group:hover .m\:group-hover\:border-gray-50 {
    border-color: #f9fafb;
  }

  .group:hover .m\:group-hover\:border-gray-100 {
    border-color: #f3f4f6;
  }

  .group:hover .m\:group-hover\:border-gray-200 {
    border-color: #e5e7eb;
  }

  .group:hover .m\:group-hover\:border-gray-300 {
    border-color: #d1d5db;
  }

  .group:hover .m\:group-hover\:border-gray-400 {
    border-color: #9ca3af;
  }

  .group:hover .m\:group-hover\:border-gray-500 {
    border-color: #6b7280;
  }

  .group:hover .m\:group-hover\:border-gray-600 {
    border-color: #4b5563;
  }

  .group:hover .m\:group-hover\:border-gray-700 {
    border-color: #374151;
  }

  .group:hover .m\:group-hover\:border-gray-800 {
    border-color: #1f2937;
  }

  .group:hover .m\:group-hover\:border-gray-900 {
    border-color: #111827;
  }

  .group:hover .m\:group-hover\:border-red-50 {
    border-color: #fef2f2;
  }

  .group:hover .m\:group-hover\:border-red-100 {
    border-color: #fee2e2;
  }

  .group:hover .m\:group-hover\:border-red-200 {
    border-color: #fecaca;
  }

  .group:hover .m\:group-hover\:border-red-300 {
    border-color: #fca5a5;
  }

  .group:hover .m\:group-hover\:border-red-400 {
    border-color: #f87171;
  }

  .group:hover .m\:group-hover\:border-red-500 {
    border-color: #ef4444;
  }

  .group:hover .m\:group-hover\:border-red-600 {
    border-color: #dc2626;
  }

  .group:hover .m\:group-hover\:border-red-700 {
    border-color: #b91c1c;
  }

  .group:hover .m\:group-hover\:border-red-800 {
    border-color: #991b1b;
  }

  .group:hover .m\:group-hover\:border-red-900 {
    border-color: #7f1d1d;
  }

  .group:hover .m\:group-hover\:border-yellow-50 {
    border-color: #fffbeb;
  }

  .group:hover .m\:group-hover\:border-yellow-100 {
    border-color: #fef3c7;
  }

  .group:hover .m\:group-hover\:border-yellow-200 {
    border-color: #fde68a;
  }

  .group:hover .m\:group-hover\:border-yellow-300 {
    border-color: #fcd34d;
  }

  .group:hover .m\:group-hover\:border-yellow-400 {
    border-color: #fbbf24;
  }

  .group:hover .m\:group-hover\:border-yellow-500 {
    border-color: #f59e0b;
  }

  .group:hover .m\:group-hover\:border-yellow-600 {
    border-color: #d97706;
  }

  .group:hover .m\:group-hover\:border-yellow-700 {
    border-color: #b45309;
  }

  .group:hover .m\:group-hover\:border-yellow-800 {
    border-color: #92400e;
  }

  .group:hover .m\:group-hover\:border-yellow-900 {
    border-color: #78350f;
  }

  .group:hover .m\:group-hover\:border-green-50 {
    border-color: #ecfdf5;
  }

  .group:hover .m\:group-hover\:border-green-100 {
    border-color: #d1fae5;
  }

  .group:hover .m\:group-hover\:border-green-200 {
    border-color: #a7f3d0;
  }

  .group:hover .m\:group-hover\:border-green-300 {
    border-color: #6ee7b7;
  }

  .group:hover .m\:group-hover\:border-green-400 {
    border-color: #34d399;
  }

  .group:hover .m\:group-hover\:border-green-500 {
    border-color: #10b981;
  }

  .group:hover .m\:group-hover\:border-green-600 {
    border-color: #059669;
  }

  .group:hover .m\:group-hover\:border-green-700 {
    border-color: #047857;
  }

  .group:hover .m\:group-hover\:border-green-800 {
    border-color: #065f46;
  }

  .group:hover .m\:group-hover\:border-green-900 {
    border-color: #064e3b;
  }

  .group:hover .m\:group-hover\:border-blue-50 {
    border-color: #eff6ff;
  }

  .group:hover .m\:group-hover\:border-blue-100 {
    border-color: #dbeafe;
  }

  .group:hover .m\:group-hover\:border-blue-200 {
    border-color: #bfdbfe;
  }

  .group:hover .m\:group-hover\:border-blue-300 {
    border-color: #93c5fd;
  }

  .group:hover .m\:group-hover\:border-blue-400 {
    border-color: #60a5fa;
  }

  .group:hover .m\:group-hover\:border-blue-500 {
    border-color: #3b82f6;
  }

  .group:hover .m\:group-hover\:border-blue-600 {
    border-color: #2563eb;
  }

  .group:hover .m\:group-hover\:border-blue-700 {
    border-color: #1d4ed8;
  }

  .group:hover .m\:group-hover\:border-blue-800 {
    border-color: #1e40af;
  }

  .group:hover .m\:group-hover\:border-blue-900 {
    border-color: #1e3a8a;
  }

  .group:hover .m\:group-hover\:border-cyan-50 {
    border-color: #ecfeff;
  }

  .group:hover .m\:group-hover\:border-cyan-100 {
    border-color: #cffafe;
  }

  .group:hover .m\:group-hover\:border-cyan-200 {
    border-color: #a5f3fc;
  }

  .group:hover .m\:group-hover\:border-cyan-300 {
    border-color: #67e8f9;
  }

  .group:hover .m\:group-hover\:border-cyan-400 {
    border-color: #22d3ee;
  }

  .group:hover .m\:group-hover\:border-cyan-500 {
    border-color: #06b6d4;
  }

  .group:hover .m\:group-hover\:border-cyan-600 {
    border-color: #0891b2;
  }

  .group:hover .m\:group-hover\:border-cyan-700 {
    border-color: #0e7490;
  }

  .group:hover .m\:group-hover\:border-cyan-800 {
    border-color: #155e75;
  }

  .group:hover .m\:group-hover\:border-cyan-900 {
    border-color: #164e63;
  }

  .group:hover .m\:group-hover\:border-indigo-50 {
    border-color: #eef2ff;
  }

  .group:hover .m\:group-hover\:border-indigo-100 {
    border-color: #e0e7ff;
  }

  .group:hover .m\:group-hover\:border-indigo-200 {
    border-color: #c7d2fe;
  }

  .group:hover .m\:group-hover\:border-indigo-300 {
    border-color: #a5b4fc;
  }

  .group:hover .m\:group-hover\:border-indigo-400 {
    border-color: #818cf8;
  }

  .group:hover .m\:group-hover\:border-indigo-500 {
    border-color: #6366f1;
  }

  .group:hover .m\:group-hover\:border-indigo-600 {
    border-color: #4f46e5;
  }

  .group:hover .m\:group-hover\:border-indigo-700 {
    border-color: #4338ca;
  }

  .group:hover .m\:group-hover\:border-indigo-800 {
    border-color: #3730a3;
  }

  .group:hover .m\:group-hover\:border-indigo-900 {
    border-color: #312e81;
  }

  .group:hover .m\:group-hover\:border-purple-50 {
    border-color: #f5f3ff;
  }

  .group:hover .m\:group-hover\:border-purple-100 {
    border-color: #ede9fe;
  }

  .group:hover .m\:group-hover\:border-purple-200 {
    border-color: #ddd6fe;
  }

  .group:hover .m\:group-hover\:border-purple-300 {
    border-color: #c4b5fd;
  }

  .group:hover .m\:group-hover\:border-purple-400 {
    border-color: #a78bfa;
  }

  .group:hover .m\:group-hover\:border-purple-500 {
    border-color: #8b5cf6;
  }

  .group:hover .m\:group-hover\:border-purple-600 {
    border-color: #7c3aed;
  }

  .group:hover .m\:group-hover\:border-purple-700 {
    border-color: #6d28d9;
  }

  .group:hover .m\:group-hover\:border-purple-800 {
    border-color: #5b21b6;
  }

  .group:hover .m\:group-hover\:border-purple-900 {
    border-color: #4c1d95;
  }

  .group:hover .m\:group-hover\:border-pink-50 {
    border-color: #fdf2f8;
  }

  .group:hover .m\:group-hover\:border-pink-100 {
    border-color: #fce7f3;
  }

  .group:hover .m\:group-hover\:border-pink-200 {
    border-color: #fbcfe8;
  }

  .group:hover .m\:group-hover\:border-pink-300 {
    border-color: #f9a8d4;
  }

  .group:hover .m\:group-hover\:border-pink-400 {
    border-color: #f472b6;
  }

  .group:hover .m\:group-hover\:border-pink-500 {
    border-color: #ec4899;
  }

  .group:hover .m\:group-hover\:border-pink-600 {
    border-color: #db2777;
  }

  .group:hover .m\:group-hover\:border-pink-700 {
    border-color: #be185d;
  }

  .group:hover .m\:group-hover\:border-pink-800 {
    border-color: #9d174d;
  }

  .group:hover .m\:group-hover\:border-pink-900 {
    border-color: #831843;
  }
}
@media (min-width: 769px) {
  .pc\:border-black {
    border-color: #000;
  }

  .pc\:border-white {
    border-color: #fff;
  }

  .pc\:border-primary {
    border-color: #007bff;
  }

  .pc\:border-secondary {
    border-color: #6c757d;
  }

  .pc\:border-success {
    border-color: #28a745;
  }

  .pc\:border-info {
    border-color: #17a2b8;
  }

  .pc\:border-warning {
    border-color: #fad733;
  }

  .pc\:border-danger {
    border-color: #dc3545;
  }

  .pc\:border-light {
    border-color: #f8f9fa;
  }

  .pc\:border-dark {
    border-color: #343a40;
  }

  .pc\:border-gray-50 {
    border-color: #f9fafb;
  }

  .pc\:border-gray-100 {
    border-color: #f3f4f6;
  }

  .pc\:border-gray-200 {
    border-color: #e5e7eb;
  }

  .pc\:border-gray-300 {
    border-color: #d1d5db;
  }

  .pc\:border-gray-400 {
    border-color: #9ca3af;
  }

  .pc\:border-gray-500 {
    border-color: #6b7280;
  }

  .pc\:border-gray-600 {
    border-color: #4b5563;
  }

  .pc\:border-gray-700 {
    border-color: #374151;
  }

  .pc\:border-gray-800 {
    border-color: #1f2937;
  }

  .pc\:border-gray-900 {
    border-color: #111827;
  }

  .pc\:border-red-50 {
    border-color: #fef2f2;
  }

  .pc\:border-red-100 {
    border-color: #fee2e2;
  }

  .pc\:border-red-200 {
    border-color: #fecaca;
  }

  .pc\:border-red-300 {
    border-color: #fca5a5;
  }

  .pc\:border-red-400 {
    border-color: #f87171;
  }

  .pc\:border-red-500 {
    border-color: #ef4444;
  }

  .pc\:border-red-600 {
    border-color: #dc2626;
  }

  .pc\:border-red-700 {
    border-color: #b91c1c;
  }

  .pc\:border-red-800 {
    border-color: #991b1b;
  }

  .pc\:border-red-900 {
    border-color: #7f1d1d;
  }

  .pc\:border-yellow-50 {
    border-color: #fffbeb;
  }

  .pc\:border-yellow-100 {
    border-color: #fef3c7;
  }

  .pc\:border-yellow-200 {
    border-color: #fde68a;
  }

  .pc\:border-yellow-300 {
    border-color: #fcd34d;
  }

  .pc\:border-yellow-400 {
    border-color: #fbbf24;
  }

  .pc\:border-yellow-500 {
    border-color: #f59e0b;
  }

  .pc\:border-yellow-600 {
    border-color: #d97706;
  }

  .pc\:border-yellow-700 {
    border-color: #b45309;
  }

  .pc\:border-yellow-800 {
    border-color: #92400e;
  }

  .pc\:border-yellow-900 {
    border-color: #78350f;
  }

  .pc\:border-green-50 {
    border-color: #ecfdf5;
  }

  .pc\:border-green-100 {
    border-color: #d1fae5;
  }

  .pc\:border-green-200 {
    border-color: #a7f3d0;
  }

  .pc\:border-green-300 {
    border-color: #6ee7b7;
  }

  .pc\:border-green-400 {
    border-color: #34d399;
  }

  .pc\:border-green-500 {
    border-color: #10b981;
  }

  .pc\:border-green-600 {
    border-color: #059669;
  }

  .pc\:border-green-700 {
    border-color: #047857;
  }

  .pc\:border-green-800 {
    border-color: #065f46;
  }

  .pc\:border-green-900 {
    border-color: #064e3b;
  }

  .pc\:border-blue-50 {
    border-color: #eff6ff;
  }

  .pc\:border-blue-100 {
    border-color: #dbeafe;
  }

  .pc\:border-blue-200 {
    border-color: #bfdbfe;
  }

  .pc\:border-blue-300 {
    border-color: #93c5fd;
  }

  .pc\:border-blue-400 {
    border-color: #60a5fa;
  }

  .pc\:border-blue-500 {
    border-color: #3b82f6;
  }

  .pc\:border-blue-600 {
    border-color: #2563eb;
  }

  .pc\:border-blue-700 {
    border-color: #1d4ed8;
  }

  .pc\:border-blue-800 {
    border-color: #1e40af;
  }

  .pc\:border-blue-900 {
    border-color: #1e3a8a;
  }

  .pc\:border-cyan-50 {
    border-color: #ecfeff;
  }

  .pc\:border-cyan-100 {
    border-color: #cffafe;
  }

  .pc\:border-cyan-200 {
    border-color: #a5f3fc;
  }

  .pc\:border-cyan-300 {
    border-color: #67e8f9;
  }

  .pc\:border-cyan-400 {
    border-color: #22d3ee;
  }

  .pc\:border-cyan-500 {
    border-color: #06b6d4;
  }

  .pc\:border-cyan-600 {
    border-color: #0891b2;
  }

  .pc\:border-cyan-700 {
    border-color: #0e7490;
  }

  .pc\:border-cyan-800 {
    border-color: #155e75;
  }

  .pc\:border-cyan-900 {
    border-color: #164e63;
  }

  .pc\:border-indigo-50 {
    border-color: #eef2ff;
  }

  .pc\:border-indigo-100 {
    border-color: #e0e7ff;
  }

  .pc\:border-indigo-200 {
    border-color: #c7d2fe;
  }

  .pc\:border-indigo-300 {
    border-color: #a5b4fc;
  }

  .pc\:border-indigo-400 {
    border-color: #818cf8;
  }

  .pc\:border-indigo-500 {
    border-color: #6366f1;
  }

  .pc\:border-indigo-600 {
    border-color: #4f46e5;
  }

  .pc\:border-indigo-700 {
    border-color: #4338ca;
  }

  .pc\:border-indigo-800 {
    border-color: #3730a3;
  }

  .pc\:border-indigo-900 {
    border-color: #312e81;
  }

  .pc\:border-purple-50 {
    border-color: #f5f3ff;
  }

  .pc\:border-purple-100 {
    border-color: #ede9fe;
  }

  .pc\:border-purple-200 {
    border-color: #ddd6fe;
  }

  .pc\:border-purple-300 {
    border-color: #c4b5fd;
  }

  .pc\:border-purple-400 {
    border-color: #a78bfa;
  }

  .pc\:border-purple-500 {
    border-color: #8b5cf6;
  }

  .pc\:border-purple-600 {
    border-color: #7c3aed;
  }

  .pc\:border-purple-700 {
    border-color: #6d28d9;
  }

  .pc\:border-purple-800 {
    border-color: #5b21b6;
  }

  .pc\:border-purple-900 {
    border-color: #4c1d95;
  }

  .pc\:border-pink-50 {
    border-color: #fdf2f8;
  }

  .pc\:border-pink-100 {
    border-color: #fce7f3;
  }

  .pc\:border-pink-200 {
    border-color: #fbcfe8;
  }

  .pc\:border-pink-300 {
    border-color: #f9a8d4;
  }

  .pc\:border-pink-400 {
    border-color: #f472b6;
  }

  .pc\:border-pink-500 {
    border-color: #ec4899;
  }

  .pc\:border-pink-600 {
    border-color: #db2777;
  }

  .pc\:border-pink-700 {
    border-color: #be185d;
  }

  .pc\:border-pink-800 {
    border-color: #9d174d;
  }

  .pc\:border-pink-900 {
    border-color: #831843;
  }

  .pc\:hover\:border-black:hover {
    border-color: #000;
  }

  .pc\:hover\:border-white:hover {
    border-color: #fff;
  }

  .pc\:hover\:border-primary:hover {
    border-color: #007bff;
  }

  .pc\:hover\:border-secondary:hover {
    border-color: #6c757d;
  }

  .pc\:hover\:border-success:hover {
    border-color: #28a745;
  }

  .pc\:hover\:border-info:hover {
    border-color: #17a2b8;
  }

  .pc\:hover\:border-warning:hover {
    border-color: #fad733;
  }

  .pc\:hover\:border-danger:hover {
    border-color: #dc3545;
  }

  .pc\:hover\:border-light:hover {
    border-color: #f8f9fa;
  }

  .pc\:hover\:border-dark:hover {
    border-color: #343a40;
  }

  .pc\:hover\:border-gray-50:hover {
    border-color: #f9fafb;
  }

  .pc\:hover\:border-gray-100:hover {
    border-color: #f3f4f6;
  }

  .pc\:hover\:border-gray-200:hover {
    border-color: #e5e7eb;
  }

  .pc\:hover\:border-gray-300:hover {
    border-color: #d1d5db;
  }

  .pc\:hover\:border-gray-400:hover {
    border-color: #9ca3af;
  }

  .pc\:hover\:border-gray-500:hover {
    border-color: #6b7280;
  }

  .pc\:hover\:border-gray-600:hover {
    border-color: #4b5563;
  }

  .pc\:hover\:border-gray-700:hover {
    border-color: #374151;
  }

  .pc\:hover\:border-gray-800:hover {
    border-color: #1f2937;
  }

  .pc\:hover\:border-gray-900:hover {
    border-color: #111827;
  }

  .pc\:hover\:border-red-50:hover {
    border-color: #fef2f2;
  }

  .pc\:hover\:border-red-100:hover {
    border-color: #fee2e2;
  }

  .pc\:hover\:border-red-200:hover {
    border-color: #fecaca;
  }

  .pc\:hover\:border-red-300:hover {
    border-color: #fca5a5;
  }

  .pc\:hover\:border-red-400:hover {
    border-color: #f87171;
  }

  .pc\:hover\:border-red-500:hover {
    border-color: #ef4444;
  }

  .pc\:hover\:border-red-600:hover {
    border-color: #dc2626;
  }

  .pc\:hover\:border-red-700:hover {
    border-color: #b91c1c;
  }

  .pc\:hover\:border-red-800:hover {
    border-color: #991b1b;
  }

  .pc\:hover\:border-red-900:hover {
    border-color: #7f1d1d;
  }

  .pc\:hover\:border-yellow-50:hover {
    border-color: #fffbeb;
  }

  .pc\:hover\:border-yellow-100:hover {
    border-color: #fef3c7;
  }

  .pc\:hover\:border-yellow-200:hover {
    border-color: #fde68a;
  }

  .pc\:hover\:border-yellow-300:hover {
    border-color: #fcd34d;
  }

  .pc\:hover\:border-yellow-400:hover {
    border-color: #fbbf24;
  }

  .pc\:hover\:border-yellow-500:hover {
    border-color: #f59e0b;
  }

  .pc\:hover\:border-yellow-600:hover {
    border-color: #d97706;
  }

  .pc\:hover\:border-yellow-700:hover {
    border-color: #b45309;
  }

  .pc\:hover\:border-yellow-800:hover {
    border-color: #92400e;
  }

  .pc\:hover\:border-yellow-900:hover {
    border-color: #78350f;
  }

  .pc\:hover\:border-green-50:hover {
    border-color: #ecfdf5;
  }

  .pc\:hover\:border-green-100:hover {
    border-color: #d1fae5;
  }

  .pc\:hover\:border-green-200:hover {
    border-color: #a7f3d0;
  }

  .pc\:hover\:border-green-300:hover {
    border-color: #6ee7b7;
  }

  .pc\:hover\:border-green-400:hover {
    border-color: #34d399;
  }

  .pc\:hover\:border-green-500:hover {
    border-color: #10b981;
  }

  .pc\:hover\:border-green-600:hover {
    border-color: #059669;
  }

  .pc\:hover\:border-green-700:hover {
    border-color: #047857;
  }

  .pc\:hover\:border-green-800:hover {
    border-color: #065f46;
  }

  .pc\:hover\:border-green-900:hover {
    border-color: #064e3b;
  }

  .pc\:hover\:border-blue-50:hover {
    border-color: #eff6ff;
  }

  .pc\:hover\:border-blue-100:hover {
    border-color: #dbeafe;
  }

  .pc\:hover\:border-blue-200:hover {
    border-color: #bfdbfe;
  }

  .pc\:hover\:border-blue-300:hover {
    border-color: #93c5fd;
  }

  .pc\:hover\:border-blue-400:hover {
    border-color: #60a5fa;
  }

  .pc\:hover\:border-blue-500:hover {
    border-color: #3b82f6;
  }

  .pc\:hover\:border-blue-600:hover {
    border-color: #2563eb;
  }

  .pc\:hover\:border-blue-700:hover {
    border-color: #1d4ed8;
  }

  .pc\:hover\:border-blue-800:hover {
    border-color: #1e40af;
  }

  .pc\:hover\:border-blue-900:hover {
    border-color: #1e3a8a;
  }

  .pc\:hover\:border-cyan-50:hover {
    border-color: #ecfeff;
  }

  .pc\:hover\:border-cyan-100:hover {
    border-color: #cffafe;
  }

  .pc\:hover\:border-cyan-200:hover {
    border-color: #a5f3fc;
  }

  .pc\:hover\:border-cyan-300:hover {
    border-color: #67e8f9;
  }

  .pc\:hover\:border-cyan-400:hover {
    border-color: #22d3ee;
  }

  .pc\:hover\:border-cyan-500:hover {
    border-color: #06b6d4;
  }

  .pc\:hover\:border-cyan-600:hover {
    border-color: #0891b2;
  }

  .pc\:hover\:border-cyan-700:hover {
    border-color: #0e7490;
  }

  .pc\:hover\:border-cyan-800:hover {
    border-color: #155e75;
  }

  .pc\:hover\:border-cyan-900:hover {
    border-color: #164e63;
  }

  .pc\:hover\:border-indigo-50:hover {
    border-color: #eef2ff;
  }

  .pc\:hover\:border-indigo-100:hover {
    border-color: #e0e7ff;
  }

  .pc\:hover\:border-indigo-200:hover {
    border-color: #c7d2fe;
  }

  .pc\:hover\:border-indigo-300:hover {
    border-color: #a5b4fc;
  }

  .pc\:hover\:border-indigo-400:hover {
    border-color: #818cf8;
  }

  .pc\:hover\:border-indigo-500:hover {
    border-color: #6366f1;
  }

  .pc\:hover\:border-indigo-600:hover {
    border-color: #4f46e5;
  }

  .pc\:hover\:border-indigo-700:hover {
    border-color: #4338ca;
  }

  .pc\:hover\:border-indigo-800:hover {
    border-color: #3730a3;
  }

  .pc\:hover\:border-indigo-900:hover {
    border-color: #312e81;
  }

  .pc\:hover\:border-purple-50:hover {
    border-color: #f5f3ff;
  }

  .pc\:hover\:border-purple-100:hover {
    border-color: #ede9fe;
  }

  .pc\:hover\:border-purple-200:hover {
    border-color: #ddd6fe;
  }

  .pc\:hover\:border-purple-300:hover {
    border-color: #c4b5fd;
  }

  .pc\:hover\:border-purple-400:hover {
    border-color: #a78bfa;
  }

  .pc\:hover\:border-purple-500:hover {
    border-color: #8b5cf6;
  }

  .pc\:hover\:border-purple-600:hover {
    border-color: #7c3aed;
  }

  .pc\:hover\:border-purple-700:hover {
    border-color: #6d28d9;
  }

  .pc\:hover\:border-purple-800:hover {
    border-color: #5b21b6;
  }

  .pc\:hover\:border-purple-900:hover {
    border-color: #4c1d95;
  }

  .pc\:hover\:border-pink-50:hover {
    border-color: #fdf2f8;
  }

  .pc\:hover\:border-pink-100:hover {
    border-color: #fce7f3;
  }

  .pc\:hover\:border-pink-200:hover {
    border-color: #fbcfe8;
  }

  .pc\:hover\:border-pink-300:hover {
    border-color: #f9a8d4;
  }

  .pc\:hover\:border-pink-400:hover {
    border-color: #f472b6;
  }

  .pc\:hover\:border-pink-500:hover {
    border-color: #ec4899;
  }

  .pc\:hover\:border-pink-600:hover {
    border-color: #db2777;
  }

  .pc\:hover\:border-pink-700:hover {
    border-color: #be185d;
  }

  .pc\:hover\:border-pink-800:hover {
    border-color: #9d174d;
  }

  .pc\:hover\:border-pink-900:hover {
    border-color: #831843;
  }

  .pc\:active\:border-black.is-active,
.pc\:active\:border-black:active {
    border-color: #000;
  }

  .pc\:active\:border-white.is-active,
.pc\:active\:border-white:active {
    border-color: #fff;
  }

  .pc\:active\:border-primary.is-active,
.pc\:active\:border-primary:active {
    border-color: #007bff;
  }

  .pc\:active\:border-secondary.is-active,
.pc\:active\:border-secondary:active {
    border-color: #6c757d;
  }

  .pc\:active\:border-success.is-active,
.pc\:active\:border-success:active {
    border-color: #28a745;
  }

  .pc\:active\:border-info.is-active,
.pc\:active\:border-info:active {
    border-color: #17a2b8;
  }

  .pc\:active\:border-warning.is-active,
.pc\:active\:border-warning:active {
    border-color: #fad733;
  }

  .pc\:active\:border-danger.is-active,
.pc\:active\:border-danger:active {
    border-color: #dc3545;
  }

  .pc\:active\:border-light.is-active,
.pc\:active\:border-light:active {
    border-color: #f8f9fa;
  }

  .pc\:active\:border-dark.is-active,
.pc\:active\:border-dark:active {
    border-color: #343a40;
  }

  .pc\:active\:border-gray-50.is-active,
.pc\:active\:border-gray-50:active {
    border-color: #f9fafb;
  }

  .pc\:active\:border-gray-100.is-active,
.pc\:active\:border-gray-100:active {
    border-color: #f3f4f6;
  }

  .pc\:active\:border-gray-200.is-active,
.pc\:active\:border-gray-200:active {
    border-color: #e5e7eb;
  }

  .pc\:active\:border-gray-300.is-active,
.pc\:active\:border-gray-300:active {
    border-color: #d1d5db;
  }

  .pc\:active\:border-gray-400.is-active,
.pc\:active\:border-gray-400:active {
    border-color: #9ca3af;
  }

  .pc\:active\:border-gray-500.is-active,
.pc\:active\:border-gray-500:active {
    border-color: #6b7280;
  }

  .pc\:active\:border-gray-600.is-active,
.pc\:active\:border-gray-600:active {
    border-color: #4b5563;
  }

  .pc\:active\:border-gray-700.is-active,
.pc\:active\:border-gray-700:active {
    border-color: #374151;
  }

  .pc\:active\:border-gray-800.is-active,
.pc\:active\:border-gray-800:active {
    border-color: #1f2937;
  }

  .pc\:active\:border-gray-900.is-active,
.pc\:active\:border-gray-900:active {
    border-color: #111827;
  }

  .pc\:active\:border-red-50.is-active,
.pc\:active\:border-red-50:active {
    border-color: #fef2f2;
  }

  .pc\:active\:border-red-100.is-active,
.pc\:active\:border-red-100:active {
    border-color: #fee2e2;
  }

  .pc\:active\:border-red-200.is-active,
.pc\:active\:border-red-200:active {
    border-color: #fecaca;
  }

  .pc\:active\:border-red-300.is-active,
.pc\:active\:border-red-300:active {
    border-color: #fca5a5;
  }

  .pc\:active\:border-red-400.is-active,
.pc\:active\:border-red-400:active {
    border-color: #f87171;
  }

  .pc\:active\:border-red-500.is-active,
.pc\:active\:border-red-500:active {
    border-color: #ef4444;
  }

  .pc\:active\:border-red-600.is-active,
.pc\:active\:border-red-600:active {
    border-color: #dc2626;
  }

  .pc\:active\:border-red-700.is-active,
.pc\:active\:border-red-700:active {
    border-color: #b91c1c;
  }

  .pc\:active\:border-red-800.is-active,
.pc\:active\:border-red-800:active {
    border-color: #991b1b;
  }

  .pc\:active\:border-red-900.is-active,
.pc\:active\:border-red-900:active {
    border-color: #7f1d1d;
  }

  .pc\:active\:border-yellow-50.is-active,
.pc\:active\:border-yellow-50:active {
    border-color: #fffbeb;
  }

  .pc\:active\:border-yellow-100.is-active,
.pc\:active\:border-yellow-100:active {
    border-color: #fef3c7;
  }

  .pc\:active\:border-yellow-200.is-active,
.pc\:active\:border-yellow-200:active {
    border-color: #fde68a;
  }

  .pc\:active\:border-yellow-300.is-active,
.pc\:active\:border-yellow-300:active {
    border-color: #fcd34d;
  }

  .pc\:active\:border-yellow-400.is-active,
.pc\:active\:border-yellow-400:active {
    border-color: #fbbf24;
  }

  .pc\:active\:border-yellow-500.is-active,
.pc\:active\:border-yellow-500:active {
    border-color: #f59e0b;
  }

  .pc\:active\:border-yellow-600.is-active,
.pc\:active\:border-yellow-600:active {
    border-color: #d97706;
  }

  .pc\:active\:border-yellow-700.is-active,
.pc\:active\:border-yellow-700:active {
    border-color: #b45309;
  }

  .pc\:active\:border-yellow-800.is-active,
.pc\:active\:border-yellow-800:active {
    border-color: #92400e;
  }

  .pc\:active\:border-yellow-900.is-active,
.pc\:active\:border-yellow-900:active {
    border-color: #78350f;
  }

  .pc\:active\:border-green-50.is-active,
.pc\:active\:border-green-50:active {
    border-color: #ecfdf5;
  }

  .pc\:active\:border-green-100.is-active,
.pc\:active\:border-green-100:active {
    border-color: #d1fae5;
  }

  .pc\:active\:border-green-200.is-active,
.pc\:active\:border-green-200:active {
    border-color: #a7f3d0;
  }

  .pc\:active\:border-green-300.is-active,
.pc\:active\:border-green-300:active {
    border-color: #6ee7b7;
  }

  .pc\:active\:border-green-400.is-active,
.pc\:active\:border-green-400:active {
    border-color: #34d399;
  }

  .pc\:active\:border-green-500.is-active,
.pc\:active\:border-green-500:active {
    border-color: #10b981;
  }

  .pc\:active\:border-green-600.is-active,
.pc\:active\:border-green-600:active {
    border-color: #059669;
  }

  .pc\:active\:border-green-700.is-active,
.pc\:active\:border-green-700:active {
    border-color: #047857;
  }

  .pc\:active\:border-green-800.is-active,
.pc\:active\:border-green-800:active {
    border-color: #065f46;
  }

  .pc\:active\:border-green-900.is-active,
.pc\:active\:border-green-900:active {
    border-color: #064e3b;
  }

  .pc\:active\:border-blue-50.is-active,
.pc\:active\:border-blue-50:active {
    border-color: #eff6ff;
  }

  .pc\:active\:border-blue-100.is-active,
.pc\:active\:border-blue-100:active {
    border-color: #dbeafe;
  }

  .pc\:active\:border-blue-200.is-active,
.pc\:active\:border-blue-200:active {
    border-color: #bfdbfe;
  }

  .pc\:active\:border-blue-300.is-active,
.pc\:active\:border-blue-300:active {
    border-color: #93c5fd;
  }

  .pc\:active\:border-blue-400.is-active,
.pc\:active\:border-blue-400:active {
    border-color: #60a5fa;
  }

  .pc\:active\:border-blue-500.is-active,
.pc\:active\:border-blue-500:active {
    border-color: #3b82f6;
  }

  .pc\:active\:border-blue-600.is-active,
.pc\:active\:border-blue-600:active {
    border-color: #2563eb;
  }

  .pc\:active\:border-blue-700.is-active,
.pc\:active\:border-blue-700:active {
    border-color: #1d4ed8;
  }

  .pc\:active\:border-blue-800.is-active,
.pc\:active\:border-blue-800:active {
    border-color: #1e40af;
  }

  .pc\:active\:border-blue-900.is-active,
.pc\:active\:border-blue-900:active {
    border-color: #1e3a8a;
  }

  .pc\:active\:border-cyan-50.is-active,
.pc\:active\:border-cyan-50:active {
    border-color: #ecfeff;
  }

  .pc\:active\:border-cyan-100.is-active,
.pc\:active\:border-cyan-100:active {
    border-color: #cffafe;
  }

  .pc\:active\:border-cyan-200.is-active,
.pc\:active\:border-cyan-200:active {
    border-color: #a5f3fc;
  }

  .pc\:active\:border-cyan-300.is-active,
.pc\:active\:border-cyan-300:active {
    border-color: #67e8f9;
  }

  .pc\:active\:border-cyan-400.is-active,
.pc\:active\:border-cyan-400:active {
    border-color: #22d3ee;
  }

  .pc\:active\:border-cyan-500.is-active,
.pc\:active\:border-cyan-500:active {
    border-color: #06b6d4;
  }

  .pc\:active\:border-cyan-600.is-active,
.pc\:active\:border-cyan-600:active {
    border-color: #0891b2;
  }

  .pc\:active\:border-cyan-700.is-active,
.pc\:active\:border-cyan-700:active {
    border-color: #0e7490;
  }

  .pc\:active\:border-cyan-800.is-active,
.pc\:active\:border-cyan-800:active {
    border-color: #155e75;
  }

  .pc\:active\:border-cyan-900.is-active,
.pc\:active\:border-cyan-900:active {
    border-color: #164e63;
  }

  .pc\:active\:border-indigo-50.is-active,
.pc\:active\:border-indigo-50:active {
    border-color: #eef2ff;
  }

  .pc\:active\:border-indigo-100.is-active,
.pc\:active\:border-indigo-100:active {
    border-color: #e0e7ff;
  }

  .pc\:active\:border-indigo-200.is-active,
.pc\:active\:border-indigo-200:active {
    border-color: #c7d2fe;
  }

  .pc\:active\:border-indigo-300.is-active,
.pc\:active\:border-indigo-300:active {
    border-color: #a5b4fc;
  }

  .pc\:active\:border-indigo-400.is-active,
.pc\:active\:border-indigo-400:active {
    border-color: #818cf8;
  }

  .pc\:active\:border-indigo-500.is-active,
.pc\:active\:border-indigo-500:active {
    border-color: #6366f1;
  }

  .pc\:active\:border-indigo-600.is-active,
.pc\:active\:border-indigo-600:active {
    border-color: #4f46e5;
  }

  .pc\:active\:border-indigo-700.is-active,
.pc\:active\:border-indigo-700:active {
    border-color: #4338ca;
  }

  .pc\:active\:border-indigo-800.is-active,
.pc\:active\:border-indigo-800:active {
    border-color: #3730a3;
  }

  .pc\:active\:border-indigo-900.is-active,
.pc\:active\:border-indigo-900:active {
    border-color: #312e81;
  }

  .pc\:active\:border-purple-50.is-active,
.pc\:active\:border-purple-50:active {
    border-color: #f5f3ff;
  }

  .pc\:active\:border-purple-100.is-active,
.pc\:active\:border-purple-100:active {
    border-color: #ede9fe;
  }

  .pc\:active\:border-purple-200.is-active,
.pc\:active\:border-purple-200:active {
    border-color: #ddd6fe;
  }

  .pc\:active\:border-purple-300.is-active,
.pc\:active\:border-purple-300:active {
    border-color: #c4b5fd;
  }

  .pc\:active\:border-purple-400.is-active,
.pc\:active\:border-purple-400:active {
    border-color: #a78bfa;
  }

  .pc\:active\:border-purple-500.is-active,
.pc\:active\:border-purple-500:active {
    border-color: #8b5cf6;
  }

  .pc\:active\:border-purple-600.is-active,
.pc\:active\:border-purple-600:active {
    border-color: #7c3aed;
  }

  .pc\:active\:border-purple-700.is-active,
.pc\:active\:border-purple-700:active {
    border-color: #6d28d9;
  }

  .pc\:active\:border-purple-800.is-active,
.pc\:active\:border-purple-800:active {
    border-color: #5b21b6;
  }

  .pc\:active\:border-purple-900.is-active,
.pc\:active\:border-purple-900:active {
    border-color: #4c1d95;
  }

  .pc\:active\:border-pink-50.is-active,
.pc\:active\:border-pink-50:active {
    border-color: #fdf2f8;
  }

  .pc\:active\:border-pink-100.is-active,
.pc\:active\:border-pink-100:active {
    border-color: #fce7f3;
  }

  .pc\:active\:border-pink-200.is-active,
.pc\:active\:border-pink-200:active {
    border-color: #fbcfe8;
  }

  .pc\:active\:border-pink-300.is-active,
.pc\:active\:border-pink-300:active {
    border-color: #f9a8d4;
  }

  .pc\:active\:border-pink-400.is-active,
.pc\:active\:border-pink-400:active {
    border-color: #f472b6;
  }

  .pc\:active\:border-pink-500.is-active,
.pc\:active\:border-pink-500:active {
    border-color: #ec4899;
  }

  .pc\:active\:border-pink-600.is-active,
.pc\:active\:border-pink-600:active {
    border-color: #db2777;
  }

  .pc\:active\:border-pink-700.is-active,
.pc\:active\:border-pink-700:active {
    border-color: #be185d;
  }

  .pc\:active\:border-pink-800.is-active,
.pc\:active\:border-pink-800:active {
    border-color: #9d174d;
  }

  .pc\:active\:border-pink-900.is-active,
.pc\:active\:border-pink-900:active {
    border-color: #831843;
  }

  .pc\:focus\:border-black:focus {
    border-color: #000;
  }

  .pc\:focus\:border-white:focus {
    border-color: #fff;
  }

  .pc\:focus\:border-primary:focus {
    border-color: #007bff;
  }

  .pc\:focus\:border-secondary:focus {
    border-color: #6c757d;
  }

  .pc\:focus\:border-success:focus {
    border-color: #28a745;
  }

  .pc\:focus\:border-info:focus {
    border-color: #17a2b8;
  }

  .pc\:focus\:border-warning:focus {
    border-color: #fad733;
  }

  .pc\:focus\:border-danger:focus {
    border-color: #dc3545;
  }

  .pc\:focus\:border-light:focus {
    border-color: #f8f9fa;
  }

  .pc\:focus\:border-dark:focus {
    border-color: #343a40;
  }

  .pc\:focus\:border-gray-50:focus {
    border-color: #f9fafb;
  }

  .pc\:focus\:border-gray-100:focus {
    border-color: #f3f4f6;
  }

  .pc\:focus\:border-gray-200:focus {
    border-color: #e5e7eb;
  }

  .pc\:focus\:border-gray-300:focus {
    border-color: #d1d5db;
  }

  .pc\:focus\:border-gray-400:focus {
    border-color: #9ca3af;
  }

  .pc\:focus\:border-gray-500:focus {
    border-color: #6b7280;
  }

  .pc\:focus\:border-gray-600:focus {
    border-color: #4b5563;
  }

  .pc\:focus\:border-gray-700:focus {
    border-color: #374151;
  }

  .pc\:focus\:border-gray-800:focus {
    border-color: #1f2937;
  }

  .pc\:focus\:border-gray-900:focus {
    border-color: #111827;
  }

  .pc\:focus\:border-red-50:focus {
    border-color: #fef2f2;
  }

  .pc\:focus\:border-red-100:focus {
    border-color: #fee2e2;
  }

  .pc\:focus\:border-red-200:focus {
    border-color: #fecaca;
  }

  .pc\:focus\:border-red-300:focus {
    border-color: #fca5a5;
  }

  .pc\:focus\:border-red-400:focus {
    border-color: #f87171;
  }

  .pc\:focus\:border-red-500:focus {
    border-color: #ef4444;
  }

  .pc\:focus\:border-red-600:focus {
    border-color: #dc2626;
  }

  .pc\:focus\:border-red-700:focus {
    border-color: #b91c1c;
  }

  .pc\:focus\:border-red-800:focus {
    border-color: #991b1b;
  }

  .pc\:focus\:border-red-900:focus {
    border-color: #7f1d1d;
  }

  .pc\:focus\:border-yellow-50:focus {
    border-color: #fffbeb;
  }

  .pc\:focus\:border-yellow-100:focus {
    border-color: #fef3c7;
  }

  .pc\:focus\:border-yellow-200:focus {
    border-color: #fde68a;
  }

  .pc\:focus\:border-yellow-300:focus {
    border-color: #fcd34d;
  }

  .pc\:focus\:border-yellow-400:focus {
    border-color: #fbbf24;
  }

  .pc\:focus\:border-yellow-500:focus {
    border-color: #f59e0b;
  }

  .pc\:focus\:border-yellow-600:focus {
    border-color: #d97706;
  }

  .pc\:focus\:border-yellow-700:focus {
    border-color: #b45309;
  }

  .pc\:focus\:border-yellow-800:focus {
    border-color: #92400e;
  }

  .pc\:focus\:border-yellow-900:focus {
    border-color: #78350f;
  }

  .pc\:focus\:border-green-50:focus {
    border-color: #ecfdf5;
  }

  .pc\:focus\:border-green-100:focus {
    border-color: #d1fae5;
  }

  .pc\:focus\:border-green-200:focus {
    border-color: #a7f3d0;
  }

  .pc\:focus\:border-green-300:focus {
    border-color: #6ee7b7;
  }

  .pc\:focus\:border-green-400:focus {
    border-color: #34d399;
  }

  .pc\:focus\:border-green-500:focus {
    border-color: #10b981;
  }

  .pc\:focus\:border-green-600:focus {
    border-color: #059669;
  }

  .pc\:focus\:border-green-700:focus {
    border-color: #047857;
  }

  .pc\:focus\:border-green-800:focus {
    border-color: #065f46;
  }

  .pc\:focus\:border-green-900:focus {
    border-color: #064e3b;
  }

  .pc\:focus\:border-blue-50:focus {
    border-color: #eff6ff;
  }

  .pc\:focus\:border-blue-100:focus {
    border-color: #dbeafe;
  }

  .pc\:focus\:border-blue-200:focus {
    border-color: #bfdbfe;
  }

  .pc\:focus\:border-blue-300:focus {
    border-color: #93c5fd;
  }

  .pc\:focus\:border-blue-400:focus {
    border-color: #60a5fa;
  }

  .pc\:focus\:border-blue-500:focus {
    border-color: #3b82f6;
  }

  .pc\:focus\:border-blue-600:focus {
    border-color: #2563eb;
  }

  .pc\:focus\:border-blue-700:focus {
    border-color: #1d4ed8;
  }

  .pc\:focus\:border-blue-800:focus {
    border-color: #1e40af;
  }

  .pc\:focus\:border-blue-900:focus {
    border-color: #1e3a8a;
  }

  .pc\:focus\:border-cyan-50:focus {
    border-color: #ecfeff;
  }

  .pc\:focus\:border-cyan-100:focus {
    border-color: #cffafe;
  }

  .pc\:focus\:border-cyan-200:focus {
    border-color: #a5f3fc;
  }

  .pc\:focus\:border-cyan-300:focus {
    border-color: #67e8f9;
  }

  .pc\:focus\:border-cyan-400:focus {
    border-color: #22d3ee;
  }

  .pc\:focus\:border-cyan-500:focus {
    border-color: #06b6d4;
  }

  .pc\:focus\:border-cyan-600:focus {
    border-color: #0891b2;
  }

  .pc\:focus\:border-cyan-700:focus {
    border-color: #0e7490;
  }

  .pc\:focus\:border-cyan-800:focus {
    border-color: #155e75;
  }

  .pc\:focus\:border-cyan-900:focus {
    border-color: #164e63;
  }

  .pc\:focus\:border-indigo-50:focus {
    border-color: #eef2ff;
  }

  .pc\:focus\:border-indigo-100:focus {
    border-color: #e0e7ff;
  }

  .pc\:focus\:border-indigo-200:focus {
    border-color: #c7d2fe;
  }

  .pc\:focus\:border-indigo-300:focus {
    border-color: #a5b4fc;
  }

  .pc\:focus\:border-indigo-400:focus {
    border-color: #818cf8;
  }

  .pc\:focus\:border-indigo-500:focus {
    border-color: #6366f1;
  }

  .pc\:focus\:border-indigo-600:focus {
    border-color: #4f46e5;
  }

  .pc\:focus\:border-indigo-700:focus {
    border-color: #4338ca;
  }

  .pc\:focus\:border-indigo-800:focus {
    border-color: #3730a3;
  }

  .pc\:focus\:border-indigo-900:focus {
    border-color: #312e81;
  }

  .pc\:focus\:border-purple-50:focus {
    border-color: #f5f3ff;
  }

  .pc\:focus\:border-purple-100:focus {
    border-color: #ede9fe;
  }

  .pc\:focus\:border-purple-200:focus {
    border-color: #ddd6fe;
  }

  .pc\:focus\:border-purple-300:focus {
    border-color: #c4b5fd;
  }

  .pc\:focus\:border-purple-400:focus {
    border-color: #a78bfa;
  }

  .pc\:focus\:border-purple-500:focus {
    border-color: #8b5cf6;
  }

  .pc\:focus\:border-purple-600:focus {
    border-color: #7c3aed;
  }

  .pc\:focus\:border-purple-700:focus {
    border-color: #6d28d9;
  }

  .pc\:focus\:border-purple-800:focus {
    border-color: #5b21b6;
  }

  .pc\:focus\:border-purple-900:focus {
    border-color: #4c1d95;
  }

  .pc\:focus\:border-pink-50:focus {
    border-color: #fdf2f8;
  }

  .pc\:focus\:border-pink-100:focus {
    border-color: #fce7f3;
  }

  .pc\:focus\:border-pink-200:focus {
    border-color: #fbcfe8;
  }

  .pc\:focus\:border-pink-300:focus {
    border-color: #f9a8d4;
  }

  .pc\:focus\:border-pink-400:focus {
    border-color: #f472b6;
  }

  .pc\:focus\:border-pink-500:focus {
    border-color: #ec4899;
  }

  .pc\:focus\:border-pink-600:focus {
    border-color: #db2777;
  }

  .pc\:focus\:border-pink-700:focus {
    border-color: #be185d;
  }

  .pc\:focus\:border-pink-800:focus {
    border-color: #9d174d;
  }

  .pc\:focus\:border-pink-900:focus {
    border-color: #831843;
  }

  .pc\:disabled\:border-black.is-disabled,
.pc\:disabled\:border-black:disabled {
    border-color: #000;
  }

  .pc\:disabled\:border-white.is-disabled,
.pc\:disabled\:border-white:disabled {
    border-color: #fff;
  }

  .pc\:disabled\:border-primary.is-disabled,
.pc\:disabled\:border-primary:disabled {
    border-color: #007bff;
  }

  .pc\:disabled\:border-secondary.is-disabled,
.pc\:disabled\:border-secondary:disabled {
    border-color: #6c757d;
  }

  .pc\:disabled\:border-success.is-disabled,
.pc\:disabled\:border-success:disabled {
    border-color: #28a745;
  }

  .pc\:disabled\:border-info.is-disabled,
.pc\:disabled\:border-info:disabled {
    border-color: #17a2b8;
  }

  .pc\:disabled\:border-warning.is-disabled,
.pc\:disabled\:border-warning:disabled {
    border-color: #fad733;
  }

  .pc\:disabled\:border-danger.is-disabled,
.pc\:disabled\:border-danger:disabled {
    border-color: #dc3545;
  }

  .pc\:disabled\:border-light.is-disabled,
.pc\:disabled\:border-light:disabled {
    border-color: #f8f9fa;
  }

  .pc\:disabled\:border-dark.is-disabled,
.pc\:disabled\:border-dark:disabled {
    border-color: #343a40;
  }

  .pc\:disabled\:border-gray-50.is-disabled,
.pc\:disabled\:border-gray-50:disabled {
    border-color: #f9fafb;
  }

  .pc\:disabled\:border-gray-100.is-disabled,
.pc\:disabled\:border-gray-100:disabled {
    border-color: #f3f4f6;
  }

  .pc\:disabled\:border-gray-200.is-disabled,
.pc\:disabled\:border-gray-200:disabled {
    border-color: #e5e7eb;
  }

  .pc\:disabled\:border-gray-300.is-disabled,
.pc\:disabled\:border-gray-300:disabled {
    border-color: #d1d5db;
  }

  .pc\:disabled\:border-gray-400.is-disabled,
.pc\:disabled\:border-gray-400:disabled {
    border-color: #9ca3af;
  }

  .pc\:disabled\:border-gray-500.is-disabled,
.pc\:disabled\:border-gray-500:disabled {
    border-color: #6b7280;
  }

  .pc\:disabled\:border-gray-600.is-disabled,
.pc\:disabled\:border-gray-600:disabled {
    border-color: #4b5563;
  }

  .pc\:disabled\:border-gray-700.is-disabled,
.pc\:disabled\:border-gray-700:disabled {
    border-color: #374151;
  }

  .pc\:disabled\:border-gray-800.is-disabled,
.pc\:disabled\:border-gray-800:disabled {
    border-color: #1f2937;
  }

  .pc\:disabled\:border-gray-900.is-disabled,
.pc\:disabled\:border-gray-900:disabled {
    border-color: #111827;
  }

  .pc\:disabled\:border-red-50.is-disabled,
.pc\:disabled\:border-red-50:disabled {
    border-color: #fef2f2;
  }

  .pc\:disabled\:border-red-100.is-disabled,
.pc\:disabled\:border-red-100:disabled {
    border-color: #fee2e2;
  }

  .pc\:disabled\:border-red-200.is-disabled,
.pc\:disabled\:border-red-200:disabled {
    border-color: #fecaca;
  }

  .pc\:disabled\:border-red-300.is-disabled,
.pc\:disabled\:border-red-300:disabled {
    border-color: #fca5a5;
  }

  .pc\:disabled\:border-red-400.is-disabled,
.pc\:disabled\:border-red-400:disabled {
    border-color: #f87171;
  }

  .pc\:disabled\:border-red-500.is-disabled,
.pc\:disabled\:border-red-500:disabled {
    border-color: #ef4444;
  }

  .pc\:disabled\:border-red-600.is-disabled,
.pc\:disabled\:border-red-600:disabled {
    border-color: #dc2626;
  }

  .pc\:disabled\:border-red-700.is-disabled,
.pc\:disabled\:border-red-700:disabled {
    border-color: #b91c1c;
  }

  .pc\:disabled\:border-red-800.is-disabled,
.pc\:disabled\:border-red-800:disabled {
    border-color: #991b1b;
  }

  .pc\:disabled\:border-red-900.is-disabled,
.pc\:disabled\:border-red-900:disabled {
    border-color: #7f1d1d;
  }

  .pc\:disabled\:border-yellow-50.is-disabled,
.pc\:disabled\:border-yellow-50:disabled {
    border-color: #fffbeb;
  }

  .pc\:disabled\:border-yellow-100.is-disabled,
.pc\:disabled\:border-yellow-100:disabled {
    border-color: #fef3c7;
  }

  .pc\:disabled\:border-yellow-200.is-disabled,
.pc\:disabled\:border-yellow-200:disabled {
    border-color: #fde68a;
  }

  .pc\:disabled\:border-yellow-300.is-disabled,
.pc\:disabled\:border-yellow-300:disabled {
    border-color: #fcd34d;
  }

  .pc\:disabled\:border-yellow-400.is-disabled,
.pc\:disabled\:border-yellow-400:disabled {
    border-color: #fbbf24;
  }

  .pc\:disabled\:border-yellow-500.is-disabled,
.pc\:disabled\:border-yellow-500:disabled {
    border-color: #f59e0b;
  }

  .pc\:disabled\:border-yellow-600.is-disabled,
.pc\:disabled\:border-yellow-600:disabled {
    border-color: #d97706;
  }

  .pc\:disabled\:border-yellow-700.is-disabled,
.pc\:disabled\:border-yellow-700:disabled {
    border-color: #b45309;
  }

  .pc\:disabled\:border-yellow-800.is-disabled,
.pc\:disabled\:border-yellow-800:disabled {
    border-color: #92400e;
  }

  .pc\:disabled\:border-yellow-900.is-disabled,
.pc\:disabled\:border-yellow-900:disabled {
    border-color: #78350f;
  }

  .pc\:disabled\:border-green-50.is-disabled,
.pc\:disabled\:border-green-50:disabled {
    border-color: #ecfdf5;
  }

  .pc\:disabled\:border-green-100.is-disabled,
.pc\:disabled\:border-green-100:disabled {
    border-color: #d1fae5;
  }

  .pc\:disabled\:border-green-200.is-disabled,
.pc\:disabled\:border-green-200:disabled {
    border-color: #a7f3d0;
  }

  .pc\:disabled\:border-green-300.is-disabled,
.pc\:disabled\:border-green-300:disabled {
    border-color: #6ee7b7;
  }

  .pc\:disabled\:border-green-400.is-disabled,
.pc\:disabled\:border-green-400:disabled {
    border-color: #34d399;
  }

  .pc\:disabled\:border-green-500.is-disabled,
.pc\:disabled\:border-green-500:disabled {
    border-color: #10b981;
  }

  .pc\:disabled\:border-green-600.is-disabled,
.pc\:disabled\:border-green-600:disabled {
    border-color: #059669;
  }

  .pc\:disabled\:border-green-700.is-disabled,
.pc\:disabled\:border-green-700:disabled {
    border-color: #047857;
  }

  .pc\:disabled\:border-green-800.is-disabled,
.pc\:disabled\:border-green-800:disabled {
    border-color: #065f46;
  }

  .pc\:disabled\:border-green-900.is-disabled,
.pc\:disabled\:border-green-900:disabled {
    border-color: #064e3b;
  }

  .pc\:disabled\:border-blue-50.is-disabled,
.pc\:disabled\:border-blue-50:disabled {
    border-color: #eff6ff;
  }

  .pc\:disabled\:border-blue-100.is-disabled,
.pc\:disabled\:border-blue-100:disabled {
    border-color: #dbeafe;
  }

  .pc\:disabled\:border-blue-200.is-disabled,
.pc\:disabled\:border-blue-200:disabled {
    border-color: #bfdbfe;
  }

  .pc\:disabled\:border-blue-300.is-disabled,
.pc\:disabled\:border-blue-300:disabled {
    border-color: #93c5fd;
  }

  .pc\:disabled\:border-blue-400.is-disabled,
.pc\:disabled\:border-blue-400:disabled {
    border-color: #60a5fa;
  }

  .pc\:disabled\:border-blue-500.is-disabled,
.pc\:disabled\:border-blue-500:disabled {
    border-color: #3b82f6;
  }

  .pc\:disabled\:border-blue-600.is-disabled,
.pc\:disabled\:border-blue-600:disabled {
    border-color: #2563eb;
  }

  .pc\:disabled\:border-blue-700.is-disabled,
.pc\:disabled\:border-blue-700:disabled {
    border-color: #1d4ed8;
  }

  .pc\:disabled\:border-blue-800.is-disabled,
.pc\:disabled\:border-blue-800:disabled {
    border-color: #1e40af;
  }

  .pc\:disabled\:border-blue-900.is-disabled,
.pc\:disabled\:border-blue-900:disabled {
    border-color: #1e3a8a;
  }

  .pc\:disabled\:border-cyan-50.is-disabled,
.pc\:disabled\:border-cyan-50:disabled {
    border-color: #ecfeff;
  }

  .pc\:disabled\:border-cyan-100.is-disabled,
.pc\:disabled\:border-cyan-100:disabled {
    border-color: #cffafe;
  }

  .pc\:disabled\:border-cyan-200.is-disabled,
.pc\:disabled\:border-cyan-200:disabled {
    border-color: #a5f3fc;
  }

  .pc\:disabled\:border-cyan-300.is-disabled,
.pc\:disabled\:border-cyan-300:disabled {
    border-color: #67e8f9;
  }

  .pc\:disabled\:border-cyan-400.is-disabled,
.pc\:disabled\:border-cyan-400:disabled {
    border-color: #22d3ee;
  }

  .pc\:disabled\:border-cyan-500.is-disabled,
.pc\:disabled\:border-cyan-500:disabled {
    border-color: #06b6d4;
  }

  .pc\:disabled\:border-cyan-600.is-disabled,
.pc\:disabled\:border-cyan-600:disabled {
    border-color: #0891b2;
  }

  .pc\:disabled\:border-cyan-700.is-disabled,
.pc\:disabled\:border-cyan-700:disabled {
    border-color: #0e7490;
  }

  .pc\:disabled\:border-cyan-800.is-disabled,
.pc\:disabled\:border-cyan-800:disabled {
    border-color: #155e75;
  }

  .pc\:disabled\:border-cyan-900.is-disabled,
.pc\:disabled\:border-cyan-900:disabled {
    border-color: #164e63;
  }

  .pc\:disabled\:border-indigo-50.is-disabled,
.pc\:disabled\:border-indigo-50:disabled {
    border-color: #eef2ff;
  }

  .pc\:disabled\:border-indigo-100.is-disabled,
.pc\:disabled\:border-indigo-100:disabled {
    border-color: #e0e7ff;
  }

  .pc\:disabled\:border-indigo-200.is-disabled,
.pc\:disabled\:border-indigo-200:disabled {
    border-color: #c7d2fe;
  }

  .pc\:disabled\:border-indigo-300.is-disabled,
.pc\:disabled\:border-indigo-300:disabled {
    border-color: #a5b4fc;
  }

  .pc\:disabled\:border-indigo-400.is-disabled,
.pc\:disabled\:border-indigo-400:disabled {
    border-color: #818cf8;
  }

  .pc\:disabled\:border-indigo-500.is-disabled,
.pc\:disabled\:border-indigo-500:disabled {
    border-color: #6366f1;
  }

  .pc\:disabled\:border-indigo-600.is-disabled,
.pc\:disabled\:border-indigo-600:disabled {
    border-color: #4f46e5;
  }

  .pc\:disabled\:border-indigo-700.is-disabled,
.pc\:disabled\:border-indigo-700:disabled {
    border-color: #4338ca;
  }

  .pc\:disabled\:border-indigo-800.is-disabled,
.pc\:disabled\:border-indigo-800:disabled {
    border-color: #3730a3;
  }

  .pc\:disabled\:border-indigo-900.is-disabled,
.pc\:disabled\:border-indigo-900:disabled {
    border-color: #312e81;
  }

  .pc\:disabled\:border-purple-50.is-disabled,
.pc\:disabled\:border-purple-50:disabled {
    border-color: #f5f3ff;
  }

  .pc\:disabled\:border-purple-100.is-disabled,
.pc\:disabled\:border-purple-100:disabled {
    border-color: #ede9fe;
  }

  .pc\:disabled\:border-purple-200.is-disabled,
.pc\:disabled\:border-purple-200:disabled {
    border-color: #ddd6fe;
  }

  .pc\:disabled\:border-purple-300.is-disabled,
.pc\:disabled\:border-purple-300:disabled {
    border-color: #c4b5fd;
  }

  .pc\:disabled\:border-purple-400.is-disabled,
.pc\:disabled\:border-purple-400:disabled {
    border-color: #a78bfa;
  }

  .pc\:disabled\:border-purple-500.is-disabled,
.pc\:disabled\:border-purple-500:disabled {
    border-color: #8b5cf6;
  }

  .pc\:disabled\:border-purple-600.is-disabled,
.pc\:disabled\:border-purple-600:disabled {
    border-color: #7c3aed;
  }

  .pc\:disabled\:border-purple-700.is-disabled,
.pc\:disabled\:border-purple-700:disabled {
    border-color: #6d28d9;
  }

  .pc\:disabled\:border-purple-800.is-disabled,
.pc\:disabled\:border-purple-800:disabled {
    border-color: #5b21b6;
  }

  .pc\:disabled\:border-purple-900.is-disabled,
.pc\:disabled\:border-purple-900:disabled {
    border-color: #4c1d95;
  }

  .pc\:disabled\:border-pink-50.is-disabled,
.pc\:disabled\:border-pink-50:disabled {
    border-color: #fdf2f8;
  }

  .pc\:disabled\:border-pink-100.is-disabled,
.pc\:disabled\:border-pink-100:disabled {
    border-color: #fce7f3;
  }

  .pc\:disabled\:border-pink-200.is-disabled,
.pc\:disabled\:border-pink-200:disabled {
    border-color: #fbcfe8;
  }

  .pc\:disabled\:border-pink-300.is-disabled,
.pc\:disabled\:border-pink-300:disabled {
    border-color: #f9a8d4;
  }

  .pc\:disabled\:border-pink-400.is-disabled,
.pc\:disabled\:border-pink-400:disabled {
    border-color: #f472b6;
  }

  .pc\:disabled\:border-pink-500.is-disabled,
.pc\:disabled\:border-pink-500:disabled {
    border-color: #ec4899;
  }

  .pc\:disabled\:border-pink-600.is-disabled,
.pc\:disabled\:border-pink-600:disabled {
    border-color: #db2777;
  }

  .pc\:disabled\:border-pink-700.is-disabled,
.pc\:disabled\:border-pink-700:disabled {
    border-color: #be185d;
  }

  .pc\:disabled\:border-pink-800.is-disabled,
.pc\:disabled\:border-pink-800:disabled {
    border-color: #9d174d;
  }

  .pc\:disabled\:border-pink-900.is-disabled,
.pc\:disabled\:border-pink-900:disabled {
    border-color: #831843;
  }

  .group:hover .pc\:group-hover\:border-black {
    border-color: #000;
  }

  .group:hover .pc\:group-hover\:border-white {
    border-color: #fff;
  }

  .group:hover .pc\:group-hover\:border-primary {
    border-color: #007bff;
  }

  .group:hover .pc\:group-hover\:border-secondary {
    border-color: #6c757d;
  }

  .group:hover .pc\:group-hover\:border-success {
    border-color: #28a745;
  }

  .group:hover .pc\:group-hover\:border-info {
    border-color: #17a2b8;
  }

  .group:hover .pc\:group-hover\:border-warning {
    border-color: #fad733;
  }

  .group:hover .pc\:group-hover\:border-danger {
    border-color: #dc3545;
  }

  .group:hover .pc\:group-hover\:border-light {
    border-color: #f8f9fa;
  }

  .group:hover .pc\:group-hover\:border-dark {
    border-color: #343a40;
  }

  .group:hover .pc\:group-hover\:border-gray-50 {
    border-color: #f9fafb;
  }

  .group:hover .pc\:group-hover\:border-gray-100 {
    border-color: #f3f4f6;
  }

  .group:hover .pc\:group-hover\:border-gray-200 {
    border-color: #e5e7eb;
  }

  .group:hover .pc\:group-hover\:border-gray-300 {
    border-color: #d1d5db;
  }

  .group:hover .pc\:group-hover\:border-gray-400 {
    border-color: #9ca3af;
  }

  .group:hover .pc\:group-hover\:border-gray-500 {
    border-color: #6b7280;
  }

  .group:hover .pc\:group-hover\:border-gray-600 {
    border-color: #4b5563;
  }

  .group:hover .pc\:group-hover\:border-gray-700 {
    border-color: #374151;
  }

  .group:hover .pc\:group-hover\:border-gray-800 {
    border-color: #1f2937;
  }

  .group:hover .pc\:group-hover\:border-gray-900 {
    border-color: #111827;
  }

  .group:hover .pc\:group-hover\:border-red-50 {
    border-color: #fef2f2;
  }

  .group:hover .pc\:group-hover\:border-red-100 {
    border-color: #fee2e2;
  }

  .group:hover .pc\:group-hover\:border-red-200 {
    border-color: #fecaca;
  }

  .group:hover .pc\:group-hover\:border-red-300 {
    border-color: #fca5a5;
  }

  .group:hover .pc\:group-hover\:border-red-400 {
    border-color: #f87171;
  }

  .group:hover .pc\:group-hover\:border-red-500 {
    border-color: #ef4444;
  }

  .group:hover .pc\:group-hover\:border-red-600 {
    border-color: #dc2626;
  }

  .group:hover .pc\:group-hover\:border-red-700 {
    border-color: #b91c1c;
  }

  .group:hover .pc\:group-hover\:border-red-800 {
    border-color: #991b1b;
  }

  .group:hover .pc\:group-hover\:border-red-900 {
    border-color: #7f1d1d;
  }

  .group:hover .pc\:group-hover\:border-yellow-50 {
    border-color: #fffbeb;
  }

  .group:hover .pc\:group-hover\:border-yellow-100 {
    border-color: #fef3c7;
  }

  .group:hover .pc\:group-hover\:border-yellow-200 {
    border-color: #fde68a;
  }

  .group:hover .pc\:group-hover\:border-yellow-300 {
    border-color: #fcd34d;
  }

  .group:hover .pc\:group-hover\:border-yellow-400 {
    border-color: #fbbf24;
  }

  .group:hover .pc\:group-hover\:border-yellow-500 {
    border-color: #f59e0b;
  }

  .group:hover .pc\:group-hover\:border-yellow-600 {
    border-color: #d97706;
  }

  .group:hover .pc\:group-hover\:border-yellow-700 {
    border-color: #b45309;
  }

  .group:hover .pc\:group-hover\:border-yellow-800 {
    border-color: #92400e;
  }

  .group:hover .pc\:group-hover\:border-yellow-900 {
    border-color: #78350f;
  }

  .group:hover .pc\:group-hover\:border-green-50 {
    border-color: #ecfdf5;
  }

  .group:hover .pc\:group-hover\:border-green-100 {
    border-color: #d1fae5;
  }

  .group:hover .pc\:group-hover\:border-green-200 {
    border-color: #a7f3d0;
  }

  .group:hover .pc\:group-hover\:border-green-300 {
    border-color: #6ee7b7;
  }

  .group:hover .pc\:group-hover\:border-green-400 {
    border-color: #34d399;
  }

  .group:hover .pc\:group-hover\:border-green-500 {
    border-color: #10b981;
  }

  .group:hover .pc\:group-hover\:border-green-600 {
    border-color: #059669;
  }

  .group:hover .pc\:group-hover\:border-green-700 {
    border-color: #047857;
  }

  .group:hover .pc\:group-hover\:border-green-800 {
    border-color: #065f46;
  }

  .group:hover .pc\:group-hover\:border-green-900 {
    border-color: #064e3b;
  }

  .group:hover .pc\:group-hover\:border-blue-50 {
    border-color: #eff6ff;
  }

  .group:hover .pc\:group-hover\:border-blue-100 {
    border-color: #dbeafe;
  }

  .group:hover .pc\:group-hover\:border-blue-200 {
    border-color: #bfdbfe;
  }

  .group:hover .pc\:group-hover\:border-blue-300 {
    border-color: #93c5fd;
  }

  .group:hover .pc\:group-hover\:border-blue-400 {
    border-color: #60a5fa;
  }

  .group:hover .pc\:group-hover\:border-blue-500 {
    border-color: #3b82f6;
  }

  .group:hover .pc\:group-hover\:border-blue-600 {
    border-color: #2563eb;
  }

  .group:hover .pc\:group-hover\:border-blue-700 {
    border-color: #1d4ed8;
  }

  .group:hover .pc\:group-hover\:border-blue-800 {
    border-color: #1e40af;
  }

  .group:hover .pc\:group-hover\:border-blue-900 {
    border-color: #1e3a8a;
  }

  .group:hover .pc\:group-hover\:border-cyan-50 {
    border-color: #ecfeff;
  }

  .group:hover .pc\:group-hover\:border-cyan-100 {
    border-color: #cffafe;
  }

  .group:hover .pc\:group-hover\:border-cyan-200 {
    border-color: #a5f3fc;
  }

  .group:hover .pc\:group-hover\:border-cyan-300 {
    border-color: #67e8f9;
  }

  .group:hover .pc\:group-hover\:border-cyan-400 {
    border-color: #22d3ee;
  }

  .group:hover .pc\:group-hover\:border-cyan-500 {
    border-color: #06b6d4;
  }

  .group:hover .pc\:group-hover\:border-cyan-600 {
    border-color: #0891b2;
  }

  .group:hover .pc\:group-hover\:border-cyan-700 {
    border-color: #0e7490;
  }

  .group:hover .pc\:group-hover\:border-cyan-800 {
    border-color: #155e75;
  }

  .group:hover .pc\:group-hover\:border-cyan-900 {
    border-color: #164e63;
  }

  .group:hover .pc\:group-hover\:border-indigo-50 {
    border-color: #eef2ff;
  }

  .group:hover .pc\:group-hover\:border-indigo-100 {
    border-color: #e0e7ff;
  }

  .group:hover .pc\:group-hover\:border-indigo-200 {
    border-color: #c7d2fe;
  }

  .group:hover .pc\:group-hover\:border-indigo-300 {
    border-color: #a5b4fc;
  }

  .group:hover .pc\:group-hover\:border-indigo-400 {
    border-color: #818cf8;
  }

  .group:hover .pc\:group-hover\:border-indigo-500 {
    border-color: #6366f1;
  }

  .group:hover .pc\:group-hover\:border-indigo-600 {
    border-color: #4f46e5;
  }

  .group:hover .pc\:group-hover\:border-indigo-700 {
    border-color: #4338ca;
  }

  .group:hover .pc\:group-hover\:border-indigo-800 {
    border-color: #3730a3;
  }

  .group:hover .pc\:group-hover\:border-indigo-900 {
    border-color: #312e81;
  }

  .group:hover .pc\:group-hover\:border-purple-50 {
    border-color: #f5f3ff;
  }

  .group:hover .pc\:group-hover\:border-purple-100 {
    border-color: #ede9fe;
  }

  .group:hover .pc\:group-hover\:border-purple-200 {
    border-color: #ddd6fe;
  }

  .group:hover .pc\:group-hover\:border-purple-300 {
    border-color: #c4b5fd;
  }

  .group:hover .pc\:group-hover\:border-purple-400 {
    border-color: #a78bfa;
  }

  .group:hover .pc\:group-hover\:border-purple-500 {
    border-color: #8b5cf6;
  }

  .group:hover .pc\:group-hover\:border-purple-600 {
    border-color: #7c3aed;
  }

  .group:hover .pc\:group-hover\:border-purple-700 {
    border-color: #6d28d9;
  }

  .group:hover .pc\:group-hover\:border-purple-800 {
    border-color: #5b21b6;
  }

  .group:hover .pc\:group-hover\:border-purple-900 {
    border-color: #4c1d95;
  }

  .group:hover .pc\:group-hover\:border-pink-50 {
    border-color: #fdf2f8;
  }

  .group:hover .pc\:group-hover\:border-pink-100 {
    border-color: #fce7f3;
  }

  .group:hover .pc\:group-hover\:border-pink-200 {
    border-color: #fbcfe8;
  }

  .group:hover .pc\:group-hover\:border-pink-300 {
    border-color: #f9a8d4;
  }

  .group:hover .pc\:group-hover\:border-pink-400 {
    border-color: #f472b6;
  }

  .group:hover .pc\:group-hover\:border-pink-500 {
    border-color: #ec4899;
  }

  .group:hover .pc\:group-hover\:border-pink-600 {
    border-color: #db2777;
  }

  .group:hover .pc\:group-hover\:border-pink-700 {
    border-color: #be185d;
  }

  .group:hover .pc\:group-hover\:border-pink-800 {
    border-color: #9d174d;
  }

  .group:hover .pc\:group-hover\:border-pink-900 {
    border-color: #831843;
  }
}
/*!markdown

---
title: 边框圆角
---
| Class       | Properties               |
| ----------- | ------------------------ |
| rounded-none | border-radius: 0px |
| rounded-sm | border-radius: 0.125rem |
| rounded | border-radius: 0.25rem |
| rounded-md | border-radius: 0.375rem |
| rounded-lg | border-radius: 0.5rem |
| rounded-xl | border-radius: 0.75rem |
| rounded-2xl | border-radius: 1rem |
| rounded-3xl | border-radius: 1.5rem |
| rounded-full | border-radius: 9999px |
| rounded-t-none | border-top-left-radius: 0px; border-top-right-radius: 0px |
| rounded-t-sm | border-top-left-radius: 0.125rem; border-top-right-radius: 0.125rem |
| rounded-t | border-top-left-radius: 0.25rem; border-top-right-radius: 0.25rem |
| rounded-t-md | border-top-left-radius: 0.375rem; border-top-right-radius: 0.375rem |
| rounded-t-lg | border-top-left-radius: 0.5rem; border-top-right-radius: 0.5rem |
| rounded-t-xl | border-top-left-radius: 0.75rem; border-top-right-radius: 0.75rem |
| rounded-t-2xl | border-top-left-radius: 1rem; border-top-right-radius: 1rem |
| rounded-t-3xl | border-top-left-radius: 1.5rem; border-top-right-radius: 1.5rem |
| rounded-t-full | border-top-left-radius: 9999px; border-top-right-radius: 9999px |
| rounded-r-none | border-top-right-radius: 0px; border-bottom-right-radius: 0px |
| rounded-r-sm | border-top-right-radius: 0.125rem; border-bottom-right-radius: 0.125rem |
| rounded-r | border-top-right-radius: 0.25rem; border-bottom-right-radius: 0.25rem |
| rounded-r-md | border-top-right-radius: 0.375rem; border-bottom-right-radius: 0.375rem |
| rounded-r-lg | border-top-right-radius: 0.5rem; border-bottom-right-radius: 0.5rem |
| rounded-r-xl | border-top-right-radius: 0.75rem; border-bottom-right-radius: 0.75rem |
| rounded-r-2xl | border-top-right-radius: 1rem; border-bottom-right-radius: 1rem |
| rounded-r-3xl | border-top-right-radius: 1.5rem; border-bottom-right-radius: 1.5rem |
| rounded-r-full | border-top-right-radius: 9999px; border-bottom-right-radius: 9999px |
| rounded-b-none | border-bottom-right-radius: 0px; border-bottom-left-radius: 0px |
| rounded-b-sm | border-bottom-right-radius: 0.125rem; border-bottom-left-radius: 0.125rem |
| rounded-b | border-bottom-right-radius: 0.25rem; border-bottom-left-radius: 0.25rem |
| rounded-b-md | border-bottom-right-radius: 0.375rem; border-bottom-left-radius: 0.375rem |
| rounded-b-lg | border-bottom-right-radius: 0.5rem; border-bottom-left-radius: 0.5rem |
| rounded-b-xl | border-bottom-right-radius: 0.75rem; border-bottom-left-radius: 0.75rem |
| rounded-b-2xl | border-bottom-right-radius: 1rem; border-bottom-left-radius: 1rem |
| rounded-b-3xl | border-bottom-right-radius: 1.5rem; border-bottom-left-radius: 1.5rem |
| rounded-b-full | border-bottom-right-radius: 9999px; border-bottom-left-radius: 9999px |
| rounded-l-none | border-top-left-radius: 0px; border-bottom-left-radius: 0px |
| rounded-l-sm | border-top-left-radius: 0.125rem; border-bottom-left-radius: 0.125rem |
| rounded-l | border-top-left-radius: 0.25rem; border-bottom-left-radius: 0.25rem |
| rounded-l-md | border-top-left-radius: 0.375rem; border-bottom-left-radius: 0.375rem |
| rounded-l-lg | border-top-left-radius: 0.5rem; border-bottom-left-radius: 0.5rem |
| rounded-l-xl | border-top-left-radius: 0.75rem; border-bottom-left-radius: 0.75rem |
| rounded-l-2xl | border-top-left-radius: 1rem; border-bottom-left-radius: 1rem |
| rounded-l-3xl | border-top-left-radius: 1.5rem; border-bottom-left-radius: 1.5rem |
| rounded-l-full | border-top-left-radius: 9999px; border-bottom-left-radius: 9999px |
| rounded-tl-none | border-top-left-radius: 0px |
| rounded-tr-none | border-top-right-radius: 0px |
| rounded-br-none | border-bottom-right-radius: 0px |
| rounded-bl-none | border-bottom-left-radius: 0px |
| rounded-tl-sm | border-top-left-radius: 0.125rem |
| rounded-tr-sm | border-top-right-radius: 0.125rem |
| rounded-br-sm | border-bottom-right-radius: 0.125rem |
| rounded-bl-sm | border-bottom-left-radius: 0.125rem |
| rounded-tl | border-top-left-radius: 0.25rem |
| rounded-tr | border-top-right-radius: 0.25rem |
| rounded-br | border-bottom-right-radius: 0.25rem |
| rounded-bl | border-bottom-left-radius: 0.25rem |
| rounded-tl-md | border-top-left-radius: 0.375rem |
| rounded-tr-md | border-top-right-radius: 0.375rem |
| rounded-br-md | border-bottom-right-radius: 0.375rem |
| rounded-bl-md | border-bottom-left-radius: 0.375rem |
| rounded-tl-lg | border-top-left-radius: 0.5rem |
| rounded-tr-lg | border-top-right-radius: 0.5rem |
| rounded-br-lg | border-bottom-right-radius: 0.5rem |
| rounded-bl-lg | border-bottom-left-radius: 0.5rem |
| rounded-tl-xl | border-top-left-radius: 0.75rem |
| rounded-tr-xl | border-top-right-radius: 0.75rem |
| rounded-br-xl | border-bottom-right-radius: 0.75rem |
| rounded-bl-xl | border-bottom-left-radius: 0.75rem |
| rounded-tl-2xl | border-top-left-radius: 1rem |
| rounded-tr-2xl | border-top-right-radius: 1rem |
| rounded-br-2xl | border-bottom-right-radius: 1rem |
| rounded-bl-2xl | border-bottom-left-radius: 1rem |
| rounded-tl-3xl | border-top-left-radius: 1.5rem |
| rounded-tr-3xl | border-top-right-radius: 1.5rem |
| rounded-br-3xl | border-bottom-right-radius: 1.5rem |
| rounded-bl-3xl | border-bottom-left-radius: 1.5rem |
| rounded-tl-full | border-top-left-radius: 9999px |
| rounded-tr-full | border-top-right-radius: 9999px |
| rounded-br-full | border-bottom-right-radius: 9999px |
| rounded-bl-full | border-bottom-left-radius: 9999px |


*/
.rounded-none {
  border-radius: 0px;
}

.rounded-sm {
  border-radius: 0.125rem;
}

.rounded {
  border-radius: 0.25rem;
}

.rounded-md {
  border-radius: 0.375rem;
}

.rounded-lg {
  border-radius: 0.5rem;
}

.rounded-xl {
  border-radius: 0.75rem;
}

.rounded-2xl {
  border-radius: 1rem;
}

.rounded-3xl {
  border-radius: 1.5rem;
}

.rounded-full {
  border-radius: 9999px;
}

.rounded-t-none {
  border-top-left-radius: 0px;
  border-top-right-radius: 0px;
}

.rounded-t-sm {
  border-top-left-radius: 0.125rem;
  border-top-right-radius: 0.125rem;
}

.rounded-t {
  border-top-left-radius: 0.25rem;
  border-top-right-radius: 0.25rem;
}

.rounded-t-md {
  border-top-left-radius: 0.375rem;
  border-top-right-radius: 0.375rem;
}

.rounded-t-lg {
  border-top-left-radius: 0.5rem;
  border-top-right-radius: 0.5rem;
}

.rounded-t-xl {
  border-top-left-radius: 0.75rem;
  border-top-right-radius: 0.75rem;
}

.rounded-t-2xl {
  border-top-left-radius: 1rem;
  border-top-right-radius: 1rem;
}

.rounded-t-3xl {
  border-top-left-radius: 1.5rem;
  border-top-right-radius: 1.5rem;
}

.rounded-t-full {
  border-top-left-radius: 9999px;
  border-top-right-radius: 9999px;
}

.rounded-r-none {
  border-top-right-radius: 0px;
  border-bottom-right-radius: 0px;
}

.rounded-r-sm {
  border-top-right-radius: 0.125rem;
  border-bottom-right-radius: 0.125rem;
}

.rounded-r {
  border-top-right-radius: 0.25rem;
  border-bottom-right-radius: 0.25rem;
}

.rounded-r-md {
  border-top-right-radius: 0.375rem;
  border-bottom-right-radius: 0.375rem;
}

.rounded-r-lg {
  border-top-right-radius: 0.5rem;
  border-bottom-right-radius: 0.5rem;
}

.rounded-r-xl {
  border-top-right-radius: 0.75rem;
  border-bottom-right-radius: 0.75rem;
}

.rounded-r-2xl {
  border-top-right-radius: 1rem;
  border-bottom-right-radius: 1rem;
}

.rounded-r-3xl {
  border-top-right-radius: 1.5rem;
  border-bottom-right-radius: 1.5rem;
}

.rounded-r-full {
  border-top-right-radius: 9999px;
  border-bottom-right-radius: 9999px;
}

.rounded-b-none {
  border-bottom-right-radius: 0px;
  border-bottom-left-radius: 0px;
}

.rounded-b-sm {
  border-bottom-right-radius: 0.125rem;
  border-bottom-left-radius: 0.125rem;
}

.rounded-b {
  border-bottom-right-radius: 0.25rem;
  border-bottom-left-radius: 0.25rem;
}

.rounded-b-md {
  border-bottom-right-radius: 0.375rem;
  border-bottom-left-radius: 0.375rem;
}

.rounded-b-lg {
  border-bottom-right-radius: 0.5rem;
  border-bottom-left-radius: 0.5rem;
}

.rounded-b-xl {
  border-bottom-right-radius: 0.75rem;
  border-bottom-left-radius: 0.75rem;
}

.rounded-b-2xl {
  border-bottom-right-radius: 1rem;
  border-bottom-left-radius: 1rem;
}

.rounded-b-3xl {
  border-bottom-right-radius: 1.5rem;
  border-bottom-left-radius: 1.5rem;
}

.rounded-b-full {
  border-bottom-right-radius: 9999px;
  border-bottom-left-radius: 9999px;
}

.rounded-l-none {
  border-top-left-radius: 0px;
  border-bottom-left-radius: 0px;
}

.rounded-l-sm {
  border-top-left-radius: 0.125rem;
  border-bottom-left-radius: 0.125rem;
}

.rounded-l {
  border-top-left-radius: 0.25rem;
  border-bottom-left-radius: 0.25rem;
}

.rounded-l-md {
  border-top-left-radius: 0.375rem;
  border-bottom-left-radius: 0.375rem;
}

.rounded-l-lg {
  border-top-left-radius: 0.5rem;
  border-bottom-left-radius: 0.5rem;
}

.rounded-l-xl {
  border-top-left-radius: 0.75rem;
  border-bottom-left-radius: 0.75rem;
}

.rounded-l-2xl {
  border-top-left-radius: 1rem;
  border-bottom-left-radius: 1rem;
}

.rounded-l-3xl {
  border-top-left-radius: 1.5rem;
  border-bottom-left-radius: 1.5rem;
}

.rounded-l-full {
  border-top-left-radius: 9999px;
  border-bottom-left-radius: 9999px;
}

.rounded-tl-none {
  border-top-left-radius: 0px;
}

.rounded-tr-none {
  border-top-right-radius: 0px;
}

.rounded-br-none {
  border-bottom-right-radius: 0px;
}

.rounded-bl-none {
  border-bottom-left-radius: 0px;
}

.rounded-tl-sm {
  border-top-left-radius: 0.125rem;
}

.rounded-tr-sm {
  border-top-right-radius: 0.125rem;
}

.rounded-br-sm {
  border-bottom-right-radius: 0.125rem;
}

.rounded-bl-sm {
  border-bottom-left-radius: 0.125rem;
}

.rounded-tl {
  border-top-left-radius: 0.25rem;
}

.rounded-tr {
  border-top-right-radius: 0.25rem;
}

.rounded-br {
  border-bottom-right-radius: 0.25rem;
}

.rounded-bl {
  border-bottom-left-radius: 0.25rem;
}

.rounded-tl-md {
  border-top-left-radius: 0.375rem;
}

.rounded-tr-md {
  border-top-right-radius: 0.375rem;
}

.rounded-br-md {
  border-bottom-right-radius: 0.375rem;
}

.rounded-bl-md {
  border-bottom-left-radius: 0.375rem;
}

.rounded-tl-lg {
  border-top-left-radius: 0.5rem;
}

.rounded-tr-lg {
  border-top-right-radius: 0.5rem;
}

.rounded-br-lg {
  border-bottom-right-radius: 0.5rem;
}

.rounded-bl-lg {
  border-bottom-left-radius: 0.5rem;
}

.rounded-tl-xl {
  border-top-left-radius: 0.75rem;
}

.rounded-tr-xl {
  border-top-right-radius: 0.75rem;
}

.rounded-br-xl {
  border-bottom-right-radius: 0.75rem;
}

.rounded-bl-xl {
  border-bottom-left-radius: 0.75rem;
}

.rounded-tl-2xl {
  border-top-left-radius: 1rem;
}

.rounded-tr-2xl {
  border-top-right-radius: 1rem;
}

.rounded-br-2xl {
  border-bottom-right-radius: 1rem;
}

.rounded-bl-2xl {
  border-bottom-left-radius: 1rem;
}

.rounded-tl-3xl {
  border-top-left-radius: 1.5rem;
}

.rounded-tr-3xl {
  border-top-right-radius: 1.5rem;
}

.rounded-br-3xl {
  border-bottom-right-radius: 1.5rem;
}

.rounded-bl-3xl {
  border-bottom-left-radius: 1.5rem;
}

.rounded-tl-full {
  border-top-left-radius: 9999px;
}

.rounded-tr-full {
  border-top-right-radius: 9999px;
}

.rounded-br-full {
  border-bottom-right-radius: 9999px;
}

.rounded-bl-full {
  border-bottom-left-radius: 9999px;
}

@media (max-width: 768px) {
  .m\:rounded-none {
    border-radius: 0px;
  }

  .m\:rounded-sm {
    border-radius: 0.125rem;
  }

  .m\:rounded {
    border-radius: 0.25rem;
  }

  .m\:rounded-md {
    border-radius: 0.375rem;
  }

  .m\:rounded-lg {
    border-radius: 0.5rem;
  }

  .m\:rounded-xl {
    border-radius: 0.75rem;
  }

  .m\:rounded-2xl {
    border-radius: 1rem;
  }

  .m\:rounded-3xl {
    border-radius: 1.5rem;
  }

  .m\:rounded-full {
    border-radius: 9999px;
  }

  .m\:rounded-t-none {
    border-top-left-radius: 0px;
    border-top-right-radius: 0px;
  }

  .m\:rounded-t-sm {
    border-top-left-radius: 0.125rem;
    border-top-right-radius: 0.125rem;
  }

  .m\:rounded-t {
    border-top-left-radius: 0.25rem;
    border-top-right-radius: 0.25rem;
  }

  .m\:rounded-t-md {
    border-top-left-radius: 0.375rem;
    border-top-right-radius: 0.375rem;
  }

  .m\:rounded-t-lg {
    border-top-left-radius: 0.5rem;
    border-top-right-radius: 0.5rem;
  }

  .m\:rounded-t-xl {
    border-top-left-radius: 0.75rem;
    border-top-right-radius: 0.75rem;
  }

  .m\:rounded-t-2xl {
    border-top-left-radius: 1rem;
    border-top-right-radius: 1rem;
  }

  .m\:rounded-t-3xl {
    border-top-left-radius: 1.5rem;
    border-top-right-radius: 1.5rem;
  }

  .m\:rounded-t-full {
    border-top-left-radius: 9999px;
    border-top-right-radius: 9999px;
  }

  .m\:rounded-r-none {
    border-top-right-radius: 0px;
    border-bottom-right-radius: 0px;
  }

  .m\:rounded-r-sm {
    border-top-right-radius: 0.125rem;
    border-bottom-right-radius: 0.125rem;
  }

  .m\:rounded-r {
    border-top-right-radius: 0.25rem;
    border-bottom-right-radius: 0.25rem;
  }

  .m\:rounded-r-md {
    border-top-right-radius: 0.375rem;
    border-bottom-right-radius: 0.375rem;
  }

  .m\:rounded-r-lg {
    border-top-right-radius: 0.5rem;
    border-bottom-right-radius: 0.5rem;
  }

  .m\:rounded-r-xl {
    border-top-right-radius: 0.75rem;
    border-bottom-right-radius: 0.75rem;
  }

  .m\:rounded-r-2xl {
    border-top-right-radius: 1rem;
    border-bottom-right-radius: 1rem;
  }

  .m\:rounded-r-3xl {
    border-top-right-radius: 1.5rem;
    border-bottom-right-radius: 1.5rem;
  }

  .m\:rounded-r-full {
    border-top-right-radius: 9999px;
    border-bottom-right-radius: 9999px;
  }

  .m\:rounded-b-none {
    border-bottom-right-radius: 0px;
    border-bottom-left-radius: 0px;
  }

  .m\:rounded-b-sm {
    border-bottom-right-radius: 0.125rem;
    border-bottom-left-radius: 0.125rem;
  }

  .m\:rounded-b {
    border-bottom-right-radius: 0.25rem;
    border-bottom-left-radius: 0.25rem;
  }

  .m\:rounded-b-md {
    border-bottom-right-radius: 0.375rem;
    border-bottom-left-radius: 0.375rem;
  }

  .m\:rounded-b-lg {
    border-bottom-right-radius: 0.5rem;
    border-bottom-left-radius: 0.5rem;
  }

  .m\:rounded-b-xl {
    border-bottom-right-radius: 0.75rem;
    border-bottom-left-radius: 0.75rem;
  }

  .m\:rounded-b-2xl {
    border-bottom-right-radius: 1rem;
    border-bottom-left-radius: 1rem;
  }

  .m\:rounded-b-3xl {
    border-bottom-right-radius: 1.5rem;
    border-bottom-left-radius: 1.5rem;
  }

  .m\:rounded-b-full {
    border-bottom-right-radius: 9999px;
    border-bottom-left-radius: 9999px;
  }

  .m\:rounded-l-none {
    border-top-left-radius: 0px;
    border-bottom-left-radius: 0px;
  }

  .m\:rounded-l-sm {
    border-top-left-radius: 0.125rem;
    border-bottom-left-radius: 0.125rem;
  }

  .m\:rounded-l {
    border-top-left-radius: 0.25rem;
    border-bottom-left-radius: 0.25rem;
  }

  .m\:rounded-l-md {
    border-top-left-radius: 0.375rem;
    border-bottom-left-radius: 0.375rem;
  }

  .m\:rounded-l-lg {
    border-top-left-radius: 0.5rem;
    border-bottom-left-radius: 0.5rem;
  }

  .m\:rounded-l-xl {
    border-top-left-radius: 0.75rem;
    border-bottom-left-radius: 0.75rem;
  }

  .m\:rounded-l-2xl {
    border-top-left-radius: 1rem;
    border-bottom-left-radius: 1rem;
  }

  .m\:rounded-l-3xl {
    border-top-left-radius: 1.5rem;
    border-bottom-left-radius: 1.5rem;
  }

  .m\:rounded-l-full {
    border-top-left-radius: 9999px;
    border-bottom-left-radius: 9999px;
  }

  .m\:rounded-tl-none {
    border-top-left-radius: 0px;
  }

  .m\:rounded-tr-none {
    border-top-right-radius: 0px;
  }

  .m\:rounded-br-none {
    border-bottom-right-radius: 0px;
  }

  .m\:rounded-bl-none {
    border-bottom-left-radius: 0px;
  }

  .m\:rounded-tl-sm {
    border-top-left-radius: 0.125rem;
  }

  .m\:rounded-tr-sm {
    border-top-right-radius: 0.125rem;
  }

  .m\:rounded-br-sm {
    border-bottom-right-radius: 0.125rem;
  }

  .m\:rounded-bl-sm {
    border-bottom-left-radius: 0.125rem;
  }

  .m\:rounded-tl {
    border-top-left-radius: 0.25rem;
  }

  .m\:rounded-tr {
    border-top-right-radius: 0.25rem;
  }

  .m\:rounded-br {
    border-bottom-right-radius: 0.25rem;
  }

  .m\:rounded-bl {
    border-bottom-left-radius: 0.25rem;
  }

  .m\:rounded-tl-md {
    border-top-left-radius: 0.375rem;
  }

  .m\:rounded-tr-md {
    border-top-right-radius: 0.375rem;
  }

  .m\:rounded-br-md {
    border-bottom-right-radius: 0.375rem;
  }

  .m\:rounded-bl-md {
    border-bottom-left-radius: 0.375rem;
  }

  .m\:rounded-tl-lg {
    border-top-left-radius: 0.5rem;
  }

  .m\:rounded-tr-lg {
    border-top-right-radius: 0.5rem;
  }

  .m\:rounded-br-lg {
    border-bottom-right-radius: 0.5rem;
  }

  .m\:rounded-bl-lg {
    border-bottom-left-radius: 0.5rem;
  }

  .m\:rounded-tl-xl {
    border-top-left-radius: 0.75rem;
  }

  .m\:rounded-tr-xl {
    border-top-right-radius: 0.75rem;
  }

  .m\:rounded-br-xl {
    border-bottom-right-radius: 0.75rem;
  }

  .m\:rounded-bl-xl {
    border-bottom-left-radius: 0.75rem;
  }

  .m\:rounded-tl-2xl {
    border-top-left-radius: 1rem;
  }

  .m\:rounded-tr-2xl {
    border-top-right-radius: 1rem;
  }

  .m\:rounded-br-2xl {
    border-bottom-right-radius: 1rem;
  }

  .m\:rounded-bl-2xl {
    border-bottom-left-radius: 1rem;
  }

  .m\:rounded-tl-3xl {
    border-top-left-radius: 1.5rem;
  }

  .m\:rounded-tr-3xl {
    border-top-right-radius: 1.5rem;
  }

  .m\:rounded-br-3xl {
    border-bottom-right-radius: 1.5rem;
  }

  .m\:rounded-bl-3xl {
    border-bottom-left-radius: 1.5rem;
  }

  .m\:rounded-tl-full {
    border-top-left-radius: 9999px;
  }

  .m\:rounded-tr-full {
    border-top-right-radius: 9999px;
  }

  .m\:rounded-br-full {
    border-bottom-right-radius: 9999px;
  }

  .m\:rounded-bl-full {
    border-bottom-left-radius: 9999px;
  }
}
@media (min-width: 769px) {
  .pc\:rounded-none {
    border-radius: 0px;
  }

  .pc\:rounded-sm {
    border-radius: 0.125rem;
  }

  .pc\:rounded {
    border-radius: 0.25rem;
  }

  .pc\:rounded-md {
    border-radius: 0.375rem;
  }

  .pc\:rounded-lg {
    border-radius: 0.5rem;
  }

  .pc\:rounded-xl {
    border-radius: 0.75rem;
  }

  .pc\:rounded-2xl {
    border-radius: 1rem;
  }

  .pc\:rounded-3xl {
    border-radius: 1.5rem;
  }

  .pc\:rounded-full {
    border-radius: 9999px;
  }

  .pc\:rounded-t-none {
    border-top-left-radius: 0px;
    border-top-right-radius: 0px;
  }

  .pc\:rounded-t-sm {
    border-top-left-radius: 0.125rem;
    border-top-right-radius: 0.125rem;
  }

  .pc\:rounded-t {
    border-top-left-radius: 0.25rem;
    border-top-right-radius: 0.25rem;
  }

  .pc\:rounded-t-md {
    border-top-left-radius: 0.375rem;
    border-top-right-radius: 0.375rem;
  }

  .pc\:rounded-t-lg {
    border-top-left-radius: 0.5rem;
    border-top-right-radius: 0.5rem;
  }

  .pc\:rounded-t-xl {
    border-top-left-radius: 0.75rem;
    border-top-right-radius: 0.75rem;
  }

  .pc\:rounded-t-2xl {
    border-top-left-radius: 1rem;
    border-top-right-radius: 1rem;
  }

  .pc\:rounded-t-3xl {
    border-top-left-radius: 1.5rem;
    border-top-right-radius: 1.5rem;
  }

  .pc\:rounded-t-full {
    border-top-left-radius: 9999px;
    border-top-right-radius: 9999px;
  }

  .pc\:rounded-r-none {
    border-top-right-radius: 0px;
    border-bottom-right-radius: 0px;
  }

  .pc\:rounded-r-sm {
    border-top-right-radius: 0.125rem;
    border-bottom-right-radius: 0.125rem;
  }

  .pc\:rounded-r {
    border-top-right-radius: 0.25rem;
    border-bottom-right-radius: 0.25rem;
  }

  .pc\:rounded-r-md {
    border-top-right-radius: 0.375rem;
    border-bottom-right-radius: 0.375rem;
  }

  .pc\:rounded-r-lg {
    border-top-right-radius: 0.5rem;
    border-bottom-right-radius: 0.5rem;
  }

  .pc\:rounded-r-xl {
    border-top-right-radius: 0.75rem;
    border-bottom-right-radius: 0.75rem;
  }

  .pc\:rounded-r-2xl {
    border-top-right-radius: 1rem;
    border-bottom-right-radius: 1rem;
  }

  .pc\:rounded-r-3xl {
    border-top-right-radius: 1.5rem;
    border-bottom-right-radius: 1.5rem;
  }

  .pc\:rounded-r-full {
    border-top-right-radius: 9999px;
    border-bottom-right-radius: 9999px;
  }

  .pc\:rounded-b-none {
    border-bottom-right-radius: 0px;
    border-bottom-left-radius: 0px;
  }

  .pc\:rounded-b-sm {
    border-bottom-right-radius: 0.125rem;
    border-bottom-left-radius: 0.125rem;
  }

  .pc\:rounded-b {
    border-bottom-right-radius: 0.25rem;
    border-bottom-left-radius: 0.25rem;
  }

  .pc\:rounded-b-md {
    border-bottom-right-radius: 0.375rem;
    border-bottom-left-radius: 0.375rem;
  }

  .pc\:rounded-b-lg {
    border-bottom-right-radius: 0.5rem;
    border-bottom-left-radius: 0.5rem;
  }

  .pc\:rounded-b-xl {
    border-bottom-right-radius: 0.75rem;
    border-bottom-left-radius: 0.75rem;
  }

  .pc\:rounded-b-2xl {
    border-bottom-right-radius: 1rem;
    border-bottom-left-radius: 1rem;
  }

  .pc\:rounded-b-3xl {
    border-bottom-right-radius: 1.5rem;
    border-bottom-left-radius: 1.5rem;
  }

  .pc\:rounded-b-full {
    border-bottom-right-radius: 9999px;
    border-bottom-left-radius: 9999px;
  }

  .pc\:rounded-l-none {
    border-top-left-radius: 0px;
    border-bottom-left-radius: 0px;
  }

  .pc\:rounded-l-sm {
    border-top-left-radius: 0.125rem;
    border-bottom-left-radius: 0.125rem;
  }

  .pc\:rounded-l {
    border-top-left-radius: 0.25rem;
    border-bottom-left-radius: 0.25rem;
  }

  .pc\:rounded-l-md {
    border-top-left-radius: 0.375rem;
    border-bottom-left-radius: 0.375rem;
  }

  .pc\:rounded-l-lg {
    border-top-left-radius: 0.5rem;
    border-bottom-left-radius: 0.5rem;
  }

  .pc\:rounded-l-xl {
    border-top-left-radius: 0.75rem;
    border-bottom-left-radius: 0.75rem;
  }

  .pc\:rounded-l-2xl {
    border-top-left-radius: 1rem;
    border-bottom-left-radius: 1rem;
  }

  .pc\:rounded-l-3xl {
    border-top-left-radius: 1.5rem;
    border-bottom-left-radius: 1.5rem;
  }

  .pc\:rounded-l-full {
    border-top-left-radius: 9999px;
    border-bottom-left-radius: 9999px;
  }

  .pc\:rounded-tl-none {
    border-top-left-radius: 0px;
  }

  .pc\:rounded-tr-none {
    border-top-right-radius: 0px;
  }

  .pc\:rounded-br-none {
    border-bottom-right-radius: 0px;
  }

  .pc\:rounded-bl-none {
    border-bottom-left-radius: 0px;
  }

  .pc\:rounded-tl-sm {
    border-top-left-radius: 0.125rem;
  }

  .pc\:rounded-tr-sm {
    border-top-right-radius: 0.125rem;
  }

  .pc\:rounded-br-sm {
    border-bottom-right-radius: 0.125rem;
  }

  .pc\:rounded-bl-sm {
    border-bottom-left-radius: 0.125rem;
  }

  .pc\:rounded-tl {
    border-top-left-radius: 0.25rem;
  }

  .pc\:rounded-tr {
    border-top-right-radius: 0.25rem;
  }

  .pc\:rounded-br {
    border-bottom-right-radius: 0.25rem;
  }

  .pc\:rounded-bl {
    border-bottom-left-radius: 0.25rem;
  }

  .pc\:rounded-tl-md {
    border-top-left-radius: 0.375rem;
  }

  .pc\:rounded-tr-md {
    border-top-right-radius: 0.375rem;
  }

  .pc\:rounded-br-md {
    border-bottom-right-radius: 0.375rem;
  }

  .pc\:rounded-bl-md {
    border-bottom-left-radius: 0.375rem;
  }

  .pc\:rounded-tl-lg {
    border-top-left-radius: 0.5rem;
  }

  .pc\:rounded-tr-lg {
    border-top-right-radius: 0.5rem;
  }

  .pc\:rounded-br-lg {
    border-bottom-right-radius: 0.5rem;
  }

  .pc\:rounded-bl-lg {
    border-bottom-left-radius: 0.5rem;
  }

  .pc\:rounded-tl-xl {
    border-top-left-radius: 0.75rem;
  }

  .pc\:rounded-tr-xl {
    border-top-right-radius: 0.75rem;
  }

  .pc\:rounded-br-xl {
    border-bottom-right-radius: 0.75rem;
  }

  .pc\:rounded-bl-xl {
    border-bottom-left-radius: 0.75rem;
  }

  .pc\:rounded-tl-2xl {
    border-top-left-radius: 1rem;
  }

  .pc\:rounded-tr-2xl {
    border-top-right-radius: 1rem;
  }

  .pc\:rounded-br-2xl {
    border-bottom-right-radius: 1rem;
  }

  .pc\:rounded-bl-2xl {
    border-bottom-left-radius: 1rem;
  }

  .pc\:rounded-tl-3xl {
    border-top-left-radius: 1.5rem;
  }

  .pc\:rounded-tr-3xl {
    border-top-right-radius: 1.5rem;
  }

  .pc\:rounded-br-3xl {
    border-bottom-right-radius: 1.5rem;
  }

  .pc\:rounded-bl-3xl {
    border-bottom-left-radius: 1.5rem;
  }

  .pc\:rounded-tl-full {
    border-top-left-radius: 9999px;
  }

  .pc\:rounded-tr-full {
    border-top-right-radius: 9999px;
  }

  .pc\:rounded-br-full {
    border-bottom-right-radius: 9999px;
  }

  .pc\:rounded-bl-full {
    border-bottom-left-radius: 9999px;
  }
}
/*!markdown

---
title: 边框宽度
---

| Class       | Properties               |
| ----------- | ------------------------ |
| border | border-width: 1px |
| border-0 | border-width: 0px |
| border-2 | border-width: 2px |
| border-4 | border-width: 4px |
| border-8 | border-width: 8px |
| border-t | border-top-width: 1px |
| border-r | border-right-width: 1px |
| border-b | border-bottom-width: 1px |
| border-l | border-left-width: 1px |
| border-t-0 | border-top-width: 0px |
| border-r-0 | border-right-width: 0px |
| border-b-0 | border-bottom-width: 0px |
| border-l-0 | border-left-width: 0px |
| border-t-2 | border-top-width: 2px |
| border-r-2 | border-right-width: 2px |
| border-b-2 | border-bottom-width: 2px |
| border-l-2 | border-left-width: 2px |
| border-t-4 | border-top-width: 4px |
| border-r-4 | border-right-width: 4px |
| border-b-4 | border-bottom-width: 4px |
| border-l-4 | border-left-width: 4px |
| border-t-8 | border-top-width: 8px |
| border-r-8 | border-right-width: 8px |
| border-b-8 | border-bottom-width: 8px |
| border-l-8 | border-left-width: 8px |


*/
.border {
  border-width: 1px;
}

.border-0 {
  border-width: 0px;
}

.border-2 {
  border-width: 2px;
}

.border-4 {
  border-width: 4px;
}

.border-8 {
  border-width: 8px;
}

.border-t {
  border-top-width: 1px;
}

.border-r {
  border-right-width: 1px;
}

.border-b {
  border-bottom-width: 1px;
}

.border-l {
  border-left-width: 1px;
}

.border-t-0 {
  border-top-width: 0px;
}

.border-r-0 {
  border-right-width: 0px;
}

.border-b-0 {
  border-bottom-width: 0px;
}

.border-l-0 {
  border-left-width: 0px;
}

.border-t-2 {
  border-top-width: 2px;
}

.border-r-2 {
  border-right-width: 2px;
}

.border-b-2 {
  border-bottom-width: 2px;
}

.border-l-2 {
  border-left-width: 2px;
}

.border-t-4 {
  border-top-width: 4px;
}

.border-r-4 {
  border-right-width: 4px;
}

.border-b-4 {
  border-bottom-width: 4px;
}

.border-l-4 {
  border-left-width: 4px;
}

.border-t-8 {
  border-top-width: 8px;
}

.border-r-8 {
  border-right-width: 8px;
}

.border-b-8 {
  border-bottom-width: 8px;
}

.border-l-8 {
  border-left-width: 8px;
}

@media (max-width: 768px) {
  .m\:border {
    border-width: 1px;
  }

  .m\:border-0 {
    border-width: 0px;
  }

  .m\:border-2 {
    border-width: 2px;
  }

  .m\:border-4 {
    border-width: 4px;
  }

  .m\:border-8 {
    border-width: 8px;
  }

  .m\:border-t {
    border-top-width: 1px;
  }

  .m\:border-r {
    border-right-width: 1px;
  }

  .m\:border-b {
    border-bottom-width: 1px;
  }

  .m\:border-l {
    border-left-width: 1px;
  }

  .m\:border-t-0 {
    border-top-width: 0px;
  }

  .m\:border-r-0 {
    border-right-width: 0px;
  }

  .m\:border-b-0 {
    border-bottom-width: 0px;
  }

  .m\:border-l-0 {
    border-left-width: 0px;
  }

  .m\:border-t-2 {
    border-top-width: 2px;
  }

  .m\:border-r-2 {
    border-right-width: 2px;
  }

  .m\:border-b-2 {
    border-bottom-width: 2px;
  }

  .m\:border-l-2 {
    border-left-width: 2px;
  }

  .m\:border-t-4 {
    border-top-width: 4px;
  }

  .m\:border-r-4 {
    border-right-width: 4px;
  }

  .m\:border-b-4 {
    border-bottom-width: 4px;
  }

  .m\:border-l-4 {
    border-left-width: 4px;
  }

  .m\:border-t-8 {
    border-top-width: 8px;
  }

  .m\:border-r-8 {
    border-right-width: 8px;
  }

  .m\:border-b-8 {
    border-bottom-width: 8px;
  }

  .m\:border-l-8 {
    border-left-width: 8px;
  }
}
@media (min-width: 769px) {
  .pc\:border {
    border-width: 1px;
  }

  .pc\:border-0 {
    border-width: 0px;
  }

  .pc\:border-2 {
    border-width: 2px;
  }

  .pc\:border-4 {
    border-width: 4px;
  }

  .pc\:border-8 {
    border-width: 8px;
  }

  .pc\:border-t {
    border-top-width: 1px;
  }

  .pc\:border-r {
    border-right-width: 1px;
  }

  .pc\:border-b {
    border-bottom-width: 1px;
  }

  .pc\:border-l {
    border-left-width: 1px;
  }

  .pc\:border-t-0 {
    border-top-width: 0px;
  }

  .pc\:border-r-0 {
    border-right-width: 0px;
  }

  .pc\:border-b-0 {
    border-bottom-width: 0px;
  }

  .pc\:border-l-0 {
    border-left-width: 0px;
  }

  .pc\:border-t-2 {
    border-top-width: 2px;
  }

  .pc\:border-r-2 {
    border-right-width: 2px;
  }

  .pc\:border-b-2 {
    border-bottom-width: 2px;
  }

  .pc\:border-l-2 {
    border-left-width: 2px;
  }

  .pc\:border-t-4 {
    border-top-width: 4px;
  }

  .pc\:border-r-4 {
    border-right-width: 4px;
  }

  .pc\:border-b-4 {
    border-bottom-width: 4px;
  }

  .pc\:border-l-4 {
    border-left-width: 4px;
  }

  .pc\:border-t-8 {
    border-top-width: 8px;
  }

  .pc\:border-r-8 {
    border-right-width: 8px;
  }

  .pc\:border-b-8 {
    border-bottom-width: 8px;
  }

  .pc\:border-l-8 {
    border-left-width: 8px;
  }
}
/*!markdown

---
title: 边框样式
---

| Class       | Properties               |
| ----------- | ------------------------ |
| border-solid | border-style: solid |
| border-dashed | border-style: dashed |
| border-dotted | border-style: dotted |
| border-double | border-style: double |
| border-none | border-style: none |


*/
.border-solid {
  border-style: solid;
}

.border-dashed {
  border-style: dashed;
}

.border-dotted {
  border-style: dotted;
}

.border-double {
  border-style: double;
}

.border-none {
  border-style: none;
}

@media (max-width: 768px) {
  .m\:border-solid {
    border-style: solid;
  }

  .m\:border-dashed {
    border-style: dashed;
  }

  .m\:border-dotted {
    border-style: dotted;
  }

  .m\:border-double {
    border-style: double;
  }

  .m\:border-none {
    border-style: none;
  }
}
@media (min-width: 769px) {
  .pc\:border-solid {
    border-style: solid;
  }

  .pc\:border-dashed {
    border-style: dashed;
  }

  .pc\:border-dotted {
    border-style: dotted;
  }

  .pc\:border-double {
    border-style: double;
  }

  .pc\:border-none {
    border-style: none;
  }
}
/*!markdown

---
title: Box Sizing
---

Box Sizing 相关样式，主要区别在于设置宽高的时候，是否包含了 padding 和 border 的大小。


| Class       | Properties               |
| ----------- | ------------------------ |
| box-border  | box-sizing: border-box;  |
| box-content | box-sizing: content-box; |

## 用法

比如这个例子：左侧是 box-border 类型，整体高宽 128px。而右侧只是内容区域是 128px + 边框(2 * 4px) + padding （2 * 16px） 一共160px。

```html
<div class="flex space-x-6">
  <div class="box-border h-32 w-32 p-4 border-4 border-blue-400 bg-blue-200 rounded-md">
    <div class="h-full w-full bg-red-400"></div>
  </div>

  <div class="box-content h-32 w-32 p-4 border-4 border-blue-400 bg-blue-200 rounded-md">
    <div class="h-full w-full bg-red-400"></div>
  </div>
</div>
```

## 响应式设计

不支持 [「响应式设计前缀」](../../../docs/style/responsive-design.md)，有需求请提 [issue](https://github.com/baidu/amis/issues)。

## 状态前缀

不支持[「状态前缀」](../../../docs/style/state.md)，有需求请提 [issue](https://github.com/baidu/amis/issues)。

*/
.box-border {
  box-sizing: border-box;
}

.box-content {
  box-sizing: content-box;
}

/*!markdown

---
title: Clear
---

清除浮动相关样式。

| Class       | Properties    |
| ----------- | ------------- |
| clear-right | clear: right; |
| clear-left  | clear: left;  |
| clear-none  | clear: none;  |
| clear-both  | clear: both;  |

## 用法

请前往以下链接查看属性含义。

https://www.w3school.com.cn/cssref/pr_class_clear.asp


# 响应式设计

支持通过添加设备前缀 `m:` 或者 `pc:` 来分别针对「手机端」或者「pc端」设置样式，更多说明请前往[「响应式设计」](../../../docs/style/responsive-design.md)。

## 状态前缀

不支持[「状态前缀」](../../../docs/style/state.md)，有需求请提 [issue](https://github.com/baidu/amis/issues)。

*/
.clear-right {
  clear: right;
}

.clear-left {
  clear: left;
}

.clear-none {
  clear: none;
}

.clear-both {
  clear: both;
}

@media (max-width: 768px) {
  .m\:clear-right {
    clear: right;
  }

  .m\:clear-left {
    clear: left;
  }

  .m\:clear-none {
    clear: none;
  }

  .m\:clear-both {
    clear: both;
  }
}
@media (min-width: 769px) {
  .pc\:clear-right {
    clear: right;
  }

  .pc\:clear-left {
    clear: left;
  }

  .pc\:clear-none {
    clear: none;
  }

  .pc\:clear-both {
    clear: both;
  }
}
/*!markdown

---
title: Display
---

布局相关样式。


| Class              | Properties                   |
| ------------------ | ---------------------------- |
| block              | display: block;              |
| inline-block       | display: inline-block;       |
| inline             | display: inline;             |
| flex               | display: flex;               |
| inline-flex        | display: inline-flex;        |
| table              | display: table;              |
| table-cell         | display: table-cell;         |
| table-column       | display: table-column;       |
| table-column-group | display: table-column-group; |
| table-footer-group | display: table-footer-group; |
| table-header-group | display: table-header-group; |
| table-row-group    | display: table-row-group;    |
| table-row          | display: table-row;          |
| flow-root          | display: flow-root;          |
| grid               | display: grid;               |
| inline-grid        | display: inline-grid;        |
| contents           | display: contents;           |
| hidden             | display: hidden;             |

## 用法
css 相关的知识点就不介绍了，请参考：

https://www.w3school.com.cn/cssref/pr_class_display.asp
https://tailwindcss.com/docs/display

# 响应式设计

支持通过添加设备前缀 `m:` 或者 `pc:` 来分别针对「手机端」或者「pc端」设置样式，更多说明请前往[「响应式设计」](../../../docs/style/responsive-design.md)。

## 状态前缀

不支持[「状态前缀」](../../../docs/style/state.md)，有需求请提 [issue](https://github.com/baidu/amis/issues)。

*/
.block {
  display: block;
}

.inline-block {
  display: inline-block;
}

.inline {
  display: inline;
}

.flex {
  display: flex;
}

.inline-flex {
  display: inline-flex;
}

.table {
  display: table;
}

.table-caption {
  display: table-caption;
}

.table-cell {
  display: table-cell;
}

.table-column {
  display: table-column;
}

.table-column-group {
  display: table-column-group;
}

.table-footer-group {
  display: table-footer-group;
}

.table-header-group {
  display: table-header-group;
}

.table-row-group {
  display: table-row-group;
}

.table-row {
  display: table-row;
}

.flow-root {
  display: flow-root;
}

.grid {
  display: grid;
}

.inline-grid {
  display: inline-grid;
}

.contents {
  display: contents;
}

.hidden {
  display: none;
}

@media (max-width: 768px) {
  .m\:block {
    display: block;
  }

  .m\:inline-block {
    display: inline-block;
  }

  .m\:inline {
    display: inline;
  }

  .m\:flex {
    display: flex;
  }

  .m\:inline-flex {
    display: inline-flex;
  }

  .m\:table {
    display: table;
  }

  .m\:table-caption {
    display: table-caption;
  }

  .m\:table-cell {
    display: table-cell;
  }

  .m\:table-column {
    display: table-column;
  }

  .m\:table-column-group {
    display: table-column-group;
  }

  .m\:table-footer-group {
    display: table-footer-group;
  }

  .m\:table-header-group {
    display: table-header-group;
  }

  .m\:table-row-group {
    display: table-row-group;
  }

  .m\:table-row {
    display: table-row;
  }

  .m\:flow-root {
    display: flow-root;
  }

  .m\:grid {
    display: grid;
  }

  .m\:inline-grid {
    display: inline-grid;
  }

  .m\:contents {
    display: contents;
  }

  .m\:hidden {
    display: none;
  }
}
@media (min-width: 769px) {
  .pc\:block {
    display: block;
  }

  .pc\:inline-block {
    display: inline-block;
  }

  .pc\:inline {
    display: inline;
  }

  .pc\:flex {
    display: flex;
  }

  .pc\:inline-flex {
    display: inline-flex;
  }

  .pc\:table {
    display: table;
  }

  .pc\:table-caption {
    display: table-caption;
  }

  .pc\:table-cell {
    display: table-cell;
  }

  .pc\:table-column {
    display: table-column;
  }

  .pc\:table-column-group {
    display: table-column-group;
  }

  .pc\:table-footer-group {
    display: table-footer-group;
  }

  .pc\:table-header-group {
    display: table-header-group;
  }

  .pc\:table-row-group {
    display: table-row-group;
  }

  .pc\:table-row {
    display: table-row;
  }

  .pc\:flow-root {
    display: flow-root;
  }

  .pc\:grid {
    display: grid;
  }

  .pc\:inline-grid {
    display: inline-grid;
  }

  .pc\:contents {
    display: contents;
  }

  .pc\:hidden {
    display: none;
  }
}
/*!markdown

---
title: Floats
---

浮动相关样式。

| Class       | Properties    |
| ----------- | ------------- |
| float-right | float: right; |
| float-left  | float: left;  |
| float-none  | float: none;  |

## 左浮

```html
<img class="w-32 m-4 pc:float-left ..." src="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAALQAAAC0CAMAAAAKE/YAAAAAP1BMVEXp7vG6vsHo7fC3ur7s8fXr8PO1uLy8wMO5vcDL0NLN0dXl6u3T19vHy86+wsXO0tbQ1djc4eTh5ejBxcjZ3eD/ULOKAAACiklEQVR42u3a2YrjMBCF4arSVrYTL3Le/1lHXqbdPTZDWheRDOcLAZGrnyLgRSIAAAAAAAAAAAAAAAAAAAAAAAAAAAD4IrmoGBHKVSxbyFEm56hMtRBN7TNPO1GRaiFpvDd5vG+lQLUQNT6EwDlCYD+4AtF2Ug4mkzKb+PFqITf6oP3wyDEEZTPaz0dT63s/2DxPw6YtFT2S7Lr0eZtrSkYP64pShrXWyZsVhaNHt6xScjdNUSy9lyG2fLTYbpyZw/NFJDeJFhdnb4wab1ohuUc0dbPnwMxB/WhFbhFtR8+boBwvSkSktmiS2fDu8oohzoqQ1BQtLgY9oht3HutrXKvrjX4SyekexTys1DVp6vojeimRf5t1ra5p0lvBTvVlz83MW3VV0TF1bfwsJOfmv9UVRYt9eN2a++gumo/qeqJJ3Ks3i+dl81FNUk90ipDX0I4TfW+WvflndT3R6WsTJ/9r3qvriSb569x8VPNaXU/0149y0XxU+4cjqSpaZK8+mq+rK4pOofE5WZFT86m6omjbzT4s1UfzZXVFf4+1uTc82aWZTeArGkzoXC3R25w1LNX2lZqVr2lfPnpZHc3MqTpOejSfmAqiHcn35kRDCk8qnnSKPpo3qqx1R6fV3swHrX/SazP/UHl0Wrml+VbRTmhpvlu0i6o3jA6IPlQTHWqJZqNv4ypumFJ0z+FtPc8VRJNI9zvln1wytrhrenLZ3GGjqHWW3O/tm5+Ftpm5Gdrht9qh2V6CCH2Y2KgmsM9imFWj+3w00eiVQx5eN8Lo44RkVJOLR5IyR2tcHJs8Y7SlDjGJtS6PteWOi53d4WQe3a8YAAAAAAAAAAAAAAAAAAAAAAAAAACgNn8AGA09DkR51CoAAAAASUVORK5CYII=">
<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nam venenatis et lorem sit amet vehicula. Etiam vel nibh nec nisi euismod mollis ultrices condimentum velit. Proin velit libero, interdum ac rhoncus sit amet, pellentesque ac turpis. Quisque ac luctus turpis, vel efficitur ante. Cras convallis risus vel vehicula dapibus. Donec eget neque fringilla, faucibus mi quis, porttitor magna. Cras pellentesque leo est, et luctus neque rutrum eu. Aliquam consequat velit sed sem posuere, vitae sollicitudin mi consequat. Mauris eget ipsum sed dui rutrum fringilla. Donec varius vehicula magna sit amet auctor. Ut congue vehicula lectus in blandit. Vivamus suscipit eleifend turpis, nec sodales sem vulputate a. Curabitur pulvinar libero viverra, efficitur odio eu, finibus justo. Etiam eu vehicula felis.</p>
```

## 右浮

```html
<img class="w-32 m-4 pc:float-right ..." src="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAALQAAAC0CAMAAAAKE/YAAAAAP1BMVEXp7vG6vsHo7fC3ur7s8fXr8PO1uLy8wMO5vcDL0NLN0dXl6u3T19vHy86+wsXO0tbQ1djc4eTh5ejBxcjZ3eD/ULOKAAACiklEQVR42u3a2YrjMBCF4arSVrYTL3Le/1lHXqbdPTZDWheRDOcLAZGrnyLgRSIAAAAAAAAAAAAAAAAAAAAAAAAAAAD4IrmoGBHKVSxbyFEm56hMtRBN7TNPO1GRaiFpvDd5vG+lQLUQNT6EwDlCYD+4AtF2Ug4mkzKb+PFqITf6oP3wyDEEZTPaz0dT63s/2DxPw6YtFT2S7Lr0eZtrSkYP64pShrXWyZsVhaNHt6xScjdNUSy9lyG2fLTYbpyZw/NFJDeJFhdnb4wab1ohuUc0dbPnwMxB/WhFbhFtR8+boBwvSkSktmiS2fDu8oohzoqQ1BQtLgY9oht3HutrXKvrjX4SyekexTys1DVp6vojeimRf5t1ra5p0lvBTvVlz83MW3VV0TF1bfwsJOfmv9UVRYt9eN2a++gumo/qeqJJ3Ks3i+dl81FNUk90ipDX0I4TfW+WvflndT3R6WsTJ/9r3qvriSb569x8VPNaXU/0149y0XxU+4cjqSpaZK8+mq+rK4pOofE5WZFT86m6omjbzT4s1UfzZXVFf4+1uTc82aWZTeArGkzoXC3R25w1LNX2lZqVr2lfPnpZHc3MqTpOejSfmAqiHcn35kRDCk8qnnSKPpo3qqx1R6fV3swHrX/SazP/UHl0Wrml+VbRTmhpvlu0i6o3jA6IPlQTHWqJZqNv4ypumFJ0z+FtPc8VRJNI9zvln1wytrhrenLZ3GGjqHWW3O/tm5+Ftpm5Gdrht9qh2V6CCH2Y2KgmsM9imFWj+3w00eiVQx5eN8Lo44RkVJOLR5IyR2tcHJs8Y7SlDjGJtS6PteWOi53d4WQe3a8YAAAAAAAAAAAAAAAAAAAAAAAAAACgNn8AGA09DkR51CoAAAAASUVORK5CYII=">
<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nam venenatis et lorem sit amet vehicula. Etiam vel nibh nec nisi euismod mollis ultrices condimentum velit. Proin velit libero, interdum ac rhoncus sit amet, pellentesque ac turpis. Quisque ac luctus turpis, vel efficitur ante. Cras convallis risus vel vehicula dapibus. Donec eget neque fringilla, faucibus mi quis, porttitor magna. Cras pellentesque leo est, et luctus neque rutrum eu. Aliquam consequat velit sed sem posuere, vitae sollicitudin mi consequat. Mauris eget ipsum sed dui rutrum fringilla. Donec varius vehicula magna sit amet auctor. Ut congue vehicula lectus in blandit. Vivamus suscipit eleifend turpis, nec sodales sem vulputate a. Curabitur pulvinar libero viverra, efficitur odio eu, finibus justo. Etiam eu vehicula felis.</p>
```

## 不浮动

```html
<img class="w-32 m-4 pc:float-none ..." src="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAALQAAAC0CAMAAAAKE/YAAAAAP1BMVEXp7vG6vsHo7fC3ur7s8fXr8PO1uLy8wMO5vcDL0NLN0dXl6u3T19vHy86+wsXO0tbQ1djc4eTh5ejBxcjZ3eD/ULOKAAACiklEQVR42u3a2YrjMBCF4arSVrYTL3Le/1lHXqbdPTZDWheRDOcLAZGrnyLgRSIAAAAAAAAAAAAAAAAAAAAAAAAAAAD4IrmoGBHKVSxbyFEm56hMtRBN7TNPO1GRaiFpvDd5vG+lQLUQNT6EwDlCYD+4AtF2Ug4mkzKb+PFqITf6oP3wyDEEZTPaz0dT63s/2DxPw6YtFT2S7Lr0eZtrSkYP64pShrXWyZsVhaNHt6xScjdNUSy9lyG2fLTYbpyZw/NFJDeJFhdnb4wab1ohuUc0dbPnwMxB/WhFbhFtR8+boBwvSkSktmiS2fDu8oohzoqQ1BQtLgY9oht3HutrXKvrjX4SyekexTys1DVp6vojeimRf5t1ra5p0lvBTvVlz83MW3VV0TF1bfwsJOfmv9UVRYt9eN2a++gumo/qeqJJ3Ks3i+dl81FNUk90ipDX0I4TfW+WvflndT3R6WsTJ/9r3qvriSb569x8VPNaXU/0149y0XxU+4cjqSpaZK8+mq+rK4pOofE5WZFT86m6omjbzT4s1UfzZXVFf4+1uTc82aWZTeArGkzoXC3R25w1LNX2lZqVr2lfPnpZHc3MqTpOejSfmAqiHcn35kRDCk8qnnSKPpo3qqx1R6fV3swHrX/SazP/UHl0Wrml+VbRTmhpvlu0i6o3jA6IPlQTHWqJZqNv4ypumFJ0z+FtPc8VRJNI9zvln1wytrhrenLZ3GGjqHWW3O/tm5+Ftpm5Gdrht9qh2V6CCH2Y2KgmsM9imFWj+3w00eiVQx5eN8Lo44RkVJOLR5IyR2tcHJs8Y7SlDjGJtS6PteWOi53d4WQe3a8YAAAAAAAAAAAAAAAAAAAAAAAAAACgNn8AGA09DkR51CoAAAAASUVORK5CYII=">
<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nam venenatis et lorem sit amet vehicula. Etiam vel nibh nec nisi euismod mollis ultrices condimentum velit. Proin velit libero, interdum ac rhoncus sit amet, pellentesque ac turpis. Quisque ac luctus turpis, vel efficitur ante. Cras convallis risus vel vehicula dapibus. Donec eget neque fringilla, faucibus mi quis, porttitor magna. Cras pellentesque leo est, et luctus neque rutrum eu. Aliquam consequat velit sed sem posuere, vitae sollicitudin mi consequat. Mauris eget ipsum sed dui rutrum fringilla. Donec varius vehicula magna sit amet auctor. Ut congue vehicula lectus in blandit. Vivamus suscipit eleifend turpis, nec sodales sem vulputate a. Curabitur pulvinar libero viverra, efficitur odio eu, finibus justo. Etiam eu vehicula felis.</p>
```



## 响应式设计

支持通过添加设备前缀 `m:` 或者 `pc:` 来分别针对「手机端」或者「pc端」设置样式，更多说明请前往[「响应式设计」](../../../docs/style/responsive-design.md)。

```html
<img class="w-32 m-4 pc:float-right ..." src="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAALQAAAC0CAMAAAAKE/YAAAAAP1BMVEXp7vG6vsHo7fC3ur7s8fXr8PO1uLy8wMO5vcDL0NLN0dXl6u3T19vHy86+wsXO0tbQ1djc4eTh5ejBxcjZ3eD/ULOKAAACiklEQVR42u3a2YrjMBCF4arSVrYTL3Le/1lHXqbdPTZDWheRDOcLAZGrnyLgRSIAAAAAAAAAAAAAAAAAAAAAAAAAAAD4IrmoGBHKVSxbyFEm56hMtRBN7TNPO1GRaiFpvDd5vG+lQLUQNT6EwDlCYD+4AtF2Ug4mkzKb+PFqITf6oP3wyDEEZTPaz0dT63s/2DxPw6YtFT2S7Lr0eZtrSkYP64pShrXWyZsVhaNHt6xScjdNUSy9lyG2fLTYbpyZw/NFJDeJFhdnb4wab1ohuUc0dbPnwMxB/WhFbhFtR8+boBwvSkSktmiS2fDu8oohzoqQ1BQtLgY9oht3HutrXKvrjX4SyekexTys1DVp6vojeimRf5t1ra5p0lvBTvVlz83MW3VV0TF1bfwsJOfmv9UVRYt9eN2a++gumo/qeqJJ3Ks3i+dl81FNUk90ipDX0I4TfW+WvflndT3R6WsTJ/9r3qvriSb569x8VPNaXU/0149y0XxU+4cjqSpaZK8+mq+rK4pOofE5WZFT86m6omjbzT4s1UfzZXVFf4+1uTc82aWZTeArGkzoXC3R25w1LNX2lZqVr2lfPnpZHc3MqTpOejSfmAqiHcn35kRDCk8qnnSKPpo3qqx1R6fV3swHrX/SazP/UHl0Wrml+VbRTmhpvlu0i6o3jA6IPlQTHWqJZqNv4ypumFJ0z+FtPc8VRJNI9zvln1wytrhrenLZ3GGjqHWW3O/tm5+Ftpm5Gdrht9qh2V6CCH2Y2KgmsM9imFWj+3w00eiVQx5eN8Lo44RkVJOLR5IyR2tcHJs8Y7SlDjGJtS6PteWOi53d4WQe3a8YAAAAAAAAAAAAAAAAAAAAAAAAAACgNn8AGA09DkR51CoAAAAASUVORK5CYII=">
<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nam venenatis et lorem sit amet vehicula. Etiam vel nibh nec nisi euismod mollis ultrices condimentum velit. Proin velit libero, interdum ac rhoncus sit amet, pellentesque ac turpis. Quisque ac luctus turpis, vel efficitur ante. Cras convallis risus vel vehicula dapibus. Donec eget neque fringilla, faucibus mi quis, porttitor magna. Cras pellentesque leo est, et luctus neque rutrum eu. Aliquam consequat velit sed sem posuere, vitae sollicitudin mi consequat. Mauris eget ipsum sed dui rutrum fringilla. Donec varius vehicula magna sit amet auctor. Ut congue vehicula lectus in blandit. Vivamus suscipit eleifend turpis, nec sodales sem vulputate a. Curabitur pulvinar libero viverra, efficitur odio eu, finibus justo. Etiam eu vehicula felis.</p>
```

## 状态前缀

不支持[「状态前缀」](../../../docs/style/state.md)，有需求请提 [issue](https://github.com/baidu/amis/issues)。
*/
.float-right {
  float: right;
}

.float-left {
  float: left;
}

.float-none {
  float: none;
}

@media (max-width: 768px) {
  .m\:float-right {
    float: right;
  }

  .m\:float-left {
    float: left;
  }

  .m\:float-none {
    float: none;
  }
}
@media (min-width: 769px) {
  .pc\:float-right {
    float: right;
  }

  .pc\:float-left {
    float: left;
  }

  .pc\:float-none {
    float: none;
  }
}
/*!markdown

---
title: Overflow
---

内容超出相关样式。

| Class       | Properties               |
| ----------- | ------------------------ |
| overflow-auto  | overflow: auto;  |
| overflow-hidden  | overflow: hidden;  |
| overflow-visible  | overflow: visible;  |
| overflow-scroll  | overflow: scroll;  |
| overflow-x-auto  | overflow-x: auto;  |
| overflow-y-auto  | overflow-y: auto;  |
| overflow-x-hidden  | overflow-x: hidden;  |
| overflow-y-hidden  | overflow-y: hidden;  |
| overflow-x-visible  | overflow-x: visible;  |
| overflow-y-visible  | overflow-y: visible;  |
| overflow-x-scroll  | overflow-x: scroll;  |
| overflow-y-scroll  | overflow-y: scroll;  |

## 用法

请前往一下文档查看属性含义。

https://www.w3school.com.cn/cssref/pr_pos_overflow.asp

# 响应式设计

支持通过添加设备前缀 `m:` 或者 `pc:` 来分别针对「手机端」或者「pc端」设置样式，更多说明请前往[「响应式设计」](../../../docs/style/responsive-design.md)。

## 状态前缀

不支持[「状态前缀」](../../../docs/style/state.md)，有需求请提 [issue](https://github.com/baidu/amis/issues)。


*/
.overflow-auto {
  overflow: auto;
}

.overflow-hidden {
  overflow: hidden;
}

.overflow-visible {
  overflow: visible;
}

.overflow-scroll {
  overflow: scroll;
}

.overflow-x-auto {
  overflow-x: auto;
}

.overflow-y-auto {
  overflow-y: auto;
}

.overflow-x-hidden {
  overflow-x: hidden;
}

.overflow-y-hidden {
  overflow-y: hidden;
}

.overflow-x-visible {
  overflow-x: visible;
}

.overflow-y-visible {
  overflow-y: visible;
}

.overflow-x-scroll {
  overflow-x: scroll;
}

.overflow-y-scroll {
  overflow-y: scroll;
}

@media (max-width: 768px) {
  .m\:overflow-auto {
    overflow: auto;
  }

  .m\:overflow-hidden {
    overflow: hidden;
  }

  .m\:overflow-visible {
    overflow: visible;
  }

  .m\:overflow-scroll {
    overflow: scroll;
  }

  .m\:overflow-x-auto {
    overflow-x: auto;
  }

  .m\:overflow-y-auto {
    overflow-y: auto;
  }

  .m\:overflow-x-hidden {
    overflow-x: hidden;
  }

  .m\:overflow-y-hidden {
    overflow-y: hidden;
  }

  .m\:overflow-x-visible {
    overflow-x: visible;
  }

  .m\:overflow-y-visible {
    overflow-y: visible;
  }

  .m\:overflow-x-scroll {
    overflow-x: scroll;
  }

  .m\:overflow-y-scroll {
    overflow-y: scroll;
  }
}
@media (min-width: 769px) {
  .pc\:overflow-auto {
    overflow: auto;
  }

  .pc\:overflow-hidden {
    overflow: hidden;
  }

  .pc\:overflow-visible {
    overflow: visible;
  }

  .pc\:overflow-scroll {
    overflow: scroll;
  }

  .pc\:overflow-x-auto {
    overflow-x: auto;
  }

  .pc\:overflow-y-auto {
    overflow-y: auto;
  }

  .pc\:overflow-x-hidden {
    overflow-x: hidden;
  }

  .pc\:overflow-y-hidden {
    overflow-y: hidden;
  }

  .pc\:overflow-x-visible {
    overflow-x: visible;
  }

  .pc\:overflow-y-visible {
    overflow-y: visible;
  }

  .pc\:overflow-x-scroll {
    overflow-x: scroll;
  }

  .pc\:overflow-y-scroll {
    overflow-y: scroll;
  }
}
/*!markdown

---
title: Position
---

定位相关样式。

| Class       | Properties               |
| ----------- | ------------------------ |
| static  | position: static; |
| fixed  | position: fixed; |
| absolute  | position: absolute; |
| relative  | position: relative; |
| sticky  | position: sticky; |

## 用法

请前往一下文档查看属性含义。

https://www.w3school.com.cn/cssref/pr_class_position.asp

# 响应式设计

支持通过添加设备前缀 `m:` 或者 `pc:` 来分别针对「手机端」或者「pc端」设置样式，更多说明请前往[「响应式设计」](../../../docs/style/responsive-design.md)。

## 状态前缀

不支持[「状态前缀」](../../../docs/style/state.md)，有需求请提 [issue](https://github.com/baidu/amis/issues)。

*/
.static {
  position: static;
}

.fixed {
  position: fixed;
}

.absolute {
  position: absolute;
}

.relative {
  position: relative;
}

.sticky {
  position: sticky;
}

@media (max-width: 768px) {
  .m\:static {
    position: static;
  }

  .m\:fixed {
    position: fixed;
  }

  .m\:absolute {
    position: absolute;
  }

  .m\:relative {
    position: relative;
  }

  .m\:sticky {
    position: sticky;
  }
}
@media (min-width: 769px) {
  .pc\:static {
    position: static;
  }

  .pc\:fixed {
    position: fixed;
  }

  .pc\:absolute {
    position: absolute;
  }

  .pc\:relative {
    position: relative;
  }

  .pc\:sticky {
    position: sticky;
  }
}
/*!markdown

---
title: Top / Right / Bottom / Left
---

用来控制位置的样式集。

| Class        | Properties                                                                        |
| ------------ | --------------------------------------------------------------------------------- |
| inset-0      | top: 0px;<br/>right: 0px;<br/>bottom: 0px;<br/>left: 0px;                         |
| -inset-0     | top: 0px;<br/>right: 0px;<br/>bottom: 0px;<br/>left: 0px;                         |
| inset-y-0    | top: 0px;<br/>bottom: 0px;                                                        |
| inset-x-0    | right: 0px;<br/>left: 0px;                                                        |
| -inset-y-0   | top: 0px;<br/>bottom: 0px;                                                        |
| -inset-x-0   | right: 0px;<br/>left: 0px;                                                        |
| top-0        | top: 0px;                                                                         |
| right-0      | right: 0px;                                                                       |
| bottom-0     | bottom: 0px;                                                                      |
| left-0       | left: 0px;                                                                        |
| -top-0       | top: 0px;                                                                         |
| -right-0     | right: 0px;                                                                       |
| -bottom-0    | bottom: 0px;                                                                      |
| -left-0      | left: 0px;                                                                        |
| inset-0.5    | top: 0.125rem;<br/>right: 0.125rem;<br/>bottom: 0.125rem;<br/>left: 0.125rem;     |
| -inset-0.5   | top: -0.125rem;<br/>right: -0.125rem;<br/>bottom: -0.125rem;<br/>left: -0.125rem; |
| inset-y-0.5  | top: 0.125rem;<br/>bottom: 0.125rem;                                              |
| inset-x-0.5  | right: 0.125rem;<br/>left: 0.125rem;                                              |
| -inset-y-0.5 | top: -0.125rem;<br/>bottom: -0.125rem;                                            |
| -inset-x-0.5 | right: -0.125rem;<br/>left: -0.125rem;                                            |
| top-0.5      | top: 0.125rem;                                                                    |
| right-0.5    | right: 0.125rem;                                                                  |
| bottom-0.5   | bottom: 0.125rem;                                                                 |
| left-0.5     | left: 0.125rem;                                                                   |
| -top-0.5     | top: -0.125rem;                                                                   |
| -right-0.5   | right: -0.125rem;                                                                 |
| -bottom-0.5  | bottom: -0.125rem;                                                                |
| -left-0.5    | left: -0.125rem;                                                                  |

按以下尺寸表依次类推

| 尺寸 | 大小           |
| ---- | -------------- |
| 0    | 0              |
| 0.5  | 0.125rem;      |
| 1    | 0.25rem        |
| 1.5  | 0.375rem       |
| 1.5  | 0.375rem       |
| 2    | 0.5rem         |
| 2.5  | 0.625rem       |
| 3    | 0.75rem        |
| 3.5  | 0.875rem       |
| 4    | 1rem           |
| 5    | 1.25rem        |
| 6    | 1.5rem         |
| 7    | 1.75rem        |
| 8    | 2rem           |
| 9    | 2.25rem        |
| 10   | 2.5rem         |
| 11   | 2.75rem        |
| 12   | 3rem           |
| 14   | 3.5rem         |
| 16   | 4rem           |
| 20   | 5rem           |
| 24   | 6rem           |
| 28   | 7rem           |
| 32   | 8rem           |
| 36   | 9rem           |
| 40   | 10rem          |
| 44   | 11rem          |
| 48   | 12rem          |
| 52   | 13rem          |
| 56   | 14rem          |
| 60   | 15rem          |
| 64   | 16rem          |
| 68   | 17rem          |
| 72   | 18rem          |
| 76   | 19rem          |
| 80   | 20rem          |
| 96   | 24rem          |
| auto | auto           |
| 1/2  | 50%            |
| 1/3  | 33.333333%     |
| 2/3  | 66.666667%     |
| 1/4  | 25%;           |
| 2/4  | 50%;           |
| 3/4  | 75%;           |
| full | 100%;          |
| px   | 0.0625rem(1px) |

## 用法

结合 relative 和 absolute 定位 和位置样式 `{top|right|bottom|left|inset}-xxx`，可以很方便的实现各种组件布局。

```html
<div class="grid grid-cols-4 m:grid-cols-2 gap-4">

<!-- Span top edge -->
<div class="relative h-32 w-32 ... bg-blue-500">
  <div class="absolute inset-x-0 top-0 h-16 w-16 ... bg-red-500 text-white font-extrabold text-2xl flex items-center justify-center">1</div>
</div>

<!-- Span right edge -->
<div class="relative h-32 w-32 ... bg-blue-500">
  <div class="absolute inset-y-0 right-0 w-16 ... bg-red-500 text-white font-extrabold text-2xl flex items-center justify-center">2</div>
</div>

<!-- Span bottom edge -->
<div class="relative h-32 w-32 ... bg-blue-500">
  <div class="absolute inset-x-0 bottom-0 h-16 w-16 ... bg-red-500 text-white font-extrabold text-2xl flex items-center justify-center">3</div>
</div>

<!-- Span left edge -->
<div class="relative h-32 w-32 ... bg-blue-500">
  <div class="absolute inset-y-0 left-0 w-16 ... bg-red-500 text-white font-extrabold text-2xl flex items-center justify-center">4</div>
</div>

<!-- Fill entire parent -->
<div class="relative h-32 w-32 ... bg-blue-500">
  <div class="absolute inset-0 bg-red-500 text-white font-extrabold text-2xl flex items-center justify-center">5</div>
</div>

<!-- Pin to top left corner -->
<div class="relative h-32 w-32 ... bg-blue-500">
  <div class="absolute left-0 top-0 h-16 w-16 ... bg-red-500 text-white font-extrabold text-2xl flex items-center justify-center">6</div>
</div>

<!-- Pin to top right corner -->
<div class="relative h-32 w-32 ... bg-blue-500">
  <div class="absolute top-0 right-0 h-16 w-16 ... bg-red-500 text-white font-extrabold text-2xl flex items-center justify-center">7</div>
</div>

<!-- Pin to bottom right corner -->
<div class="relative h-32 w-32 ... bg-blue-500">
  <div class="absolute bottom-0 right-0 h-16 w-16 ... bg-red-500 text-white font-extrabold text-2xl flex items-center justify-center">8</div>
</div>

<!-- Pin to bottom left corner -->
<div class="relative h-32 w-32 ... bg-blue-500">
  <div class="absolute bottom-0 left-0 h-16 w-16 ... bg-red-500 text-white font-extrabold text-2xl flex items-center justify-center">9</div>
</div>

</div>
```

## 响应式设计

支持通过添加设备前缀 `m:` 或者 `pc:` 来分别针对「手机端」或者「pc端」设置样式，更多说明请前往[「响应式设计」](../../../docs/style/responsive-design.md)。

## 状态前缀

不支持[「状态前缀」](../../../docs/style/state.md)，有需求请提 [issue](https://github.com/baidu/amis/issues)。

*/
.top-px {
  top: 0.0625rem;
}

.top-0 {
  top: 0;
}

.top-none {
  top: 0;
}

.top-0\.5 {
  top: 0.125rem;
}

.top-1 {
  top: 0.25rem;
}

.top-1\.5 {
  top: 0.375rem;
}

.top-2 {
  top: 0.5rem;
}

.top-2\.5 {
  top: 0.625rem;
}

.top-3 {
  top: 0.75rem;
}

.top-3\.5 {
  top: 0.875rem;
}

.top-4 {
  top: 1rem;
}

.top-5 {
  top: 1.25rem;
}

.top-6 {
  top: 1.5rem;
}

.top-7 {
  top: 1.75rem;
}

.top-8 {
  top: 2rem;
}

.top-9 {
  top: 2.25rem;
}

.top-10 {
  top: 2.5rem;
}

.top-11 {
  top: 2.75rem;
}

.top-12 {
  top: 3rem;
}

.top-14 {
  top: 3.5rem;
}

.top-16 {
  top: 4rem;
}

.top-18 {
  top: 4.5rem;
}

.top-20 {
  top: 5rem;
}

.top-24 {
  top: 6rem;
}

.top-28 {
  top: 7rem;
}

.top-32 {
  top: 8rem;
}

.top-36 {
  top: 9rem;
}

.top-40 {
  top: 10rem;
}

.top-44 {
  top: 11rem;
}

.top-48 {
  top: 12rem;
}

.top-52 {
  top: 13rem;
}

.top-56 {
  top: 14rem;
}

.top-60 {
  top: 15rem;
}

.top-64 {
  top: 16rem;
}

.top-72 {
  top: 18rem;
}

.top-80 {
  top: 20rem;
}

.top-96 {
  top: 24rem;
}

.top-auto {
  top: auto;
}

.top-1\/2 {
  top: 50%;
}

.top-1\/3 {
  top: 33.333333%;
}

.top-2\/3 {
  top: 66.666667%;
}

.top-1\/4 {
  top: 25%;
}

.top-2\/4 {
  top: 50%;
}

.top-3\/4 {
  top: 75%;
}

.top-full {
  top: 100%;
}

.-top-px {
  top: -0.0625rem;
}

.-top-0 {
  top: 0;
}

.-top-none {
  top: 0;
}

.-top-0\.5 {
  top: -0.125rem;
}

.-top-1 {
  top: -0.25rem;
}

.-top-1\.5 {
  top: -0.375rem;
}

.-top-2 {
  top: -0.5rem;
}

.-top-2\.5 {
  top: -0.625rem;
}

.-top-3 {
  top: -0.75rem;
}

.-top-3\.5 {
  top: -0.875rem;
}

.-top-4 {
  top: -1rem;
}

.-top-5 {
  top: -1.25rem;
}

.-top-6 {
  top: -1.5rem;
}

.-top-7 {
  top: -1.75rem;
}

.-top-8 {
  top: -2rem;
}

.-top-9 {
  top: -2.25rem;
}

.-top-10 {
  top: -2.5rem;
}

.-top-11 {
  top: -2.75rem;
}

.-top-12 {
  top: -3rem;
}

.-top-14 {
  top: -3.5rem;
}

.-top-16 {
  top: -4rem;
}

.-top-18 {
  top: -4.5rem;
}

.-top-20 {
  top: -5rem;
}

.-top-24 {
  top: -6rem;
}

.-top-28 {
  top: -7rem;
}

.-top-32 {
  top: -8rem;
}

.-top-36 {
  top: -9rem;
}

.-top-40 {
  top: -10rem;
}

.-top-44 {
  top: -11rem;
}

.-top-48 {
  top: -12rem;
}

.-top-52 {
  top: -13rem;
}

.-top-56 {
  top: -14rem;
}

.-top-60 {
  top: -15rem;
}

.-top-64 {
  top: -16rem;
}

.-top-72 {
  top: -18rem;
}

.-top-80 {
  top: -20rem;
}

.-top-96 {
  top: -24rem;
}

.-top-1\/2 {
  top: -50%;
}

.-top-1\/3 {
  top: -33.333333%;
}

.-top-2\/3 {
  top: -66.666667%;
}

.-top-1\/4 {
  top: -25%;
}

.-top-2\/4 {
  top: -50%;
}

.-top-3\/4 {
  top: -75%;
}

.-top-full {
  top: -100%;
}

.right-px {
  right: 0.0625rem;
}

.right-0 {
  right: 0;
}

.right-none {
  right: 0;
}

.right-0\.5 {
  right: 0.125rem;
}

.right-1 {
  right: 0.25rem;
}

.right-1\.5 {
  right: 0.375rem;
}

.right-2 {
  right: 0.5rem;
}

.right-2\.5 {
  right: 0.625rem;
}

.right-3 {
  right: 0.75rem;
}

.right-3\.5 {
  right: 0.875rem;
}

.right-4 {
  right: 1rem;
}

.right-5 {
  right: 1.25rem;
}

.right-6 {
  right: 1.5rem;
}

.right-7 {
  right: 1.75rem;
}

.right-8 {
  right: 2rem;
}

.right-9 {
  right: 2.25rem;
}

.right-10 {
  right: 2.5rem;
}

.right-11 {
  right: 2.75rem;
}

.right-12 {
  right: 3rem;
}

.right-14 {
  right: 3.5rem;
}

.right-16 {
  right: 4rem;
}

.right-18 {
  right: 4.5rem;
}

.right-20 {
  right: 5rem;
}

.right-24 {
  right: 6rem;
}

.right-28 {
  right: 7rem;
}

.right-32 {
  right: 8rem;
}

.right-36 {
  right: 9rem;
}

.right-40 {
  right: 10rem;
}

.right-44 {
  right: 11rem;
}

.right-48 {
  right: 12rem;
}

.right-52 {
  right: 13rem;
}

.right-56 {
  right: 14rem;
}

.right-60 {
  right: 15rem;
}

.right-64 {
  right: 16rem;
}

.right-72 {
  right: 18rem;
}

.right-80 {
  right: 20rem;
}

.right-96 {
  right: 24rem;
}

.right-auto {
  right: auto;
}

.right-1\/2 {
  right: 50%;
}

.right-1\/3 {
  right: 33.333333%;
}

.right-2\/3 {
  right: 66.666667%;
}

.right-1\/4 {
  right: 25%;
}

.right-2\/4 {
  right: 50%;
}

.right-3\/4 {
  right: 75%;
}

.right-full {
  right: 100%;
}

.-right-px {
  right: -0.0625rem;
}

.-right-0 {
  right: 0;
}

.-right-none {
  right: 0;
}

.-right-0\.5 {
  right: -0.125rem;
}

.-right-1 {
  right: -0.25rem;
}

.-right-1\.5 {
  right: -0.375rem;
}

.-right-2 {
  right: -0.5rem;
}

.-right-2\.5 {
  right: -0.625rem;
}

.-right-3 {
  right: -0.75rem;
}

.-right-3\.5 {
  right: -0.875rem;
}

.-right-4 {
  right: -1rem;
}

.-right-5 {
  right: -1.25rem;
}

.-right-6 {
  right: -1.5rem;
}

.-right-7 {
  right: -1.75rem;
}

.-right-8 {
  right: -2rem;
}

.-right-9 {
  right: -2.25rem;
}

.-right-10 {
  right: -2.5rem;
}

.-right-11 {
  right: -2.75rem;
}

.-right-12 {
  right: -3rem;
}

.-right-14 {
  right: -3.5rem;
}

.-right-16 {
  right: -4rem;
}

.-right-18 {
  right: -4.5rem;
}

.-right-20 {
  right: -5rem;
}

.-right-24 {
  right: -6rem;
}

.-right-28 {
  right: -7rem;
}

.-right-32 {
  right: -8rem;
}

.-right-36 {
  right: -9rem;
}

.-right-40 {
  right: -10rem;
}

.-right-44 {
  right: -11rem;
}

.-right-48 {
  right: -12rem;
}

.-right-52 {
  right: -13rem;
}

.-right-56 {
  right: -14rem;
}

.-right-60 {
  right: -15rem;
}

.-right-64 {
  right: -16rem;
}

.-right-72 {
  right: -18rem;
}

.-right-80 {
  right: -20rem;
}

.-right-96 {
  right: -24rem;
}

.-right-1\/2 {
  right: -50%;
}

.-right-1\/3 {
  right: -33.333333%;
}

.-right-2\/3 {
  right: -66.666667%;
}

.-right-1\/4 {
  right: -25%;
}

.-right-2\/4 {
  right: -50%;
}

.-right-3\/4 {
  right: -75%;
}

.-right-full {
  right: -100%;
}

.bottom-px {
  bottom: 0.0625rem;
}

.bottom-0 {
  bottom: 0;
}

.bottom-none {
  bottom: 0;
}

.bottom-0\.5 {
  bottom: 0.125rem;
}

.bottom-1 {
  bottom: 0.25rem;
}

.bottom-1\.5 {
  bottom: 0.375rem;
}

.bottom-2 {
  bottom: 0.5rem;
}

.bottom-2\.5 {
  bottom: 0.625rem;
}

.bottom-3 {
  bottom: 0.75rem;
}

.bottom-3\.5 {
  bottom: 0.875rem;
}

.bottom-4 {
  bottom: 1rem;
}

.bottom-5 {
  bottom: 1.25rem;
}

.bottom-6 {
  bottom: 1.5rem;
}

.bottom-7 {
  bottom: 1.75rem;
}

.bottom-8 {
  bottom: 2rem;
}

.bottom-9 {
  bottom: 2.25rem;
}

.bottom-10 {
  bottom: 2.5rem;
}

.bottom-11 {
  bottom: 2.75rem;
}

.bottom-12 {
  bottom: 3rem;
}

.bottom-14 {
  bottom: 3.5rem;
}

.bottom-16 {
  bottom: 4rem;
}

.bottom-18 {
  bottom: 4.5rem;
}

.bottom-20 {
  bottom: 5rem;
}

.bottom-24 {
  bottom: 6rem;
}

.bottom-28 {
  bottom: 7rem;
}

.bottom-32 {
  bottom: 8rem;
}

.bottom-36 {
  bottom: 9rem;
}

.bottom-40 {
  bottom: 10rem;
}

.bottom-44 {
  bottom: 11rem;
}

.bottom-48 {
  bottom: 12rem;
}

.bottom-52 {
  bottom: 13rem;
}

.bottom-56 {
  bottom: 14rem;
}

.bottom-60 {
  bottom: 15rem;
}

.bottom-64 {
  bottom: 16rem;
}

.bottom-72 {
  bottom: 18rem;
}

.bottom-80 {
  bottom: 20rem;
}

.bottom-96 {
  bottom: 24rem;
}

.bottom-auto {
  bottom: auto;
}

.bottom-1\/2 {
  bottom: 50%;
}

.bottom-1\/3 {
  bottom: 33.333333%;
}

.bottom-2\/3 {
  bottom: 66.666667%;
}

.bottom-1\/4 {
  bottom: 25%;
}

.bottom-2\/4 {
  bottom: 50%;
}

.bottom-3\/4 {
  bottom: 75%;
}

.bottom-full {
  bottom: 100%;
}

.-bottom-px {
  bottom: -0.0625rem;
}

.-bottom-0 {
  bottom: 0;
}

.-bottom-none {
  bottom: 0;
}

.-bottom-0\.5 {
  bottom: -0.125rem;
}

.-bottom-1 {
  bottom: -0.25rem;
}

.-bottom-1\.5 {
  bottom: -0.375rem;
}

.-bottom-2 {
  bottom: -0.5rem;
}

.-bottom-2\.5 {
  bottom: -0.625rem;
}

.-bottom-3 {
  bottom: -0.75rem;
}

.-bottom-3\.5 {
  bottom: -0.875rem;
}

.-bottom-4 {
  bottom: -1rem;
}

.-bottom-5 {
  bottom: -1.25rem;
}

.-bottom-6 {
  bottom: -1.5rem;
}

.-bottom-7 {
  bottom: -1.75rem;
}

.-bottom-8 {
  bottom: -2rem;
}

.-bottom-9 {
  bottom: -2.25rem;
}

.-bottom-10 {
  bottom: -2.5rem;
}

.-bottom-11 {
  bottom: -2.75rem;
}

.-bottom-12 {
  bottom: -3rem;
}

.-bottom-14 {
  bottom: -3.5rem;
}

.-bottom-16 {
  bottom: -4rem;
}

.-bottom-18 {
  bottom: -4.5rem;
}

.-bottom-20 {
  bottom: -5rem;
}

.-bottom-24 {
  bottom: -6rem;
}

.-bottom-28 {
  bottom: -7rem;
}

.-bottom-32 {
  bottom: -8rem;
}

.-bottom-36 {
  bottom: -9rem;
}

.-bottom-40 {
  bottom: -10rem;
}

.-bottom-44 {
  bottom: -11rem;
}

.-bottom-48 {
  bottom: -12rem;
}

.-bottom-52 {
  bottom: -13rem;
}

.-bottom-56 {
  bottom: -14rem;
}

.-bottom-60 {
  bottom: -15rem;
}

.-bottom-64 {
  bottom: -16rem;
}

.-bottom-72 {
  bottom: -18rem;
}

.-bottom-80 {
  bottom: -20rem;
}

.-bottom-96 {
  bottom: -24rem;
}

.-bottom-1\/2 {
  bottom: -50%;
}

.-bottom-1\/3 {
  bottom: -33.333333%;
}

.-bottom-2\/3 {
  bottom: -66.666667%;
}

.-bottom-1\/4 {
  bottom: -25%;
}

.-bottom-2\/4 {
  bottom: -50%;
}

.-bottom-3\/4 {
  bottom: -75%;
}

.-bottom-full {
  bottom: -100%;
}

.left-px {
  left: 0.0625rem;
}

.left-0 {
  left: 0;
}

.left-none {
  left: 0;
}

.left-0\.5 {
  left: 0.125rem;
}

.left-1 {
  left: 0.25rem;
}

.left-1\.5 {
  left: 0.375rem;
}

.left-2 {
  left: 0.5rem;
}

.left-2\.5 {
  left: 0.625rem;
}

.left-3 {
  left: 0.75rem;
}

.left-3\.5 {
  left: 0.875rem;
}

.left-4 {
  left: 1rem;
}

.left-5 {
  left: 1.25rem;
}

.left-6 {
  left: 1.5rem;
}

.left-7 {
  left: 1.75rem;
}

.left-8 {
  left: 2rem;
}

.left-9 {
  left: 2.25rem;
}

.left-10 {
  left: 2.5rem;
}

.left-11 {
  left: 2.75rem;
}

.left-12 {
  left: 3rem;
}

.left-14 {
  left: 3.5rem;
}

.left-16 {
  left: 4rem;
}

.left-18 {
  left: 4.5rem;
}

.left-20 {
  left: 5rem;
}

.left-24 {
  left: 6rem;
}

.left-28 {
  left: 7rem;
}

.left-32 {
  left: 8rem;
}

.left-36 {
  left: 9rem;
}

.left-40 {
  left: 10rem;
}

.left-44 {
  left: 11rem;
}

.left-48 {
  left: 12rem;
}

.left-52 {
  left: 13rem;
}

.left-56 {
  left: 14rem;
}

.left-60 {
  left: 15rem;
}

.left-64 {
  left: 16rem;
}

.left-72 {
  left: 18rem;
}

.left-80 {
  left: 20rem;
}

.left-96 {
  left: 24rem;
}

.left-auto {
  left: auto;
}

.left-1\/2 {
  left: 50%;
}

.left-1\/3 {
  left: 33.333333%;
}

.left-2\/3 {
  left: 66.666667%;
}

.left-1\/4 {
  left: 25%;
}

.left-2\/4 {
  left: 50%;
}

.left-3\/4 {
  left: 75%;
}

.left-full {
  left: 100%;
}

.-left-px {
  left: -0.0625rem;
}

.-left-0 {
  left: 0;
}

.-left-none {
  left: 0;
}

.-left-0\.5 {
  left: -0.125rem;
}

.-left-1 {
  left: -0.25rem;
}

.-left-1\.5 {
  left: -0.375rem;
}

.-left-2 {
  left: -0.5rem;
}

.-left-2\.5 {
  left: -0.625rem;
}

.-left-3 {
  left: -0.75rem;
}

.-left-3\.5 {
  left: -0.875rem;
}

.-left-4 {
  left: -1rem;
}

.-left-5 {
  left: -1.25rem;
}

.-left-6 {
  left: -1.5rem;
}

.-left-7 {
  left: -1.75rem;
}

.-left-8 {
  left: -2rem;
}

.-left-9 {
  left: -2.25rem;
}

.-left-10 {
  left: -2.5rem;
}

.-left-11 {
  left: -2.75rem;
}

.-left-12 {
  left: -3rem;
}

.-left-14 {
  left: -3.5rem;
}

.-left-16 {
  left: -4rem;
}

.-left-18 {
  left: -4.5rem;
}

.-left-20 {
  left: -5rem;
}

.-left-24 {
  left: -6rem;
}

.-left-28 {
  left: -7rem;
}

.-left-32 {
  left: -8rem;
}

.-left-36 {
  left: -9rem;
}

.-left-40 {
  left: -10rem;
}

.-left-44 {
  left: -11rem;
}

.-left-48 {
  left: -12rem;
}

.-left-52 {
  left: -13rem;
}

.-left-56 {
  left: -14rem;
}

.-left-60 {
  left: -15rem;
}

.-left-64 {
  left: -16rem;
}

.-left-72 {
  left: -18rem;
}

.-left-80 {
  left: -20rem;
}

.-left-96 {
  left: -24rem;
}

.-left-1\/2 {
  left: -50%;
}

.-left-1\/3 {
  left: -33.333333%;
}

.-left-2\/3 {
  left: -66.666667%;
}

.-left-1\/4 {
  left: -25%;
}

.-left-2\/4 {
  left: -50%;
}

.-left-3\/4 {
  left: -75%;
}

.-left-full {
  left: -100%;
}

.inset-px {
  top: 0.0625rem;
  right: 0.0625rem;
  bottom: 0.0625rem;
  left: 0.0625rem;
}

.inset-0 {
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
}

.inset-none {
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
}

.inset-0\.5 {
  top: 0.125rem;
  right: 0.125rem;
  bottom: 0.125rem;
  left: 0.125rem;
}

.inset-1 {
  top: 0.25rem;
  right: 0.25rem;
  bottom: 0.25rem;
  left: 0.25rem;
}

.inset-1\.5 {
  top: 0.375rem;
  right: 0.375rem;
  bottom: 0.375rem;
  left: 0.375rem;
}

.inset-2 {
  top: 0.5rem;
  right: 0.5rem;
  bottom: 0.5rem;
  left: 0.5rem;
}

.inset-2\.5 {
  top: 0.625rem;
  right: 0.625rem;
  bottom: 0.625rem;
  left: 0.625rem;
}

.inset-3 {
  top: 0.75rem;
  right: 0.75rem;
  bottom: 0.75rem;
  left: 0.75rem;
}

.inset-3\.5 {
  top: 0.875rem;
  right: 0.875rem;
  bottom: 0.875rem;
  left: 0.875rem;
}

.inset-4 {
  top: 1rem;
  right: 1rem;
  bottom: 1rem;
  left: 1rem;
}

.inset-5 {
  top: 1.25rem;
  right: 1.25rem;
  bottom: 1.25rem;
  left: 1.25rem;
}

.inset-6 {
  top: 1.5rem;
  right: 1.5rem;
  bottom: 1.5rem;
  left: 1.5rem;
}

.inset-7 {
  top: 1.75rem;
  right: 1.75rem;
  bottom: 1.75rem;
  left: 1.75rem;
}

.inset-8 {
  top: 2rem;
  right: 2rem;
  bottom: 2rem;
  left: 2rem;
}

.inset-9 {
  top: 2.25rem;
  right: 2.25rem;
  bottom: 2.25rem;
  left: 2.25rem;
}

.inset-10 {
  top: 2.5rem;
  right: 2.5rem;
  bottom: 2.5rem;
  left: 2.5rem;
}

.inset-11 {
  top: 2.75rem;
  right: 2.75rem;
  bottom: 2.75rem;
  left: 2.75rem;
}

.inset-12 {
  top: 3rem;
  right: 3rem;
  bottom: 3rem;
  left: 3rem;
}

.inset-14 {
  top: 3.5rem;
  right: 3.5rem;
  bottom: 3.5rem;
  left: 3.5rem;
}

.inset-16 {
  top: 4rem;
  right: 4rem;
  bottom: 4rem;
  left: 4rem;
}

.inset-18 {
  top: 4.5rem;
  right: 4.5rem;
  bottom: 4.5rem;
  left: 4.5rem;
}

.inset-20 {
  top: 5rem;
  right: 5rem;
  bottom: 5rem;
  left: 5rem;
}

.inset-24 {
  top: 6rem;
  right: 6rem;
  bottom: 6rem;
  left: 6rem;
}

.inset-28 {
  top: 7rem;
  right: 7rem;
  bottom: 7rem;
  left: 7rem;
}

.inset-32 {
  top: 8rem;
  right: 8rem;
  bottom: 8rem;
  left: 8rem;
}

.inset-36 {
  top: 9rem;
  right: 9rem;
  bottom: 9rem;
  left: 9rem;
}

.inset-40 {
  top: 10rem;
  right: 10rem;
  bottom: 10rem;
  left: 10rem;
}

.inset-44 {
  top: 11rem;
  right: 11rem;
  bottom: 11rem;
  left: 11rem;
}

.inset-48 {
  top: 12rem;
  right: 12rem;
  bottom: 12rem;
  left: 12rem;
}

.inset-52 {
  top: 13rem;
  right: 13rem;
  bottom: 13rem;
  left: 13rem;
}

.inset-56 {
  top: 14rem;
  right: 14rem;
  bottom: 14rem;
  left: 14rem;
}

.inset-60 {
  top: 15rem;
  right: 15rem;
  bottom: 15rem;
  left: 15rem;
}

.inset-64 {
  top: 16rem;
  right: 16rem;
  bottom: 16rem;
  left: 16rem;
}

.inset-72 {
  top: 18rem;
  right: 18rem;
  bottom: 18rem;
  left: 18rem;
}

.inset-80 {
  top: 20rem;
  right: 20rem;
  bottom: 20rem;
  left: 20rem;
}

.inset-96 {
  top: 24rem;
  right: 24rem;
  bottom: 24rem;
  left: 24rem;
}

.inset-auto {
  top: auto;
  right: auto;
  bottom: auto;
  left: auto;
}

.inset-1\/2 {
  top: 50%;
  right: 50%;
  bottom: 50%;
  left: 50%;
}

.inset-1\/3 {
  top: 33.333333%;
  right: 33.333333%;
  bottom: 33.333333%;
  left: 33.333333%;
}

.inset-2\/3 {
  top: 66.666667%;
  right: 66.666667%;
  bottom: 66.666667%;
  left: 66.666667%;
}

.inset-1\/4 {
  top: 25%;
  right: 25%;
  bottom: 25%;
  left: 25%;
}

.inset-2\/4 {
  top: 50%;
  right: 50%;
  bottom: 50%;
  left: 50%;
}

.inset-3\/4 {
  top: 75%;
  right: 75%;
  bottom: 75%;
  left: 75%;
}

.inset-full {
  top: 100%;
  right: 100%;
  bottom: 100%;
  left: 100%;
}

.-inset-px {
  top: -0.0625rem;
  right: -0.0625rem;
  bottom: -0.0625rem;
  left: -0.0625rem;
}

.-inset-0 {
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
}

.-inset-none {
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
}

.-inset-0\.5 {
  top: -0.125rem;
  right: -0.125rem;
  bottom: -0.125rem;
  left: -0.125rem;
}

.-inset-1 {
  top: -0.25rem;
  right: -0.25rem;
  bottom: -0.25rem;
  left: -0.25rem;
}

.-inset-1\.5 {
  top: -0.375rem;
  right: -0.375rem;
  bottom: -0.375rem;
  left: -0.375rem;
}

.-inset-2 {
  top: -0.5rem;
  right: -0.5rem;
  bottom: -0.5rem;
  left: -0.5rem;
}

.-inset-2\.5 {
  top: -0.625rem;
  right: -0.625rem;
  bottom: -0.625rem;
  left: -0.625rem;
}

.-inset-3 {
  top: -0.75rem;
  right: -0.75rem;
  bottom: -0.75rem;
  left: -0.75rem;
}

.-inset-3\.5 {
  top: -0.875rem;
  right: -0.875rem;
  bottom: -0.875rem;
  left: -0.875rem;
}

.-inset-4 {
  top: -1rem;
  right: -1rem;
  bottom: -1rem;
  left: -1rem;
}

.-inset-5 {
  top: -1.25rem;
  right: -1.25rem;
  bottom: -1.25rem;
  left: -1.25rem;
}

.-inset-6 {
  top: -1.5rem;
  right: -1.5rem;
  bottom: -1.5rem;
  left: -1.5rem;
}

.-inset-7 {
  top: -1.75rem;
  right: -1.75rem;
  bottom: -1.75rem;
  left: -1.75rem;
}

.-inset-8 {
  top: -2rem;
  right: -2rem;
  bottom: -2rem;
  left: -2rem;
}

.-inset-9 {
  top: -2.25rem;
  right: -2.25rem;
  bottom: -2.25rem;
  left: -2.25rem;
}

.-inset-10 {
  top: -2.5rem;
  right: -2.5rem;
  bottom: -2.5rem;
  left: -2.5rem;
}

.-inset-11 {
  top: -2.75rem;
  right: -2.75rem;
  bottom: -2.75rem;
  left: -2.75rem;
}

.-inset-12 {
  top: -3rem;
  right: -3rem;
  bottom: -3rem;
  left: -3rem;
}

.-inset-14 {
  top: -3.5rem;
  right: -3.5rem;
  bottom: -3.5rem;
  left: -3.5rem;
}

.-inset-16 {
  top: -4rem;
  right: -4rem;
  bottom: -4rem;
  left: -4rem;
}

.-inset-18 {
  top: -4.5rem;
  right: -4.5rem;
  bottom: -4.5rem;
  left: -4.5rem;
}

.-inset-20 {
  top: -5rem;
  right: -5rem;
  bottom: -5rem;
  left: -5rem;
}

.-inset-24 {
  top: -6rem;
  right: -6rem;
  bottom: -6rem;
  left: -6rem;
}

.-inset-28 {
  top: -7rem;
  right: -7rem;
  bottom: -7rem;
  left: -7rem;
}

.-inset-32 {
  top: -8rem;
  right: -8rem;
  bottom: -8rem;
  left: -8rem;
}

.-inset-36 {
  top: -9rem;
  right: -9rem;
  bottom: -9rem;
  left: -9rem;
}

.-inset-40 {
  top: -10rem;
  right: -10rem;
  bottom: -10rem;
  left: -10rem;
}

.-inset-44 {
  top: -11rem;
  right: -11rem;
  bottom: -11rem;
  left: -11rem;
}

.-inset-48 {
  top: -12rem;
  right: -12rem;
  bottom: -12rem;
  left: -12rem;
}

.-inset-52 {
  top: -13rem;
  right: -13rem;
  bottom: -13rem;
  left: -13rem;
}

.-inset-56 {
  top: -14rem;
  right: -14rem;
  bottom: -14rem;
  left: -14rem;
}

.-inset-60 {
  top: -15rem;
  right: -15rem;
  bottom: -15rem;
  left: -15rem;
}

.-inset-64 {
  top: -16rem;
  right: -16rem;
  bottom: -16rem;
  left: -16rem;
}

.-inset-72 {
  top: -18rem;
  right: -18rem;
  bottom: -18rem;
  left: -18rem;
}

.-inset-80 {
  top: -20rem;
  right: -20rem;
  bottom: -20rem;
  left: -20rem;
}

.-inset-96 {
  top: -24rem;
  right: -24rem;
  bottom: -24rem;
  left: -24rem;
}

.-inset-1\/2 {
  top: -50%;
  right: -50%;
  bottom: -50%;
  left: -50%;
}

.-inset-1\/3 {
  top: -33.333333%;
  right: -33.333333%;
  bottom: -33.333333%;
  left: -33.333333%;
}

.-inset-2\/3 {
  top: -66.666667%;
  right: -66.666667%;
  bottom: -66.666667%;
  left: -66.666667%;
}

.-inset-1\/4 {
  top: -25%;
  right: -25%;
  bottom: -25%;
  left: -25%;
}

.-inset-2\/4 {
  top: -50%;
  right: -50%;
  bottom: -50%;
  left: -50%;
}

.-inset-3\/4 {
  top: -75%;
  right: -75%;
  bottom: -75%;
  left: -75%;
}

.-inset-full {
  top: -100%;
  right: -100%;
  bottom: -100%;
  left: -100%;
}

.inset-x-px {
  right: 0.0625rem;
  left: 0.0625rem;
}

.inset-x-0 {
  right: 0;
  left: 0;
}

.inset-x-none {
  right: 0;
  left: 0;
}

.inset-x-0\.5 {
  right: 0.125rem;
  left: 0.125rem;
}

.inset-x-1 {
  right: 0.25rem;
  left: 0.25rem;
}

.inset-x-1\.5 {
  right: 0.375rem;
  left: 0.375rem;
}

.inset-x-2 {
  right: 0.5rem;
  left: 0.5rem;
}

.inset-x-2\.5 {
  right: 0.625rem;
  left: 0.625rem;
}

.inset-x-3 {
  right: 0.75rem;
  left: 0.75rem;
}

.inset-x-3\.5 {
  right: 0.875rem;
  left: 0.875rem;
}

.inset-x-4 {
  right: 1rem;
  left: 1rem;
}

.inset-x-5 {
  right: 1.25rem;
  left: 1.25rem;
}

.inset-x-6 {
  right: 1.5rem;
  left: 1.5rem;
}

.inset-x-7 {
  right: 1.75rem;
  left: 1.75rem;
}

.inset-x-8 {
  right: 2rem;
  left: 2rem;
}

.inset-x-9 {
  right: 2.25rem;
  left: 2.25rem;
}

.inset-x-10 {
  right: 2.5rem;
  left: 2.5rem;
}

.inset-x-11 {
  right: 2.75rem;
  left: 2.75rem;
}

.inset-x-12 {
  right: 3rem;
  left: 3rem;
}

.inset-x-14 {
  right: 3.5rem;
  left: 3.5rem;
}

.inset-x-16 {
  right: 4rem;
  left: 4rem;
}

.inset-x-18 {
  right: 4.5rem;
  left: 4.5rem;
}

.inset-x-20 {
  right: 5rem;
  left: 5rem;
}

.inset-x-24 {
  right: 6rem;
  left: 6rem;
}

.inset-x-28 {
  right: 7rem;
  left: 7rem;
}

.inset-x-32 {
  right: 8rem;
  left: 8rem;
}

.inset-x-36 {
  right: 9rem;
  left: 9rem;
}

.inset-x-40 {
  right: 10rem;
  left: 10rem;
}

.inset-x-44 {
  right: 11rem;
  left: 11rem;
}

.inset-x-48 {
  right: 12rem;
  left: 12rem;
}

.inset-x-52 {
  right: 13rem;
  left: 13rem;
}

.inset-x-56 {
  right: 14rem;
  left: 14rem;
}

.inset-x-60 {
  right: 15rem;
  left: 15rem;
}

.inset-x-64 {
  right: 16rem;
  left: 16rem;
}

.inset-x-72 {
  right: 18rem;
  left: 18rem;
}

.inset-x-80 {
  right: 20rem;
  left: 20rem;
}

.inset-x-96 {
  right: 24rem;
  left: 24rem;
}

.inset-x-auto {
  right: auto;
  left: auto;
}

.inset-x-1\/2 {
  right: 50%;
  left: 50%;
}

.inset-x-1\/3 {
  right: 33.333333%;
  left: 33.333333%;
}

.inset-x-2\/3 {
  right: 66.666667%;
  left: 66.666667%;
}

.inset-x-1\/4 {
  right: 25%;
  left: 25%;
}

.inset-x-2\/4 {
  right: 50%;
  left: 50%;
}

.inset-x-3\/4 {
  right: 75%;
  left: 75%;
}

.inset-x-full {
  right: 100%;
  left: 100%;
}

.-inset-x-px {
  right: -0.0625rem;
  left: -0.0625rem;
}

.-inset-x-0 {
  right: 0;
  left: 0;
}

.-inset-x-none {
  right: 0;
  left: 0;
}

.-inset-x-0\.5 {
  right: -0.125rem;
  left: -0.125rem;
}

.-inset-x-1 {
  right: -0.25rem;
  left: -0.25rem;
}

.-inset-x-1\.5 {
  right: -0.375rem;
  left: -0.375rem;
}

.-inset-x-2 {
  right: -0.5rem;
  left: -0.5rem;
}

.-inset-x-2\.5 {
  right: -0.625rem;
  left: -0.625rem;
}

.-inset-x-3 {
  right: -0.75rem;
  left: -0.75rem;
}

.-inset-x-3\.5 {
  right: -0.875rem;
  left: -0.875rem;
}

.-inset-x-4 {
  right: -1rem;
  left: -1rem;
}

.-inset-x-5 {
  right: -1.25rem;
  left: -1.25rem;
}

.-inset-x-6 {
  right: -1.5rem;
  left: -1.5rem;
}

.-inset-x-7 {
  right: -1.75rem;
  left: -1.75rem;
}

.-inset-x-8 {
  right: -2rem;
  left: -2rem;
}

.-inset-x-9 {
  right: -2.25rem;
  left: -2.25rem;
}

.-inset-x-10 {
  right: -2.5rem;
  left: -2.5rem;
}

.-inset-x-11 {
  right: -2.75rem;
  left: -2.75rem;
}

.-inset-x-12 {
  right: -3rem;
  left: -3rem;
}

.-inset-x-14 {
  right: -3.5rem;
  left: -3.5rem;
}

.-inset-x-16 {
  right: -4rem;
  left: -4rem;
}

.-inset-x-18 {
  right: -4.5rem;
  left: -4.5rem;
}

.-inset-x-20 {
  right: -5rem;
  left: -5rem;
}

.-inset-x-24 {
  right: -6rem;
  left: -6rem;
}

.-inset-x-28 {
  right: -7rem;
  left: -7rem;
}

.-inset-x-32 {
  right: -8rem;
  left: -8rem;
}

.-inset-x-36 {
  right: -9rem;
  left: -9rem;
}

.-inset-x-40 {
  right: -10rem;
  left: -10rem;
}

.-inset-x-44 {
  right: -11rem;
  left: -11rem;
}

.-inset-x-48 {
  right: -12rem;
  left: -12rem;
}

.-inset-x-52 {
  right: -13rem;
  left: -13rem;
}

.-inset-x-56 {
  right: -14rem;
  left: -14rem;
}

.-inset-x-60 {
  right: -15rem;
  left: -15rem;
}

.-inset-x-64 {
  right: -16rem;
  left: -16rem;
}

.-inset-x-72 {
  right: -18rem;
  left: -18rem;
}

.-inset-x-80 {
  right: -20rem;
  left: -20rem;
}

.-inset-x-96 {
  right: -24rem;
  left: -24rem;
}

.-inset-x-1\/2 {
  right: -50%;
  left: -50%;
}

.-inset-x-1\/3 {
  right: -33.333333%;
  left: -33.333333%;
}

.-inset-x-2\/3 {
  right: -66.666667%;
  left: -66.666667%;
}

.-inset-x-1\/4 {
  right: -25%;
  left: -25%;
}

.-inset-x-2\/4 {
  right: -50%;
  left: -50%;
}

.-inset-x-3\/4 {
  right: -75%;
  left: -75%;
}

.-inset-x-full {
  right: -100%;
  left: -100%;
}

.inset-y-px {
  top: 0.0625rem;
  bottom: 0.0625rem;
}

.inset-y-0 {
  top: 0;
  bottom: 0;
}

.inset-y-none {
  top: 0;
  bottom: 0;
}

.inset-y-0\.5 {
  top: 0.125rem;
  bottom: 0.125rem;
}

.inset-y-1 {
  top: 0.25rem;
  bottom: 0.25rem;
}

.inset-y-1\.5 {
  top: 0.375rem;
  bottom: 0.375rem;
}

.inset-y-2 {
  top: 0.5rem;
  bottom: 0.5rem;
}

.inset-y-2\.5 {
  top: 0.625rem;
  bottom: 0.625rem;
}

.inset-y-3 {
  top: 0.75rem;
  bottom: 0.75rem;
}

.inset-y-3\.5 {
  top: 0.875rem;
  bottom: 0.875rem;
}

.inset-y-4 {
  top: 1rem;
  bottom: 1rem;
}

.inset-y-5 {
  top: 1.25rem;
  bottom: 1.25rem;
}

.inset-y-6 {
  top: 1.5rem;
  bottom: 1.5rem;
}

.inset-y-7 {
  top: 1.75rem;
  bottom: 1.75rem;
}

.inset-y-8 {
  top: 2rem;
  bottom: 2rem;
}

.inset-y-9 {
  top: 2.25rem;
  bottom: 2.25rem;
}

.inset-y-10 {
  top: 2.5rem;
  bottom: 2.5rem;
}

.inset-y-11 {
  top: 2.75rem;
  bottom: 2.75rem;
}

.inset-y-12 {
  top: 3rem;
  bottom: 3rem;
}

.inset-y-14 {
  top: 3.5rem;
  bottom: 3.5rem;
}

.inset-y-16 {
  top: 4rem;
  bottom: 4rem;
}

.inset-y-18 {
  top: 4.5rem;
  bottom: 4.5rem;
}

.inset-y-20 {
  top: 5rem;
  bottom: 5rem;
}

.inset-y-24 {
  top: 6rem;
  bottom: 6rem;
}

.inset-y-28 {
  top: 7rem;
  bottom: 7rem;
}

.inset-y-32 {
  top: 8rem;
  bottom: 8rem;
}

.inset-y-36 {
  top: 9rem;
  bottom: 9rem;
}

.inset-y-40 {
  top: 10rem;
  bottom: 10rem;
}

.inset-y-44 {
  top: 11rem;
  bottom: 11rem;
}

.inset-y-48 {
  top: 12rem;
  bottom: 12rem;
}

.inset-y-52 {
  top: 13rem;
  bottom: 13rem;
}

.inset-y-56 {
  top: 14rem;
  bottom: 14rem;
}

.inset-y-60 {
  top: 15rem;
  bottom: 15rem;
}

.inset-y-64 {
  top: 16rem;
  bottom: 16rem;
}

.inset-y-72 {
  top: 18rem;
  bottom: 18rem;
}

.inset-y-80 {
  top: 20rem;
  bottom: 20rem;
}

.inset-y-96 {
  top: 24rem;
  bottom: 24rem;
}

.inset-y-auto {
  top: auto;
  bottom: auto;
}

.inset-y-1\/2 {
  top: 50%;
  bottom: 50%;
}

.inset-y-1\/3 {
  top: 33.333333%;
  bottom: 33.333333%;
}

.inset-y-2\/3 {
  top: 66.666667%;
  bottom: 66.666667%;
}

.inset-y-1\/4 {
  top: 25%;
  bottom: 25%;
}

.inset-y-2\/4 {
  top: 50%;
  bottom: 50%;
}

.inset-y-3\/4 {
  top: 75%;
  bottom: 75%;
}

.inset-y-full {
  top: 100%;
  bottom: 100%;
}

.-inset-y-px {
  top: -0.0625rem;
  bottom: -0.0625rem;
}

.-inset-y-0 {
  top: 0;
  bottom: 0;
}

.-inset-y-none {
  top: 0;
  bottom: 0;
}

.-inset-y-0\.5 {
  top: -0.125rem;
  bottom: -0.125rem;
}

.-inset-y-1 {
  top: -0.25rem;
  bottom: -0.25rem;
}

.-inset-y-1\.5 {
  top: -0.375rem;
  bottom: -0.375rem;
}

.-inset-y-2 {
  top: -0.5rem;
  bottom: -0.5rem;
}

.-inset-y-2\.5 {
  top: -0.625rem;
  bottom: -0.625rem;
}

.-inset-y-3 {
  top: -0.75rem;
  bottom: -0.75rem;
}

.-inset-y-3\.5 {
  top: -0.875rem;
  bottom: -0.875rem;
}

.-inset-y-4 {
  top: -1rem;
  bottom: -1rem;
}

.-inset-y-5 {
  top: -1.25rem;
  bottom: -1.25rem;
}

.-inset-y-6 {
  top: -1.5rem;
  bottom: -1.5rem;
}

.-inset-y-7 {
  top: -1.75rem;
  bottom: -1.75rem;
}

.-inset-y-8 {
  top: -2rem;
  bottom: -2rem;
}

.-inset-y-9 {
  top: -2.25rem;
  bottom: -2.25rem;
}

.-inset-y-10 {
  top: -2.5rem;
  bottom: -2.5rem;
}

.-inset-y-11 {
  top: -2.75rem;
  bottom: -2.75rem;
}

.-inset-y-12 {
  top: -3rem;
  bottom: -3rem;
}

.-inset-y-14 {
  top: -3.5rem;
  bottom: -3.5rem;
}

.-inset-y-16 {
  top: -4rem;
  bottom: -4rem;
}

.-inset-y-18 {
  top: -4.5rem;
  bottom: -4.5rem;
}

.-inset-y-20 {
  top: -5rem;
  bottom: -5rem;
}

.-inset-y-24 {
  top: -6rem;
  bottom: -6rem;
}

.-inset-y-28 {
  top: -7rem;
  bottom: -7rem;
}

.-inset-y-32 {
  top: -8rem;
  bottom: -8rem;
}

.-inset-y-36 {
  top: -9rem;
  bottom: -9rem;
}

.-inset-y-40 {
  top: -10rem;
  bottom: -10rem;
}

.-inset-y-44 {
  top: -11rem;
  bottom: -11rem;
}

.-inset-y-48 {
  top: -12rem;
  bottom: -12rem;
}

.-inset-y-52 {
  top: -13rem;
  bottom: -13rem;
}

.-inset-y-56 {
  top: -14rem;
  bottom: -14rem;
}

.-inset-y-60 {
  top: -15rem;
  bottom: -15rem;
}

.-inset-y-64 {
  top: -16rem;
  bottom: -16rem;
}

.-inset-y-72 {
  top: -18rem;
  bottom: -18rem;
}

.-inset-y-80 {
  top: -20rem;
  bottom: -20rem;
}

.-inset-y-96 {
  top: -24rem;
  bottom: -24rem;
}

.-inset-y-1\/2 {
  top: -50%;
  bottom: -50%;
}

.-inset-y-1\/3 {
  top: -33.333333%;
  bottom: -33.333333%;
}

.-inset-y-2\/3 {
  top: -66.666667%;
  bottom: -66.666667%;
}

.-inset-y-1\/4 {
  top: -25%;
  bottom: -25%;
}

.-inset-y-2\/4 {
  top: -50%;
  bottom: -50%;
}

.-inset-y-3\/4 {
  top: -75%;
  bottom: -75%;
}

.-inset-y-full {
  top: -100%;
  bottom: -100%;
}

@media (max-width: 768px) {
  .m\:top-px {
    top: 0.0625rem;
  }

  .m\:top-0 {
    top: 0;
  }

  .m\:top-none {
    top: 0;
  }

  .m\:top-0\.5 {
    top: 0.125rem;
  }

  .m\:top-1 {
    top: 0.25rem;
  }

  .m\:top-1\.5 {
    top: 0.375rem;
  }

  .m\:top-2 {
    top: 0.5rem;
  }

  .m\:top-2\.5 {
    top: 0.625rem;
  }

  .m\:top-3 {
    top: 0.75rem;
  }

  .m\:top-3\.5 {
    top: 0.875rem;
  }

  .m\:top-4 {
    top: 1rem;
  }

  .m\:top-5 {
    top: 1.25rem;
  }

  .m\:top-6 {
    top: 1.5rem;
  }

  .m\:top-7 {
    top: 1.75rem;
  }

  .m\:top-8 {
    top: 2rem;
  }

  .m\:top-9 {
    top: 2.25rem;
  }

  .m\:top-10 {
    top: 2.5rem;
  }

  .m\:top-11 {
    top: 2.75rem;
  }

  .m\:top-12 {
    top: 3rem;
  }

  .m\:top-14 {
    top: 3.5rem;
  }

  .m\:top-16 {
    top: 4rem;
  }

  .m\:top-18 {
    top: 4.5rem;
  }

  .m\:top-20 {
    top: 5rem;
  }

  .m\:top-24 {
    top: 6rem;
  }

  .m\:top-28 {
    top: 7rem;
  }

  .m\:top-32 {
    top: 8rem;
  }

  .m\:top-36 {
    top: 9rem;
  }

  .m\:top-40 {
    top: 10rem;
  }

  .m\:top-44 {
    top: 11rem;
  }

  .m\:top-48 {
    top: 12rem;
  }

  .m\:top-52 {
    top: 13rem;
  }

  .m\:top-56 {
    top: 14rem;
  }

  .m\:top-60 {
    top: 15rem;
  }

  .m\:top-64 {
    top: 16rem;
  }

  .m\:top-72 {
    top: 18rem;
  }

  .m\:top-80 {
    top: 20rem;
  }

  .m\:top-96 {
    top: 24rem;
  }

  .m\:top-auto {
    top: auto;
  }

  .m\:top-1\/2 {
    top: 50%;
  }

  .m\:top-1\/3 {
    top: 33.333333%;
  }

  .m\:top-2\/3 {
    top: 66.666667%;
  }

  .m\:top-1\/4 {
    top: 25%;
  }

  .m\:top-2\/4 {
    top: 50%;
  }

  .m\:top-3\/4 {
    top: 75%;
  }

  .m\:top-full {
    top: 100%;
  }

  .m\:-top-px {
    top: -0.0625rem;
  }

  .m\:-top-0 {
    top: 0;
  }

  .m\:-top-none {
    top: 0;
  }

  .m\:-top-0\.5 {
    top: -0.125rem;
  }

  .m\:-top-1 {
    top: -0.25rem;
  }

  .m\:-top-1\.5 {
    top: -0.375rem;
  }

  .m\:-top-2 {
    top: -0.5rem;
  }

  .m\:-top-2\.5 {
    top: -0.625rem;
  }

  .m\:-top-3 {
    top: -0.75rem;
  }

  .m\:-top-3\.5 {
    top: -0.875rem;
  }

  .m\:-top-4 {
    top: -1rem;
  }

  .m\:-top-5 {
    top: -1.25rem;
  }

  .m\:-top-6 {
    top: -1.5rem;
  }

  .m\:-top-7 {
    top: -1.75rem;
  }

  .m\:-top-8 {
    top: -2rem;
  }

  .m\:-top-9 {
    top: -2.25rem;
  }

  .m\:-top-10 {
    top: -2.5rem;
  }

  .m\:-top-11 {
    top: -2.75rem;
  }

  .m\:-top-12 {
    top: -3rem;
  }

  .m\:-top-14 {
    top: -3.5rem;
  }

  .m\:-top-16 {
    top: -4rem;
  }

  .m\:-top-18 {
    top: -4.5rem;
  }

  .m\:-top-20 {
    top: -5rem;
  }

  .m\:-top-24 {
    top: -6rem;
  }

  .m\:-top-28 {
    top: -7rem;
  }

  .m\:-top-32 {
    top: -8rem;
  }

  .m\:-top-36 {
    top: -9rem;
  }

  .m\:-top-40 {
    top: -10rem;
  }

  .m\:-top-44 {
    top: -11rem;
  }

  .m\:-top-48 {
    top: -12rem;
  }

  .m\:-top-52 {
    top: -13rem;
  }

  .m\:-top-56 {
    top: -14rem;
  }

  .m\:-top-60 {
    top: -15rem;
  }

  .m\:-top-64 {
    top: -16rem;
  }

  .m\:-top-72 {
    top: -18rem;
  }

  .m\:-top-80 {
    top: -20rem;
  }

  .m\:-top-96 {
    top: -24rem;
  }

  .m\:-top-1\/2 {
    top: -50%;
  }

  .m\:-top-1\/3 {
    top: -33.333333%;
  }

  .m\:-top-2\/3 {
    top: -66.666667%;
  }

  .m\:-top-1\/4 {
    top: -25%;
  }

  .m\:-top-2\/4 {
    top: -50%;
  }

  .m\:-top-3\/4 {
    top: -75%;
  }

  .m\:-top-full {
    top: -100%;
  }

  .m\:right-px {
    right: 0.0625rem;
  }

  .m\:right-0 {
    right: 0;
  }

  .m\:right-none {
    right: 0;
  }

  .m\:right-0\.5 {
    right: 0.125rem;
  }

  .m\:right-1 {
    right: 0.25rem;
  }

  .m\:right-1\.5 {
    right: 0.375rem;
  }

  .m\:right-2 {
    right: 0.5rem;
  }

  .m\:right-2\.5 {
    right: 0.625rem;
  }

  .m\:right-3 {
    right: 0.75rem;
  }

  .m\:right-3\.5 {
    right: 0.875rem;
  }

  .m\:right-4 {
    right: 1rem;
  }

  .m\:right-5 {
    right: 1.25rem;
  }

  .m\:right-6 {
    right: 1.5rem;
  }

  .m\:right-7 {
    right: 1.75rem;
  }

  .m\:right-8 {
    right: 2rem;
  }

  .m\:right-9 {
    right: 2.25rem;
  }

  .m\:right-10 {
    right: 2.5rem;
  }

  .m\:right-11 {
    right: 2.75rem;
  }

  .m\:right-12 {
    right: 3rem;
  }

  .m\:right-14 {
    right: 3.5rem;
  }

  .m\:right-16 {
    right: 4rem;
  }

  .m\:right-18 {
    right: 4.5rem;
  }

  .m\:right-20 {
    right: 5rem;
  }

  .m\:right-24 {
    right: 6rem;
  }

  .m\:right-28 {
    right: 7rem;
  }

  .m\:right-32 {
    right: 8rem;
  }

  .m\:right-36 {
    right: 9rem;
  }

  .m\:right-40 {
    right: 10rem;
  }

  .m\:right-44 {
    right: 11rem;
  }

  .m\:right-48 {
    right: 12rem;
  }

  .m\:right-52 {
    right: 13rem;
  }

  .m\:right-56 {
    right: 14rem;
  }

  .m\:right-60 {
    right: 15rem;
  }

  .m\:right-64 {
    right: 16rem;
  }

  .m\:right-72 {
    right: 18rem;
  }

  .m\:right-80 {
    right: 20rem;
  }

  .m\:right-96 {
    right: 24rem;
  }

  .m\:right-auto {
    right: auto;
  }

  .m\:right-1\/2 {
    right: 50%;
  }

  .m\:right-1\/3 {
    right: 33.333333%;
  }

  .m\:right-2\/3 {
    right: 66.666667%;
  }

  .m\:right-1\/4 {
    right: 25%;
  }

  .m\:right-2\/4 {
    right: 50%;
  }

  .m\:right-3\/4 {
    right: 75%;
  }

  .m\:right-full {
    right: 100%;
  }

  .m\:-right-px {
    right: -0.0625rem;
  }

  .m\:-right-0 {
    right: 0;
  }

  .m\:-right-none {
    right: 0;
  }

  .m\:-right-0\.5 {
    right: -0.125rem;
  }

  .m\:-right-1 {
    right: -0.25rem;
  }

  .m\:-right-1\.5 {
    right: -0.375rem;
  }

  .m\:-right-2 {
    right: -0.5rem;
  }

  .m\:-right-2\.5 {
    right: -0.625rem;
  }

  .m\:-right-3 {
    right: -0.75rem;
  }

  .m\:-right-3\.5 {
    right: -0.875rem;
  }

  .m\:-right-4 {
    right: -1rem;
  }

  .m\:-right-5 {
    right: -1.25rem;
  }

  .m\:-right-6 {
    right: -1.5rem;
  }

  .m\:-right-7 {
    right: -1.75rem;
  }

  .m\:-right-8 {
    right: -2rem;
  }

  .m\:-right-9 {
    right: -2.25rem;
  }

  .m\:-right-10 {
    right: -2.5rem;
  }

  .m\:-right-11 {
    right: -2.75rem;
  }

  .m\:-right-12 {
    right: -3rem;
  }

  .m\:-right-14 {
    right: -3.5rem;
  }

  .m\:-right-16 {
    right: -4rem;
  }

  .m\:-right-18 {
    right: -4.5rem;
  }

  .m\:-right-20 {
    right: -5rem;
  }

  .m\:-right-24 {
    right: -6rem;
  }

  .m\:-right-28 {
    right: -7rem;
  }

  .m\:-right-32 {
    right: -8rem;
  }

  .m\:-right-36 {
    right: -9rem;
  }

  .m\:-right-40 {
    right: -10rem;
  }

  .m\:-right-44 {
    right: -11rem;
  }

  .m\:-right-48 {
    right: -12rem;
  }

  .m\:-right-52 {
    right: -13rem;
  }

  .m\:-right-56 {
    right: -14rem;
  }

  .m\:-right-60 {
    right: -15rem;
  }

  .m\:-right-64 {
    right: -16rem;
  }

  .m\:-right-72 {
    right: -18rem;
  }

  .m\:-right-80 {
    right: -20rem;
  }

  .m\:-right-96 {
    right: -24rem;
  }

  .m\:-right-1\/2 {
    right: -50%;
  }

  .m\:-right-1\/3 {
    right: -33.333333%;
  }

  .m\:-right-2\/3 {
    right: -66.666667%;
  }

  .m\:-right-1\/4 {
    right: -25%;
  }

  .m\:-right-2\/4 {
    right: -50%;
  }

  .m\:-right-3\/4 {
    right: -75%;
  }

  .m\:-right-full {
    right: -100%;
  }

  .m\:bottom-px {
    bottom: 0.0625rem;
  }

  .m\:bottom-0 {
    bottom: 0;
  }

  .m\:bottom-none {
    bottom: 0;
  }

  .m\:bottom-0\.5 {
    bottom: 0.125rem;
  }

  .m\:bottom-1 {
    bottom: 0.25rem;
  }

  .m\:bottom-1\.5 {
    bottom: 0.375rem;
  }

  .m\:bottom-2 {
    bottom: 0.5rem;
  }

  .m\:bottom-2\.5 {
    bottom: 0.625rem;
  }

  .m\:bottom-3 {
    bottom: 0.75rem;
  }

  .m\:bottom-3\.5 {
    bottom: 0.875rem;
  }

  .m\:bottom-4 {
    bottom: 1rem;
  }

  .m\:bottom-5 {
    bottom: 1.25rem;
  }

  .m\:bottom-6 {
    bottom: 1.5rem;
  }

  .m\:bottom-7 {
    bottom: 1.75rem;
  }

  .m\:bottom-8 {
    bottom: 2rem;
  }

  .m\:bottom-9 {
    bottom: 2.25rem;
  }

  .m\:bottom-10 {
    bottom: 2.5rem;
  }

  .m\:bottom-11 {
    bottom: 2.75rem;
  }

  .m\:bottom-12 {
    bottom: 3rem;
  }

  .m\:bottom-14 {
    bottom: 3.5rem;
  }

  .m\:bottom-16 {
    bottom: 4rem;
  }

  .m\:bottom-18 {
    bottom: 4.5rem;
  }

  .m\:bottom-20 {
    bottom: 5rem;
  }

  .m\:bottom-24 {
    bottom: 6rem;
  }

  .m\:bottom-28 {
    bottom: 7rem;
  }

  .m\:bottom-32 {
    bottom: 8rem;
  }

  .m\:bottom-36 {
    bottom: 9rem;
  }

  .m\:bottom-40 {
    bottom: 10rem;
  }

  .m\:bottom-44 {
    bottom: 11rem;
  }

  .m\:bottom-48 {
    bottom: 12rem;
  }

  .m\:bottom-52 {
    bottom: 13rem;
  }

  .m\:bottom-56 {
    bottom: 14rem;
  }

  .m\:bottom-60 {
    bottom: 15rem;
  }

  .m\:bottom-64 {
    bottom: 16rem;
  }

  .m\:bottom-72 {
    bottom: 18rem;
  }

  .m\:bottom-80 {
    bottom: 20rem;
  }

  .m\:bottom-96 {
    bottom: 24rem;
  }

  .m\:bottom-auto {
    bottom: auto;
  }

  .m\:bottom-1\/2 {
    bottom: 50%;
  }

  .m\:bottom-1\/3 {
    bottom: 33.333333%;
  }

  .m\:bottom-2\/3 {
    bottom: 66.666667%;
  }

  .m\:bottom-1\/4 {
    bottom: 25%;
  }

  .m\:bottom-2\/4 {
    bottom: 50%;
  }

  .m\:bottom-3\/4 {
    bottom: 75%;
  }

  .m\:bottom-full {
    bottom: 100%;
  }

  .m\:-bottom-px {
    bottom: -0.0625rem;
  }

  .m\:-bottom-0 {
    bottom: 0;
  }

  .m\:-bottom-none {
    bottom: 0;
  }

  .m\:-bottom-0\.5 {
    bottom: -0.125rem;
  }

  .m\:-bottom-1 {
    bottom: -0.25rem;
  }

  .m\:-bottom-1\.5 {
    bottom: -0.375rem;
  }

  .m\:-bottom-2 {
    bottom: -0.5rem;
  }

  .m\:-bottom-2\.5 {
    bottom: -0.625rem;
  }

  .m\:-bottom-3 {
    bottom: -0.75rem;
  }

  .m\:-bottom-3\.5 {
    bottom: -0.875rem;
  }

  .m\:-bottom-4 {
    bottom: -1rem;
  }

  .m\:-bottom-5 {
    bottom: -1.25rem;
  }

  .m\:-bottom-6 {
    bottom: -1.5rem;
  }

  .m\:-bottom-7 {
    bottom: -1.75rem;
  }

  .m\:-bottom-8 {
    bottom: -2rem;
  }

  .m\:-bottom-9 {
    bottom: -2.25rem;
  }

  .m\:-bottom-10 {
    bottom: -2.5rem;
  }

  .m\:-bottom-11 {
    bottom: -2.75rem;
  }

  .m\:-bottom-12 {
    bottom: -3rem;
  }

  .m\:-bottom-14 {
    bottom: -3.5rem;
  }

  .m\:-bottom-16 {
    bottom: -4rem;
  }

  .m\:-bottom-18 {
    bottom: -4.5rem;
  }

  .m\:-bottom-20 {
    bottom: -5rem;
  }

  .m\:-bottom-24 {
    bottom: -6rem;
  }

  .m\:-bottom-28 {
    bottom: -7rem;
  }

  .m\:-bottom-32 {
    bottom: -8rem;
  }

  .m\:-bottom-36 {
    bottom: -9rem;
  }

  .m\:-bottom-40 {
    bottom: -10rem;
  }

  .m\:-bottom-44 {
    bottom: -11rem;
  }

  .m\:-bottom-48 {
    bottom: -12rem;
  }

  .m\:-bottom-52 {
    bottom: -13rem;
  }

  .m\:-bottom-56 {
    bottom: -14rem;
  }

  .m\:-bottom-60 {
    bottom: -15rem;
  }

  .m\:-bottom-64 {
    bottom: -16rem;
  }

  .m\:-bottom-72 {
    bottom: -18rem;
  }

  .m\:-bottom-80 {
    bottom: -20rem;
  }

  .m\:-bottom-96 {
    bottom: -24rem;
  }

  .m\:-bottom-1\/2 {
    bottom: -50%;
  }

  .m\:-bottom-1\/3 {
    bottom: -33.333333%;
  }

  .m\:-bottom-2\/3 {
    bottom: -66.666667%;
  }

  .m\:-bottom-1\/4 {
    bottom: -25%;
  }

  .m\:-bottom-2\/4 {
    bottom: -50%;
  }

  .m\:-bottom-3\/4 {
    bottom: -75%;
  }

  .m\:-bottom-full {
    bottom: -100%;
  }

  .m\:left-px {
    left: 0.0625rem;
  }

  .m\:left-0 {
    left: 0;
  }

  .m\:left-none {
    left: 0;
  }

  .m\:left-0\.5 {
    left: 0.125rem;
  }

  .m\:left-1 {
    left: 0.25rem;
  }

  .m\:left-1\.5 {
    left: 0.375rem;
  }

  .m\:left-2 {
    left: 0.5rem;
  }

  .m\:left-2\.5 {
    left: 0.625rem;
  }

  .m\:left-3 {
    left: 0.75rem;
  }

  .m\:left-3\.5 {
    left: 0.875rem;
  }

  .m\:left-4 {
    left: 1rem;
  }

  .m\:left-5 {
    left: 1.25rem;
  }

  .m\:left-6 {
    left: 1.5rem;
  }

  .m\:left-7 {
    left: 1.75rem;
  }

  .m\:left-8 {
    left: 2rem;
  }

  .m\:left-9 {
    left: 2.25rem;
  }

  .m\:left-10 {
    left: 2.5rem;
  }

  .m\:left-11 {
    left: 2.75rem;
  }

  .m\:left-12 {
    left: 3rem;
  }

  .m\:left-14 {
    left: 3.5rem;
  }

  .m\:left-16 {
    left: 4rem;
  }

  .m\:left-18 {
    left: 4.5rem;
  }

  .m\:left-20 {
    left: 5rem;
  }

  .m\:left-24 {
    left: 6rem;
  }

  .m\:left-28 {
    left: 7rem;
  }

  .m\:left-32 {
    left: 8rem;
  }

  .m\:left-36 {
    left: 9rem;
  }

  .m\:left-40 {
    left: 10rem;
  }

  .m\:left-44 {
    left: 11rem;
  }

  .m\:left-48 {
    left: 12rem;
  }

  .m\:left-52 {
    left: 13rem;
  }

  .m\:left-56 {
    left: 14rem;
  }

  .m\:left-60 {
    left: 15rem;
  }

  .m\:left-64 {
    left: 16rem;
  }

  .m\:left-72 {
    left: 18rem;
  }

  .m\:left-80 {
    left: 20rem;
  }

  .m\:left-96 {
    left: 24rem;
  }

  .m\:left-auto {
    left: auto;
  }

  .m\:left-1\/2 {
    left: 50%;
  }

  .m\:left-1\/3 {
    left: 33.333333%;
  }

  .m\:left-2\/3 {
    left: 66.666667%;
  }

  .m\:left-1\/4 {
    left: 25%;
  }

  .m\:left-2\/4 {
    left: 50%;
  }

  .m\:left-3\/4 {
    left: 75%;
  }

  .m\:left-full {
    left: 100%;
  }

  .m\:-left-px {
    left: -0.0625rem;
  }

  .m\:-left-0 {
    left: 0;
  }

  .m\:-left-none {
    left: 0;
  }

  .m\:-left-0\.5 {
    left: -0.125rem;
  }

  .m\:-left-1 {
    left: -0.25rem;
  }

  .m\:-left-1\.5 {
    left: -0.375rem;
  }

  .m\:-left-2 {
    left: -0.5rem;
  }

  .m\:-left-2\.5 {
    left: -0.625rem;
  }

  .m\:-left-3 {
    left: -0.75rem;
  }

  .m\:-left-3\.5 {
    left: -0.875rem;
  }

  .m\:-left-4 {
    left: -1rem;
  }

  .m\:-left-5 {
    left: -1.25rem;
  }

  .m\:-left-6 {
    left: -1.5rem;
  }

  .m\:-left-7 {
    left: -1.75rem;
  }

  .m\:-left-8 {
    left: -2rem;
  }

  .m\:-left-9 {
    left: -2.25rem;
  }

  .m\:-left-10 {
    left: -2.5rem;
  }

  .m\:-left-11 {
    left: -2.75rem;
  }

  .m\:-left-12 {
    left: -3rem;
  }

  .m\:-left-14 {
    left: -3.5rem;
  }

  .m\:-left-16 {
    left: -4rem;
  }

  .m\:-left-18 {
    left: -4.5rem;
  }

  .m\:-left-20 {
    left: -5rem;
  }

  .m\:-left-24 {
    left: -6rem;
  }

  .m\:-left-28 {
    left: -7rem;
  }

  .m\:-left-32 {
    left: -8rem;
  }

  .m\:-left-36 {
    left: -9rem;
  }

  .m\:-left-40 {
    left: -10rem;
  }

  .m\:-left-44 {
    left: -11rem;
  }

  .m\:-left-48 {
    left: -12rem;
  }

  .m\:-left-52 {
    left: -13rem;
  }

  .m\:-left-56 {
    left: -14rem;
  }

  .m\:-left-60 {
    left: -15rem;
  }

  .m\:-left-64 {
    left: -16rem;
  }

  .m\:-left-72 {
    left: -18rem;
  }

  .m\:-left-80 {
    left: -20rem;
  }

  .m\:-left-96 {
    left: -24rem;
  }

  .m\:-left-1\/2 {
    left: -50%;
  }

  .m\:-left-1\/3 {
    left: -33.333333%;
  }

  .m\:-left-2\/3 {
    left: -66.666667%;
  }

  .m\:-left-1\/4 {
    left: -25%;
  }

  .m\:-left-2\/4 {
    left: -50%;
  }

  .m\:-left-3\/4 {
    left: -75%;
  }

  .m\:-left-full {
    left: -100%;
  }

  .m\:inset-px {
    top: 0.0625rem;
    right: 0.0625rem;
    bottom: 0.0625rem;
    left: 0.0625rem;
  }

  .m\:inset-0 {
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
  }

  .m\:inset-none {
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
  }

  .m\:inset-0\.5 {
    top: 0.125rem;
    right: 0.125rem;
    bottom: 0.125rem;
    left: 0.125rem;
  }

  .m\:inset-1 {
    top: 0.25rem;
    right: 0.25rem;
    bottom: 0.25rem;
    left: 0.25rem;
  }

  .m\:inset-1\.5 {
    top: 0.375rem;
    right: 0.375rem;
    bottom: 0.375rem;
    left: 0.375rem;
  }

  .m\:inset-2 {
    top: 0.5rem;
    right: 0.5rem;
    bottom: 0.5rem;
    left: 0.5rem;
  }

  .m\:inset-2\.5 {
    top: 0.625rem;
    right: 0.625rem;
    bottom: 0.625rem;
    left: 0.625rem;
  }

  .m\:inset-3 {
    top: 0.75rem;
    right: 0.75rem;
    bottom: 0.75rem;
    left: 0.75rem;
  }

  .m\:inset-3\.5 {
    top: 0.875rem;
    right: 0.875rem;
    bottom: 0.875rem;
    left: 0.875rem;
  }

  .m\:inset-4 {
    top: 1rem;
    right: 1rem;
    bottom: 1rem;
    left: 1rem;
  }

  .m\:inset-5 {
    top: 1.25rem;
    right: 1.25rem;
    bottom: 1.25rem;
    left: 1.25rem;
  }

  .m\:inset-6 {
    top: 1.5rem;
    right: 1.5rem;
    bottom: 1.5rem;
    left: 1.5rem;
  }

  .m\:inset-7 {
    top: 1.75rem;
    right: 1.75rem;
    bottom: 1.75rem;
    left: 1.75rem;
  }

  .m\:inset-8 {
    top: 2rem;
    right: 2rem;
    bottom: 2rem;
    left: 2rem;
  }

  .m\:inset-9 {
    top: 2.25rem;
    right: 2.25rem;
    bottom: 2.25rem;
    left: 2.25rem;
  }

  .m\:inset-10 {
    top: 2.5rem;
    right: 2.5rem;
    bottom: 2.5rem;
    left: 2.5rem;
  }

  .m\:inset-11 {
    top: 2.75rem;
    right: 2.75rem;
    bottom: 2.75rem;
    left: 2.75rem;
  }

  .m\:inset-12 {
    top: 3rem;
    right: 3rem;
    bottom: 3rem;
    left: 3rem;
  }

  .m\:inset-14 {
    top: 3.5rem;
    right: 3.5rem;
    bottom: 3.5rem;
    left: 3.5rem;
  }

  .m\:inset-16 {
    top: 4rem;
    right: 4rem;
    bottom: 4rem;
    left: 4rem;
  }

  .m\:inset-18 {
    top: 4.5rem;
    right: 4.5rem;
    bottom: 4.5rem;
    left: 4.5rem;
  }

  .m\:inset-20 {
    top: 5rem;
    right: 5rem;
    bottom: 5rem;
    left: 5rem;
  }

  .m\:inset-24 {
    top: 6rem;
    right: 6rem;
    bottom: 6rem;
    left: 6rem;
  }

  .m\:inset-28 {
    top: 7rem;
    right: 7rem;
    bottom: 7rem;
    left: 7rem;
  }

  .m\:inset-32 {
    top: 8rem;
    right: 8rem;
    bottom: 8rem;
    left: 8rem;
  }

  .m\:inset-36 {
    top: 9rem;
    right: 9rem;
    bottom: 9rem;
    left: 9rem;
  }

  .m\:inset-40 {
    top: 10rem;
    right: 10rem;
    bottom: 10rem;
    left: 10rem;
  }

  .m\:inset-44 {
    top: 11rem;
    right: 11rem;
    bottom: 11rem;
    left: 11rem;
  }

  .m\:inset-48 {
    top: 12rem;
    right: 12rem;
    bottom: 12rem;
    left: 12rem;
  }

  .m\:inset-52 {
    top: 13rem;
    right: 13rem;
    bottom: 13rem;
    left: 13rem;
  }

  .m\:inset-56 {
    top: 14rem;
    right: 14rem;
    bottom: 14rem;
    left: 14rem;
  }

  .m\:inset-60 {
    top: 15rem;
    right: 15rem;
    bottom: 15rem;
    left: 15rem;
  }

  .m\:inset-64 {
    top: 16rem;
    right: 16rem;
    bottom: 16rem;
    left: 16rem;
  }

  .m\:inset-72 {
    top: 18rem;
    right: 18rem;
    bottom: 18rem;
    left: 18rem;
  }

  .m\:inset-80 {
    top: 20rem;
    right: 20rem;
    bottom: 20rem;
    left: 20rem;
  }

  .m\:inset-96 {
    top: 24rem;
    right: 24rem;
    bottom: 24rem;
    left: 24rem;
  }

  .m\:inset-auto {
    top: auto;
    right: auto;
    bottom: auto;
    left: auto;
  }

  .m\:inset-1\/2 {
    top: 50%;
    right: 50%;
    bottom: 50%;
    left: 50%;
  }

  .m\:inset-1\/3 {
    top: 33.333333%;
    right: 33.333333%;
    bottom: 33.333333%;
    left: 33.333333%;
  }

  .m\:inset-2\/3 {
    top: 66.666667%;
    right: 66.666667%;
    bottom: 66.666667%;
    left: 66.666667%;
  }

  .m\:inset-1\/4 {
    top: 25%;
    right: 25%;
    bottom: 25%;
    left: 25%;
  }

  .m\:inset-2\/4 {
    top: 50%;
    right: 50%;
    bottom: 50%;
    left: 50%;
  }

  .m\:inset-3\/4 {
    top: 75%;
    right: 75%;
    bottom: 75%;
    left: 75%;
  }

  .m\:inset-full {
    top: 100%;
    right: 100%;
    bottom: 100%;
    left: 100%;
  }

  .m\:-inset-px {
    top: -0.0625rem;
    right: -0.0625rem;
    bottom: -0.0625rem;
    left: -0.0625rem;
  }

  .m\:-inset-0 {
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
  }

  .m\:-inset-none {
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
  }

  .m\:-inset-0\.5 {
    top: -0.125rem;
    right: -0.125rem;
    bottom: -0.125rem;
    left: -0.125rem;
  }

  .m\:-inset-1 {
    top: -0.25rem;
    right: -0.25rem;
    bottom: -0.25rem;
    left: -0.25rem;
  }

  .m\:-inset-1\.5 {
    top: -0.375rem;
    right: -0.375rem;
    bottom: -0.375rem;
    left: -0.375rem;
  }

  .m\:-inset-2 {
    top: -0.5rem;
    right: -0.5rem;
    bottom: -0.5rem;
    left: -0.5rem;
  }

  .m\:-inset-2\.5 {
    top: -0.625rem;
    right: -0.625rem;
    bottom: -0.625rem;
    left: -0.625rem;
  }

  .m\:-inset-3 {
    top: -0.75rem;
    right: -0.75rem;
    bottom: -0.75rem;
    left: -0.75rem;
  }

  .m\:-inset-3\.5 {
    top: -0.875rem;
    right: -0.875rem;
    bottom: -0.875rem;
    left: -0.875rem;
  }

  .m\:-inset-4 {
    top: -1rem;
    right: -1rem;
    bottom: -1rem;
    left: -1rem;
  }

  .m\:-inset-5 {
    top: -1.25rem;
    right: -1.25rem;
    bottom: -1.25rem;
    left: -1.25rem;
  }

  .m\:-inset-6 {
    top: -1.5rem;
    right: -1.5rem;
    bottom: -1.5rem;
    left: -1.5rem;
  }

  .m\:-inset-7 {
    top: -1.75rem;
    right: -1.75rem;
    bottom: -1.75rem;
    left: -1.75rem;
  }

  .m\:-inset-8 {
    top: -2rem;
    right: -2rem;
    bottom: -2rem;
    left: -2rem;
  }

  .m\:-inset-9 {
    top: -2.25rem;
    right: -2.25rem;
    bottom: -2.25rem;
    left: -2.25rem;
  }

  .m\:-inset-10 {
    top: -2.5rem;
    right: -2.5rem;
    bottom: -2.5rem;
    left: -2.5rem;
  }

  .m\:-inset-11 {
    top: -2.75rem;
    right: -2.75rem;
    bottom: -2.75rem;
    left: -2.75rem;
  }

  .m\:-inset-12 {
    top: -3rem;
    right: -3rem;
    bottom: -3rem;
    left: -3rem;
  }

  .m\:-inset-14 {
    top: -3.5rem;
    right: -3.5rem;
    bottom: -3.5rem;
    left: -3.5rem;
  }

  .m\:-inset-16 {
    top: -4rem;
    right: -4rem;
    bottom: -4rem;
    left: -4rem;
  }

  .m\:-inset-18 {
    top: -4.5rem;
    right: -4.5rem;
    bottom: -4.5rem;
    left: -4.5rem;
  }

  .m\:-inset-20 {
    top: -5rem;
    right: -5rem;
    bottom: -5rem;
    left: -5rem;
  }

  .m\:-inset-24 {
    top: -6rem;
    right: -6rem;
    bottom: -6rem;
    left: -6rem;
  }

  .m\:-inset-28 {
    top: -7rem;
    right: -7rem;
    bottom: -7rem;
    left: -7rem;
  }

  .m\:-inset-32 {
    top: -8rem;
    right: -8rem;
    bottom: -8rem;
    left: -8rem;
  }

  .m\:-inset-36 {
    top: -9rem;
    right: -9rem;
    bottom: -9rem;
    left: -9rem;
  }

  .m\:-inset-40 {
    top: -10rem;
    right: -10rem;
    bottom: -10rem;
    left: -10rem;
  }

  .m\:-inset-44 {
    top: -11rem;
    right: -11rem;
    bottom: -11rem;
    left: -11rem;
  }

  .m\:-inset-48 {
    top: -12rem;
    right: -12rem;
    bottom: -12rem;
    left: -12rem;
  }

  .m\:-inset-52 {
    top: -13rem;
    right: -13rem;
    bottom: -13rem;
    left: -13rem;
  }

  .m\:-inset-56 {
    top: -14rem;
    right: -14rem;
    bottom: -14rem;
    left: -14rem;
  }

  .m\:-inset-60 {
    top: -15rem;
    right: -15rem;
    bottom: -15rem;
    left: -15rem;
  }

  .m\:-inset-64 {
    top: -16rem;
    right: -16rem;
    bottom: -16rem;
    left: -16rem;
  }

  .m\:-inset-72 {
    top: -18rem;
    right: -18rem;
    bottom: -18rem;
    left: -18rem;
  }

  .m\:-inset-80 {
    top: -20rem;
    right: -20rem;
    bottom: -20rem;
    left: -20rem;
  }

  .m\:-inset-96 {
    top: -24rem;
    right: -24rem;
    bottom: -24rem;
    left: -24rem;
  }

  .m\:-inset-1\/2 {
    top: -50%;
    right: -50%;
    bottom: -50%;
    left: -50%;
  }

  .m\:-inset-1\/3 {
    top: -33.333333%;
    right: -33.333333%;
    bottom: -33.333333%;
    left: -33.333333%;
  }

  .m\:-inset-2\/3 {
    top: -66.666667%;
    right: -66.666667%;
    bottom: -66.666667%;
    left: -66.666667%;
  }

  .m\:-inset-1\/4 {
    top: -25%;
    right: -25%;
    bottom: -25%;
    left: -25%;
  }

  .m\:-inset-2\/4 {
    top: -50%;
    right: -50%;
    bottom: -50%;
    left: -50%;
  }

  .m\:-inset-3\/4 {
    top: -75%;
    right: -75%;
    bottom: -75%;
    left: -75%;
  }

  .m\:-inset-full {
    top: -100%;
    right: -100%;
    bottom: -100%;
    left: -100%;
  }

  .m\:inset-x-px {
    right: 0.0625rem;
    left: 0.0625rem;
  }

  .m\:inset-x-0 {
    right: 0;
    left: 0;
  }

  .m\:inset-x-none {
    right: 0;
    left: 0;
  }

  .m\:inset-x-0\.5 {
    right: 0.125rem;
    left: 0.125rem;
  }

  .m\:inset-x-1 {
    right: 0.25rem;
    left: 0.25rem;
  }

  .m\:inset-x-1\.5 {
    right: 0.375rem;
    left: 0.375rem;
  }

  .m\:inset-x-2 {
    right: 0.5rem;
    left: 0.5rem;
  }

  .m\:inset-x-2\.5 {
    right: 0.625rem;
    left: 0.625rem;
  }

  .m\:inset-x-3 {
    right: 0.75rem;
    left: 0.75rem;
  }

  .m\:inset-x-3\.5 {
    right: 0.875rem;
    left: 0.875rem;
  }

  .m\:inset-x-4 {
    right: 1rem;
    left: 1rem;
  }

  .m\:inset-x-5 {
    right: 1.25rem;
    left: 1.25rem;
  }

  .m\:inset-x-6 {
    right: 1.5rem;
    left: 1.5rem;
  }

  .m\:inset-x-7 {
    right: 1.75rem;
    left: 1.75rem;
  }

  .m\:inset-x-8 {
    right: 2rem;
    left: 2rem;
  }

  .m\:inset-x-9 {
    right: 2.25rem;
    left: 2.25rem;
  }

  .m\:inset-x-10 {
    right: 2.5rem;
    left: 2.5rem;
  }

  .m\:inset-x-11 {
    right: 2.75rem;
    left: 2.75rem;
  }

  .m\:inset-x-12 {
    right: 3rem;
    left: 3rem;
  }

  .m\:inset-x-14 {
    right: 3.5rem;
    left: 3.5rem;
  }

  .m\:inset-x-16 {
    right: 4rem;
    left: 4rem;
  }

  .m\:inset-x-18 {
    right: 4.5rem;
    left: 4.5rem;
  }

  .m\:inset-x-20 {
    right: 5rem;
    left: 5rem;
  }

  .m\:inset-x-24 {
    right: 6rem;
    left: 6rem;
  }

  .m\:inset-x-28 {
    right: 7rem;
    left: 7rem;
  }

  .m\:inset-x-32 {
    right: 8rem;
    left: 8rem;
  }

  .m\:inset-x-36 {
    right: 9rem;
    left: 9rem;
  }

  .m\:inset-x-40 {
    right: 10rem;
    left: 10rem;
  }

  .m\:inset-x-44 {
    right: 11rem;
    left: 11rem;
  }

  .m\:inset-x-48 {
    right: 12rem;
    left: 12rem;
  }

  .m\:inset-x-52 {
    right: 13rem;
    left: 13rem;
  }

  .m\:inset-x-56 {
    right: 14rem;
    left: 14rem;
  }

  .m\:inset-x-60 {
    right: 15rem;
    left: 15rem;
  }

  .m\:inset-x-64 {
    right: 16rem;
    left: 16rem;
  }

  .m\:inset-x-72 {
    right: 18rem;
    left: 18rem;
  }

  .m\:inset-x-80 {
    right: 20rem;
    left: 20rem;
  }

  .m\:inset-x-96 {
    right: 24rem;
    left: 24rem;
  }

  .m\:inset-x-auto {
    right: auto;
    left: auto;
  }

  .m\:inset-x-1\/2 {
    right: 50%;
    left: 50%;
  }

  .m\:inset-x-1\/3 {
    right: 33.333333%;
    left: 33.333333%;
  }

  .m\:inset-x-2\/3 {
    right: 66.666667%;
    left: 66.666667%;
  }

  .m\:inset-x-1\/4 {
    right: 25%;
    left: 25%;
  }

  .m\:inset-x-2\/4 {
    right: 50%;
    left: 50%;
  }

  .m\:inset-x-3\/4 {
    right: 75%;
    left: 75%;
  }

  .m\:inset-x-full {
    right: 100%;
    left: 100%;
  }

  .m\:-inset-x-px {
    right: -0.0625rem;
    left: -0.0625rem;
  }

  .m\:-inset-x-0 {
    right: 0;
    left: 0;
  }

  .m\:-inset-x-none {
    right: 0;
    left: 0;
  }

  .m\:-inset-x-0\.5 {
    right: -0.125rem;
    left: -0.125rem;
  }

  .m\:-inset-x-1 {
    right: -0.25rem;
    left: -0.25rem;
  }

  .m\:-inset-x-1\.5 {
    right: -0.375rem;
    left: -0.375rem;
  }

  .m\:-inset-x-2 {
    right: -0.5rem;
    left: -0.5rem;
  }

  .m\:-inset-x-2\.5 {
    right: -0.625rem;
    left: -0.625rem;
  }

  .m\:-inset-x-3 {
    right: -0.75rem;
    left: -0.75rem;
  }

  .m\:-inset-x-3\.5 {
    right: -0.875rem;
    left: -0.875rem;
  }

  .m\:-inset-x-4 {
    right: -1rem;
    left: -1rem;
  }

  .m\:-inset-x-5 {
    right: -1.25rem;
    left: -1.25rem;
  }

  .m\:-inset-x-6 {
    right: -1.5rem;
    left: -1.5rem;
  }

  .m\:-inset-x-7 {
    right: -1.75rem;
    left: -1.75rem;
  }

  .m\:-inset-x-8 {
    right: -2rem;
    left: -2rem;
  }

  .m\:-inset-x-9 {
    right: -2.25rem;
    left: -2.25rem;
  }

  .m\:-inset-x-10 {
    right: -2.5rem;
    left: -2.5rem;
  }

  .m\:-inset-x-11 {
    right: -2.75rem;
    left: -2.75rem;
  }

  .m\:-inset-x-12 {
    right: -3rem;
    left: -3rem;
  }

  .m\:-inset-x-14 {
    right: -3.5rem;
    left: -3.5rem;
  }

  .m\:-inset-x-16 {
    right: -4rem;
    left: -4rem;
  }

  .m\:-inset-x-18 {
    right: -4.5rem;
    left: -4.5rem;
  }

  .m\:-inset-x-20 {
    right: -5rem;
    left: -5rem;
  }

  .m\:-inset-x-24 {
    right: -6rem;
    left: -6rem;
  }

  .m\:-inset-x-28 {
    right: -7rem;
    left: -7rem;
  }

  .m\:-inset-x-32 {
    right: -8rem;
    left: -8rem;
  }

  .m\:-inset-x-36 {
    right: -9rem;
    left: -9rem;
  }

  .m\:-inset-x-40 {
    right: -10rem;
    left: -10rem;
  }

  .m\:-inset-x-44 {
    right: -11rem;
    left: -11rem;
  }

  .m\:-inset-x-48 {
    right: -12rem;
    left: -12rem;
  }

  .m\:-inset-x-52 {
    right: -13rem;
    left: -13rem;
  }

  .m\:-inset-x-56 {
    right: -14rem;
    left: -14rem;
  }

  .m\:-inset-x-60 {
    right: -15rem;
    left: -15rem;
  }

  .m\:-inset-x-64 {
    right: -16rem;
    left: -16rem;
  }

  .m\:-inset-x-72 {
    right: -18rem;
    left: -18rem;
  }

  .m\:-inset-x-80 {
    right: -20rem;
    left: -20rem;
  }

  .m\:-inset-x-96 {
    right: -24rem;
    left: -24rem;
  }

  .m\:-inset-x-1\/2 {
    right: -50%;
    left: -50%;
  }

  .m\:-inset-x-1\/3 {
    right: -33.333333%;
    left: -33.333333%;
  }

  .m\:-inset-x-2\/3 {
    right: -66.666667%;
    left: -66.666667%;
  }

  .m\:-inset-x-1\/4 {
    right: -25%;
    left: -25%;
  }

  .m\:-inset-x-2\/4 {
    right: -50%;
    left: -50%;
  }

  .m\:-inset-x-3\/4 {
    right: -75%;
    left: -75%;
  }

  .m\:-inset-x-full {
    right: -100%;
    left: -100%;
  }

  .m\:inset-y-px {
    top: 0.0625rem;
    bottom: 0.0625rem;
  }

  .m\:inset-y-0 {
    top: 0;
    bottom: 0;
  }

  .m\:inset-y-none {
    top: 0;
    bottom: 0;
  }

  .m\:inset-y-0\.5 {
    top: 0.125rem;
    bottom: 0.125rem;
  }

  .m\:inset-y-1 {
    top: 0.25rem;
    bottom: 0.25rem;
  }

  .m\:inset-y-1\.5 {
    top: 0.375rem;
    bottom: 0.375rem;
  }

  .m\:inset-y-2 {
    top: 0.5rem;
    bottom: 0.5rem;
  }

  .m\:inset-y-2\.5 {
    top: 0.625rem;
    bottom: 0.625rem;
  }

  .m\:inset-y-3 {
    top: 0.75rem;
    bottom: 0.75rem;
  }

  .m\:inset-y-3\.5 {
    top: 0.875rem;
    bottom: 0.875rem;
  }

  .m\:inset-y-4 {
    top: 1rem;
    bottom: 1rem;
  }

  .m\:inset-y-5 {
    top: 1.25rem;
    bottom: 1.25rem;
  }

  .m\:inset-y-6 {
    top: 1.5rem;
    bottom: 1.5rem;
  }

  .m\:inset-y-7 {
    top: 1.75rem;
    bottom: 1.75rem;
  }

  .m\:inset-y-8 {
    top: 2rem;
    bottom: 2rem;
  }

  .m\:inset-y-9 {
    top: 2.25rem;
    bottom: 2.25rem;
  }

  .m\:inset-y-10 {
    top: 2.5rem;
    bottom: 2.5rem;
  }

  .m\:inset-y-11 {
    top: 2.75rem;
    bottom: 2.75rem;
  }

  .m\:inset-y-12 {
    top: 3rem;
    bottom: 3rem;
  }

  .m\:inset-y-14 {
    top: 3.5rem;
    bottom: 3.5rem;
  }

  .m\:inset-y-16 {
    top: 4rem;
    bottom: 4rem;
  }

  .m\:inset-y-18 {
    top: 4.5rem;
    bottom: 4.5rem;
  }

  .m\:inset-y-20 {
    top: 5rem;
    bottom: 5rem;
  }

  .m\:inset-y-24 {
    top: 6rem;
    bottom: 6rem;
  }

  .m\:inset-y-28 {
    top: 7rem;
    bottom: 7rem;
  }

  .m\:inset-y-32 {
    top: 8rem;
    bottom: 8rem;
  }

  .m\:inset-y-36 {
    top: 9rem;
    bottom: 9rem;
  }

  .m\:inset-y-40 {
    top: 10rem;
    bottom: 10rem;
  }

  .m\:inset-y-44 {
    top: 11rem;
    bottom: 11rem;
  }

  .m\:inset-y-48 {
    top: 12rem;
    bottom: 12rem;
  }

  .m\:inset-y-52 {
    top: 13rem;
    bottom: 13rem;
  }

  .m\:inset-y-56 {
    top: 14rem;
    bottom: 14rem;
  }

  .m\:inset-y-60 {
    top: 15rem;
    bottom: 15rem;
  }

  .m\:inset-y-64 {
    top: 16rem;
    bottom: 16rem;
  }

  .m\:inset-y-72 {
    top: 18rem;
    bottom: 18rem;
  }

  .m\:inset-y-80 {
    top: 20rem;
    bottom: 20rem;
  }

  .m\:inset-y-96 {
    top: 24rem;
    bottom: 24rem;
  }

  .m\:inset-y-auto {
    top: auto;
    bottom: auto;
  }

  .m\:inset-y-1\/2 {
    top: 50%;
    bottom: 50%;
  }

  .m\:inset-y-1\/3 {
    top: 33.333333%;
    bottom: 33.333333%;
  }

  .m\:inset-y-2\/3 {
    top: 66.666667%;
    bottom: 66.666667%;
  }

  .m\:inset-y-1\/4 {
    top: 25%;
    bottom: 25%;
  }

  .m\:inset-y-2\/4 {
    top: 50%;
    bottom: 50%;
  }

  .m\:inset-y-3\/4 {
    top: 75%;
    bottom: 75%;
  }

  .m\:inset-y-full {
    top: 100%;
    bottom: 100%;
  }

  .m\:-inset-y-px {
    top: -0.0625rem;
    bottom: -0.0625rem;
  }

  .m\:-inset-y-0 {
    top: 0;
    bottom: 0;
  }

  .m\:-inset-y-none {
    top: 0;
    bottom: 0;
  }

  .m\:-inset-y-0\.5 {
    top: -0.125rem;
    bottom: -0.125rem;
  }

  .m\:-inset-y-1 {
    top: -0.25rem;
    bottom: -0.25rem;
  }

  .m\:-inset-y-1\.5 {
    top: -0.375rem;
    bottom: -0.375rem;
  }

  .m\:-inset-y-2 {
    top: -0.5rem;
    bottom: -0.5rem;
  }

  .m\:-inset-y-2\.5 {
    top: -0.625rem;
    bottom: -0.625rem;
  }

  .m\:-inset-y-3 {
    top: -0.75rem;
    bottom: -0.75rem;
  }

  .m\:-inset-y-3\.5 {
    top: -0.875rem;
    bottom: -0.875rem;
  }

  .m\:-inset-y-4 {
    top: -1rem;
    bottom: -1rem;
  }

  .m\:-inset-y-5 {
    top: -1.25rem;
    bottom: -1.25rem;
  }

  .m\:-inset-y-6 {
    top: -1.5rem;
    bottom: -1.5rem;
  }

  .m\:-inset-y-7 {
    top: -1.75rem;
    bottom: -1.75rem;
  }

  .m\:-inset-y-8 {
    top: -2rem;
    bottom: -2rem;
  }

  .m\:-inset-y-9 {
    top: -2.25rem;
    bottom: -2.25rem;
  }

  .m\:-inset-y-10 {
    top: -2.5rem;
    bottom: -2.5rem;
  }

  .m\:-inset-y-11 {
    top: -2.75rem;
    bottom: -2.75rem;
  }

  .m\:-inset-y-12 {
    top: -3rem;
    bottom: -3rem;
  }

  .m\:-inset-y-14 {
    top: -3.5rem;
    bottom: -3.5rem;
  }

  .m\:-inset-y-16 {
    top: -4rem;
    bottom: -4rem;
  }

  .m\:-inset-y-18 {
    top: -4.5rem;
    bottom: -4.5rem;
  }

  .m\:-inset-y-20 {
    top: -5rem;
    bottom: -5rem;
  }

  .m\:-inset-y-24 {
    top: -6rem;
    bottom: -6rem;
  }

  .m\:-inset-y-28 {
    top: -7rem;
    bottom: -7rem;
  }

  .m\:-inset-y-32 {
    top: -8rem;
    bottom: -8rem;
  }

  .m\:-inset-y-36 {
    top: -9rem;
    bottom: -9rem;
  }

  .m\:-inset-y-40 {
    top: -10rem;
    bottom: -10rem;
  }

  .m\:-inset-y-44 {
    top: -11rem;
    bottom: -11rem;
  }

  .m\:-inset-y-48 {
    top: -12rem;
    bottom: -12rem;
  }

  .m\:-inset-y-52 {
    top: -13rem;
    bottom: -13rem;
  }

  .m\:-inset-y-56 {
    top: -14rem;
    bottom: -14rem;
  }

  .m\:-inset-y-60 {
    top: -15rem;
    bottom: -15rem;
  }

  .m\:-inset-y-64 {
    top: -16rem;
    bottom: -16rem;
  }

  .m\:-inset-y-72 {
    top: -18rem;
    bottom: -18rem;
  }

  .m\:-inset-y-80 {
    top: -20rem;
    bottom: -20rem;
  }

  .m\:-inset-y-96 {
    top: -24rem;
    bottom: -24rem;
  }

  .m\:-inset-y-1\/2 {
    top: -50%;
    bottom: -50%;
  }

  .m\:-inset-y-1\/3 {
    top: -33.333333%;
    bottom: -33.333333%;
  }

  .m\:-inset-y-2\/3 {
    top: -66.666667%;
    bottom: -66.666667%;
  }

  .m\:-inset-y-1\/4 {
    top: -25%;
    bottom: -25%;
  }

  .m\:-inset-y-2\/4 {
    top: -50%;
    bottom: -50%;
  }

  .m\:-inset-y-3\/4 {
    top: -75%;
    bottom: -75%;
  }

  .m\:-inset-y-full {
    top: -100%;
    bottom: -100%;
  }
}
@media (min-width: 769px) {
  .pc\:top-px {
    top: 0.0625rem;
  }

  .pc\:top-0 {
    top: 0;
  }

  .pc\:top-none {
    top: 0;
  }

  .pc\:top-0\.5 {
    top: 0.125rem;
  }

  .pc\:top-1 {
    top: 0.25rem;
  }

  .pc\:top-1\.5 {
    top: 0.375rem;
  }

  .pc\:top-2 {
    top: 0.5rem;
  }

  .pc\:top-2\.5 {
    top: 0.625rem;
  }

  .pc\:top-3 {
    top: 0.75rem;
  }

  .pc\:top-3\.5 {
    top: 0.875rem;
  }

  .pc\:top-4 {
    top: 1rem;
  }

  .pc\:top-5 {
    top: 1.25rem;
  }

  .pc\:top-6 {
    top: 1.5rem;
  }

  .pc\:top-7 {
    top: 1.75rem;
  }

  .pc\:top-8 {
    top: 2rem;
  }

  .pc\:top-9 {
    top: 2.25rem;
  }

  .pc\:top-10 {
    top: 2.5rem;
  }

  .pc\:top-11 {
    top: 2.75rem;
  }

  .pc\:top-12 {
    top: 3rem;
  }

  .pc\:top-14 {
    top: 3.5rem;
  }

  .pc\:top-16 {
    top: 4rem;
  }

  .pc\:top-18 {
    top: 4.5rem;
  }

  .pc\:top-20 {
    top: 5rem;
  }

  .pc\:top-24 {
    top: 6rem;
  }

  .pc\:top-28 {
    top: 7rem;
  }

  .pc\:top-32 {
    top: 8rem;
  }

  .pc\:top-36 {
    top: 9rem;
  }

  .pc\:top-40 {
    top: 10rem;
  }

  .pc\:top-44 {
    top: 11rem;
  }

  .pc\:top-48 {
    top: 12rem;
  }

  .pc\:top-52 {
    top: 13rem;
  }

  .pc\:top-56 {
    top: 14rem;
  }

  .pc\:top-60 {
    top: 15rem;
  }

  .pc\:top-64 {
    top: 16rem;
  }

  .pc\:top-72 {
    top: 18rem;
  }

  .pc\:top-80 {
    top: 20rem;
  }

  .pc\:top-96 {
    top: 24rem;
  }

  .pc\:top-auto {
    top: auto;
  }

  .pc\:top-1\/2 {
    top: 50%;
  }

  .pc\:top-1\/3 {
    top: 33.333333%;
  }

  .pc\:top-2\/3 {
    top: 66.666667%;
  }

  .pc\:top-1\/4 {
    top: 25%;
  }

  .pc\:top-2\/4 {
    top: 50%;
  }

  .pc\:top-3\/4 {
    top: 75%;
  }

  .pc\:top-full {
    top: 100%;
  }

  .pc\:-top-px {
    top: -0.0625rem;
  }

  .pc\:-top-0 {
    top: 0;
  }

  .pc\:-top-none {
    top: 0;
  }

  .pc\:-top-0\.5 {
    top: -0.125rem;
  }

  .pc\:-top-1 {
    top: -0.25rem;
  }

  .pc\:-top-1\.5 {
    top: -0.375rem;
  }

  .pc\:-top-2 {
    top: -0.5rem;
  }

  .pc\:-top-2\.5 {
    top: -0.625rem;
  }

  .pc\:-top-3 {
    top: -0.75rem;
  }

  .pc\:-top-3\.5 {
    top: -0.875rem;
  }

  .pc\:-top-4 {
    top: -1rem;
  }

  .pc\:-top-5 {
    top: -1.25rem;
  }

  .pc\:-top-6 {
    top: -1.5rem;
  }

  .pc\:-top-7 {
    top: -1.75rem;
  }

  .pc\:-top-8 {
    top: -2rem;
  }

  .pc\:-top-9 {
    top: -2.25rem;
  }

  .pc\:-top-10 {
    top: -2.5rem;
  }

  .pc\:-top-11 {
    top: -2.75rem;
  }

  .pc\:-top-12 {
    top: -3rem;
  }

  .pc\:-top-14 {
    top: -3.5rem;
  }

  .pc\:-top-16 {
    top: -4rem;
  }

  .pc\:-top-18 {
    top: -4.5rem;
  }

  .pc\:-top-20 {
    top: -5rem;
  }

  .pc\:-top-24 {
    top: -6rem;
  }

  .pc\:-top-28 {
    top: -7rem;
  }

  .pc\:-top-32 {
    top: -8rem;
  }

  .pc\:-top-36 {
    top: -9rem;
  }

  .pc\:-top-40 {
    top: -10rem;
  }

  .pc\:-top-44 {
    top: -11rem;
  }

  .pc\:-top-48 {
    top: -12rem;
  }

  .pc\:-top-52 {
    top: -13rem;
  }

  .pc\:-top-56 {
    top: -14rem;
  }

  .pc\:-top-60 {
    top: -15rem;
  }

  .pc\:-top-64 {
    top: -16rem;
  }

  .pc\:-top-72 {
    top: -18rem;
  }

  .pc\:-top-80 {
    top: -20rem;
  }

  .pc\:-top-96 {
    top: -24rem;
  }

  .pc\:-top-1\/2 {
    top: -50%;
  }

  .pc\:-top-1\/3 {
    top: -33.333333%;
  }

  .pc\:-top-2\/3 {
    top: -66.666667%;
  }

  .pc\:-top-1\/4 {
    top: -25%;
  }

  .pc\:-top-2\/4 {
    top: -50%;
  }

  .pc\:-top-3\/4 {
    top: -75%;
  }

  .pc\:-top-full {
    top: -100%;
  }

  .pc\:right-px {
    right: 0.0625rem;
  }

  .pc\:right-0 {
    right: 0;
  }

  .pc\:right-none {
    right: 0;
  }

  .pc\:right-0\.5 {
    right: 0.125rem;
  }

  .pc\:right-1 {
    right: 0.25rem;
  }

  .pc\:right-1\.5 {
    right: 0.375rem;
  }

  .pc\:right-2 {
    right: 0.5rem;
  }

  .pc\:right-2\.5 {
    right: 0.625rem;
  }

  .pc\:right-3 {
    right: 0.75rem;
  }

  .pc\:right-3\.5 {
    right: 0.875rem;
  }

  .pc\:right-4 {
    right: 1rem;
  }

  .pc\:right-5 {
    right: 1.25rem;
  }

  .pc\:right-6 {
    right: 1.5rem;
  }

  .pc\:right-7 {
    right: 1.75rem;
  }

  .pc\:right-8 {
    right: 2rem;
  }

  .pc\:right-9 {
    right: 2.25rem;
  }

  .pc\:right-10 {
    right: 2.5rem;
  }

  .pc\:right-11 {
    right: 2.75rem;
  }

  .pc\:right-12 {
    right: 3rem;
  }

  .pc\:right-14 {
    right: 3.5rem;
  }

  .pc\:right-16 {
    right: 4rem;
  }

  .pc\:right-18 {
    right: 4.5rem;
  }

  .pc\:right-20 {
    right: 5rem;
  }

  .pc\:right-24 {
    right: 6rem;
  }

  .pc\:right-28 {
    right: 7rem;
  }

  .pc\:right-32 {
    right: 8rem;
  }

  .pc\:right-36 {
    right: 9rem;
  }

  .pc\:right-40 {
    right: 10rem;
  }

  .pc\:right-44 {
    right: 11rem;
  }

  .pc\:right-48 {
    right: 12rem;
  }

  .pc\:right-52 {
    right: 13rem;
  }

  .pc\:right-56 {
    right: 14rem;
  }

  .pc\:right-60 {
    right: 15rem;
  }

  .pc\:right-64 {
    right: 16rem;
  }

  .pc\:right-72 {
    right: 18rem;
  }

  .pc\:right-80 {
    right: 20rem;
  }

  .pc\:right-96 {
    right: 24rem;
  }

  .pc\:right-auto {
    right: auto;
  }

  .pc\:right-1\/2 {
    right: 50%;
  }

  .pc\:right-1\/3 {
    right: 33.333333%;
  }

  .pc\:right-2\/3 {
    right: 66.666667%;
  }

  .pc\:right-1\/4 {
    right: 25%;
  }

  .pc\:right-2\/4 {
    right: 50%;
  }

  .pc\:right-3\/4 {
    right: 75%;
  }

  .pc\:right-full {
    right: 100%;
  }

  .pc\:-right-px {
    right: -0.0625rem;
  }

  .pc\:-right-0 {
    right: 0;
  }

  .pc\:-right-none {
    right: 0;
  }

  .pc\:-right-0\.5 {
    right: -0.125rem;
  }

  .pc\:-right-1 {
    right: -0.25rem;
  }

  .pc\:-right-1\.5 {
    right: -0.375rem;
  }

  .pc\:-right-2 {
    right: -0.5rem;
  }

  .pc\:-right-2\.5 {
    right: -0.625rem;
  }

  .pc\:-right-3 {
    right: -0.75rem;
  }

  .pc\:-right-3\.5 {
    right: -0.875rem;
  }

  .pc\:-right-4 {
    right: -1rem;
  }

  .pc\:-right-5 {
    right: -1.25rem;
  }

  .pc\:-right-6 {
    right: -1.5rem;
  }

  .pc\:-right-7 {
    right: -1.75rem;
  }

  .pc\:-right-8 {
    right: -2rem;
  }

  .pc\:-right-9 {
    right: -2.25rem;
  }

  .pc\:-right-10 {
    right: -2.5rem;
  }

  .pc\:-right-11 {
    right: -2.75rem;
  }

  .pc\:-right-12 {
    right: -3rem;
  }

  .pc\:-right-14 {
    right: -3.5rem;
  }

  .pc\:-right-16 {
    right: -4rem;
  }

  .pc\:-right-18 {
    right: -4.5rem;
  }

  .pc\:-right-20 {
    right: -5rem;
  }

  .pc\:-right-24 {
    right: -6rem;
  }

  .pc\:-right-28 {
    right: -7rem;
  }

  .pc\:-right-32 {
    right: -8rem;
  }

  .pc\:-right-36 {
    right: -9rem;
  }

  .pc\:-right-40 {
    right: -10rem;
  }

  .pc\:-right-44 {
    right: -11rem;
  }

  .pc\:-right-48 {
    right: -12rem;
  }

  .pc\:-right-52 {
    right: -13rem;
  }

  .pc\:-right-56 {
    right: -14rem;
  }

  .pc\:-right-60 {
    right: -15rem;
  }

  .pc\:-right-64 {
    right: -16rem;
  }

  .pc\:-right-72 {
    right: -18rem;
  }

  .pc\:-right-80 {
    right: -20rem;
  }

  .pc\:-right-96 {
    right: -24rem;
  }

  .pc\:-right-1\/2 {
    right: -50%;
  }

  .pc\:-right-1\/3 {
    right: -33.333333%;
  }

  .pc\:-right-2\/3 {
    right: -66.666667%;
  }

  .pc\:-right-1\/4 {
    right: -25%;
  }

  .pc\:-right-2\/4 {
    right: -50%;
  }

  .pc\:-right-3\/4 {
    right: -75%;
  }

  .pc\:-right-full {
    right: -100%;
  }

  .pc\:bottom-px {
    bottom: 0.0625rem;
  }

  .pc\:bottom-0 {
    bottom: 0;
  }

  .pc\:bottom-none {
    bottom: 0;
  }

  .pc\:bottom-0\.5 {
    bottom: 0.125rem;
  }

  .pc\:bottom-1 {
    bottom: 0.25rem;
  }

  .pc\:bottom-1\.5 {
    bottom: 0.375rem;
  }

  .pc\:bottom-2 {
    bottom: 0.5rem;
  }

  .pc\:bottom-2\.5 {
    bottom: 0.625rem;
  }

  .pc\:bottom-3 {
    bottom: 0.75rem;
  }

  .pc\:bottom-3\.5 {
    bottom: 0.875rem;
  }

  .pc\:bottom-4 {
    bottom: 1rem;
  }

  .pc\:bottom-5 {
    bottom: 1.25rem;
  }

  .pc\:bottom-6 {
    bottom: 1.5rem;
  }

  .pc\:bottom-7 {
    bottom: 1.75rem;
  }

  .pc\:bottom-8 {
    bottom: 2rem;
  }

  .pc\:bottom-9 {
    bottom: 2.25rem;
  }

  .pc\:bottom-10 {
    bottom: 2.5rem;
  }

  .pc\:bottom-11 {
    bottom: 2.75rem;
  }

  .pc\:bottom-12 {
    bottom: 3rem;
  }

  .pc\:bottom-14 {
    bottom: 3.5rem;
  }

  .pc\:bottom-16 {
    bottom: 4rem;
  }

  .pc\:bottom-18 {
    bottom: 4.5rem;
  }

  .pc\:bottom-20 {
    bottom: 5rem;
  }

  .pc\:bottom-24 {
    bottom: 6rem;
  }

  .pc\:bottom-28 {
    bottom: 7rem;
  }

  .pc\:bottom-32 {
    bottom: 8rem;
  }

  .pc\:bottom-36 {
    bottom: 9rem;
  }

  .pc\:bottom-40 {
    bottom: 10rem;
  }

  .pc\:bottom-44 {
    bottom: 11rem;
  }

  .pc\:bottom-48 {
    bottom: 12rem;
  }

  .pc\:bottom-52 {
    bottom: 13rem;
  }

  .pc\:bottom-56 {
    bottom: 14rem;
  }

  .pc\:bottom-60 {
    bottom: 15rem;
  }

  .pc\:bottom-64 {
    bottom: 16rem;
  }

  .pc\:bottom-72 {
    bottom: 18rem;
  }

  .pc\:bottom-80 {
    bottom: 20rem;
  }

  .pc\:bottom-96 {
    bottom: 24rem;
  }

  .pc\:bottom-auto {
    bottom: auto;
  }

  .pc\:bottom-1\/2 {
    bottom: 50%;
  }

  .pc\:bottom-1\/3 {
    bottom: 33.333333%;
  }

  .pc\:bottom-2\/3 {
    bottom: 66.666667%;
  }

  .pc\:bottom-1\/4 {
    bottom: 25%;
  }

  .pc\:bottom-2\/4 {
    bottom: 50%;
  }

  .pc\:bottom-3\/4 {
    bottom: 75%;
  }

  .pc\:bottom-full {
    bottom: 100%;
  }

  .pc\:-bottom-px {
    bottom: -0.0625rem;
  }

  .pc\:-bottom-0 {
    bottom: 0;
  }

  .pc\:-bottom-none {
    bottom: 0;
  }

  .pc\:-bottom-0\.5 {
    bottom: -0.125rem;
  }

  .pc\:-bottom-1 {
    bottom: -0.25rem;
  }

  .pc\:-bottom-1\.5 {
    bottom: -0.375rem;
  }

  .pc\:-bottom-2 {
    bottom: -0.5rem;
  }

  .pc\:-bottom-2\.5 {
    bottom: -0.625rem;
  }

  .pc\:-bottom-3 {
    bottom: -0.75rem;
  }

  .pc\:-bottom-3\.5 {
    bottom: -0.875rem;
  }

  .pc\:-bottom-4 {
    bottom: -1rem;
  }

  .pc\:-bottom-5 {
    bottom: -1.25rem;
  }

  .pc\:-bottom-6 {
    bottom: -1.5rem;
  }

  .pc\:-bottom-7 {
    bottom: -1.75rem;
  }

  .pc\:-bottom-8 {
    bottom: -2rem;
  }

  .pc\:-bottom-9 {
    bottom: -2.25rem;
  }

  .pc\:-bottom-10 {
    bottom: -2.5rem;
  }

  .pc\:-bottom-11 {
    bottom: -2.75rem;
  }

  .pc\:-bottom-12 {
    bottom: -3rem;
  }

  .pc\:-bottom-14 {
    bottom: -3.5rem;
  }

  .pc\:-bottom-16 {
    bottom: -4rem;
  }

  .pc\:-bottom-18 {
    bottom: -4.5rem;
  }

  .pc\:-bottom-20 {
    bottom: -5rem;
  }

  .pc\:-bottom-24 {
    bottom: -6rem;
  }

  .pc\:-bottom-28 {
    bottom: -7rem;
  }

  .pc\:-bottom-32 {
    bottom: -8rem;
  }

  .pc\:-bottom-36 {
    bottom: -9rem;
  }

  .pc\:-bottom-40 {
    bottom: -10rem;
  }

  .pc\:-bottom-44 {
    bottom: -11rem;
  }

  .pc\:-bottom-48 {
    bottom: -12rem;
  }

  .pc\:-bottom-52 {
    bottom: -13rem;
  }

  .pc\:-bottom-56 {
    bottom: -14rem;
  }

  .pc\:-bottom-60 {
    bottom: -15rem;
  }

  .pc\:-bottom-64 {
    bottom: -16rem;
  }

  .pc\:-bottom-72 {
    bottom: -18rem;
  }

  .pc\:-bottom-80 {
    bottom: -20rem;
  }

  .pc\:-bottom-96 {
    bottom: -24rem;
  }

  .pc\:-bottom-1\/2 {
    bottom: -50%;
  }

  .pc\:-bottom-1\/3 {
    bottom: -33.333333%;
  }

  .pc\:-bottom-2\/3 {
    bottom: -66.666667%;
  }

  .pc\:-bottom-1\/4 {
    bottom: -25%;
  }

  .pc\:-bottom-2\/4 {
    bottom: -50%;
  }

  .pc\:-bottom-3\/4 {
    bottom: -75%;
  }

  .pc\:-bottom-full {
    bottom: -100%;
  }

  .pc\:left-px {
    left: 0.0625rem;
  }

  .pc\:left-0 {
    left: 0;
  }

  .pc\:left-none {
    left: 0;
  }

  .pc\:left-0\.5 {
    left: 0.125rem;
  }

  .pc\:left-1 {
    left: 0.25rem;
  }

  .pc\:left-1\.5 {
    left: 0.375rem;
  }

  .pc\:left-2 {
    left: 0.5rem;
  }

  .pc\:left-2\.5 {
    left: 0.625rem;
  }

  .pc\:left-3 {
    left: 0.75rem;
  }

  .pc\:left-3\.5 {
    left: 0.875rem;
  }

  .pc\:left-4 {
    left: 1rem;
  }

  .pc\:left-5 {
    left: 1.25rem;
  }

  .pc\:left-6 {
    left: 1.5rem;
  }

  .pc\:left-7 {
    left: 1.75rem;
  }

  .pc\:left-8 {
    left: 2rem;
  }

  .pc\:left-9 {
    left: 2.25rem;
  }

  .pc\:left-10 {
    left: 2.5rem;
  }

  .pc\:left-11 {
    left: 2.75rem;
  }

  .pc\:left-12 {
    left: 3rem;
  }

  .pc\:left-14 {
    left: 3.5rem;
  }

  .pc\:left-16 {
    left: 4rem;
  }

  .pc\:left-18 {
    left: 4.5rem;
  }

  .pc\:left-20 {
    left: 5rem;
  }

  .pc\:left-24 {
    left: 6rem;
  }

  .pc\:left-28 {
    left: 7rem;
  }

  .pc\:left-32 {
    left: 8rem;
  }

  .pc\:left-36 {
    left: 9rem;
  }

  .pc\:left-40 {
    left: 10rem;
  }

  .pc\:left-44 {
    left: 11rem;
  }

  .pc\:left-48 {
    left: 12rem;
  }

  .pc\:left-52 {
    left: 13rem;
  }

  .pc\:left-56 {
    left: 14rem;
  }

  .pc\:left-60 {
    left: 15rem;
  }

  .pc\:left-64 {
    left: 16rem;
  }

  .pc\:left-72 {
    left: 18rem;
  }

  .pc\:left-80 {
    left: 20rem;
  }

  .pc\:left-96 {
    left: 24rem;
  }

  .pc\:left-auto {
    left: auto;
  }

  .pc\:left-1\/2 {
    left: 50%;
  }

  .pc\:left-1\/3 {
    left: 33.333333%;
  }

  .pc\:left-2\/3 {
    left: 66.666667%;
  }

  .pc\:left-1\/4 {
    left: 25%;
  }

  .pc\:left-2\/4 {
    left: 50%;
  }

  .pc\:left-3\/4 {
    left: 75%;
  }

  .pc\:left-full {
    left: 100%;
  }

  .pc\:-left-px {
    left: -0.0625rem;
  }

  .pc\:-left-0 {
    left: 0;
  }

  .pc\:-left-none {
    left: 0;
  }

  .pc\:-left-0\.5 {
    left: -0.125rem;
  }

  .pc\:-left-1 {
    left: -0.25rem;
  }

  .pc\:-left-1\.5 {
    left: -0.375rem;
  }

  .pc\:-left-2 {
    left: -0.5rem;
  }

  .pc\:-left-2\.5 {
    left: -0.625rem;
  }

  .pc\:-left-3 {
    left: -0.75rem;
  }

  .pc\:-left-3\.5 {
    left: -0.875rem;
  }

  .pc\:-left-4 {
    left: -1rem;
  }

  .pc\:-left-5 {
    left: -1.25rem;
  }

  .pc\:-left-6 {
    left: -1.5rem;
  }

  .pc\:-left-7 {
    left: -1.75rem;
  }

  .pc\:-left-8 {
    left: -2rem;
  }

  .pc\:-left-9 {
    left: -2.25rem;
  }

  .pc\:-left-10 {
    left: -2.5rem;
  }

  .pc\:-left-11 {
    left: -2.75rem;
  }

  .pc\:-left-12 {
    left: -3rem;
  }

  .pc\:-left-14 {
    left: -3.5rem;
  }

  .pc\:-left-16 {
    left: -4rem;
  }

  .pc\:-left-18 {
    left: -4.5rem;
  }

  .pc\:-left-20 {
    left: -5rem;
  }

  .pc\:-left-24 {
    left: -6rem;
  }

  .pc\:-left-28 {
    left: -7rem;
  }

  .pc\:-left-32 {
    left: -8rem;
  }

  .pc\:-left-36 {
    left: -9rem;
  }

  .pc\:-left-40 {
    left: -10rem;
  }

  .pc\:-left-44 {
    left: -11rem;
  }

  .pc\:-left-48 {
    left: -12rem;
  }

  .pc\:-left-52 {
    left: -13rem;
  }

  .pc\:-left-56 {
    left: -14rem;
  }

  .pc\:-left-60 {
    left: -15rem;
  }

  .pc\:-left-64 {
    left: -16rem;
  }

  .pc\:-left-72 {
    left: -18rem;
  }

  .pc\:-left-80 {
    left: -20rem;
  }

  .pc\:-left-96 {
    left: -24rem;
  }

  .pc\:-left-1\/2 {
    left: -50%;
  }

  .pc\:-left-1\/3 {
    left: -33.333333%;
  }

  .pc\:-left-2\/3 {
    left: -66.666667%;
  }

  .pc\:-left-1\/4 {
    left: -25%;
  }

  .pc\:-left-2\/4 {
    left: -50%;
  }

  .pc\:-left-3\/4 {
    left: -75%;
  }

  .pc\:-left-full {
    left: -100%;
  }

  .pc\:inset-px {
    top: 0.0625rem;
    right: 0.0625rem;
    bottom: 0.0625rem;
    left: 0.0625rem;
  }

  .pc\:inset-0 {
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
  }

  .pc\:inset-none {
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
  }

  .pc\:inset-0\.5 {
    top: 0.125rem;
    right: 0.125rem;
    bottom: 0.125rem;
    left: 0.125rem;
  }

  .pc\:inset-1 {
    top: 0.25rem;
    right: 0.25rem;
    bottom: 0.25rem;
    left: 0.25rem;
  }

  .pc\:inset-1\.5 {
    top: 0.375rem;
    right: 0.375rem;
    bottom: 0.375rem;
    left: 0.375rem;
  }

  .pc\:inset-2 {
    top: 0.5rem;
    right: 0.5rem;
    bottom: 0.5rem;
    left: 0.5rem;
  }

  .pc\:inset-2\.5 {
    top: 0.625rem;
    right: 0.625rem;
    bottom: 0.625rem;
    left: 0.625rem;
  }

  .pc\:inset-3 {
    top: 0.75rem;
    right: 0.75rem;
    bottom: 0.75rem;
    left: 0.75rem;
  }

  .pc\:inset-3\.5 {
    top: 0.875rem;
    right: 0.875rem;
    bottom: 0.875rem;
    left: 0.875rem;
  }

  .pc\:inset-4 {
    top: 1rem;
    right: 1rem;
    bottom: 1rem;
    left: 1rem;
  }

  .pc\:inset-5 {
    top: 1.25rem;
    right: 1.25rem;
    bottom: 1.25rem;
    left: 1.25rem;
  }

  .pc\:inset-6 {
    top: 1.5rem;
    right: 1.5rem;
    bottom: 1.5rem;
    left: 1.5rem;
  }

  .pc\:inset-7 {
    top: 1.75rem;
    right: 1.75rem;
    bottom: 1.75rem;
    left: 1.75rem;
  }

  .pc\:inset-8 {
    top: 2rem;
    right: 2rem;
    bottom: 2rem;
    left: 2rem;
  }

  .pc\:inset-9 {
    top: 2.25rem;
    right: 2.25rem;
    bottom: 2.25rem;
    left: 2.25rem;
  }

  .pc\:inset-10 {
    top: 2.5rem;
    right: 2.5rem;
    bottom: 2.5rem;
    left: 2.5rem;
  }

  .pc\:inset-11 {
    top: 2.75rem;
    right: 2.75rem;
    bottom: 2.75rem;
    left: 2.75rem;
  }

  .pc\:inset-12 {
    top: 3rem;
    right: 3rem;
    bottom: 3rem;
    left: 3rem;
  }

  .pc\:inset-14 {
    top: 3.5rem;
    right: 3.5rem;
    bottom: 3.5rem;
    left: 3.5rem;
  }

  .pc\:inset-16 {
    top: 4rem;
    right: 4rem;
    bottom: 4rem;
    left: 4rem;
  }

  .pc\:inset-18 {
    top: 4.5rem;
    right: 4.5rem;
    bottom: 4.5rem;
    left: 4.5rem;
  }

  .pc\:inset-20 {
    top: 5rem;
    right: 5rem;
    bottom: 5rem;
    left: 5rem;
  }

  .pc\:inset-24 {
    top: 6rem;
    right: 6rem;
    bottom: 6rem;
    left: 6rem;
  }

  .pc\:inset-28 {
    top: 7rem;
    right: 7rem;
    bottom: 7rem;
    left: 7rem;
  }

  .pc\:inset-32 {
    top: 8rem;
    right: 8rem;
    bottom: 8rem;
    left: 8rem;
  }

  .pc\:inset-36 {
    top: 9rem;
    right: 9rem;
    bottom: 9rem;
    left: 9rem;
  }

  .pc\:inset-40 {
    top: 10rem;
    right: 10rem;
    bottom: 10rem;
    left: 10rem;
  }

  .pc\:inset-44 {
    top: 11rem;
    right: 11rem;
    bottom: 11rem;
    left: 11rem;
  }

  .pc\:inset-48 {
    top: 12rem;
    right: 12rem;
    bottom: 12rem;
    left: 12rem;
  }

  .pc\:inset-52 {
    top: 13rem;
    right: 13rem;
    bottom: 13rem;
    left: 13rem;
  }

  .pc\:inset-56 {
    top: 14rem;
    right: 14rem;
    bottom: 14rem;
    left: 14rem;
  }

  .pc\:inset-60 {
    top: 15rem;
    right: 15rem;
    bottom: 15rem;
    left: 15rem;
  }

  .pc\:inset-64 {
    top: 16rem;
    right: 16rem;
    bottom: 16rem;
    left: 16rem;
  }

  .pc\:inset-72 {
    top: 18rem;
    right: 18rem;
    bottom: 18rem;
    left: 18rem;
  }

  .pc\:inset-80 {
    top: 20rem;
    right: 20rem;
    bottom: 20rem;
    left: 20rem;
  }

  .pc\:inset-96 {
    top: 24rem;
    right: 24rem;
    bottom: 24rem;
    left: 24rem;
  }

  .pc\:inset-auto {
    top: auto;
    right: auto;
    bottom: auto;
    left: auto;
  }

  .pc\:inset-1\/2 {
    top: 50%;
    right: 50%;
    bottom: 50%;
    left: 50%;
  }

  .pc\:inset-1\/3 {
    top: 33.333333%;
    right: 33.333333%;
    bottom: 33.333333%;
    left: 33.333333%;
  }

  .pc\:inset-2\/3 {
    top: 66.666667%;
    right: 66.666667%;
    bottom: 66.666667%;
    left: 66.666667%;
  }

  .pc\:inset-1\/4 {
    top: 25%;
    right: 25%;
    bottom: 25%;
    left: 25%;
  }

  .pc\:inset-2\/4 {
    top: 50%;
    right: 50%;
    bottom: 50%;
    left: 50%;
  }

  .pc\:inset-3\/4 {
    top: 75%;
    right: 75%;
    bottom: 75%;
    left: 75%;
  }

  .pc\:inset-full {
    top: 100%;
    right: 100%;
    bottom: 100%;
    left: 100%;
  }

  .pc\:-inset-px {
    top: -0.0625rem;
    right: -0.0625rem;
    bottom: -0.0625rem;
    left: -0.0625rem;
  }

  .pc\:-inset-0 {
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
  }

  .pc\:-inset-none {
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
  }

  .pc\:-inset-0\.5 {
    top: -0.125rem;
    right: -0.125rem;
    bottom: -0.125rem;
    left: -0.125rem;
  }

  .pc\:-inset-1 {
    top: -0.25rem;
    right: -0.25rem;
    bottom: -0.25rem;
    left: -0.25rem;
  }

  .pc\:-inset-1\.5 {
    top: -0.375rem;
    right: -0.375rem;
    bottom: -0.375rem;
    left: -0.375rem;
  }

  .pc\:-inset-2 {
    top: -0.5rem;
    right: -0.5rem;
    bottom: -0.5rem;
    left: -0.5rem;
  }

  .pc\:-inset-2\.5 {
    top: -0.625rem;
    right: -0.625rem;
    bottom: -0.625rem;
    left: -0.625rem;
  }

  .pc\:-inset-3 {
    top: -0.75rem;
    right: -0.75rem;
    bottom: -0.75rem;
    left: -0.75rem;
  }

  .pc\:-inset-3\.5 {
    top: -0.875rem;
    right: -0.875rem;
    bottom: -0.875rem;
    left: -0.875rem;
  }

  .pc\:-inset-4 {
    top: -1rem;
    right: -1rem;
    bottom: -1rem;
    left: -1rem;
  }

  .pc\:-inset-5 {
    top: -1.25rem;
    right: -1.25rem;
    bottom: -1.25rem;
    left: -1.25rem;
  }

  .pc\:-inset-6 {
    top: -1.5rem;
    right: -1.5rem;
    bottom: -1.5rem;
    left: -1.5rem;
  }

  .pc\:-inset-7 {
    top: -1.75rem;
    right: -1.75rem;
    bottom: -1.75rem;
    left: -1.75rem;
  }

  .pc\:-inset-8 {
    top: -2rem;
    right: -2rem;
    bottom: -2rem;
    left: -2rem;
  }

  .pc\:-inset-9 {
    top: -2.25rem;
    right: -2.25rem;
    bottom: -2.25rem;
    left: -2.25rem;
  }

  .pc\:-inset-10 {
    top: -2.5rem;
    right: -2.5rem;
    bottom: -2.5rem;
    left: -2.5rem;
  }

  .pc\:-inset-11 {
    top: -2.75rem;
    right: -2.75rem;
    bottom: -2.75rem;
    left: -2.75rem;
  }

  .pc\:-inset-12 {
    top: -3rem;
    right: -3rem;
    bottom: -3rem;
    left: -3rem;
  }

  .pc\:-inset-14 {
    top: -3.5rem;
    right: -3.5rem;
    bottom: -3.5rem;
    left: -3.5rem;
  }

  .pc\:-inset-16 {
    top: -4rem;
    right: -4rem;
    bottom: -4rem;
    left: -4rem;
  }

  .pc\:-inset-18 {
    top: -4.5rem;
    right: -4.5rem;
    bottom: -4.5rem;
    left: -4.5rem;
  }

  .pc\:-inset-20 {
    top: -5rem;
    right: -5rem;
    bottom: -5rem;
    left: -5rem;
  }

  .pc\:-inset-24 {
    top: -6rem;
    right: -6rem;
    bottom: -6rem;
    left: -6rem;
  }

  .pc\:-inset-28 {
    top: -7rem;
    right: -7rem;
    bottom: -7rem;
    left: -7rem;
  }

  .pc\:-inset-32 {
    top: -8rem;
    right: -8rem;
    bottom: -8rem;
    left: -8rem;
  }

  .pc\:-inset-36 {
    top: -9rem;
    right: -9rem;
    bottom: -9rem;
    left: -9rem;
  }

  .pc\:-inset-40 {
    top: -10rem;
    right: -10rem;
    bottom: -10rem;
    left: -10rem;
  }

  .pc\:-inset-44 {
    top: -11rem;
    right: -11rem;
    bottom: -11rem;
    left: -11rem;
  }

  .pc\:-inset-48 {
    top: -12rem;
    right: -12rem;
    bottom: -12rem;
    left: -12rem;
  }

  .pc\:-inset-52 {
    top: -13rem;
    right: -13rem;
    bottom: -13rem;
    left: -13rem;
  }

  .pc\:-inset-56 {
    top: -14rem;
    right: -14rem;
    bottom: -14rem;
    left: -14rem;
  }

  .pc\:-inset-60 {
    top: -15rem;
    right: -15rem;
    bottom: -15rem;
    left: -15rem;
  }

  .pc\:-inset-64 {
    top: -16rem;
    right: -16rem;
    bottom: -16rem;
    left: -16rem;
  }

  .pc\:-inset-72 {
    top: -18rem;
    right: -18rem;
    bottom: -18rem;
    left: -18rem;
  }

  .pc\:-inset-80 {
    top: -20rem;
    right: -20rem;
    bottom: -20rem;
    left: -20rem;
  }

  .pc\:-inset-96 {
    top: -24rem;
    right: -24rem;
    bottom: -24rem;
    left: -24rem;
  }

  .pc\:-inset-1\/2 {
    top: -50%;
    right: -50%;
    bottom: -50%;
    left: -50%;
  }

  .pc\:-inset-1\/3 {
    top: -33.333333%;
    right: -33.333333%;
    bottom: -33.333333%;
    left: -33.333333%;
  }

  .pc\:-inset-2\/3 {
    top: -66.666667%;
    right: -66.666667%;
    bottom: -66.666667%;
    left: -66.666667%;
  }

  .pc\:-inset-1\/4 {
    top: -25%;
    right: -25%;
    bottom: -25%;
    left: -25%;
  }

  .pc\:-inset-2\/4 {
    top: -50%;
    right: -50%;
    bottom: -50%;
    left: -50%;
  }

  .pc\:-inset-3\/4 {
    top: -75%;
    right: -75%;
    bottom: -75%;
    left: -75%;
  }

  .pc\:-inset-full {
    top: -100%;
    right: -100%;
    bottom: -100%;
    left: -100%;
  }

  .pc\:inset-x-px {
    right: 0.0625rem;
    left: 0.0625rem;
  }

  .pc\:inset-x-0 {
    right: 0;
    left: 0;
  }

  .pc\:inset-x-none {
    right: 0;
    left: 0;
  }

  .pc\:inset-x-0\.5 {
    right: 0.125rem;
    left: 0.125rem;
  }

  .pc\:inset-x-1 {
    right: 0.25rem;
    left: 0.25rem;
  }

  .pc\:inset-x-1\.5 {
    right: 0.375rem;
    left: 0.375rem;
  }

  .pc\:inset-x-2 {
    right: 0.5rem;
    left: 0.5rem;
  }

  .pc\:inset-x-2\.5 {
    right: 0.625rem;
    left: 0.625rem;
  }

  .pc\:inset-x-3 {
    right: 0.75rem;
    left: 0.75rem;
  }

  .pc\:inset-x-3\.5 {
    right: 0.875rem;
    left: 0.875rem;
  }

  .pc\:inset-x-4 {
    right: 1rem;
    left: 1rem;
  }

  .pc\:inset-x-5 {
    right: 1.25rem;
    left: 1.25rem;
  }

  .pc\:inset-x-6 {
    right: 1.5rem;
    left: 1.5rem;
  }

  .pc\:inset-x-7 {
    right: 1.75rem;
    left: 1.75rem;
  }

  .pc\:inset-x-8 {
    right: 2rem;
    left: 2rem;
  }

  .pc\:inset-x-9 {
    right: 2.25rem;
    left: 2.25rem;
  }

  .pc\:inset-x-10 {
    right: 2.5rem;
    left: 2.5rem;
  }

  .pc\:inset-x-11 {
    right: 2.75rem;
    left: 2.75rem;
  }

  .pc\:inset-x-12 {
    right: 3rem;
    left: 3rem;
  }

  .pc\:inset-x-14 {
    right: 3.5rem;
    left: 3.5rem;
  }

  .pc\:inset-x-16 {
    right: 4rem;
    left: 4rem;
  }

  .pc\:inset-x-18 {
    right: 4.5rem;
    left: 4.5rem;
  }

  .pc\:inset-x-20 {
    right: 5rem;
    left: 5rem;
  }

  .pc\:inset-x-24 {
    right: 6rem;
    left: 6rem;
  }

  .pc\:inset-x-28 {
    right: 7rem;
    left: 7rem;
  }

  .pc\:inset-x-32 {
    right: 8rem;
    left: 8rem;
  }

  .pc\:inset-x-36 {
    right: 9rem;
    left: 9rem;
  }

  .pc\:inset-x-40 {
    right: 10rem;
    left: 10rem;
  }

  .pc\:inset-x-44 {
    right: 11rem;
    left: 11rem;
  }

  .pc\:inset-x-48 {
    right: 12rem;
    left: 12rem;
  }

  .pc\:inset-x-52 {
    right: 13rem;
    left: 13rem;
  }

  .pc\:inset-x-56 {
    right: 14rem;
    left: 14rem;
  }

  .pc\:inset-x-60 {
    right: 15rem;
    left: 15rem;
  }

  .pc\:inset-x-64 {
    right: 16rem;
    left: 16rem;
  }

  .pc\:inset-x-72 {
    right: 18rem;
    left: 18rem;
  }

  .pc\:inset-x-80 {
    right: 20rem;
    left: 20rem;
  }

  .pc\:inset-x-96 {
    right: 24rem;
    left: 24rem;
  }

  .pc\:inset-x-auto {
    right: auto;
    left: auto;
  }

  .pc\:inset-x-1\/2 {
    right: 50%;
    left: 50%;
  }

  .pc\:inset-x-1\/3 {
    right: 33.333333%;
    left: 33.333333%;
  }

  .pc\:inset-x-2\/3 {
    right: 66.666667%;
    left: 66.666667%;
  }

  .pc\:inset-x-1\/4 {
    right: 25%;
    left: 25%;
  }

  .pc\:inset-x-2\/4 {
    right: 50%;
    left: 50%;
  }

  .pc\:inset-x-3\/4 {
    right: 75%;
    left: 75%;
  }

  .pc\:inset-x-full {
    right: 100%;
    left: 100%;
  }

  .pc\:-inset-x-px {
    right: -0.0625rem;
    left: -0.0625rem;
  }

  .pc\:-inset-x-0 {
    right: 0;
    left: 0;
  }

  .pc\:-inset-x-none {
    right: 0;
    left: 0;
  }

  .pc\:-inset-x-0\.5 {
    right: -0.125rem;
    left: -0.125rem;
  }

  .pc\:-inset-x-1 {
    right: -0.25rem;
    left: -0.25rem;
  }

  .pc\:-inset-x-1\.5 {
    right: -0.375rem;
    left: -0.375rem;
  }

  .pc\:-inset-x-2 {
    right: -0.5rem;
    left: -0.5rem;
  }

  .pc\:-inset-x-2\.5 {
    right: -0.625rem;
    left: -0.625rem;
  }

  .pc\:-inset-x-3 {
    right: -0.75rem;
    left: -0.75rem;
  }

  .pc\:-inset-x-3\.5 {
    right: -0.875rem;
    left: -0.875rem;
  }

  .pc\:-inset-x-4 {
    right: -1rem;
    left: -1rem;
  }

  .pc\:-inset-x-5 {
    right: -1.25rem;
    left: -1.25rem;
  }

  .pc\:-inset-x-6 {
    right: -1.5rem;
    left: -1.5rem;
  }

  .pc\:-inset-x-7 {
    right: -1.75rem;
    left: -1.75rem;
  }

  .pc\:-inset-x-8 {
    right: -2rem;
    left: -2rem;
  }

  .pc\:-inset-x-9 {
    right: -2.25rem;
    left: -2.25rem;
  }

  .pc\:-inset-x-10 {
    right: -2.5rem;
    left: -2.5rem;
  }

  .pc\:-inset-x-11 {
    right: -2.75rem;
    left: -2.75rem;
  }

  .pc\:-inset-x-12 {
    right: -3rem;
    left: -3rem;
  }

  .pc\:-inset-x-14 {
    right: -3.5rem;
    left: -3.5rem;
  }

  .pc\:-inset-x-16 {
    right: -4rem;
    left: -4rem;
  }

  .pc\:-inset-x-18 {
    right: -4.5rem;
    left: -4.5rem;
  }

  .pc\:-inset-x-20 {
    right: -5rem;
    left: -5rem;
  }

  .pc\:-inset-x-24 {
    right: -6rem;
    left: -6rem;
  }

  .pc\:-inset-x-28 {
    right: -7rem;
    left: -7rem;
  }

  .pc\:-inset-x-32 {
    right: -8rem;
    left: -8rem;
  }

  .pc\:-inset-x-36 {
    right: -9rem;
    left: -9rem;
  }

  .pc\:-inset-x-40 {
    right: -10rem;
    left: -10rem;
  }

  .pc\:-inset-x-44 {
    right: -11rem;
    left: -11rem;
  }

  .pc\:-inset-x-48 {
    right: -12rem;
    left: -12rem;
  }

  .pc\:-inset-x-52 {
    right: -13rem;
    left: -13rem;
  }

  .pc\:-inset-x-56 {
    right: -14rem;
    left: -14rem;
  }

  .pc\:-inset-x-60 {
    right: -15rem;
    left: -15rem;
  }

  .pc\:-inset-x-64 {
    right: -16rem;
    left: -16rem;
  }

  .pc\:-inset-x-72 {
    right: -18rem;
    left: -18rem;
  }

  .pc\:-inset-x-80 {
    right: -20rem;
    left: -20rem;
  }

  .pc\:-inset-x-96 {
    right: -24rem;
    left: -24rem;
  }

  .pc\:-inset-x-1\/2 {
    right: -50%;
    left: -50%;
  }

  .pc\:-inset-x-1\/3 {
    right: -33.333333%;
    left: -33.333333%;
  }

  .pc\:-inset-x-2\/3 {
    right: -66.666667%;
    left: -66.666667%;
  }

  .pc\:-inset-x-1\/4 {
    right: -25%;
    left: -25%;
  }

  .pc\:-inset-x-2\/4 {
    right: -50%;
    left: -50%;
  }

  .pc\:-inset-x-3\/4 {
    right: -75%;
    left: -75%;
  }

  .pc\:-inset-x-full {
    right: -100%;
    left: -100%;
  }

  .pc\:inset-y-px {
    top: 0.0625rem;
    bottom: 0.0625rem;
  }

  .pc\:inset-y-0 {
    top: 0;
    bottom: 0;
  }

  .pc\:inset-y-none {
    top: 0;
    bottom: 0;
  }

  .pc\:inset-y-0\.5 {
    top: 0.125rem;
    bottom: 0.125rem;
  }

  .pc\:inset-y-1 {
    top: 0.25rem;
    bottom: 0.25rem;
  }

  .pc\:inset-y-1\.5 {
    top: 0.375rem;
    bottom: 0.375rem;
  }

  .pc\:inset-y-2 {
    top: 0.5rem;
    bottom: 0.5rem;
  }

  .pc\:inset-y-2\.5 {
    top: 0.625rem;
    bottom: 0.625rem;
  }

  .pc\:inset-y-3 {
    top: 0.75rem;
    bottom: 0.75rem;
  }

  .pc\:inset-y-3\.5 {
    top: 0.875rem;
    bottom: 0.875rem;
  }

  .pc\:inset-y-4 {
    top: 1rem;
    bottom: 1rem;
  }

  .pc\:inset-y-5 {
    top: 1.25rem;
    bottom: 1.25rem;
  }

  .pc\:inset-y-6 {
    top: 1.5rem;
    bottom: 1.5rem;
  }

  .pc\:inset-y-7 {
    top: 1.75rem;
    bottom: 1.75rem;
  }

  .pc\:inset-y-8 {
    top: 2rem;
    bottom: 2rem;
  }

  .pc\:inset-y-9 {
    top: 2.25rem;
    bottom: 2.25rem;
  }

  .pc\:inset-y-10 {
    top: 2.5rem;
    bottom: 2.5rem;
  }

  .pc\:inset-y-11 {
    top: 2.75rem;
    bottom: 2.75rem;
  }

  .pc\:inset-y-12 {
    top: 3rem;
    bottom: 3rem;
  }

  .pc\:inset-y-14 {
    top: 3.5rem;
    bottom: 3.5rem;
  }

  .pc\:inset-y-16 {
    top: 4rem;
    bottom: 4rem;
  }

  .pc\:inset-y-18 {
    top: 4.5rem;
    bottom: 4.5rem;
  }

  .pc\:inset-y-20 {
    top: 5rem;
    bottom: 5rem;
  }

  .pc\:inset-y-24 {
    top: 6rem;
    bottom: 6rem;
  }

  .pc\:inset-y-28 {
    top: 7rem;
    bottom: 7rem;
  }

  .pc\:inset-y-32 {
    top: 8rem;
    bottom: 8rem;
  }

  .pc\:inset-y-36 {
    top: 9rem;
    bottom: 9rem;
  }

  .pc\:inset-y-40 {
    top: 10rem;
    bottom: 10rem;
  }

  .pc\:inset-y-44 {
    top: 11rem;
    bottom: 11rem;
  }

  .pc\:inset-y-48 {
    top: 12rem;
    bottom: 12rem;
  }

  .pc\:inset-y-52 {
    top: 13rem;
    bottom: 13rem;
  }

  .pc\:inset-y-56 {
    top: 14rem;
    bottom: 14rem;
  }

  .pc\:inset-y-60 {
    top: 15rem;
    bottom: 15rem;
  }

  .pc\:inset-y-64 {
    top: 16rem;
    bottom: 16rem;
  }

  .pc\:inset-y-72 {
    top: 18rem;
    bottom: 18rem;
  }

  .pc\:inset-y-80 {
    top: 20rem;
    bottom: 20rem;
  }

  .pc\:inset-y-96 {
    top: 24rem;
    bottom: 24rem;
  }

  .pc\:inset-y-auto {
    top: auto;
    bottom: auto;
  }

  .pc\:inset-y-1\/2 {
    top: 50%;
    bottom: 50%;
  }

  .pc\:inset-y-1\/3 {
    top: 33.333333%;
    bottom: 33.333333%;
  }

  .pc\:inset-y-2\/3 {
    top: 66.666667%;
    bottom: 66.666667%;
  }

  .pc\:inset-y-1\/4 {
    top: 25%;
    bottom: 25%;
  }

  .pc\:inset-y-2\/4 {
    top: 50%;
    bottom: 50%;
  }

  .pc\:inset-y-3\/4 {
    top: 75%;
    bottom: 75%;
  }

  .pc\:inset-y-full {
    top: 100%;
    bottom: 100%;
  }

  .pc\:-inset-y-px {
    top: -0.0625rem;
    bottom: -0.0625rem;
  }

  .pc\:-inset-y-0 {
    top: 0;
    bottom: 0;
  }

  .pc\:-inset-y-none {
    top: 0;
    bottom: 0;
  }

  .pc\:-inset-y-0\.5 {
    top: -0.125rem;
    bottom: -0.125rem;
  }

  .pc\:-inset-y-1 {
    top: -0.25rem;
    bottom: -0.25rem;
  }

  .pc\:-inset-y-1\.5 {
    top: -0.375rem;
    bottom: -0.375rem;
  }

  .pc\:-inset-y-2 {
    top: -0.5rem;
    bottom: -0.5rem;
  }

  .pc\:-inset-y-2\.5 {
    top: -0.625rem;
    bottom: -0.625rem;
  }

  .pc\:-inset-y-3 {
    top: -0.75rem;
    bottom: -0.75rem;
  }

  .pc\:-inset-y-3\.5 {
    top: -0.875rem;
    bottom: -0.875rem;
  }

  .pc\:-inset-y-4 {
    top: -1rem;
    bottom: -1rem;
  }

  .pc\:-inset-y-5 {
    top: -1.25rem;
    bottom: -1.25rem;
  }

  .pc\:-inset-y-6 {
    top: -1.5rem;
    bottom: -1.5rem;
  }

  .pc\:-inset-y-7 {
    top: -1.75rem;
    bottom: -1.75rem;
  }

  .pc\:-inset-y-8 {
    top: -2rem;
    bottom: -2rem;
  }

  .pc\:-inset-y-9 {
    top: -2.25rem;
    bottom: -2.25rem;
  }

  .pc\:-inset-y-10 {
    top: -2.5rem;
    bottom: -2.5rem;
  }

  .pc\:-inset-y-11 {
    top: -2.75rem;
    bottom: -2.75rem;
  }

  .pc\:-inset-y-12 {
    top: -3rem;
    bottom: -3rem;
  }

  .pc\:-inset-y-14 {
    top: -3.5rem;
    bottom: -3.5rem;
  }

  .pc\:-inset-y-16 {
    top: -4rem;
    bottom: -4rem;
  }

  .pc\:-inset-y-18 {
    top: -4.5rem;
    bottom: -4.5rem;
  }

  .pc\:-inset-y-20 {
    top: -5rem;
    bottom: -5rem;
  }

  .pc\:-inset-y-24 {
    top: -6rem;
    bottom: -6rem;
  }

  .pc\:-inset-y-28 {
    top: -7rem;
    bottom: -7rem;
  }

  .pc\:-inset-y-32 {
    top: -8rem;
    bottom: -8rem;
  }

  .pc\:-inset-y-36 {
    top: -9rem;
    bottom: -9rem;
  }

  .pc\:-inset-y-40 {
    top: -10rem;
    bottom: -10rem;
  }

  .pc\:-inset-y-44 {
    top: -11rem;
    bottom: -11rem;
  }

  .pc\:-inset-y-48 {
    top: -12rem;
    bottom: -12rem;
  }

  .pc\:-inset-y-52 {
    top: -13rem;
    bottom: -13rem;
  }

  .pc\:-inset-y-56 {
    top: -14rem;
    bottom: -14rem;
  }

  .pc\:-inset-y-60 {
    top: -15rem;
    bottom: -15rem;
  }

  .pc\:-inset-y-64 {
    top: -16rem;
    bottom: -16rem;
  }

  .pc\:-inset-y-72 {
    top: -18rem;
    bottom: -18rem;
  }

  .pc\:-inset-y-80 {
    top: -20rem;
    bottom: -20rem;
  }

  .pc\:-inset-y-96 {
    top: -24rem;
    bottom: -24rem;
  }

  .pc\:-inset-y-1\/2 {
    top: -50%;
    bottom: -50%;
  }

  .pc\:-inset-y-1\/3 {
    top: -33.333333%;
    bottom: -33.333333%;
  }

  .pc\:-inset-y-2\/3 {
    top: -66.666667%;
    bottom: -66.666667%;
  }

  .pc\:-inset-y-1\/4 {
    top: -25%;
    bottom: -25%;
  }

  .pc\:-inset-y-2\/4 {
    top: -50%;
    bottom: -50%;
  }

  .pc\:-inset-y-3\/4 {
    top: -75%;
    bottom: -75%;
  }

  .pc\:-inset-y-full {
    top: -100%;
    bottom: -100%;
  }
}
/*!markdown

---
title: Visibility
---

显示与隐藏。

| Class     | Properties           |
| --------- | -------------------- |
| visible   | visibility: visible; |
| invisible | visibility: hidden;  |

## 用法


# 响应式设计

支持通过添加设备前缀 `m:` 或者 `pc:` 来分别针对「手机端」或者「pc端」设置样式，更多说明请前往[「响应式设计」](../../../docs/style/responsive-design.md)。

## 状态前缀

不支持[「状态前缀」](../../../docs/style/state.md)，有需求请提 [issue](https://github.com/baidu/amis/issues)。

*/
.visible {
  visibility: visible;
}

.invisible {
  visibility: hidden;
}

@media (max-width: 768px) {
  .m\:visible {
    visibility: visible;
  }

  .m\:invisible {
    visibility: hidden;
  }
}
@media (min-width: 769px) {
  .pc\:visible {
    visibility: visible;
  }

  .pc\:invisible {
    visibility: hidden;
  }
}
/*!markdown

---
title: Z-Index
---

Utilities for controlling the stack order of an element.



| Class       | Properties               |
| ----------- | ------------------------ |
| z-0  | z-index: 0  |
| z-10  | z-index: 10  |
| z-20  | z-index: 20  |
| z-30  | z-index: 30  |
| z-40  | z-index: 40  |
| z-50  | z-index: 50  |
| z-auto  | z-index: auto  |

## 用法

```html
<div class="flex ... justify-center relative h-28 text-center transform translate-x-12">
  <div class="z-40 ... relative w-20 h-20 bg-purple-500 border-r border-opacity-50 border-purple-600 rounded-md shadow-md flex justify-center items-center text-white text-2xl font-extrabold">5</div>
  <div class="z-30 ... relative w-20 h-20 -left-6 top-2 bg-purple-500 border-r border-opacity-50 border-purple-600 rounded-md shadow-md flex justify-center items-center text-white text-2xl font-extrabold">4</div>
  <div class="z-20 ... relative w-20 h-20 -left-12 top-4 bg-purple-500 border-r border-opacity-50 border-purple-600 rounded-md shadow-md flex justify-center items-center text-white text-2xl font-extrabold">3</div>
  <div class="z-10 ... relative w-20 h-20 -left-18 top-6 bg-purple-500 border-r border-opacity-50 border-purple-600 rounded-md shadow-md flex justify-center items-center text-white text-2xl font-extrabold">2</div>
  <div class="z-0 ... relative w-20 h-20 -left-24 top-8 bg-purple-500 rounded-md shadow-md flex justify-center items-center text-white text-2xl font-extrabold">1</div>
</div>
```

# 响应式设计

支持通过添加设备前缀 `m:` 或者 `pc:` 来分别针对「手机端」或者「pc端」设置样式，更多说明请前往[「响应式设计」](../../../docs/style/responsive-design.md)。

## 状态前缀

不支持[「状态前缀」](../../../docs/style/state.md)，有需求请提 [issue](https://github.com/baidu/amis/issues)。

*/
.z-0 {
  z-index: 0;
}

.z-10 {
  z-index: 10;
}

.z-20 {
  z-index: 20;
}

.z-30 {
  z-index: 30;
}

.z-40 {
  z-index: 40;
}

.z-50 {
  z-index: 50;
}

.z-auto {
  z-index: auto;
}

@media (max-width: 768px) {
  .m\:z-0 {
    z-index: 0;
  }

  .m\:z-10 {
    z-index: 10;
  }

  .m\:z-20 {
    z-index: 20;
  }

  .m\:z-30 {
    z-index: 30;
  }

  .m\:z-40 {
    z-index: 40;
  }

  .m\:z-50 {
    z-index: 50;
  }

  .m\:z-auto {
    z-index: auto;
  }
}
@media (min-width: 769px) {
  .pc\:z-0 {
    z-index: 0;
  }

  .pc\:z-10 {
    z-index: 10;
  }

  .pc\:z-20 {
    z-index: 20;
  }

  .pc\:z-30 {
    z-index: 30;
  }

  .pc\:z-40 {
    z-index: 40;
  }

  .pc\:z-50 {
    z-index: 50;
  }

  .pc\:z-auto {
    z-index: auto;
  }
}
/*!markdown

---
title: Flex Direction
---

| Class       | Properties               |
| ----------- | ------------------------ |
| flex-row | flex-direction: row |
| flex-row-reverse | flex-direction: row-reverse |
| flex-col | flex-direction: column |
| flex-col-reverse | flex-direction: column-reverse |


*/
.flex-row {
  flex-direction: row;
}

.flex-row-reverse {
  flex-direction: row-reverse;
}

.flex-col {
  flex-direction: column;
}

.flex-col-reverse {
  flex-direction: column-reverse;
}

@media (max-width: 768px) {
  .m\:flex-row {
    flex-direction: row;
  }

  .m\:flex-row-reverse {
    flex-direction: row-reverse;
  }

  .m\:flex-col {
    flex-direction: column;
  }

  .m\:flex-col-reverse {
    flex-direction: column-reverse;
  }
}
@media (min-width: 769px) {
  .pc\:flex-row {
    flex-direction: row;
  }

  .pc\:flex-row-reverse {
    flex-direction: row-reverse;
  }

  .pc\:flex-col {
    flex-direction: column;
  }

  .pc\:flex-col-reverse {
    flex-direction: column-reverse;
  }
}
/*!markdown

---
title: Flex
---

| Class       | Properties               |
| ----------- | ------------------------ |
| flex-1 | flex: 1 1 0% |
| flex-auto | flex: 1 1 auto |
| flex-initial | flex: 0 1 auto |
| flex-none | flex: none |


*/
.flex-1 {
  flex: 1 1 0%;
}

.flex-auto {
  flex: 1 1 auto;
}

.flex-initial {
  flex: 0 1 auto;
}

.flex-none {
  flex: none;
}

@media (max-width: 768px) {
  .m\:flex-1 {
    flex: 1 1 0%;
  }

  .m\:flex-auto {
    flex: 1 1 auto;
  }

  .m\:flex-initial {
    flex: 0 1 auto;
  }

  .m\:flex-none {
    flex: none;
  }
}
@media (min-width: 769px) {
  .pc\:flex-1 {
    flex: 1 1 0%;
  }

  .pc\:flex-auto {
    flex: 1 1 auto;
  }

  .pc\:flex-initial {
    flex: 0 1 auto;
  }

  .pc\:flex-none {
    flex: none;
  }
}
/*!markdown

---
title: Flex Grow
---

| Class       | Properties               |
| ----------- | ------------------------ |
| flex-grow-0 | flex-grow: 0 |
| flex-grow | flex-grow: 1 |


*/
.flex-grow-0 {
  flex-grow: 0;
}

.flex-grow {
  flex-grow: 1;
}

@media (max-width: 768px) {
  .m\:flex-grow-0 {
    flex-grow: 0;
  }

  .m\:flex-grow {
    flex-grow: 1;
  }
}
@media (min-width: 769px) {
  .pc\:flex-grow-0 {
    flex-grow: 0;
  }

  .pc\:flex-grow {
    flex-grow: 1;
  }
}
/*!markdown

---
title: Flex Order
---

| Class       | Properties               |
| ----------- | ------------------------ |
| order-1 | order: 1 |
| order-2 | order: 2 |
| order-3 | order: 3 |
| order-4 | order: 4 |
| order-5 | order: 5 |
| order-6 | order: 6 |
| order-7 | order: 7 |
| order-8 | order: 8 |
| order-9 | order: 9 |
| order-10 | order: 10 |
| order-11 | order: 11 |
| order-12 | order: 12 |
| order-first | order: -9999 |
| order-last | order: 9999 |

*/
.order-1 {
  order: 1;
}

.order-2 {
  order: 2;
}

.order-3 {
  order: 3;
}

.order-4 {
  order: 4;
}

.order-5 {
  order: 5;
}

.order-6 {
  order: 6;
}

.order-7 {
  order: 7;
}

.order-8 {
  order: 8;
}

.order-9 {
  order: 9;
}

.order-10 {
  order: 10;
}

.order-11 {
  order: 11;
}

.order-12 {
  order: 12;
}

.order-first {
  order: -9999;
}

.order-last {
  order: 9999;
}

@media (max-width: 768px) {
  .m\:order-1 {
    order: 1;
  }

  .m\:order-2 {
    order: 2;
  }

  .m\:order-3 {
    order: 3;
  }

  .m\:order-4 {
    order: 4;
  }

  .m\:order-5 {
    order: 5;
  }

  .m\:order-6 {
    order: 6;
  }

  .m\:order-7 {
    order: 7;
  }

  .m\:order-8 {
    order: 8;
  }

  .m\:order-9 {
    order: 9;
  }

  .m\:order-10 {
    order: 10;
  }

  .m\:order-11 {
    order: 11;
  }

  .m\:order-12 {
    order: 12;
  }

  .m\:order-first {
    order: -9999;
  }

  .m\:order-last {
    order: 9999;
  }
}
@media (min-width: 769px) {
  .pc\:order-1 {
    order: 1;
  }

  .pc\:order-2 {
    order: 2;
  }

  .pc\:order-3 {
    order: 3;
  }

  .pc\:order-4 {
    order: 4;
  }

  .pc\:order-5 {
    order: 5;
  }

  .pc\:order-6 {
    order: 6;
  }

  .pc\:order-7 {
    order: 7;
  }

  .pc\:order-8 {
    order: 8;
  }

  .pc\:order-9 {
    order: 9;
  }

  .pc\:order-10 {
    order: 10;
  }

  .pc\:order-11 {
    order: 11;
  }

  .pc\:order-12 {
    order: 12;
  }

  .pc\:order-first {
    order: -9999;
  }

  .pc\:order-last {
    order: 9999;
  }
}
/*!markdown

---
title: Flex Shrink
---

| Class       | Properties               |
| ----------- | ------------------------ |
| flex-shrink-0 | flex-shrink: 0 |
| flex-shrink | flex-shrink: 1 |

*/
.flex-shrink-0 {
  flex-shrink: 0;
}

.flex-shrink {
  flex-shrink: 1;
}

@media (max-width: 768px) {
  .m\:flex-shrink-0 {
    flex-shrink: 0;
  }

  .m\:flex-shrink {
    flex-shrink: 1;
  }
}
@media (min-width: 769px) {
  .pc\:flex-shrink-0 {
    flex-shrink: 0;
  }

  .pc\:flex-shrink {
    flex-shrink: 1;
  }
}
/*!markdown

---
title: Flex Wrap
---

| Class       | Properties               |
| ----------- | ------------------------ |
| flex-wrap | flex-wrap: wrap |
| flex-wrap-reverse | flex-wrap: wrap-reverse |
| flex-nowrap | flex-wrap: nowrap |


*/
.flex-wrap {
  flex-wrap: wrap;
}

.flex-wrap-reverse {
  flex-wrap: wrap-reverse;
}

.flex-nowrap {
  flex-wrap: nowrap;
}

@media (max-width: 768px) {
  .m\:flex-wrap {
    flex-wrap: wrap;
  }

  .m\:flex-wrap-reverse {
    flex-wrap: wrap-reverse;
  }

  .m\:flex-nowrap {
    flex-wrap: nowrap;
  }
}
@media (min-width: 769px) {
  .pc\:flex-wrap {
    flex-wrap: wrap;
  }

  .pc\:flex-wrap-reverse {
    flex-wrap: wrap-reverse;
  }

  .pc\:flex-nowrap {
    flex-wrap: nowrap;
  }
}
/*!markdown

---
title: Grid Auto Columns
---

| Class       | Properties               |
| ----------- | ------------------------ |
| auto-cols-auto | grid-auto-columns: auto |
| auto-cols-min | grid-auto-columns: min-content |
| auto-cols-max | grid-auto-columns: max-content |
| auto-cols-fr | grid-auto-columns: minmax(0, 1fr) |


*/
.auto-cols-auto {
  grid-auto-columns: auto;
}

.auto-cols-min {
  grid-auto-columns: min-content;
}

.auto-cols-max {
  grid-auto-columns: max-content;
}

.auto-cols-fr {
  grid-auto-columns: minmax(0, 1fr);
}

@media (max-width: 768px) {
  .m\:auto-cols-auto {
    grid-auto-columns: auto;
  }

  .m\:auto-cols-min {
    grid-auto-columns: min-content;
  }

  .m\:auto-cols-max {
    grid-auto-columns: max-content;
  }

  .m\:auto-cols-fr {
    grid-auto-columns: minmax(0, 1fr);
  }
}
@media (min-width: 769px) {
  .pc\:auto-cols-auto {
    grid-auto-columns: auto;
  }

  .pc\:auto-cols-min {
    grid-auto-columns: min-content;
  }

  .pc\:auto-cols-max {
    grid-auto-columns: max-content;
  }

  .pc\:auto-cols-fr {
    grid-auto-columns: minmax(0, 1fr);
  }
}
/*!markdown

---
title: Grid Auto Flow
---

| Class       | Properties               |
| ----------- | ------------------------ |
| grid-flow-row | grid-auto-flow: row |
| grid-flow-col | grid-auto-flow: column |
| grid-flow-row-dense | grid-auto-flow: row dense |
| grid-flow-col-dense | grid-auto-flow: column dense |


*/
.grid-flow-row {
  grid-auto-flow: row;
}

.grid-flow-col {
  grid-auto-flow: column;
}

.grid-flow-row-dense {
  grid-auto-flow: row dense;
}

.grid-flow-col-dense {
  grid-auto-flow: column dense;
}

@media (max-width: 768px) {
  .m\:grid-flow-row {
    grid-auto-flow: row;
  }

  .m\:grid-flow-col {
    grid-auto-flow: column;
  }

  .m\:grid-flow-row-dense {
    grid-auto-flow: row dense;
  }

  .m\:grid-flow-col-dense {
    grid-auto-flow: column dense;
  }
}
@media (min-width: 769px) {
  .pc\:grid-flow-row {
    grid-auto-flow: row;
  }

  .pc\:grid-flow-col {
    grid-auto-flow: column;
  }

  .pc\:grid-flow-row-dense {
    grid-auto-flow: row dense;
  }

  .pc\:grid-flow-col-dense {
    grid-auto-flow: column dense;
  }
}
/*!markdown

---
title: Grid Auto Flow
---

| Class       | Properties               |
| ----------- | ------------------------ |
| auto-rows-auto | grid-auto-rows: auto |
| auto-rows-min | grid-auto-rows: min-content |
| auto-rows-max | grid-auto-rows: max-content |
| auto-rows-fr | grid-auto-rows: minmax(0, 1fr) |


*/
.auto-rows-auto {
  grid-auto-rows: auto;
}

.auto-rows-min {
  grid-auto-rows: min-content;
}

.auto-rows-max {
  grid-auto-rows: max-content;
}

.auto-rows-fr {
  grid-auto-rows: minmax(0, 1fr);
}

@media (max-width: 768px) {
  .m\:auto-rows-auto {
    grid-auto-rows: auto;
  }

  .m\:auto-rows-min {
    grid-auto-rows: min-content;
  }

  .m\:auto-rows-max {
    grid-auto-rows: max-content;
  }

  .m\:auto-rows-fr {
    grid-auto-rows: minmax(0, 1fr);
  }
}
@media (min-width: 769px) {
  .pc\:auto-rows-auto {
    grid-auto-rows: auto;
  }

  .pc\:auto-rows-min {
    grid-auto-rows: min-content;
  }

  .pc\:auto-rows-max {
    grid-auto-rows: max-content;
  }

  .pc\:auto-rows-fr {
    grid-auto-rows: minmax(0, 1fr);
  }
}
/*!markdown

---
title: Grid Row Start / End
---

| Class       | Properties               |
| ----------- | ------------------------ |
| col-auto | grid-column: auto |
| col-span-1 | grid-column: span 1/span 1 |
| col-span-2 | grid-column: span 2/span 2 |
| col-span-3 | grid-column: span 3/span 3 |
| col-span-4 | grid-column: span 4/span 4 |
| col-span-5 | grid-column: span 5/span 5 |
| col-span-6 | grid-column: span 6/span 6 |
| col-span-7 | grid-column: span 7/span 7 |
| col-span-8 | grid-column: span 8/span 8 |
| col-span-9 | grid-column: span 9/span 9 |
| col-span-10 | grid-column: span 10/span 10 |
| col-span-11 | grid-column: span 11/span 1 |
| col-span-12 | grid-column: span 12/span 12 |
| col-span-full | grid-column: 1/-1 |
| col-start-1 | grid-column-start: 1 |
| col-start-2 | grid-column-start: 2 |
| col-start-3 | grid-column-start: 3 |
| col-start-4 | grid-column-start: 4 |
| col-start-5 | grid-column-start: 5 |
| col-start-6 | grid-column-start: 6 |
| col-start-7 | grid-column-start: 7 |
| col-start-8 | grid-column-start: 8 |
| col-start-9 | grid-column-start: 9 |
| col-start-10 | grid-column-start: 10 |
| col-start-11 | grid-column-start: 11 |
| col-start-12 | grid-column-start: 12 |
| col-start-13 | grid-column-start: 13 |
| col-start-auto | grid-column-start: auto |
| col-end-1 | grid-column-end: 1 |
| col-end-2 | grid-column-end: 2 |
| col-end-3 | grid-column-end: 3 |
| col-end-4 | grid-column-end: 4 |
| col-end-5 | grid-column-end: 5 |
| col-end-6 | grid-column-end: 6 |
| col-end-7 | grid-column-end: 7 |
| col-end-8 | grid-column-end: 8 |
| col-end-9 | grid-column-end: 9 |
| col-end-10 | grid-column-end: 10 |
| col-end-11 | grid-column-end: 11 |
| col-end-12 | grid-column-end: 12 |
| col-end-13 | grid-column-end: 13 |
| col-end-auto | grid-column-end: auto |


*/
.col-auto {
  grid-column: auto;
}

.col-span-1 {
  grid-column: span 1/span 1;
}

.col-span-2 {
  grid-column: span 2/span 2;
}

.col-span-3 {
  grid-column: span 3/span 3;
}

.col-span-4 {
  grid-column: span 4/span 4;
}

.col-span-5 {
  grid-column: span 5/span 5;
}

.col-span-6 {
  grid-column: span 6/span 6;
}

.col-span-7 {
  grid-column: span 7/span 7;
}

.col-span-8 {
  grid-column: span 8/span 8;
}

.col-span-9 {
  grid-column: span 9/span 9;
}

.col-span-10 {
  grid-column: span 10/span 10;
}

.col-span-11 {
  grid-column: span 11/span 1;
}

.col-span-12 {
  grid-column: span 12/span 12;
}

.col-span-full {
  grid-column: 1/-1;
}

.col-start-1 {
  grid-column-start: 1;
}

.col-start-2 {
  grid-column-start: 2;
}

.col-start-3 {
  grid-column-start: 3;
}

.col-start-4 {
  grid-column-start: 4;
}

.col-start-5 {
  grid-column-start: 5;
}

.col-start-6 {
  grid-column-start: 6;
}

.col-start-7 {
  grid-column-start: 7;
}

.col-start-8 {
  grid-column-start: 8;
}

.col-start-9 {
  grid-column-start: 9;
}

.col-start-10 {
  grid-column-start: 10;
}

.col-start-11 {
  grid-column-start: 11;
}

.col-start-12 {
  grid-column-start: 12;
}

.col-start-13 {
  grid-column-start: 13;
}

.col-start-auto {
  grid-column-start: auto;
}

.col-end-1 {
  grid-column-end: 1;
}

.col-end-2 {
  grid-column-end: 2;
}

.col-end-3 {
  grid-column-end: 3;
}

.col-end-4 {
  grid-column-end: 4;
}

.col-end-5 {
  grid-column-end: 5;
}

.col-end-6 {
  grid-column-end: 6;
}

.col-end-7 {
  grid-column-end: 7;
}

.col-end-8 {
  grid-column-end: 8;
}

.col-end-9 {
  grid-column-end: 9;
}

.col-end-10 {
  grid-column-end: 10;
}

.col-end-11 {
  grid-column-end: 11;
}

.col-end-12 {
  grid-column-end: 12;
}

.col-end-13 {
  grid-column-end: 13;
}

.col-end-auto {
  grid-column-end: auto;
}

@media (max-width: 768px) {
  .m\:col-auto {
    grid-column: auto;
  }

  .m\:col-span-1 {
    grid-column: span 1/span 1;
  }

  .m\:col-span-2 {
    grid-column: span 2/span 2;
  }

  .m\:col-span-3 {
    grid-column: span 3/span 3;
  }

  .m\:col-span-4 {
    grid-column: span 4/span 4;
  }

  .m\:col-span-5 {
    grid-column: span 5/span 5;
  }

  .m\:col-span-6 {
    grid-column: span 6/span 6;
  }

  .m\:col-span-7 {
    grid-column: span 7/span 7;
  }

  .m\:col-span-8 {
    grid-column: span 8/span 8;
  }

  .m\:col-span-9 {
    grid-column: span 9/span 9;
  }

  .m\:col-span-10 {
    grid-column: span 10/span 10;
  }

  .m\:col-span-11 {
    grid-column: span 11/span 1;
  }

  .m\:col-span-12 {
    grid-column: span 12/span 12;
  }

  .m\:col-span-full {
    grid-column: 1/-1;
  }

  .m\:col-start-1 {
    grid-column-start: 1;
  }

  .m\:col-start-2 {
    grid-column-start: 2;
  }

  .m\:col-start-3 {
    grid-column-start: 3;
  }

  .m\:col-start-4 {
    grid-column-start: 4;
  }

  .m\:col-start-5 {
    grid-column-start: 5;
  }

  .m\:col-start-6 {
    grid-column-start: 6;
  }

  .m\:col-start-7 {
    grid-column-start: 7;
  }

  .m\:col-start-8 {
    grid-column-start: 8;
  }

  .m\:col-start-9 {
    grid-column-start: 9;
  }

  .m\:col-start-10 {
    grid-column-start: 10;
  }

  .m\:col-start-11 {
    grid-column-start: 11;
  }

  .m\:col-start-12 {
    grid-column-start: 12;
  }

  .m\:col-start-13 {
    grid-column-start: 13;
  }

  .m\:col-start-auto {
    grid-column-start: auto;
  }

  .m\:col-end-1 {
    grid-column-end: 1;
  }

  .m\:col-end-2 {
    grid-column-end: 2;
  }

  .m\:col-end-3 {
    grid-column-end: 3;
  }

  .m\:col-end-4 {
    grid-column-end: 4;
  }

  .m\:col-end-5 {
    grid-column-end: 5;
  }

  .m\:col-end-6 {
    grid-column-end: 6;
  }

  .m\:col-end-7 {
    grid-column-end: 7;
  }

  .m\:col-end-8 {
    grid-column-end: 8;
  }

  .m\:col-end-9 {
    grid-column-end: 9;
  }

  .m\:col-end-10 {
    grid-column-end: 10;
  }

  .m\:col-end-11 {
    grid-column-end: 11;
  }

  .m\:col-end-12 {
    grid-column-end: 12;
  }

  .m\:col-end-13 {
    grid-column-end: 13;
  }

  .m\:col-end-auto {
    grid-column-end: auto;
  }
}
@media (min-width: 769px) {
  .pc\:col-auto {
    grid-column: auto;
  }

  .pc\:col-span-1 {
    grid-column: span 1/span 1;
  }

  .pc\:col-span-2 {
    grid-column: span 2/span 2;
  }

  .pc\:col-span-3 {
    grid-column: span 3/span 3;
  }

  .pc\:col-span-4 {
    grid-column: span 4/span 4;
  }

  .pc\:col-span-5 {
    grid-column: span 5/span 5;
  }

  .pc\:col-span-6 {
    grid-column: span 6/span 6;
  }

  .pc\:col-span-7 {
    grid-column: span 7/span 7;
  }

  .pc\:col-span-8 {
    grid-column: span 8/span 8;
  }

  .pc\:col-span-9 {
    grid-column: span 9/span 9;
  }

  .pc\:col-span-10 {
    grid-column: span 10/span 10;
  }

  .pc\:col-span-11 {
    grid-column: span 11/span 1;
  }

  .pc\:col-span-12 {
    grid-column: span 12/span 12;
  }

  .pc\:col-span-full {
    grid-column: 1/-1;
  }

  .pc\:col-start-1 {
    grid-column-start: 1;
  }

  .pc\:col-start-2 {
    grid-column-start: 2;
  }

  .pc\:col-start-3 {
    grid-column-start: 3;
  }

  .pc\:col-start-4 {
    grid-column-start: 4;
  }

  .pc\:col-start-5 {
    grid-column-start: 5;
  }

  .pc\:col-start-6 {
    grid-column-start: 6;
  }

  .pc\:col-start-7 {
    grid-column-start: 7;
  }

  .pc\:col-start-8 {
    grid-column-start: 8;
  }

  .pc\:col-start-9 {
    grid-column-start: 9;
  }

  .pc\:col-start-10 {
    grid-column-start: 10;
  }

  .pc\:col-start-11 {
    grid-column-start: 11;
  }

  .pc\:col-start-12 {
    grid-column-start: 12;
  }

  .pc\:col-start-13 {
    grid-column-start: 13;
  }

  .pc\:col-start-auto {
    grid-column-start: auto;
  }

  .pc\:col-end-1 {
    grid-column-end: 1;
  }

  .pc\:col-end-2 {
    grid-column-end: 2;
  }

  .pc\:col-end-3 {
    grid-column-end: 3;
  }

  .pc\:col-end-4 {
    grid-column-end: 4;
  }

  .pc\:col-end-5 {
    grid-column-end: 5;
  }

  .pc\:col-end-6 {
    grid-column-end: 6;
  }

  .pc\:col-end-7 {
    grid-column-end: 7;
  }

  .pc\:col-end-8 {
    grid-column-end: 8;
  }

  .pc\:col-end-9 {
    grid-column-end: 9;
  }

  .pc\:col-end-10 {
    grid-column-end: 10;
  }

  .pc\:col-end-11 {
    grid-column-end: 11;
  }

  .pc\:col-end-12 {
    grid-column-end: 12;
  }

  .pc\:col-end-13 {
    grid-column-end: 13;
  }

  .pc\:col-end-auto {
    grid-column-end: auto;
  }
}
/*!markdown

---
title: Grid Template Columns
---

| Class       | Properties               |
| ----------- | ------------------------ |
| grid-cols-1 | grid-template-columns: repeat(1, minmax(0, 1fr)) |
| grid-cols-2 | grid-template-columns: repeat(2, minmax(0, 1fr)) |
| grid-cols-3 | grid-template-columns: repeat(3, minmax(0, 1fr)) |
| grid-cols-4 | grid-template-columns: repeat(4, minmax(0, 1fr)) |
| grid-cols-5 | grid-template-columns: repeat(5, minmax(0, 1fr)) |
| grid-cols-6 | grid-template-columns: repeat(6, minmax(0, 1fr)) |
| grid-cols-7 | grid-template-columns: repeat(6, minmax(0, 1fr)) |
| grid-cols-8 | grid-template-columns: repeat(8, minmax(0, 1fr)) |
| grid-cols-9 | grid-template-columns: repeat(9, minmax(0, 1fr)) |
| grid-cols-10 | grid-template-columns: repeat(10, minmax(0, 1fr)) |
| grid-cols-11 | grid-template-columns: repeat(11, minmax(0, 1fr)) |
| grid-cols-12 | grid-template-columns: repeat(12, minmax(0, 1fr)) |
| grid-cols-none | grid-template-columns: none |


*/
.grid-cols-1 {
  grid-template-columns: repeat(1, minmax(0, 1fr));
}

.grid-cols-2 {
  grid-template-columns: repeat(2, minmax(0, 1fr));
}

.grid-cols-3 {
  grid-template-columns: repeat(3, minmax(0, 1fr));
}

.grid-cols-4 {
  grid-template-columns: repeat(4, minmax(0, 1fr));
}

.grid-cols-5 {
  grid-template-columns: repeat(5, minmax(0, 1fr));
}

.grid-cols-6 {
  grid-template-columns: repeat(6, minmax(0, 1fr));
}

.grid-cols-7 {
  grid-template-columns: repeat(6, minmax(0, 1fr));
}

.grid-cols-8 {
  grid-template-columns: repeat(8, minmax(0, 1fr));
}

.grid-cols-9 {
  grid-template-columns: repeat(9, minmax(0, 1fr));
}

.grid-cols-10 {
  grid-template-columns: repeat(10, minmax(0, 1fr));
}

.grid-cols-11 {
  grid-template-columns: repeat(11, minmax(0, 1fr));
}

.grid-cols-12 {
  grid-template-columns: repeat(12, minmax(0, 1fr));
}

.grid-cols-none {
  grid-template-columns: none;
}

@media (max-width: 768px) {
  .m\:grid-cols-1 {
    grid-template-columns: repeat(1, minmax(0, 1fr));
  }

  .m\:grid-cols-2 {
    grid-template-columns: repeat(2, minmax(0, 1fr));
  }

  .m\:grid-cols-3 {
    grid-template-columns: repeat(3, minmax(0, 1fr));
  }

  .m\:grid-cols-4 {
    grid-template-columns: repeat(4, minmax(0, 1fr));
  }

  .m\:grid-cols-5 {
    grid-template-columns: repeat(5, minmax(0, 1fr));
  }

  .m\:grid-cols-6 {
    grid-template-columns: repeat(6, minmax(0, 1fr));
  }

  .m\:grid-cols-7 {
    grid-template-columns: repeat(6, minmax(0, 1fr));
  }

  .m\:grid-cols-8 {
    grid-template-columns: repeat(8, minmax(0, 1fr));
  }

  .m\:grid-cols-9 {
    grid-template-columns: repeat(9, minmax(0, 1fr));
  }

  .m\:grid-cols-10 {
    grid-template-columns: repeat(10, minmax(0, 1fr));
  }

  .m\:grid-cols-11 {
    grid-template-columns: repeat(11, minmax(0, 1fr));
  }

  .m\:grid-cols-12 {
    grid-template-columns: repeat(12, minmax(0, 1fr));
  }

  .m\:grid-cols-none {
    grid-template-columns: none;
  }
}
@media (min-width: 769px) {
  .pc\:grid-cols-1 {
    grid-template-columns: repeat(1, minmax(0, 1fr));
  }

  .pc\:grid-cols-2 {
    grid-template-columns: repeat(2, minmax(0, 1fr));
  }

  .pc\:grid-cols-3 {
    grid-template-columns: repeat(3, minmax(0, 1fr));
  }

  .pc\:grid-cols-4 {
    grid-template-columns: repeat(4, minmax(0, 1fr));
  }

  .pc\:grid-cols-5 {
    grid-template-columns: repeat(5, minmax(0, 1fr));
  }

  .pc\:grid-cols-6 {
    grid-template-columns: repeat(6, minmax(0, 1fr));
  }

  .pc\:grid-cols-7 {
    grid-template-columns: repeat(6, minmax(0, 1fr));
  }

  .pc\:grid-cols-8 {
    grid-template-columns: repeat(8, minmax(0, 1fr));
  }

  .pc\:grid-cols-9 {
    grid-template-columns: repeat(9, minmax(0, 1fr));
  }

  .pc\:grid-cols-10 {
    grid-template-columns: repeat(10, minmax(0, 1fr));
  }

  .pc\:grid-cols-11 {
    grid-template-columns: repeat(11, minmax(0, 1fr));
  }

  .pc\:grid-cols-12 {
    grid-template-columns: repeat(12, minmax(0, 1fr));
  }

  .pc\:grid-cols-none {
    grid-template-columns: none;
  }
}
/*!markdown

---
title: Gap
---

| Class       | Properties               |
| ----------- | ------------------------ |
| gap-px | gap: 0.0625rem |
| gap-x-px | column-gap: 0.0625rem |
| gap-y-px | row-gap: 0.0625rem |
| gap-0 | gap: 0 |
| gap-x-0 | column-gap: 0 |
| gap-y-0 | row-gap: 0 |
| gap-none | gap: 0 |
| gap-x-none | column-gap: 0 |
| gap-y-none | row-gap: 0 |
| gap-0\.5 | gap: 0.125rem |
| gap-x-0\.5 | column-gap: 0.125rem |
| gap-y-0\.5 | row-gap: 0.125rem |
| gap-1 | gap: 0.25rem |
| gap-x-1 | column-gap: 0.25rem |
| gap-y-1 | row-gap: 0.25rem |
| gap-1\.5 | gap: 0.375rem |
| gap-x-1\.5 | column-gap: 0.375rem |
| gap-y-1\.5 | row-gap: 0.375rem |
| gap-2 | gap: 0.5rem |
| gap-x-2 | column-gap: 0.5rem |
| gap-y-2 | row-gap: 0.5rem |
| gap-2\.5 | gap: 0.625rem |
| gap-x-2\.5 | column-gap: 0.625rem |
| gap-y-2\.5 | row-gap: 0.625rem |
| gap-3 | gap: 0.75rem |
| gap-x-3 | column-gap: 0.75rem |
| gap-y-3 | row-gap: 0.75rem |
| gap-3\.5 | gap: 0.875rem |
| gap-x-3\.5 | column-gap: 0.875rem |
| gap-y-3\.5 | row-gap: 0.875rem |
| gap-4 | gap: 1rem |
| gap-x-4 | column-gap: 1rem |
| gap-y-4 | row-gap: 1rem |
| gap-5 | gap: 1.25rem |
| gap-x-5 | column-gap: 1.25rem |
| gap-y-5 | row-gap: 1.25rem |
| gap-6 | gap: 1.5rem |
| gap-x-6 | column-gap: 1.5rem |
| gap-y-6 | row-gap: 1.5rem |
| gap-7 | gap: 1.75rem |
| gap-x-7 | column-gap: 1.75rem |
| gap-y-7 | row-gap: 1.75rem |
| gap-8 | gap: 2rem |
| gap-x-8 | column-gap: 2rem |
| gap-y-8 | row-gap: 2rem |
| gap-9 | gap: 2.25rem |
| gap-x-9 | column-gap: 2.25rem |
| gap-y-9 | row-gap: 2.25rem |
| gap-10 | gap: 2.5rem |
| gap-x-10 | column-gap: 2.5rem |
| gap-y-10 | row-gap: 2.5rem |
| gap-11 | gap: 2.75rem |
| gap-x-11 | column-gap: 2.75rem |
| gap-y-11 | row-gap: 2.75rem |
| gap-12 | gap: 3rem |
| gap-x-12 | column-gap: 3rem |
| gap-y-12 | row-gap: 3rem |
| gap-14 | gap: 3.5rem |
| gap-x-14 | column-gap: 3.5rem |
| gap-y-14 | row-gap: 3.5rem |
| gap-16 | gap: 4rem |
| gap-x-16 | column-gap: 4rem |
| gap-y-16 | row-gap: 4rem |
| gap-18 | gap: 4.5rem |
| gap-x-18 | column-gap: 4.5rem |
| gap-y-18 | row-gap: 4.5rem |
| gap-20 | gap: 5rem |
| gap-x-20 | column-gap: 5rem |
| gap-y-20 | row-gap: 5rem |
| gap-24 | gap: 6rem |
| gap-x-24 | column-gap: 6rem |
| gap-y-24 | row-gap: 6rem |
| gap-28 | gap: 7rem |
| gap-x-28 | column-gap: 7rem |
| gap-y-28 | row-gap: 7rem |
| gap-32 | gap: 8rem |
| gap-x-32 | column-gap: 8rem |
| gap-y-32 | row-gap: 8rem |
| gap-36 | gap: 9rem |
| gap-x-36 | column-gap: 9rem |
| gap-y-36 | row-gap: 9rem |
| gap-40 | gap: 10rem |
| gap-x-40 | column-gap: 10rem |
| gap-y-40 | row-gap: 10rem |
| gap-44 | gap: 11rem |
| gap-x-44 | column-gap: 11rem |
| gap-y-44 | row-gap: 11rem |
| gap-48 | gap: 12rem |
| gap-x-48 | column-gap: 12rem |
| gap-y-48 | row-gap: 12rem |
| gap-52 | gap: 13rem |
| gap-x-52 | column-gap: 13rem |
| gap-y-52 | row-gap: 13rem |
| gap-56 | gap: 14rem |
| gap-x-56 | column-gap: 14rem |
| gap-y-56 | row-gap: 14rem |
| gap-60 | gap: 15rem |
| gap-x-60 | column-gap: 15rem |
| gap-y-60 | row-gap: 15rem |
| gap-64 | gap: 16rem |
| gap-x-64 | column-gap: 16rem |
| gap-y-64 | row-gap: 16rem |
| gap-72 | gap: 18rem |
| gap-x-72 | column-gap: 18rem |
| gap-y-72 | row-gap: 18rem |
| gap-80 | gap: 20rem |
| gap-x-80 | column-gap: 20rem |
| gap-y-80 | row-gap: 20rem |
| gap-96 | gap: 24rem |
| gap-x-96 | column-gap: 24rem |
| gap-y-96 | row-gap: 24rem |


*/
.gap-px {
  gap: 0.0625rem;
}

.gap-x-px {
  column-gap: 0.0625rem;
}

.gap-y-px {
  row-gap: 0.0625rem;
}

.gap-0 {
  gap: 0;
}

.gap-x-0 {
  column-gap: 0;
}

.gap-y-0 {
  row-gap: 0;
}

.gap-none {
  gap: 0;
}

.gap-x-none {
  column-gap: 0;
}

.gap-y-none {
  row-gap: 0;
}

.gap-0\.5 {
  gap: 0.125rem;
}

.gap-x-0\.5 {
  column-gap: 0.125rem;
}

.gap-y-0\.5 {
  row-gap: 0.125rem;
}

.gap-1 {
  gap: 0.25rem;
}

.gap-x-1 {
  column-gap: 0.25rem;
}

.gap-y-1 {
  row-gap: 0.25rem;
}

.gap-1\.5 {
  gap: 0.375rem;
}

.gap-x-1\.5 {
  column-gap: 0.375rem;
}

.gap-y-1\.5 {
  row-gap: 0.375rem;
}

.gap-2 {
  gap: 0.5rem;
}

.gap-x-2 {
  column-gap: 0.5rem;
}

.gap-y-2 {
  row-gap: 0.5rem;
}

.gap-2\.5 {
  gap: 0.625rem;
}

.gap-x-2\.5 {
  column-gap: 0.625rem;
}

.gap-y-2\.5 {
  row-gap: 0.625rem;
}

.gap-3 {
  gap: 0.75rem;
}

.gap-x-3 {
  column-gap: 0.75rem;
}

.gap-y-3 {
  row-gap: 0.75rem;
}

.gap-3\.5 {
  gap: 0.875rem;
}

.gap-x-3\.5 {
  column-gap: 0.875rem;
}

.gap-y-3\.5 {
  row-gap: 0.875rem;
}

.gap-4 {
  gap: 1rem;
}

.gap-x-4 {
  column-gap: 1rem;
}

.gap-y-4 {
  row-gap: 1rem;
}

.gap-5 {
  gap: 1.25rem;
}

.gap-x-5 {
  column-gap: 1.25rem;
}

.gap-y-5 {
  row-gap: 1.25rem;
}

.gap-6 {
  gap: 1.5rem;
}

.gap-x-6 {
  column-gap: 1.5rem;
}

.gap-y-6 {
  row-gap: 1.5rem;
}

.gap-7 {
  gap: 1.75rem;
}

.gap-x-7 {
  column-gap: 1.75rem;
}

.gap-y-7 {
  row-gap: 1.75rem;
}

.gap-8 {
  gap: 2rem;
}

.gap-x-8 {
  column-gap: 2rem;
}

.gap-y-8 {
  row-gap: 2rem;
}

.gap-9 {
  gap: 2.25rem;
}

.gap-x-9 {
  column-gap: 2.25rem;
}

.gap-y-9 {
  row-gap: 2.25rem;
}

.gap-10 {
  gap: 2.5rem;
}

.gap-x-10 {
  column-gap: 2.5rem;
}

.gap-y-10 {
  row-gap: 2.5rem;
}

.gap-11 {
  gap: 2.75rem;
}

.gap-x-11 {
  column-gap: 2.75rem;
}

.gap-y-11 {
  row-gap: 2.75rem;
}

.gap-12 {
  gap: 3rem;
}

.gap-x-12 {
  column-gap: 3rem;
}

.gap-y-12 {
  row-gap: 3rem;
}

.gap-14 {
  gap: 3.5rem;
}

.gap-x-14 {
  column-gap: 3.5rem;
}

.gap-y-14 {
  row-gap: 3.5rem;
}

.gap-16 {
  gap: 4rem;
}

.gap-x-16 {
  column-gap: 4rem;
}

.gap-y-16 {
  row-gap: 4rem;
}

.gap-18 {
  gap: 4.5rem;
}

.gap-x-18 {
  column-gap: 4.5rem;
}

.gap-y-18 {
  row-gap: 4.5rem;
}

.gap-20 {
  gap: 5rem;
}

.gap-x-20 {
  column-gap: 5rem;
}

.gap-y-20 {
  row-gap: 5rem;
}

.gap-24 {
  gap: 6rem;
}

.gap-x-24 {
  column-gap: 6rem;
}

.gap-y-24 {
  row-gap: 6rem;
}

.gap-28 {
  gap: 7rem;
}

.gap-x-28 {
  column-gap: 7rem;
}

.gap-y-28 {
  row-gap: 7rem;
}

.gap-32 {
  gap: 8rem;
}

.gap-x-32 {
  column-gap: 8rem;
}

.gap-y-32 {
  row-gap: 8rem;
}

.gap-36 {
  gap: 9rem;
}

.gap-x-36 {
  column-gap: 9rem;
}

.gap-y-36 {
  row-gap: 9rem;
}

.gap-40 {
  gap: 10rem;
}

.gap-x-40 {
  column-gap: 10rem;
}

.gap-y-40 {
  row-gap: 10rem;
}

.gap-44 {
  gap: 11rem;
}

.gap-x-44 {
  column-gap: 11rem;
}

.gap-y-44 {
  row-gap: 11rem;
}

.gap-48 {
  gap: 12rem;
}

.gap-x-48 {
  column-gap: 12rem;
}

.gap-y-48 {
  row-gap: 12rem;
}

.gap-52 {
  gap: 13rem;
}

.gap-x-52 {
  column-gap: 13rem;
}

.gap-y-52 {
  row-gap: 13rem;
}

.gap-56 {
  gap: 14rem;
}

.gap-x-56 {
  column-gap: 14rem;
}

.gap-y-56 {
  row-gap: 14rem;
}

.gap-60 {
  gap: 15rem;
}

.gap-x-60 {
  column-gap: 15rem;
}

.gap-y-60 {
  row-gap: 15rem;
}

.gap-64 {
  gap: 16rem;
}

.gap-x-64 {
  column-gap: 16rem;
}

.gap-y-64 {
  row-gap: 16rem;
}

.gap-72 {
  gap: 18rem;
}

.gap-x-72 {
  column-gap: 18rem;
}

.gap-y-72 {
  row-gap: 18rem;
}

.gap-80 {
  gap: 20rem;
}

.gap-x-80 {
  column-gap: 20rem;
}

.gap-y-80 {
  row-gap: 20rem;
}

.gap-96 {
  gap: 24rem;
}

.gap-x-96 {
  column-gap: 24rem;
}

.gap-y-96 {
  row-gap: 24rem;
}

@media (max-width: 768px) {
  .m\:gap-px {
    gap: 0.0625rem;
  }

  .m\:gap-x-px {
    column-gap: 0.0625rem;
  }

  .m\:gap-y-px {
    row-gap: 0.0625rem;
  }

  .m\:gap-0 {
    gap: 0;
  }

  .m\:gap-x-0 {
    column-gap: 0;
  }

  .m\:gap-y-0 {
    row-gap: 0;
  }

  .m\:gap-none {
    gap: 0;
  }

  .m\:gap-x-none {
    column-gap: 0;
  }

  .m\:gap-y-none {
    row-gap: 0;
  }

  .m\:gap-0\.5 {
    gap: 0.125rem;
  }

  .m\:gap-x-0\.5 {
    column-gap: 0.125rem;
  }

  .m\:gap-y-0\.5 {
    row-gap: 0.125rem;
  }

  .m\:gap-1 {
    gap: 0.25rem;
  }

  .m\:gap-x-1 {
    column-gap: 0.25rem;
  }

  .m\:gap-y-1 {
    row-gap: 0.25rem;
  }

  .m\:gap-1\.5 {
    gap: 0.375rem;
  }

  .m\:gap-x-1\.5 {
    column-gap: 0.375rem;
  }

  .m\:gap-y-1\.5 {
    row-gap: 0.375rem;
  }

  .m\:gap-2 {
    gap: 0.5rem;
  }

  .m\:gap-x-2 {
    column-gap: 0.5rem;
  }

  .m\:gap-y-2 {
    row-gap: 0.5rem;
  }

  .m\:gap-2\.5 {
    gap: 0.625rem;
  }

  .m\:gap-x-2\.5 {
    column-gap: 0.625rem;
  }

  .m\:gap-y-2\.5 {
    row-gap: 0.625rem;
  }

  .m\:gap-3 {
    gap: 0.75rem;
  }

  .m\:gap-x-3 {
    column-gap: 0.75rem;
  }

  .m\:gap-y-3 {
    row-gap: 0.75rem;
  }

  .m\:gap-3\.5 {
    gap: 0.875rem;
  }

  .m\:gap-x-3\.5 {
    column-gap: 0.875rem;
  }

  .m\:gap-y-3\.5 {
    row-gap: 0.875rem;
  }

  .m\:gap-4 {
    gap: 1rem;
  }

  .m\:gap-x-4 {
    column-gap: 1rem;
  }

  .m\:gap-y-4 {
    row-gap: 1rem;
  }

  .m\:gap-5 {
    gap: 1.25rem;
  }

  .m\:gap-x-5 {
    column-gap: 1.25rem;
  }

  .m\:gap-y-5 {
    row-gap: 1.25rem;
  }

  .m\:gap-6 {
    gap: 1.5rem;
  }

  .m\:gap-x-6 {
    column-gap: 1.5rem;
  }

  .m\:gap-y-6 {
    row-gap: 1.5rem;
  }

  .m\:gap-7 {
    gap: 1.75rem;
  }

  .m\:gap-x-7 {
    column-gap: 1.75rem;
  }

  .m\:gap-y-7 {
    row-gap: 1.75rem;
  }

  .m\:gap-8 {
    gap: 2rem;
  }

  .m\:gap-x-8 {
    column-gap: 2rem;
  }

  .m\:gap-y-8 {
    row-gap: 2rem;
  }

  .m\:gap-9 {
    gap: 2.25rem;
  }

  .m\:gap-x-9 {
    column-gap: 2.25rem;
  }

  .m\:gap-y-9 {
    row-gap: 2.25rem;
  }

  .m\:gap-10 {
    gap: 2.5rem;
  }

  .m\:gap-x-10 {
    column-gap: 2.5rem;
  }

  .m\:gap-y-10 {
    row-gap: 2.5rem;
  }

  .m\:gap-11 {
    gap: 2.75rem;
  }

  .m\:gap-x-11 {
    column-gap: 2.75rem;
  }

  .m\:gap-y-11 {
    row-gap: 2.75rem;
  }

  .m\:gap-12 {
    gap: 3rem;
  }

  .m\:gap-x-12 {
    column-gap: 3rem;
  }

  .m\:gap-y-12 {
    row-gap: 3rem;
  }

  .m\:gap-14 {
    gap: 3.5rem;
  }

  .m\:gap-x-14 {
    column-gap: 3.5rem;
  }

  .m\:gap-y-14 {
    row-gap: 3.5rem;
  }

  .m\:gap-16 {
    gap: 4rem;
  }

  .m\:gap-x-16 {
    column-gap: 4rem;
  }

  .m\:gap-y-16 {
    row-gap: 4rem;
  }

  .m\:gap-18 {
    gap: 4.5rem;
  }

  .m\:gap-x-18 {
    column-gap: 4.5rem;
  }

  .m\:gap-y-18 {
    row-gap: 4.5rem;
  }

  .m\:gap-20 {
    gap: 5rem;
  }

  .m\:gap-x-20 {
    column-gap: 5rem;
  }

  .m\:gap-y-20 {
    row-gap: 5rem;
  }

  .m\:gap-24 {
    gap: 6rem;
  }

  .m\:gap-x-24 {
    column-gap: 6rem;
  }

  .m\:gap-y-24 {
    row-gap: 6rem;
  }

  .m\:gap-28 {
    gap: 7rem;
  }

  .m\:gap-x-28 {
    column-gap: 7rem;
  }

  .m\:gap-y-28 {
    row-gap: 7rem;
  }

  .m\:gap-32 {
    gap: 8rem;
  }

  .m\:gap-x-32 {
    column-gap: 8rem;
  }

  .m\:gap-y-32 {
    row-gap: 8rem;
  }

  .m\:gap-36 {
    gap: 9rem;
  }

  .m\:gap-x-36 {
    column-gap: 9rem;
  }

  .m\:gap-y-36 {
    row-gap: 9rem;
  }

  .m\:gap-40 {
    gap: 10rem;
  }

  .m\:gap-x-40 {
    column-gap: 10rem;
  }

  .m\:gap-y-40 {
    row-gap: 10rem;
  }

  .m\:gap-44 {
    gap: 11rem;
  }

  .m\:gap-x-44 {
    column-gap: 11rem;
  }

  .m\:gap-y-44 {
    row-gap: 11rem;
  }

  .m\:gap-48 {
    gap: 12rem;
  }

  .m\:gap-x-48 {
    column-gap: 12rem;
  }

  .m\:gap-y-48 {
    row-gap: 12rem;
  }

  .m\:gap-52 {
    gap: 13rem;
  }

  .m\:gap-x-52 {
    column-gap: 13rem;
  }

  .m\:gap-y-52 {
    row-gap: 13rem;
  }

  .m\:gap-56 {
    gap: 14rem;
  }

  .m\:gap-x-56 {
    column-gap: 14rem;
  }

  .m\:gap-y-56 {
    row-gap: 14rem;
  }

  .m\:gap-60 {
    gap: 15rem;
  }

  .m\:gap-x-60 {
    column-gap: 15rem;
  }

  .m\:gap-y-60 {
    row-gap: 15rem;
  }

  .m\:gap-64 {
    gap: 16rem;
  }

  .m\:gap-x-64 {
    column-gap: 16rem;
  }

  .m\:gap-y-64 {
    row-gap: 16rem;
  }

  .m\:gap-72 {
    gap: 18rem;
  }

  .m\:gap-x-72 {
    column-gap: 18rem;
  }

  .m\:gap-y-72 {
    row-gap: 18rem;
  }

  .m\:gap-80 {
    gap: 20rem;
  }

  .m\:gap-x-80 {
    column-gap: 20rem;
  }

  .m\:gap-y-80 {
    row-gap: 20rem;
  }

  .m\:gap-96 {
    gap: 24rem;
  }

  .m\:gap-x-96 {
    column-gap: 24rem;
  }

  .m\:gap-y-96 {
    row-gap: 24rem;
  }
}
@media (min-width: 769px) {
  .pc\:gap-px {
    gap: 0.0625rem;
  }

  .pc\:gap-x-px {
    column-gap: 0.0625rem;
  }

  .pc\:gap-y-px {
    row-gap: 0.0625rem;
  }

  .pc\:gap-0 {
    gap: 0;
  }

  .pc\:gap-x-0 {
    column-gap: 0;
  }

  .pc\:gap-y-0 {
    row-gap: 0;
  }

  .pc\:gap-none {
    gap: 0;
  }

  .pc\:gap-x-none {
    column-gap: 0;
  }

  .pc\:gap-y-none {
    row-gap: 0;
  }

  .pc\:gap-0\.5 {
    gap: 0.125rem;
  }

  .pc\:gap-x-0\.5 {
    column-gap: 0.125rem;
  }

  .pc\:gap-y-0\.5 {
    row-gap: 0.125rem;
  }

  .pc\:gap-1 {
    gap: 0.25rem;
  }

  .pc\:gap-x-1 {
    column-gap: 0.25rem;
  }

  .pc\:gap-y-1 {
    row-gap: 0.25rem;
  }

  .pc\:gap-1\.5 {
    gap: 0.375rem;
  }

  .pc\:gap-x-1\.5 {
    column-gap: 0.375rem;
  }

  .pc\:gap-y-1\.5 {
    row-gap: 0.375rem;
  }

  .pc\:gap-2 {
    gap: 0.5rem;
  }

  .pc\:gap-x-2 {
    column-gap: 0.5rem;
  }

  .pc\:gap-y-2 {
    row-gap: 0.5rem;
  }

  .pc\:gap-2\.5 {
    gap: 0.625rem;
  }

  .pc\:gap-x-2\.5 {
    column-gap: 0.625rem;
  }

  .pc\:gap-y-2\.5 {
    row-gap: 0.625rem;
  }

  .pc\:gap-3 {
    gap: 0.75rem;
  }

  .pc\:gap-x-3 {
    column-gap: 0.75rem;
  }

  .pc\:gap-y-3 {
    row-gap: 0.75rem;
  }

  .pc\:gap-3\.5 {
    gap: 0.875rem;
  }

  .pc\:gap-x-3\.5 {
    column-gap: 0.875rem;
  }

  .pc\:gap-y-3\.5 {
    row-gap: 0.875rem;
  }

  .pc\:gap-4 {
    gap: 1rem;
  }

  .pc\:gap-x-4 {
    column-gap: 1rem;
  }

  .pc\:gap-y-4 {
    row-gap: 1rem;
  }

  .pc\:gap-5 {
    gap: 1.25rem;
  }

  .pc\:gap-x-5 {
    column-gap: 1.25rem;
  }

  .pc\:gap-y-5 {
    row-gap: 1.25rem;
  }

  .pc\:gap-6 {
    gap: 1.5rem;
  }

  .pc\:gap-x-6 {
    column-gap: 1.5rem;
  }

  .pc\:gap-y-6 {
    row-gap: 1.5rem;
  }

  .pc\:gap-7 {
    gap: 1.75rem;
  }

  .pc\:gap-x-7 {
    column-gap: 1.75rem;
  }

  .pc\:gap-y-7 {
    row-gap: 1.75rem;
  }

  .pc\:gap-8 {
    gap: 2rem;
  }

  .pc\:gap-x-8 {
    column-gap: 2rem;
  }

  .pc\:gap-y-8 {
    row-gap: 2rem;
  }

  .pc\:gap-9 {
    gap: 2.25rem;
  }

  .pc\:gap-x-9 {
    column-gap: 2.25rem;
  }

  .pc\:gap-y-9 {
    row-gap: 2.25rem;
  }

  .pc\:gap-10 {
    gap: 2.5rem;
  }

  .pc\:gap-x-10 {
    column-gap: 2.5rem;
  }

  .pc\:gap-y-10 {
    row-gap: 2.5rem;
  }

  .pc\:gap-11 {
    gap: 2.75rem;
  }

  .pc\:gap-x-11 {
    column-gap: 2.75rem;
  }

  .pc\:gap-y-11 {
    row-gap: 2.75rem;
  }

  .pc\:gap-12 {
    gap: 3rem;
  }

  .pc\:gap-x-12 {
    column-gap: 3rem;
  }

  .pc\:gap-y-12 {
    row-gap: 3rem;
  }

  .pc\:gap-14 {
    gap: 3.5rem;
  }

  .pc\:gap-x-14 {
    column-gap: 3.5rem;
  }

  .pc\:gap-y-14 {
    row-gap: 3.5rem;
  }

  .pc\:gap-16 {
    gap: 4rem;
  }

  .pc\:gap-x-16 {
    column-gap: 4rem;
  }

  .pc\:gap-y-16 {
    row-gap: 4rem;
  }

  .pc\:gap-18 {
    gap: 4.5rem;
  }

  .pc\:gap-x-18 {
    column-gap: 4.5rem;
  }

  .pc\:gap-y-18 {
    row-gap: 4.5rem;
  }

  .pc\:gap-20 {
    gap: 5rem;
  }

  .pc\:gap-x-20 {
    column-gap: 5rem;
  }

  .pc\:gap-y-20 {
    row-gap: 5rem;
  }

  .pc\:gap-24 {
    gap: 6rem;
  }

  .pc\:gap-x-24 {
    column-gap: 6rem;
  }

  .pc\:gap-y-24 {
    row-gap: 6rem;
  }

  .pc\:gap-28 {
    gap: 7rem;
  }

  .pc\:gap-x-28 {
    column-gap: 7rem;
  }

  .pc\:gap-y-28 {
    row-gap: 7rem;
  }

  .pc\:gap-32 {
    gap: 8rem;
  }

  .pc\:gap-x-32 {
    column-gap: 8rem;
  }

  .pc\:gap-y-32 {
    row-gap: 8rem;
  }

  .pc\:gap-36 {
    gap: 9rem;
  }

  .pc\:gap-x-36 {
    column-gap: 9rem;
  }

  .pc\:gap-y-36 {
    row-gap: 9rem;
  }

  .pc\:gap-40 {
    gap: 10rem;
  }

  .pc\:gap-x-40 {
    column-gap: 10rem;
  }

  .pc\:gap-y-40 {
    row-gap: 10rem;
  }

  .pc\:gap-44 {
    gap: 11rem;
  }

  .pc\:gap-x-44 {
    column-gap: 11rem;
  }

  .pc\:gap-y-44 {
    row-gap: 11rem;
  }

  .pc\:gap-48 {
    gap: 12rem;
  }

  .pc\:gap-x-48 {
    column-gap: 12rem;
  }

  .pc\:gap-y-48 {
    row-gap: 12rem;
  }

  .pc\:gap-52 {
    gap: 13rem;
  }

  .pc\:gap-x-52 {
    column-gap: 13rem;
  }

  .pc\:gap-y-52 {
    row-gap: 13rem;
  }

  .pc\:gap-56 {
    gap: 14rem;
  }

  .pc\:gap-x-56 {
    column-gap: 14rem;
  }

  .pc\:gap-y-56 {
    row-gap: 14rem;
  }

  .pc\:gap-60 {
    gap: 15rem;
  }

  .pc\:gap-x-60 {
    column-gap: 15rem;
  }

  .pc\:gap-y-60 {
    row-gap: 15rem;
  }

  .pc\:gap-64 {
    gap: 16rem;
  }

  .pc\:gap-x-64 {
    column-gap: 16rem;
  }

  .pc\:gap-y-64 {
    row-gap: 16rem;
  }

  .pc\:gap-72 {
    gap: 18rem;
  }

  .pc\:gap-x-72 {
    column-gap: 18rem;
  }

  .pc\:gap-y-72 {
    row-gap: 18rem;
  }

  .pc\:gap-80 {
    gap: 20rem;
  }

  .pc\:gap-x-80 {
    column-gap: 20rem;
  }

  .pc\:gap-y-80 {
    row-gap: 20rem;
  }

  .pc\:gap-96 {
    gap: 24rem;
  }

  .pc\:gap-x-96 {
    column-gap: 24rem;
  }

  .pc\:gap-y-96 {
    row-gap: 24rem;
  }
}
/*!markdown

---
title: Grid Row Start / End
---

| Class       | Properties               |
| ----------- | ------------------------ |
| row-auto | grid-row: auto |
| row-span-1 | grid-row: span 1/span 1 |
| row-span-2 | grid-row: span 2/span 2 |
| row-span-3 | grid-row: span 3/span 3 |
| row-span-4 | grid-row: span 4/span 4 |
| row-span-5 | grid-row: span 5/span 5 |
| row-span-6 | grid-row: span 6/span 6 |
| row-span-7 | grid-row: span 7/span 7 |
| row-span-8 | grid-row: span 8/span 8 |
| row-span-9 | grid-row: span 9/span 9 |
| row-span-10 | grid-row: span 10/span 10 |
| row-span-11 | grid-row: span 11/span 1 |
| row-span-12 | grid-row: span 12/span 12 |
| row-span-full | grid-row: 1/-1 |
| row-start-1 | grid-row-start: 1 |
| row-start-2 | grid-row-start: 2 |
| row-start-3 | grid-row-start: 3 |
| row-start-4 | grid-row-start: 4 |
| row-start-5 | grid-row-start: 5 |
| row-start-6 | grid-row-start: 6 |
| row-start-7 | grid-row-start: 7 |
| row-start-8 | grid-row-start: 8 |
| row-start-9 | grid-row-start: 9 |
| row-start-10 | grid-row-start: 10 |
| row-start-11 | grid-row-start: 11 |
| row-start-12 | grid-row-start: 12 |
| row-start-13 | grid-row-start: 13 |
| row-start-auto | grid-row-start: auto |
| row-end-1 | grid-row-end: 1 |
| row-end-2 | grid-row-end: 2 |
| row-end-3 | grid-row-end: 3 |
| row-end-4 | grid-row-end: 4 |
| row-end-5 | grid-row-end: 5 |
| row-end-6 | grid-row-end: 6 |
| row-end-7 | grid-row-end: 7 |
| row-end-8 | grid-row-end: 8 |
| row-end-9 | grid-row-end: 9 |
| row-end-10 | grid-row-end: 10 |
| row-end-11 | grid-row-end: 11 |
| row-end-12 | grid-row-end: 12 |
| row-end-13 | grid-row-end: 13 |
| row-end-auto | grid-row-end: auto |


*/
.row-auto {
  grid-row: auto;
}

.row-span-1 {
  grid-row: span 1/span 1;
}

.row-span-2 {
  grid-row: span 2/span 2;
}

.row-span-3 {
  grid-row: span 3/span 3;
}

.row-span-4 {
  grid-row: span 4/span 4;
}

.row-span-5 {
  grid-row: span 5/span 5;
}

.row-span-6 {
  grid-row: span 6/span 6;
}

.row-span-7 {
  grid-row: span 7/span 7;
}

.row-span-8 {
  grid-row: span 8/span 8;
}

.row-span-9 {
  grid-row: span 9/span 9;
}

.row-span-10 {
  grid-row: span 10/span 10;
}

.row-span-11 {
  grid-row: span 11/span 1;
}

.row-span-12 {
  grid-row: span 12/span 12;
}

.row-span-full {
  grid-row: 1/-1;
}

.row-start-1 {
  grid-row-start: 1;
}

.row-start-2 {
  grid-row-start: 2;
}

.row-start-3 {
  grid-row-start: 3;
}

.row-start-4 {
  grid-row-start: 4;
}

.row-start-5 {
  grid-row-start: 5;
}

.row-start-6 {
  grid-row-start: 6;
}

.row-start-7 {
  grid-row-start: 7;
}

.row-start-8 {
  grid-row-start: 8;
}

.row-start-9 {
  grid-row-start: 9;
}

.row-start-10 {
  grid-row-start: 10;
}

.row-start-11 {
  grid-row-start: 11;
}

.row-start-12 {
  grid-row-start: 12;
}

.row-start-13 {
  grid-row-start: 13;
}

.row-start-auto {
  grid-row-start: auto;
}

.row-end-1 {
  grid-row-end: 1;
}

.row-end-2 {
  grid-row-end: 2;
}

.row-end-3 {
  grid-row-end: 3;
}

.row-end-4 {
  grid-row-end: 4;
}

.row-end-5 {
  grid-row-end: 5;
}

.row-end-6 {
  grid-row-end: 6;
}

.row-end-7 {
  grid-row-end: 7;
}

.row-end-8 {
  grid-row-end: 8;
}

.row-end-9 {
  grid-row-end: 9;
}

.row-end-10 {
  grid-row-end: 10;
}

.row-end-11 {
  grid-row-end: 11;
}

.row-end-12 {
  grid-row-end: 12;
}

.row-end-13 {
  grid-row-end: 13;
}

.row-end-auto {
  grid-row-end: auto;
}

@media (max-width: 768px) {
  .m\:row-auto {
    grid-row: auto;
  }

  .m\:row-span-1 {
    grid-row: span 1/span 1;
  }

  .m\:row-span-2 {
    grid-row: span 2/span 2;
  }

  .m\:row-span-3 {
    grid-row: span 3/span 3;
  }

  .m\:row-span-4 {
    grid-row: span 4/span 4;
  }

  .m\:row-span-5 {
    grid-row: span 5/span 5;
  }

  .m\:row-span-6 {
    grid-row: span 6/span 6;
  }

  .m\:row-span-7 {
    grid-row: span 7/span 7;
  }

  .m\:row-span-8 {
    grid-row: span 8/span 8;
  }

  .m\:row-span-9 {
    grid-row: span 9/span 9;
  }

  .m\:row-span-10 {
    grid-row: span 10/span 10;
  }

  .m\:row-span-11 {
    grid-row: span 11/span 1;
  }

  .m\:row-span-12 {
    grid-row: span 12/span 12;
  }

  .m\:row-span-full {
    grid-row: 1/-1;
  }

  .m\:row-start-1 {
    grid-row-start: 1;
  }

  .m\:row-start-2 {
    grid-row-start: 2;
  }

  .m\:row-start-3 {
    grid-row-start: 3;
  }

  .m\:row-start-4 {
    grid-row-start: 4;
  }

  .m\:row-start-5 {
    grid-row-start: 5;
  }

  .m\:row-start-6 {
    grid-row-start: 6;
  }

  .m\:row-start-7 {
    grid-row-start: 7;
  }

  .m\:row-start-8 {
    grid-row-start: 8;
  }

  .m\:row-start-9 {
    grid-row-start: 9;
  }

  .m\:row-start-10 {
    grid-row-start: 10;
  }

  .m\:row-start-11 {
    grid-row-start: 11;
  }

  .m\:row-start-12 {
    grid-row-start: 12;
  }

  .m\:row-start-13 {
    grid-row-start: 13;
  }

  .m\:row-start-auto {
    grid-row-start: auto;
  }

  .m\:row-end-1 {
    grid-row-end: 1;
  }

  .m\:row-end-2 {
    grid-row-end: 2;
  }

  .m\:row-end-3 {
    grid-row-end: 3;
  }

  .m\:row-end-4 {
    grid-row-end: 4;
  }

  .m\:row-end-5 {
    grid-row-end: 5;
  }

  .m\:row-end-6 {
    grid-row-end: 6;
  }

  .m\:row-end-7 {
    grid-row-end: 7;
  }

  .m\:row-end-8 {
    grid-row-end: 8;
  }

  .m\:row-end-9 {
    grid-row-end: 9;
  }

  .m\:row-end-10 {
    grid-row-end: 10;
  }

  .m\:row-end-11 {
    grid-row-end: 11;
  }

  .m\:row-end-12 {
    grid-row-end: 12;
  }

  .m\:row-end-13 {
    grid-row-end: 13;
  }

  .m\:row-end-auto {
    grid-row-end: auto;
  }
}
@media (min-width: 769px) {
  .pc\:row-auto {
    grid-row: auto;
  }

  .pc\:row-span-1 {
    grid-row: span 1/span 1;
  }

  .pc\:row-span-2 {
    grid-row: span 2/span 2;
  }

  .pc\:row-span-3 {
    grid-row: span 3/span 3;
  }

  .pc\:row-span-4 {
    grid-row: span 4/span 4;
  }

  .pc\:row-span-5 {
    grid-row: span 5/span 5;
  }

  .pc\:row-span-6 {
    grid-row: span 6/span 6;
  }

  .pc\:row-span-7 {
    grid-row: span 7/span 7;
  }

  .pc\:row-span-8 {
    grid-row: span 8/span 8;
  }

  .pc\:row-span-9 {
    grid-row: span 9/span 9;
  }

  .pc\:row-span-10 {
    grid-row: span 10/span 10;
  }

  .pc\:row-span-11 {
    grid-row: span 11/span 1;
  }

  .pc\:row-span-12 {
    grid-row: span 12/span 12;
  }

  .pc\:row-span-full {
    grid-row: 1/-1;
  }

  .pc\:row-start-1 {
    grid-row-start: 1;
  }

  .pc\:row-start-2 {
    grid-row-start: 2;
  }

  .pc\:row-start-3 {
    grid-row-start: 3;
  }

  .pc\:row-start-4 {
    grid-row-start: 4;
  }

  .pc\:row-start-5 {
    grid-row-start: 5;
  }

  .pc\:row-start-6 {
    grid-row-start: 6;
  }

  .pc\:row-start-7 {
    grid-row-start: 7;
  }

  .pc\:row-start-8 {
    grid-row-start: 8;
  }

  .pc\:row-start-9 {
    grid-row-start: 9;
  }

  .pc\:row-start-10 {
    grid-row-start: 10;
  }

  .pc\:row-start-11 {
    grid-row-start: 11;
  }

  .pc\:row-start-12 {
    grid-row-start: 12;
  }

  .pc\:row-start-13 {
    grid-row-start: 13;
  }

  .pc\:row-start-auto {
    grid-row-start: auto;
  }

  .pc\:row-end-1 {
    grid-row-end: 1;
  }

  .pc\:row-end-2 {
    grid-row-end: 2;
  }

  .pc\:row-end-3 {
    grid-row-end: 3;
  }

  .pc\:row-end-4 {
    grid-row-end: 4;
  }

  .pc\:row-end-5 {
    grid-row-end: 5;
  }

  .pc\:row-end-6 {
    grid-row-end: 6;
  }

  .pc\:row-end-7 {
    grid-row-end: 7;
  }

  .pc\:row-end-8 {
    grid-row-end: 8;
  }

  .pc\:row-end-9 {
    grid-row-end: 9;
  }

  .pc\:row-end-10 {
    grid-row-end: 10;
  }

  .pc\:row-end-11 {
    grid-row-end: 11;
  }

  .pc\:row-end-12 {
    grid-row-end: 12;
  }

  .pc\:row-end-13 {
    grid-row-end: 13;
  }

  .pc\:row-end-auto {
    grid-row-end: auto;
  }
}
/*!markdown

---
title: Grid Template Rows
---

| Class       | Properties               |
| ----------- | ------------------------ |
| grid-rows-1 | grid-template-rows: repeat(1, minmax(0, 1fr)) |
| grid-rows-2 | grid-template-rows: repeat(2, minmax(0, 1fr)) |
| grid-rows-3 | grid-template-rows: repeat(3, minmax(0, 1fr)) |
| grid-rows-4 | grid-template-rows: repeat(4, minmax(0, 1fr)) |
| grid-rows-5 | grid-template-rows: repeat(5, minmax(0, 1fr)) |
| grid-rows-6 | grid-template-rows: repeat(6, minmax(0, 1fr)) |
| grid-rows-none | grid-template-rows: none |


*/
.grid-rows-1 {
  grid-template-rows: repeat(1, minmax(0, 1fr));
}

.grid-rows-2 {
  grid-template-rows: repeat(2, minmax(0, 1fr));
}

.grid-rows-3 {
  grid-template-rows: repeat(3, minmax(0, 1fr));
}

.grid-rows-4 {
  grid-template-rows: repeat(4, minmax(0, 1fr));
}

.grid-rows-5 {
  grid-template-rows: repeat(5, minmax(0, 1fr));
}

.grid-rows-6 {
  grid-template-rows: repeat(6, minmax(0, 1fr));
}

.grid-rows-none {
  grid-template-rows: none;
}

@media (max-width: 768px) {
  .m\:grid-rows-1 {
    grid-template-rows: repeat(1, minmax(0, 1fr));
  }

  .m\:grid-rows-2 {
    grid-template-rows: repeat(2, minmax(0, 1fr));
  }

  .m\:grid-rows-3 {
    grid-template-rows: repeat(3, minmax(0, 1fr));
  }

  .m\:grid-rows-4 {
    grid-template-rows: repeat(4, minmax(0, 1fr));
  }

  .m\:grid-rows-5 {
    grid-template-rows: repeat(5, minmax(0, 1fr));
  }

  .m\:grid-rows-6 {
    grid-template-rows: repeat(6, minmax(0, 1fr));
  }

  .m\:grid-rows-none {
    grid-template-rows: none;
  }
}
@media (min-width: 769px) {
  .pc\:grid-rows-1 {
    grid-template-rows: repeat(1, minmax(0, 1fr));
  }

  .pc\:grid-rows-2 {
    grid-template-rows: repeat(2, minmax(0, 1fr));
  }

  .pc\:grid-rows-3 {
    grid-template-rows: repeat(3, minmax(0, 1fr));
  }

  .pc\:grid-rows-4 {
    grid-template-rows: repeat(4, minmax(0, 1fr));
  }

  .pc\:grid-rows-5 {
    grid-template-rows: repeat(5, minmax(0, 1fr));
  }

  .pc\:grid-rows-6 {
    grid-template-rows: repeat(6, minmax(0, 1fr));
  }

  .pc\:grid-rows-none {
    grid-template-rows: none;
  }
}
/*!markdown

---
title: Align Content
---

| Class       | Properties               |
| ----------- | ------------------------ |
| content-center | align-content: center |
| content-start | align-content: flex-start |
| content-end | align-content: flex-end |
| content-between | align-content: space-between |
| content-around | align-content: space-around |
| content-evenly | align-content: space-evenly |


*/
.content-center {
  align-content: center;
}

.content-start {
  align-content: flex-start;
}

.content-end {
  align-content: flex-end;
}

.content-between {
  align-content: space-between;
}

.content-around {
  align-content: space-around;
}

.content-evenly {
  align-content: space-evenly;
}

@media (max-width: 768px) {
  .m\:content-center {
    align-content: center;
  }

  .m\:content-start {
    align-content: flex-start;
  }

  .m\:content-end {
    align-content: flex-end;
  }

  .m\:content-between {
    align-content: space-between;
  }

  .m\:content-around {
    align-content: space-around;
  }

  .m\:content-evenly {
    align-content: space-evenly;
  }
}
@media (min-width: 769px) {
  .pc\:content-center {
    align-content: center;
  }

  .pc\:content-start {
    align-content: flex-start;
  }

  .pc\:content-end {
    align-content: flex-end;
  }

  .pc\:content-between {
    align-content: space-between;
  }

  .pc\:content-around {
    align-content: space-around;
  }

  .pc\:content-evenly {
    align-content: space-evenly;
  }
}
/*!markdown

---
title: Align Items
---

| Class       | Properties               |
| ----------- | ------------------------ |
| items-start | align-items: flex-start |
| items-end | align-items: flex-end |
| items-center | align-items: center |
| items-baseline | align-items: baseline |
| items-stretch | align-items: stretch |


*/
.items-start {
  align-items: flex-start;
}

.items-end {
  align-items: flex-end;
}

.items-center {
  align-items: center;
}

.items-baseline {
  align-items: baseline;
}

.items-stretch {
  align-items: stretch;
}

@media (max-width: 768px) {
  .m\:items-start {
    align-items: flex-start;
  }

  .m\:items-end {
    align-items: flex-end;
  }

  .m\:items-center {
    align-items: center;
  }

  .m\:items-baseline {
    align-items: baseline;
  }

  .m\:items-stretch {
    align-items: stretch;
  }
}
@media (min-width: 769px) {
  .pc\:items-start {
    align-items: flex-start;
  }

  .pc\:items-end {
    align-items: flex-end;
  }

  .pc\:items-center {
    align-items: center;
  }

  .pc\:items-baseline {
    align-items: baseline;
  }

  .pc\:items-stretch {
    align-items: stretch;
  }
}
/*!markdown

---
title: Align Self
---

| Class       | Properties               |
| ----------- | ------------------------ |
| self-auto | align-self: auto |
| self-start | align-self: flex-start |
| self-end | align-self: flex-end |
| self-center | align-self: center |
| self-stretch | align-self: stretch |

*/
.self-auto {
  align-self: auto;
}

.self-start {
  align-self: flex-start;
}

.self-end {
  align-self: flex-end;
}

.self-center {
  align-self: center;
}

.self-stretch {
  align-self: stretch;
}

@media (max-width: 768px) {
  .m\:self-auto {
    align-self: auto;
  }

  .m\:self-start {
    align-self: flex-start;
  }

  .m\:self-end {
    align-self: flex-end;
  }

  .m\:self-center {
    align-self: center;
  }

  .m\:self-stretch {
    align-self: stretch;
  }
}
@media (min-width: 769px) {
  .pc\:self-auto {
    align-self: auto;
  }

  .pc\:self-start {
    align-self: flex-start;
  }

  .pc\:self-end {
    align-self: flex-end;
  }

  .pc\:self-center {
    align-self: center;
  }

  .pc\:self-stretch {
    align-self: stretch;
  }
}
/*!markdown

---
title: Jsutify Content
---

| Class       | Properties               |
| ----------- | ------------------------ |
| justify-start | justify-content: flex-start |
| justify-end | justify-content: flex-end |
| justify-center | justify-content: center |
| justify-between | justify-content: space-between |
| justify-around | justify-content: space-around |
| justify-evenly | justify-content: space-evenly |


*/
.justify-start {
  justify-content: flex-start;
}

.justify-end {
  justify-content: flex-end;
}

.justify-center {
  justify-content: center;
}

.justify-between {
  justify-content: space-between;
}

.justify-around {
  justify-content: space-around;
}

.justify-evenly {
  justify-content: space-evenly;
}

@media (max-width: 768px) {
  .m\:justify-start {
    justify-content: flex-start;
  }

  .m\:justify-end {
    justify-content: flex-end;
  }

  .m\:justify-center {
    justify-content: center;
  }

  .m\:justify-between {
    justify-content: space-between;
  }

  .m\:justify-around {
    justify-content: space-around;
  }

  .m\:justify-evenly {
    justify-content: space-evenly;
  }
}
@media (min-width: 769px) {
  .pc\:justify-start {
    justify-content: flex-start;
  }

  .pc\:justify-end {
    justify-content: flex-end;
  }

  .pc\:justify-center {
    justify-content: center;
  }

  .pc\:justify-between {
    justify-content: space-between;
  }

  .pc\:justify-around {
    justify-content: space-around;
  }

  .pc\:justify-evenly {
    justify-content: space-evenly;
  }
}
/*!markdown

---
title: Justify Items
---

| Class       | Properties               |
| ----------- | ------------------------ |
| justify-items-auto | justify-items: auto |
| justify-items-start | justify-items: start |
| justify-items-end | justify-items: end |
| justify-items-center | justify-items: center |
| justify-items-stretch | justify-items: stretch |


*/
.justify-items-auto {
  justify-items: auto;
}

.justify-items-start {
  justify-items: start;
}

.justify-items-end {
  justify-items: end;
}

.justify-items-center {
  justify-items: center;
}

.justify-items-stretch {
  justify-items: stretch;
}

@media (max-width: 768px) {
  .m\:justify-items-auto {
    justify-items: auto;
  }

  .m\:justify-items-start {
    justify-items: start;
  }

  .m\:justify-items-end {
    justify-items: end;
  }

  .m\:justify-items-center {
    justify-items: center;
  }

  .m\:justify-items-stretch {
    justify-items: stretch;
  }
}
@media (min-width: 769px) {
  .pc\:justify-items-auto {
    justify-items: auto;
  }

  .pc\:justify-items-start {
    justify-items: start;
  }

  .pc\:justify-items-end {
    justify-items: end;
  }

  .pc\:justify-items-center {
    justify-items: center;
  }

  .pc\:justify-items-stretch {
    justify-items: stretch;
  }
}
/*!markdown

---
title: Jsutify Self
---

| Class       | Properties               |
| ----------- | ------------------------ |
| justify-self-auto | justify-self: auto |
| justify-self-start | justify-self: start |
| justify-self-end | justify-self: end |
| justify-self-center | justify-self: center |
| justify-self-stretch | justify-self: stretch |


*/
.justify-self-auto {
  justify-self: auto;
}

.justify-self-start {
  justify-self: start;
}

.justify-self-end {
  justify-self: end;
}

.justify-self-center {
  justify-self: center;
}

.justify-self-stretch {
  justify-self: stretch;
}

@media (max-width: 768px) {
  .m\:justify-self-auto {
    justify-self: auto;
  }

  .m\:justify-self-start {
    justify-self: start;
  }

  .m\:justify-self-end {
    justify-self: end;
  }

  .m\:justify-self-center {
    justify-self: center;
  }

  .m\:justify-self-stretch {
    justify-self: stretch;
  }
}
@media (min-width: 769px) {
  .pc\:justify-self-auto {
    justify-self: auto;
  }

  .pc\:justify-self-start {
    justify-self: start;
  }

  .pc\:justify-self-end {
    justify-self: end;
  }

  .pc\:justify-self-center {
    justify-self: center;
  }

  .pc\:justify-self-stretch {
    justify-self: stretch;
  }
}
/*!markdown

---
title: Place Content
---

| Class       | Properties               |
| ----------- | ------------------------ |
| place-content-center | place-content: center |
| place-content-start | place-content: start |
| place-content-end | place-content: end |
| place-content-between | place-content: space-between |
| place-content-around | place-content: space-around |
| place-content-evenly | place-content: space-evenly |
| place-content-stretch | place-content: stretch |


*/
.place-content-center {
  place-content: center;
}

.place-content-start {
  place-content: start;
}

.place-content-end {
  place-content: end;
}

.place-content-between {
  place-content: space-between;
}

.place-content-around {
  place-content: space-around;
}

.place-content-evenly {
  place-content: space-evenly;
}

.place-content-stretch {
  place-content: stretch;
}

@media (max-width: 768px) {
  .m\:place-content-center {
    place-content: center;
  }

  .m\:place-content-start {
    place-content: start;
  }

  .m\:place-content-end {
    place-content: end;
  }

  .m\:place-content-between {
    place-content: space-between;
  }

  .m\:place-content-around {
    place-content: space-around;
  }

  .m\:place-content-evenly {
    place-content: space-evenly;
  }

  .m\:place-content-stretch {
    place-content: stretch;
  }
}
@media (min-width: 769px) {
  .pc\:place-content-center {
    place-content: center;
  }

  .pc\:place-content-start {
    place-content: start;
  }

  .pc\:place-content-end {
    place-content: end;
  }

  .pc\:place-content-between {
    place-content: space-between;
  }

  .pc\:place-content-around {
    place-content: space-around;
  }

  .pc\:place-content-evenly {
    place-content: space-evenly;
  }

  .pc\:place-content-stretch {
    place-content: stretch;
  }
}
/*!markdown

---
title: Place Items
---

| Class       | Properties               |
| ----------- | ------------------------ |
| place-items-auto | place-items: auto |
| place-items-start | place-items: start |
| place-items-end | place-items: end |
| place-items-center | place-items: center |
| place-items-stretch | place-items: stretch |


*/
.place-items-auto {
  place-items: auto;
}

.place-items-start {
  place-items: start;
}

.place-items-end {
  place-items: end;
}

.place-items-center {
  place-items: center;
}

.place-items-stretch {
  place-items: stretch;
}

@media (max-width: 768px) {
  .m\:place-items-auto {
    place-items: auto;
  }

  .m\:place-items-start {
    place-items: start;
  }

  .m\:place-items-end {
    place-items: end;
  }

  .m\:place-items-center {
    place-items: center;
  }

  .m\:place-items-stretch {
    place-items: stretch;
  }
}
@media (min-width: 769px) {
  .pc\:place-items-auto {
    place-items: auto;
  }

  .pc\:place-items-start {
    place-items: start;
  }

  .pc\:place-items-end {
    place-items: end;
  }

  .pc\:place-items-center {
    place-items: center;
  }

  .pc\:place-items-stretch {
    place-items: stretch;
  }
}
/*!markdown

---
title: Place Self
---

| Class       | Properties               |
| ----------- | ------------------------ |
| place-self-auto | place-self: auto |
| place-self-start | place-self: start |
| place-self-end | place-self: end |
| place-self-center | place-self: center |
| place-self-stretch | place-self: stretch |


*/
.place-self-auto {
  place-self: auto;
}

.place-self-start {
  place-self: start;
}

.place-self-end {
  place-self: end;
}

.place-self-center {
  place-self: center;
}

.place-self-stretch {
  place-self: stretch;
}

@media (max-width: 768px) {
  .m\:place-self-auto {
    place-self: auto;
  }

  .m\:place-self-start {
    place-self: start;
  }

  .m\:place-self-end {
    place-self: end;
  }

  .m\:place-self-center {
    place-self: center;
  }

  .m\:place-self-stretch {
    place-self: stretch;
  }
}
@media (min-width: 769px) {
  .pc\:place-self-auto {
    place-self: auto;
  }

  .pc\:place-self-start {
    place-self: start;
  }

  .pc\:place-self-end {
    place-self: end;
  }

  .pc\:place-self-center {
    place-self: center;
  }

  .pc\:place-self-stretch {
    place-self: stretch;
  }
}
/*!markdown

---
title: Box Shadow
---

| Class       | Properties               |
| ----------- | ------------------------ |
| shadow-sm | box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05) |
| shadow | box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06) |
| shadow-md | box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06) |
| shadow-lg | box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05) |
| shadow-xl | box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1) , 0 10px 10px -5px rgba(0, 0, 0, 0.04) |
| shadow-2xl | box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25) |
| shadow-inner | box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06) |
| shadow-none | box-shadow: none |

还有 hover、active、focus 扩展，比如 `hover:shadow-sm`

*/
.shadow-sm {
  box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);
}

.shadow {
  box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);
}

.shadow-md {
  box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);
}

.shadow-lg {
  box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);
}

.shadow-xl {
  box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1) , 0 10px 10px -5px rgba(0, 0, 0, 0.04);
}

.shadow-2xl {
  box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);
}

.shadow-inner {
  box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);
}

.shadow-none {
  box-shadow: none;
}

.hover\:shadow-sm:hover {
  box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);
}

.hover\:shadow:hover {
  box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);
}

.hover\:shadow-md:hover {
  box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);
}

.hover\:shadow-lg:hover {
  box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);
}

.hover\:shadow-xl:hover {
  box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1) , 0 10px 10px -5px rgba(0, 0, 0, 0.04);
}

.hover\:shadow-2xl:hover {
  box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);
}

.hover\:shadow-inner:hover {
  box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);
}

.hover\:shadow-none:hover {
  box-shadow: none;
}

.active\:shadow-sm.is-active,
.active\:shadow-sm:active {
  box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);
}

.active\:shadow.is-active,
.active\:shadow:active {
  box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);
}

.active\:shadow-md.is-active,
.active\:shadow-md:active {
  box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);
}

.active\:shadow-lg.is-active,
.active\:shadow-lg:active {
  box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);
}

.active\:shadow-xl.is-active,
.active\:shadow-xl:active {
  box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1) , 0 10px 10px -5px rgba(0, 0, 0, 0.04);
}

.active\:shadow-2xl.is-active,
.active\:shadow-2xl:active {
  box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);
}

.active\:shadow-inner.is-active,
.active\:shadow-inner:active {
  box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);
}

.active\:shadow-none.is-active,
.active\:shadow-none:active {
  box-shadow: none;
}

.focus\:shadow-sm:focus {
  box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);
}

.focus\:shadow:focus {
  box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);
}

.focus\:shadow-md:focus {
  box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);
}

.focus\:shadow-lg:focus {
  box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);
}

.focus\:shadow-xl:focus {
  box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1) , 0 10px 10px -5px rgba(0, 0, 0, 0.04);
}

.focus\:shadow-2xl:focus {
  box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);
}

.focus\:shadow-inner:focus {
  box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);
}

.focus\:shadow-none:focus {
  box-shadow: none;
}

.disabled\:shadow-sm.is-disabled,
.disabled\:shadow-sm:disabled {
  box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);
}

.disabled\:shadow.is-disabled,
.disabled\:shadow:disabled {
  box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);
}

.disabled\:shadow-md.is-disabled,
.disabled\:shadow-md:disabled {
  box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);
}

.disabled\:shadow-lg.is-disabled,
.disabled\:shadow-lg:disabled {
  box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);
}

.disabled\:shadow-xl.is-disabled,
.disabled\:shadow-xl:disabled {
  box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1) , 0 10px 10px -5px rgba(0, 0, 0, 0.04);
}

.disabled\:shadow-2xl.is-disabled,
.disabled\:shadow-2xl:disabled {
  box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);
}

.disabled\:shadow-inner.is-disabled,
.disabled\:shadow-inner:disabled {
  box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);
}

.disabled\:shadow-none.is-disabled,
.disabled\:shadow-none:disabled {
  box-shadow: none;
}

.group:hover .group-hover\:shadow-sm {
  box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);
}

.group:hover .group-hover\:shadow {
  box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);
}

.group:hover .group-hover\:shadow-md {
  box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);
}

.group:hover .group-hover\:shadow-lg {
  box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);
}

.group:hover .group-hover\:shadow-xl {
  box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1) , 0 10px 10px -5px rgba(0, 0, 0, 0.04);
}

.group:hover .group-hover\:shadow-2xl {
  box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);
}

.group:hover .group-hover\:shadow-inner {
  box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);
}

.group:hover .group-hover\:shadow-none {
  box-shadow: none;
}

@media (max-width: 768px) {
  .m\:shadow-sm {
    box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);
  }

  .m\:shadow {
    box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);
  }

  .m\:shadow-md {
    box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);
  }

  .m\:shadow-lg {
    box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);
  }

  .m\:shadow-xl {
    box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1) , 0 10px 10px -5px rgba(0, 0, 0, 0.04);
  }

  .m\:shadow-2xl {
    box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);
  }

  .m\:shadow-inner {
    box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);
  }

  .m\:shadow-none {
    box-shadow: none;
  }

  .m\:hover\:shadow-sm:hover {
    box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);
  }

  .m\:hover\:shadow:hover {
    box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);
  }

  .m\:hover\:shadow-md:hover {
    box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);
  }

  .m\:hover\:shadow-lg:hover {
    box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);
  }

  .m\:hover\:shadow-xl:hover {
    box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1) , 0 10px 10px -5px rgba(0, 0, 0, 0.04);
  }

  .m\:hover\:shadow-2xl:hover {
    box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);
  }

  .m\:hover\:shadow-inner:hover {
    box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);
  }

  .m\:hover\:shadow-none:hover {
    box-shadow: none;
  }

  .m\:active\:shadow-sm.is-active,
.m\:active\:shadow-sm:active {
    box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);
  }

  .m\:active\:shadow.is-active,
.m\:active\:shadow:active {
    box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);
  }

  .m\:active\:shadow-md.is-active,
.m\:active\:shadow-md:active {
    box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);
  }

  .m\:active\:shadow-lg.is-active,
.m\:active\:shadow-lg:active {
    box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);
  }

  .m\:active\:shadow-xl.is-active,
.m\:active\:shadow-xl:active {
    box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1) , 0 10px 10px -5px rgba(0, 0, 0, 0.04);
  }

  .m\:active\:shadow-2xl.is-active,
.m\:active\:shadow-2xl:active {
    box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);
  }

  .m\:active\:shadow-inner.is-active,
.m\:active\:shadow-inner:active {
    box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);
  }

  .m\:active\:shadow-none.is-active,
.m\:active\:shadow-none:active {
    box-shadow: none;
  }

  .m\:focus\:shadow-sm:focus {
    box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);
  }

  .m\:focus\:shadow:focus {
    box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);
  }

  .m\:focus\:shadow-md:focus {
    box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);
  }

  .m\:focus\:shadow-lg:focus {
    box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);
  }

  .m\:focus\:shadow-xl:focus {
    box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1) , 0 10px 10px -5px rgba(0, 0, 0, 0.04);
  }

  .m\:focus\:shadow-2xl:focus {
    box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);
  }

  .m\:focus\:shadow-inner:focus {
    box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);
  }

  .m\:focus\:shadow-none:focus {
    box-shadow: none;
  }

  .m\:disabled\:shadow-sm.is-disabled,
.m\:disabled\:shadow-sm:disabled {
    box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);
  }

  .m\:disabled\:shadow.is-disabled,
.m\:disabled\:shadow:disabled {
    box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);
  }

  .m\:disabled\:shadow-md.is-disabled,
.m\:disabled\:shadow-md:disabled {
    box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);
  }

  .m\:disabled\:shadow-lg.is-disabled,
.m\:disabled\:shadow-lg:disabled {
    box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);
  }

  .m\:disabled\:shadow-xl.is-disabled,
.m\:disabled\:shadow-xl:disabled {
    box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1) , 0 10px 10px -5px rgba(0, 0, 0, 0.04);
  }

  .m\:disabled\:shadow-2xl.is-disabled,
.m\:disabled\:shadow-2xl:disabled {
    box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);
  }

  .m\:disabled\:shadow-inner.is-disabled,
.m\:disabled\:shadow-inner:disabled {
    box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);
  }

  .m\:disabled\:shadow-none.is-disabled,
.m\:disabled\:shadow-none:disabled {
    box-shadow: none;
  }

  .group:hover .m\:group-hover\:shadow-sm {
    box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);
  }

  .group:hover .m\:group-hover\:shadow {
    box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);
  }

  .group:hover .m\:group-hover\:shadow-md {
    box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);
  }

  .group:hover .m\:group-hover\:shadow-lg {
    box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);
  }

  .group:hover .m\:group-hover\:shadow-xl {
    box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1) , 0 10px 10px -5px rgba(0, 0, 0, 0.04);
  }

  .group:hover .m\:group-hover\:shadow-2xl {
    box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);
  }

  .group:hover .m\:group-hover\:shadow-inner {
    box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);
  }

  .group:hover .m\:group-hover\:shadow-none {
    box-shadow: none;
  }
}
@media (min-width: 769px) {
  .pc\:shadow-sm {
    box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);
  }

  .pc\:shadow {
    box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);
  }

  .pc\:shadow-md {
    box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);
  }

  .pc\:shadow-lg {
    box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);
  }

  .pc\:shadow-xl {
    box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1) , 0 10px 10px -5px rgba(0, 0, 0, 0.04);
  }

  .pc\:shadow-2xl {
    box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);
  }

  .pc\:shadow-inner {
    box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);
  }

  .pc\:shadow-none {
    box-shadow: none;
  }

  .pc\:hover\:shadow-sm:hover {
    box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);
  }

  .pc\:hover\:shadow:hover {
    box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);
  }

  .pc\:hover\:shadow-md:hover {
    box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);
  }

  .pc\:hover\:shadow-lg:hover {
    box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);
  }

  .pc\:hover\:shadow-xl:hover {
    box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1) , 0 10px 10px -5px rgba(0, 0, 0, 0.04);
  }

  .pc\:hover\:shadow-2xl:hover {
    box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);
  }

  .pc\:hover\:shadow-inner:hover {
    box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);
  }

  .pc\:hover\:shadow-none:hover {
    box-shadow: none;
  }

  .pc\:active\:shadow-sm.is-active,
.pc\:active\:shadow-sm:active {
    box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);
  }

  .pc\:active\:shadow.is-active,
.pc\:active\:shadow:active {
    box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);
  }

  .pc\:active\:shadow-md.is-active,
.pc\:active\:shadow-md:active {
    box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);
  }

  .pc\:active\:shadow-lg.is-active,
.pc\:active\:shadow-lg:active {
    box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);
  }

  .pc\:active\:shadow-xl.is-active,
.pc\:active\:shadow-xl:active {
    box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1) , 0 10px 10px -5px rgba(0, 0, 0, 0.04);
  }

  .pc\:active\:shadow-2xl.is-active,
.pc\:active\:shadow-2xl:active {
    box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);
  }

  .pc\:active\:shadow-inner.is-active,
.pc\:active\:shadow-inner:active {
    box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);
  }

  .pc\:active\:shadow-none.is-active,
.pc\:active\:shadow-none:active {
    box-shadow: none;
  }

  .pc\:focus\:shadow-sm:focus {
    box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);
  }

  .pc\:focus\:shadow:focus {
    box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);
  }

  .pc\:focus\:shadow-md:focus {
    box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);
  }

  .pc\:focus\:shadow-lg:focus {
    box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);
  }

  .pc\:focus\:shadow-xl:focus {
    box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1) , 0 10px 10px -5px rgba(0, 0, 0, 0.04);
  }

  .pc\:focus\:shadow-2xl:focus {
    box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);
  }

  .pc\:focus\:shadow-inner:focus {
    box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);
  }

  .pc\:focus\:shadow-none:focus {
    box-shadow: none;
  }

  .pc\:disabled\:shadow-sm.is-disabled,
.pc\:disabled\:shadow-sm:disabled {
    box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);
  }

  .pc\:disabled\:shadow.is-disabled,
.pc\:disabled\:shadow:disabled {
    box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);
  }

  .pc\:disabled\:shadow-md.is-disabled,
.pc\:disabled\:shadow-md:disabled {
    box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);
  }

  .pc\:disabled\:shadow-lg.is-disabled,
.pc\:disabled\:shadow-lg:disabled {
    box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);
  }

  .pc\:disabled\:shadow-xl.is-disabled,
.pc\:disabled\:shadow-xl:disabled {
    box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1) , 0 10px 10px -5px rgba(0, 0, 0, 0.04);
  }

  .pc\:disabled\:shadow-2xl.is-disabled,
.pc\:disabled\:shadow-2xl:disabled {
    box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);
  }

  .pc\:disabled\:shadow-inner.is-disabled,
.pc\:disabled\:shadow-inner:disabled {
    box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);
  }

  .pc\:disabled\:shadow-none.is-disabled,
.pc\:disabled\:shadow-none:disabled {
    box-shadow: none;
  }

  .group:hover .pc\:group-hover\:shadow-sm {
    box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);
  }

  .group:hover .pc\:group-hover\:shadow {
    box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);
  }

  .group:hover .pc\:group-hover\:shadow-md {
    box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);
  }

  .group:hover .pc\:group-hover\:shadow-lg {
    box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);
  }

  .group:hover .pc\:group-hover\:shadow-xl {
    box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1) , 0 10px 10px -5px rgba(0, 0, 0, 0.04);
  }

  .group:hover .pc\:group-hover\:shadow-2xl {
    box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);
  }

  .group:hover .pc\:group-hover\:shadow-inner {
    box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);
  }

  .group:hover .pc\:group-hover\:shadow-none {
    box-shadow: none;
  }
}
/*!markdown

---
title: Margin
---

| Class       | Properties               |
| ----------- | ------------------------ |
| m-px | margin: 0.0625rem |
| m-0 | margin: 0 |
| m-none | margin: 0 |
| m-0\.5 | margin: 0.125rem |
| m-1 | margin: 0.25rem |
| m-1\.5 | margin: 0.375rem |
| m-2 | margin: 0.5rem |
| m-2\.5 | margin: 0.625rem |
| m-3 | margin: 0.75rem |
| m-3\.5 | margin: 0.875rem |
| m-4 | margin: 1rem |
| m-5 | margin: 1.25rem |
| m-6 | margin: 1.5rem |
| m-7 | margin: 1.75rem |
| m-8 | margin: 2rem |
| m-9 | margin: 2.25rem |
| m-10 | margin: 2.5rem |
| m-11 | margin: 2.75rem |
| m-12 | margin: 3rem |
| m-14 | margin: 3.5rem |
| m-16 | margin: 4rem |
| m-18 | margin: 4.5rem |
| m-20 | margin: 5rem |
| m-24 | margin: 6rem |
| m-28 | margin: 7rem |
| m-32 | margin: 8rem |
| m-36 | margin: 9rem |
| m-40 | margin: 10rem |
| m-44 | margin: 11rem |
| m-48 | margin: 12rem |
| m-52 | margin: 13rem |
| m-56 | margin: 14rem |
| m-60 | margin: 15rem |
| m-64 | margin: 16rem |
| m-72 | margin: 18rem |
| m-80 | margin: 20rem |
| m-96 | margin: 24rem |
| m-auto | margin: auto |
| -m-px | margin: -0.0625rem |
| -m-0 | margin: 0 |
| -m-none | margin: 0 |
| -m-0\.5 | margin: -0.125rem |
| -m-1 | margin: -0.25rem |
| -m-1\.5 | margin: -0.375rem |
| -m-2 | margin: -0.5rem |
| -m-2\.5 | margin: -0.625rem |
| -m-3 | margin: -0.75rem |
| -m-3\.5 | margin: -0.875rem |
| -m-4 | margin: -1rem |
| -m-5 | margin: -1.25rem |
| -m-6 | margin: -1.5rem |
| -m-7 | margin: -1.75rem |
| -m-8 | margin: -2rem |
| -m-9 | margin: -2.25rem |
| -m-10 | margin: -2.5rem |
| -m-11 | margin: -2.75rem |
| -m-12 | margin: -3rem |
| -m-14 | margin: -3.5rem |
| -m-16 | margin: -4rem |
| -m-18 | margin: -4.5rem |
| -m-20 | margin: -5rem |
| -m-24 | margin: -6rem |
| -m-28 | margin: -7rem |
| -m-32 | margin: -8rem |
| -m-36 | margin: -9rem |
| -m-40 | margin: -10rem |
| -m-44 | margin: -11rem |
| -m-48 | margin: -12rem |
| -m-52 | margin: -13rem |
| -m-56 | margin: -14rem |
| -m-60 | margin: -15rem |
| -m-64 | margin: -16rem |
| -m-72 | margin: -18rem |
| -m-80 | margin: -20rem |
| -m-96 | margin: -24rem |
| mx-px | margin-left: 0.0625rem; margin-right: 0.0625rem |
| mx-0 | margin-left: 0; margin-right: 0 |
| mx-none | margin-left: 0; margin-right: 0 |
| mx-0\.5 | margin-left: 0.125rem; margin-right: 0.125rem |
| mx-1 | margin-left: 0.25rem; margin-right: 0.25rem |
| mx-1\.5 | margin-left: 0.375rem; margin-right: 0.375rem |
| mx-2 | margin-left: 0.5rem; margin-right: 0.5rem |
| mx-2\.5 | margin-left: 0.625rem; margin-right: 0.625rem |
| mx-3 | margin-left: 0.75rem; margin-right: 0.75rem |
| mx-3\.5 | margin-left: 0.875rem; margin-right: 0.875rem |
| mx-4 | margin-left: 1rem; margin-right: 1rem |
| mx-5 | margin-left: 1.25rem; margin-right: 1.25rem |
| mx-6 | margin-left: 1.5rem; margin-right: 1.5rem |
| mx-7 | margin-left: 1.75rem; margin-right: 1.75rem |
| mx-8 | margin-left: 2rem; margin-right: 2rem |
| mx-9 | margin-left: 2.25rem; margin-right: 2.25rem |
| mx-10 | margin-left: 2.5rem; margin-right: 2.5rem |
| mx-11 | margin-left: 2.75rem; margin-right: 2.75rem |
| mx-12 | margin-left: 3rem; margin-right: 3rem |
| mx-14 | margin-left: 3.5rem; margin-right: 3.5rem |
| mx-16 | margin-left: 4rem; margin-right: 4rem |
| mx-18 | margin-left: 4.5rem; margin-right: 4.5rem |
| mx-20 | margin-left: 5rem; margin-right: 5rem |
| mx-24 | margin-left: 6rem; margin-right: 6rem |
| mx-28 | margin-left: 7rem; margin-right: 7rem |
| mx-32 | margin-left: 8rem; margin-right: 8rem |
| mx-36 | margin-left: 9rem; margin-right: 9rem |
| mx-40 | margin-left: 10rem; margin-right: 10rem |
| mx-44 | margin-left: 11rem; margin-right: 11rem |
| mx-48 | margin-left: 12rem; margin-right: 12rem |
| mx-52 | margin-left: 13rem; margin-right: 13rem |
| mx-56 | margin-left: 14rem; margin-right: 14rem |
| mx-60 | margin-left: 15rem; margin-right: 15rem |
| mx-64 | margin-left: 16rem; margin-right: 16rem |
| mx-72 | margin-left: 18rem; margin-right: 18rem |
| mx-80 | margin-left: 20rem; margin-right: 20rem |
| mx-96 | margin-left: 24rem; margin-right: 24rem |
| mx-auto | margin-left: auto; margin-right: auto |
| -mx-px | margin-left: -0.0625rem; margin-right: -0.0625rem |
| -mx-0 | margin-left: 0; margin-right: 0 |
| -mx-none | margin-left: 0; margin-right: 0 |
| -mx-0\.5 | margin-left: -0.125rem; margin-right: -0.125rem |
| -mx-1 | margin-left: -0.25rem; margin-right: -0.25rem |
| -mx-1\.5 | margin-left: -0.375rem; margin-right: -0.375rem |
| -mx-2 | margin-left: -0.5rem; margin-right: -0.5rem |
| -mx-2\.5 | margin-left: -0.625rem; margin-right: -0.625rem |
| -mx-3 | margin-left: -0.75rem; margin-right: -0.75rem |
| -mx-3\.5 | margin-left: -0.875rem; margin-right: -0.875rem |
| -mx-4 | margin-left: -1rem; margin-right: -1rem |
| -mx-5 | margin-left: -1.25rem; margin-right: -1.25rem |
| -mx-6 | margin-left: -1.5rem; margin-right: -1.5rem |
| -mx-7 | margin-left: -1.75rem; margin-right: -1.75rem |
| -mx-8 | margin-left: -2rem; margin-right: -2rem |
| -mx-9 | margin-left: -2.25rem; margin-right: -2.25rem |
| -mx-10 | margin-left: -2.5rem; margin-right: -2.5rem |
| -mx-11 | margin-left: -2.75rem; margin-right: -2.75rem |
| -mx-12 | margin-left: -3rem; margin-right: -3rem |
| -mx-14 | margin-left: -3.5rem; margin-right: -3.5rem |
| -mx-16 | margin-left: -4rem; margin-right: -4rem |
| -mx-18 | margin-left: -4.5rem; margin-right: -4.5rem |
| -mx-20 | margin-left: -5rem; margin-right: -5rem |
| -mx-24 | margin-left: -6rem; margin-right: -6rem |
| -mx-28 | margin-left: -7rem; margin-right: -7rem |
| -mx-32 | margin-left: -8rem; margin-right: -8rem |
| -mx-36 | margin-left: -9rem; margin-right: -9rem |
| -mx-40 | margin-left: -10rem; margin-right: -10rem |
| -mx-44 | margin-left: -11rem; margin-right: -11rem |
| -mx-48 | margin-left: -12rem; margin-right: -12rem |
| -mx-52 | margin-left: -13rem; margin-right: -13rem |
| -mx-56 | margin-left: -14rem; margin-right: -14rem |
| -mx-60 | margin-left: -15rem; margin-right: -15rem |
| -mx-64 | margin-left: -16rem; margin-right: -16rem |
| -mx-72 | margin-left: -18rem; margin-right: -18rem |
| -mx-80 | margin-left: -20rem; margin-right: -20rem |
| -mx-96 | margin-left: -24rem; margin-right: -24rem |
| my-px | margin-top: 0.0625rem; margin-bottom: 0.0625rem |
| my-0 | margin-top: 0; margin-bottom: 0 |
| my-none | margin-top: 0; margin-bottom: 0 |
| my-0\.5 | margin-top: 0.125rem; margin-bottom: 0.125rem |
| my-1 | margin-top: 0.25rem; margin-bottom: 0.25rem |
| my-1\.5 | margin-top: 0.375rem; margin-bottom: 0.375rem |
| my-2 | margin-top: 0.5rem; margin-bottom: 0.5rem |
| my-2\.5 | margin-top: 0.625rem; margin-bottom: 0.625rem |
| my-3 | margin-top: 0.75rem; margin-bottom: 0.75rem |
| my-3\.5 | margin-top: 0.875rem; margin-bottom: 0.875rem |
| my-4 | margin-top: 1rem; margin-bottom: 1rem |
| my-5 | margin-top: 1.25rem; margin-bottom: 1.25rem |
| my-6 | margin-top: 1.5rem; margin-bottom: 1.5rem |
| my-7 | margin-top: 1.75rem; margin-bottom: 1.75rem |
| my-8 | margin-top: 2rem; margin-bottom: 2rem |
| my-9 | margin-top: 2.25rem; margin-bottom: 2.25rem |
| my-10 | margin-top: 2.5rem; margin-bottom: 2.5rem |
| my-11 | margin-top: 2.75rem; margin-bottom: 2.75rem |
| my-12 | margin-top: 3rem; margin-bottom: 3rem |
| my-14 | margin-top: 3.5rem; margin-bottom: 3.5rem |
| my-16 | margin-top: 4rem; margin-bottom: 4rem |
| my-18 | margin-top: 4.5rem; margin-bottom: 4.5rem |
| my-20 | margin-top: 5rem; margin-bottom: 5rem |
| my-24 | margin-top: 6rem; margin-bottom: 6rem |
| my-28 | margin-top: 7rem; margin-bottom: 7rem |
| my-32 | margin-top: 8rem; margin-bottom: 8rem |
| my-36 | margin-top: 9rem; margin-bottom: 9rem |
| my-40 | margin-top: 10rem; margin-bottom: 10rem |
| my-44 | margin-top: 11rem; margin-bottom: 11rem |
| my-48 | margin-top: 12rem; margin-bottom: 12rem |
| my-52 | margin-top: 13rem; margin-bottom: 13rem |
| my-56 | margin-top: 14rem; margin-bottom: 14rem |
| my-60 | margin-top: 15rem; margin-bottom: 15rem |
| my-64 | margin-top: 16rem; margin-bottom: 16rem |
| my-72 | margin-top: 18rem; margin-bottom: 18rem |
| my-80 | margin-top: 20rem; margin-bottom: 20rem |
| my-96 | margin-top: 24rem; margin-bottom: 24rem |
| my-auto | margin-top: auto; margin-bottom: auto |
| -my-px | margin-top: -0.0625rem; margin-bottom: -0.0625rem |
| -my-0 | margin-top: 0; margin-bottom: 0 |
| -my-none | margin-top: 0; margin-bottom: 0 |
| -my-0\.5 | margin-top: -0.125rem; margin-bottom: -0.125rem |
| -my-1 | margin-top: -0.25rem; margin-bottom: -0.25rem |
| -my-1\.5 | margin-top: -0.375rem; margin-bottom: -0.375rem |
| -my-2 | margin-top: -0.5rem; margin-bottom: -0.5rem |
| -my-2\.5 | margin-top: -0.625rem; margin-bottom: -0.625rem |
| -my-3 | margin-top: -0.75rem; margin-bottom: -0.75rem |
| -my-3\.5 | margin-top: -0.875rem; margin-bottom: -0.875rem |
| -my-4 | margin-top: -1rem; margin-bottom: -1rem |
| -my-5 | margin-top: -1.25rem; margin-bottom: -1.25rem |
| -my-6 | margin-top: -1.5rem; margin-bottom: -1.5rem |
| -my-7 | margin-top: -1.75rem; margin-bottom: -1.75rem |
| -my-8 | margin-top: -2rem; margin-bottom: -2rem |
| -my-9 | margin-top: -2.25rem; margin-bottom: -2.25rem |
| -my-10 | margin-top: -2.5rem; margin-bottom: -2.5rem |
| -my-11 | margin-top: -2.75rem; margin-bottom: -2.75rem |
| -my-12 | margin-top: -3rem; margin-bottom: -3rem |
| -my-14 | margin-top: -3.5rem; margin-bottom: -3.5rem |
| -my-16 | margin-top: -4rem; margin-bottom: -4rem |
| -my-18 | margin-top: -4.5rem; margin-bottom: -4.5rem |
| -my-20 | margin-top: -5rem; margin-bottom: -5rem |
| -my-24 | margin-top: -6rem; margin-bottom: -6rem |
| -my-28 | margin-top: -7rem; margin-bottom: -7rem |
| -my-32 | margin-top: -8rem; margin-bottom: -8rem |
| -my-36 | margin-top: -9rem; margin-bottom: -9rem |
| -my-40 | margin-top: -10rem; margin-bottom: -10rem |
| -my-44 | margin-top: -11rem; margin-bottom: -11rem |
| -my-48 | margin-top: -12rem; margin-bottom: -12rem |
| -my-52 | margin-top: -13rem; margin-bottom: -13rem |
| -my-56 | margin-top: -14rem; margin-bottom: -14rem |
| -my-60 | margin-top: -15rem; margin-bottom: -15rem |
| -my-64 | margin-top: -16rem; margin-bottom: -16rem |
| -my-72 | margin-top: -18rem; margin-bottom: -18rem |
| -my-80 | margin-top: -20rem; margin-bottom: -20rem |
| -my-96 | margin-top: -24rem; margin-bottom: -24rem |
| mt-px | margin-top: 0.0625rem |
| mt-0 | margin-top: 0 |
| mt-none | margin-top: 0 |
| mt-0\.5 | margin-top: 0.125rem |
| mt-1 | margin-top: 0.25rem |
| mt-1\.5 | margin-top: 0.375rem |
| mt-2 | margin-top: 0.5rem |
| mt-2\.5 | margin-top: 0.625rem |
| mt-3 | margin-top: 0.75rem |
| mt-3\.5 | margin-top: 0.875rem |
| mt-4 | margin-top: 1rem |
| mt-5 | margin-top: 1.25rem |
| mt-6 | margin-top: 1.5rem |
| mt-7 | margin-top: 1.75rem |
| mt-8 | margin-top: 2rem |
| mt-9 | margin-top: 2.25rem |
| mt-10 | margin-top: 2.5rem |
| mt-11 | margin-top: 2.75rem |
| mt-12 | margin-top: 3rem |
| mt-14 | margin-top: 3.5rem |
| mt-16 | margin-top: 4rem |
| mt-18 | margin-top: 4.5rem |
| mt-20 | margin-top: 5rem |
| mt-24 | margin-top: 6rem |
| mt-28 | margin-top: 7rem |
| mt-32 | margin-top: 8rem |
| mt-36 | margin-top: 9rem |
| mt-40 | margin-top: 10rem |
| mt-44 | margin-top: 11rem |
| mt-48 | margin-top: 12rem |
| mt-52 | margin-top: 13rem |
| mt-56 | margin-top: 14rem |
| mt-60 | margin-top: 15rem |
| mt-64 | margin-top: 16rem |
| mt-72 | margin-top: 18rem |
| mt-80 | margin-top: 20rem |
| mt-96 | margin-top: 24rem |
| -mt-px | margin-top: -0.0625rem |
| -mt-0 | margin-top: 0 |
| -mt-none | margin-top: 0 |
| -mt-0\.5 | margin-top: -0.125rem |
| -mt-1 | margin-top: -0.25rem |
| -mt-1\.5 | margin-top: -0.375rem |
| -mt-2 | margin-top: -0.5rem |
| -mt-2\.5 | margin-top: -0.625rem |
| -mt-3 | margin-top: -0.75rem |
| -mt-3\.5 | margin-top: -0.875rem |
| -mt-4 | margin-top: -1rem |
| -mt-5 | margin-top: -1.25rem |
| -mt-6 | margin-top: -1.5rem |
| -mt-7 | margin-top: -1.75rem |
| -mt-8 | margin-top: -2rem |
| -mt-9 | margin-top: -2.25rem |
| -mt-10 | margin-top: -2.5rem |
| -mt-11 | margin-top: -2.75rem |
| -mt-12 | margin-top: -3rem |
| -mt-14 | margin-top: -3.5rem |
| -mt-16 | margin-top: -4rem |
| -mt-18 | margin-top: -4.5rem |
| -mt-20 | margin-top: -5rem |
| -mt-24 | margin-top: -6rem |
| -mt-28 | margin-top: -7rem |
| -mt-32 | margin-top: -8rem |
| -mt-36 | margin-top: -9rem |
| -mt-40 | margin-top: -10rem |
| -mt-44 | margin-top: -11rem |
| -mt-48 | margin-top: -12rem |
| -mt-52 | margin-top: -13rem |
| -mt-56 | margin-top: -14rem |
| -mt-60 | margin-top: -15rem |
| -mt-64 | margin-top: -16rem |
| -mt-72 | margin-top: -18rem |
| -mt-80 | margin-top: -20rem |
| -mt-96 | margin-top: -24rem |
| mr-px | margin-right: 0.0625rem |
| mr-0 | margin-right: 0 |
| mr-none | margin-right: 0 |
| mr-0\.5 | margin-right: 0.125rem |
| mr-1 | margin-right: 0.25rem |
| mr-1\.5 | margin-right: 0.375rem |
| mr-2 | margin-right: 0.5rem |
| mr-2\.5 | margin-right: 0.625rem |
| mr-3 | margin-right: 0.75rem |
| mr-3\.5 | margin-right: 0.875rem |
| mr-4 | margin-right: 1rem |
| mr-5 | margin-right: 1.25rem |
| mr-6 | margin-right: 1.5rem |
| mr-7 | margin-right: 1.75rem |
| mr-8 | margin-right: 2rem |
| mr-9 | margin-right: 2.25rem |
| mr-10 | margin-right: 2.5rem |
| mr-11 | margin-right: 2.75rem |
| mr-12 | margin-right: 3rem |
| mr-14 | margin-right: 3.5rem |
| mr-16 | margin-right: 4rem |
| mr-18 | margin-right: 4.5rem |
| mr-20 | margin-right: 5rem |
| mr-24 | margin-right: 6rem |
| mr-28 | margin-right: 7rem |
| mr-32 | margin-right: 8rem |
| mr-36 | margin-right: 9rem |
| mr-40 | margin-right: 10rem |
| mr-44 | margin-right: 11rem |
| mr-48 | margin-right: 12rem |
| mr-52 | margin-right: 13rem |
| mr-56 | margin-right: 14rem |
| mr-60 | margin-right: 15rem |
| mr-64 | margin-right: 16rem |
| mr-72 | margin-right: 18rem |
| mr-80 | margin-right: 20rem |
| mr-96 | margin-right: 24rem |
| -mr-px | margin-right: -0.0625rem |
| -mr-0 | margin-right: 0 |
| -mr-none | margin-right: 0 |
| -mr-0\.5 | margin-right: -0.125rem |
| -mr-1 | margin-right: -0.25rem |
| -mr-1\.5 | margin-right: -0.375rem |
| -mr-2 | margin-right: -0.5rem |
| -mr-2\.5 | margin-right: -0.625rem |
| -mr-3 | margin-right: -0.75rem |
| -mr-3\.5 | margin-right: -0.875rem |
| -mr-4 | margin-right: -1rem |
| -mr-5 | margin-right: -1.25rem |
| -mr-6 | margin-right: -1.5rem |
| -mr-7 | margin-right: -1.75rem |
| -mr-8 | margin-right: -2rem |
| -mr-9 | margin-right: -2.25rem |
| -mr-10 | margin-right: -2.5rem |
| -mr-11 | margin-right: -2.75rem |
| -mr-12 | margin-right: -3rem |
| -mr-14 | margin-right: -3.5rem |
| -mr-16 | margin-right: -4rem |
| -mr-18 | margin-right: -4.5rem |
| -mr-20 | margin-right: -5rem |
| -mr-24 | margin-right: -6rem |
| -mr-28 | margin-right: -7rem |
| -mr-32 | margin-right: -8rem |
| -mr-36 | margin-right: -9rem |
| -mr-40 | margin-right: -10rem |
| -mr-44 | margin-right: -11rem |
| -mr-48 | margin-right: -12rem |
| -mr-52 | margin-right: -13rem |
| -mr-56 | margin-right: -14rem |
| -mr-60 | margin-right: -15rem |
| -mr-64 | margin-right: -16rem |
| -mr-72 | margin-right: -18rem |
| -mr-80 | margin-right: -20rem |
| -mr-96 | margin-right: -24rem |
| mb-px | margin-bottom: 0.0625rem |
| mb-0 | margin-bottom: 0 |
| mb-none | margin-bottom: 0 |
| mb-0\.5 | margin-bottom: 0.125rem |
| mb-1 | margin-bottom: 0.25rem |
| mb-1\.5 | margin-bottom: 0.375rem |
| mb-2 | margin-bottom: 0.5rem |
| mb-2\.5 | margin-bottom: 0.625rem |
| mb-3 | margin-bottom: 0.75rem |
| mb-3\.5 | margin-bottom: 0.875rem |
| mb-4 | margin-bottom: 1rem |
| mb-5 | margin-bottom: 1.25rem |
| mb-6 | margin-bottom: 1.5rem |
| mb-7 | margin-bottom: 1.75rem |
| mb-8 | margin-bottom: 2rem |
| mb-9 | margin-bottom: 2.25rem |
| mb-10 | margin-bottom: 2.5rem |
| mb-11 | margin-bottom: 2.75rem |
| mb-12 | margin-bottom: 3rem |
| mb-14 | margin-bottom: 3.5rem |
| mb-16 | margin-bottom: 4rem |
| mb-18 | margin-bottom: 4.5rem |
| mb-20 | margin-bottom: 5rem |
| mb-24 | margin-bottom: 6rem |
| mb-28 | margin-bottom: 7rem |
| mb-32 | margin-bottom: 8rem |
| mb-36 | margin-bottom: 9rem |
| mb-40 | margin-bottom: 10rem |
| mb-44 | margin-bottom: 11rem |
| mb-48 | margin-bottom: 12rem |
| mb-52 | margin-bottom: 13rem |
| mb-56 | margin-bottom: 14rem |
| mb-60 | margin-bottom: 15rem |
| mb-64 | margin-bottom: 16rem |
| mb-72 | margin-bottom: 18rem |
| mb-80 | margin-bottom: 20rem |
| mb-96 | margin-bottom: 24rem |
| -mb-px | margin-bottom: -0.0625rem |
| -mb-0 | margin-bottom: 0 |
| -mb-none | margin-bottom: 0 |
| -mb-0\.5 | margin-bottom: -0.125rem |
| -mb-1 | margin-bottom: -0.25rem |
| -mb-1\.5 | margin-bottom: -0.375rem |
| -mb-2 | margin-bottom: -0.5rem |
| -mb-2\.5 | margin-bottom: -0.625rem |
| -mb-3 | margin-bottom: -0.75rem |
| -mb-3\.5 | margin-bottom: -0.875rem |
| -mb-4 | margin-bottom: -1rem |
| -mb-5 | margin-bottom: -1.25rem |
| -mb-6 | margin-bottom: -1.5rem |
| -mb-7 | margin-bottom: -1.75rem |
| -mb-8 | margin-bottom: -2rem |
| -mb-9 | margin-bottom: -2.25rem |
| -mb-10 | margin-bottom: -2.5rem |
| -mb-11 | margin-bottom: -2.75rem |
| -mb-12 | margin-bottom: -3rem |
| -mb-14 | margin-bottom: -3.5rem |
| -mb-16 | margin-bottom: -4rem |
| -mb-18 | margin-bottom: -4.5rem |
| -mb-20 | margin-bottom: -5rem |
| -mb-24 | margin-bottom: -6rem |
| -mb-28 | margin-bottom: -7rem |
| -mb-32 | margin-bottom: -8rem |
| -mb-36 | margin-bottom: -9rem |
| -mb-40 | margin-bottom: -10rem |
| -mb-44 | margin-bottom: -11rem |
| -mb-48 | margin-bottom: -12rem |
| -mb-52 | margin-bottom: -13rem |
| -mb-56 | margin-bottom: -14rem |
| -mb-60 | margin-bottom: -15rem |
| -mb-64 | margin-bottom: -16rem |
| -mb-72 | margin-bottom: -18rem |
| -mb-80 | margin-bottom: -20rem |
| -mb-96 | margin-bottom: -24rem |
| ml-px | margin-left: 0.0625rem |
| ml-0 | margin-left: 0 |
| ml-none | margin-left: 0 |
| ml-0\.5 | margin-left: 0.125rem |
| ml-1 | margin-left: 0.25rem |
| ml-1\.5 | margin-left: 0.375rem |
| ml-2 | margin-left: 0.5rem |
| ml-2\.5 | margin-left: 0.625rem |
| ml-3 | margin-left: 0.75rem |
| ml-3\.5 | margin-left: 0.875rem |
| ml-4 | margin-left: 1rem |
| ml-5 | margin-left: 1.25rem |
| ml-6 | margin-left: 1.5rem |
| ml-7 | margin-left: 1.75rem |
| ml-8 | margin-left: 2rem |
| ml-9 | margin-left: 2.25rem |
| ml-10 | margin-left: 2.5rem |
| ml-11 | margin-left: 2.75rem |
| ml-12 | margin-left: 3rem |
| ml-14 | margin-left: 3.5rem |
| ml-16 | margin-left: 4rem |
| ml-18 | margin-left: 4.5rem |
| ml-20 | margin-left: 5rem |
| ml-24 | margin-left: 6rem |
| ml-28 | margin-left: 7rem |
| ml-32 | margin-left: 8rem |
| ml-36 | margin-left: 9rem |
| ml-40 | margin-left: 10rem |
| ml-44 | margin-left: 11rem |
| ml-48 | margin-left: 12rem |
| ml-52 | margin-left: 13rem |
| ml-56 | margin-left: 14rem |
| ml-60 | margin-left: 15rem |
| ml-64 | margin-left: 16rem |
| ml-72 | margin-left: 18rem |
| ml-80 | margin-left: 20rem |
| ml-96 | margin-left: 24rem |
| -ml-px | margin-left: -0.0625rem |
| -ml-0 | margin-left: 0 |
| -ml-none | margin-left: 0 |
| -ml-0\.5 | margin-left: -0.125rem |
| -ml-1 | margin-left: -0.25rem |
| -ml-1\.5 | margin-left: -0.375rem |
| -ml-2 | margin-left: -0.5rem |
| -ml-2\.5 | margin-left: -0.625rem |
| -ml-3 | margin-left: -0.75rem |
| -ml-3\.5 | margin-left: -0.875rem |
| -ml-4 | margin-left: -1rem |
| -ml-5 | margin-left: -1.25rem |
| -ml-6 | margin-left: -1.5rem |
| -ml-7 | margin-left: -1.75rem |
| -ml-8 | margin-left: -2rem |
| -ml-9 | margin-left: -2.25rem |
| -ml-10 | margin-left: -2.5rem |
| -ml-11 | margin-left: -2.75rem |
| -ml-12 | margin-left: -3rem |
| -ml-14 | margin-left: -3.5rem |
| -ml-16 | margin-left: -4rem |
| -ml-18 | margin-left: -4.5rem |
| -ml-20 | margin-left: -5rem |
| -ml-24 | margin-left: -6rem |
| -ml-28 | margin-left: -7rem |
| -ml-32 | margin-left: -8rem |
| -ml-36 | margin-left: -9rem |
| -ml-40 | margin-left: -10rem |
| -ml-44 | margin-left: -11rem |
| -ml-48 | margin-left: -12rem |
| -ml-52 | margin-left: -13rem |
| -ml-56 | margin-left: -14rem |
| -ml-60 | margin-left: -15rem |
| -ml-64 | margin-left: -16rem |
| -ml-72 | margin-left: -18rem |
| -ml-80 | margin-left: -20rem |
| -ml-96 | margin-left: -24rem |



*/
.m-px {
  margin: 0.0625rem;
}

.m-0 {
  margin: 0;
}

.m-none {
  margin: 0;
}

.m-0\.5 {
  margin: 0.125rem;
}

.m-1 {
  margin: 0.25rem;
}

.m-1\.5 {
  margin: 0.375rem;
}

.m-2 {
  margin: 0.5rem;
}

.m-2\.5 {
  margin: 0.625rem;
}

.m-3 {
  margin: 0.75rem;
}

.m-3\.5 {
  margin: 0.875rem;
}

.m-4 {
  margin: 1rem;
}

.m-5 {
  margin: 1.25rem;
}

.m-6 {
  margin: 1.5rem;
}

.m-7 {
  margin: 1.75rem;
}

.m-8 {
  margin: 2rem;
}

.m-9 {
  margin: 2.25rem;
}

.m-10 {
  margin: 2.5rem;
}

.m-11 {
  margin: 2.75rem;
}

.m-12 {
  margin: 3rem;
}

.m-14 {
  margin: 3.5rem;
}

.m-16 {
  margin: 4rem;
}

.m-18 {
  margin: 4.5rem;
}

.m-20 {
  margin: 5rem;
}

.m-24 {
  margin: 6rem;
}

.m-28 {
  margin: 7rem;
}

.m-32 {
  margin: 8rem;
}

.m-36 {
  margin: 9rem;
}

.m-40 {
  margin: 10rem;
}

.m-44 {
  margin: 11rem;
}

.m-48 {
  margin: 12rem;
}

.m-52 {
  margin: 13rem;
}

.m-56 {
  margin: 14rem;
}

.m-60 {
  margin: 15rem;
}

.m-64 {
  margin: 16rem;
}

.m-72 {
  margin: 18rem;
}

.m-80 {
  margin: 20rem;
}

.m-96 {
  margin: 24rem;
}

.m-auto {
  margin: auto;
}

.-m-px {
  margin: -0.0625rem;
}

.-m-0 {
  margin: 0;
}

.-m-none {
  margin: 0;
}

.-m-0\.5 {
  margin: -0.125rem;
}

.-m-1 {
  margin: -0.25rem;
}

.-m-1\.5 {
  margin: -0.375rem;
}

.-m-2 {
  margin: -0.5rem;
}

.-m-2\.5 {
  margin: -0.625rem;
}

.-m-3 {
  margin: -0.75rem;
}

.-m-3\.5 {
  margin: -0.875rem;
}

.-m-4 {
  margin: -1rem;
}

.-m-5 {
  margin: -1.25rem;
}

.-m-6 {
  margin: -1.5rem;
}

.-m-7 {
  margin: -1.75rem;
}

.-m-8 {
  margin: -2rem;
}

.-m-9 {
  margin: -2.25rem;
}

.-m-10 {
  margin: -2.5rem;
}

.-m-11 {
  margin: -2.75rem;
}

.-m-12 {
  margin: -3rem;
}

.-m-14 {
  margin: -3.5rem;
}

.-m-16 {
  margin: -4rem;
}

.-m-18 {
  margin: -4.5rem;
}

.-m-20 {
  margin: -5rem;
}

.-m-24 {
  margin: -6rem;
}

.-m-28 {
  margin: -7rem;
}

.-m-32 {
  margin: -8rem;
}

.-m-36 {
  margin: -9rem;
}

.-m-40 {
  margin: -10rem;
}

.-m-44 {
  margin: -11rem;
}

.-m-48 {
  margin: -12rem;
}

.-m-52 {
  margin: -13rem;
}

.-m-56 {
  margin: -14rem;
}

.-m-60 {
  margin: -15rem;
}

.-m-64 {
  margin: -16rem;
}

.-m-72 {
  margin: -18rem;
}

.-m-80 {
  margin: -20rem;
}

.-m-96 {
  margin: -24rem;
}

.mx-px {
  margin-left: 0.0625rem;
  margin-right: 0.0625rem;
}

.mx-0 {
  margin-left: 0;
  margin-right: 0;
}

.mx-none {
  margin-left: 0;
  margin-right: 0;
}

.mx-0\.5 {
  margin-left: 0.125rem;
  margin-right: 0.125rem;
}

.mx-1 {
  margin-left: 0.25rem;
  margin-right: 0.25rem;
}

.mx-1\.5 {
  margin-left: 0.375rem;
  margin-right: 0.375rem;
}

.mx-2 {
  margin-left: 0.5rem;
  margin-right: 0.5rem;
}

.mx-2\.5 {
  margin-left: 0.625rem;
  margin-right: 0.625rem;
}

.mx-3 {
  margin-left: 0.75rem;
  margin-right: 0.75rem;
}

.mx-3\.5 {
  margin-left: 0.875rem;
  margin-right: 0.875rem;
}

.mx-4 {
  margin-left: 1rem;
  margin-right: 1rem;
}

.mx-5 {
  margin-left: 1.25rem;
  margin-right: 1.25rem;
}

.mx-6 {
  margin-left: 1.5rem;
  margin-right: 1.5rem;
}

.mx-7 {
  margin-left: 1.75rem;
  margin-right: 1.75rem;
}

.mx-8 {
  margin-left: 2rem;
  margin-right: 2rem;
}

.mx-9 {
  margin-left: 2.25rem;
  margin-right: 2.25rem;
}

.mx-10 {
  margin-left: 2.5rem;
  margin-right: 2.5rem;
}

.mx-11 {
  margin-left: 2.75rem;
  margin-right: 2.75rem;
}

.mx-12 {
  margin-left: 3rem;
  margin-right: 3rem;
}

.mx-14 {
  margin-left: 3.5rem;
  margin-right: 3.5rem;
}

.mx-16 {
  margin-left: 4rem;
  margin-right: 4rem;
}

.mx-18 {
  margin-left: 4.5rem;
  margin-right: 4.5rem;
}

.mx-20 {
  margin-left: 5rem;
  margin-right: 5rem;
}

.mx-24 {
  margin-left: 6rem;
  margin-right: 6rem;
}

.mx-28 {
  margin-left: 7rem;
  margin-right: 7rem;
}

.mx-32 {
  margin-left: 8rem;
  margin-right: 8rem;
}

.mx-36 {
  margin-left: 9rem;
  margin-right: 9rem;
}

.mx-40 {
  margin-left: 10rem;
  margin-right: 10rem;
}

.mx-44 {
  margin-left: 11rem;
  margin-right: 11rem;
}

.mx-48 {
  margin-left: 12rem;
  margin-right: 12rem;
}

.mx-52 {
  margin-left: 13rem;
  margin-right: 13rem;
}

.mx-56 {
  margin-left: 14rem;
  margin-right: 14rem;
}

.mx-60 {
  margin-left: 15rem;
  margin-right: 15rem;
}

.mx-64 {
  margin-left: 16rem;
  margin-right: 16rem;
}

.mx-72 {
  margin-left: 18rem;
  margin-right: 18rem;
}

.mx-80 {
  margin-left: 20rem;
  margin-right: 20rem;
}

.mx-96 {
  margin-left: 24rem;
  margin-right: 24rem;
}

.mx-auto {
  margin-left: auto;
  margin-right: auto;
}

.mx-auto {
  margin-left: auto;
  margin-right: auto;
}

.-mx-px {
  margin-left: -0.0625rem;
  margin-right: -0.0625rem;
}

.-mx-0 {
  margin-left: 0;
  margin-right: 0;
}

.-mx-none {
  margin-left: 0;
  margin-right: 0;
}

.-mx-0\.5 {
  margin-left: -0.125rem;
  margin-right: -0.125rem;
}

.-mx-1 {
  margin-left: -0.25rem;
  margin-right: -0.25rem;
}

.-mx-1\.5 {
  margin-left: -0.375rem;
  margin-right: -0.375rem;
}

.-mx-2 {
  margin-left: -0.5rem;
  margin-right: -0.5rem;
}

.-mx-2\.5 {
  margin-left: -0.625rem;
  margin-right: -0.625rem;
}

.-mx-3 {
  margin-left: -0.75rem;
  margin-right: -0.75rem;
}

.-mx-3\.5 {
  margin-left: -0.875rem;
  margin-right: -0.875rem;
}

.-mx-4 {
  margin-left: -1rem;
  margin-right: -1rem;
}

.-mx-5 {
  margin-left: -1.25rem;
  margin-right: -1.25rem;
}

.-mx-6 {
  margin-left: -1.5rem;
  margin-right: -1.5rem;
}

.-mx-7 {
  margin-left: -1.75rem;
  margin-right: -1.75rem;
}

.-mx-8 {
  margin-left: -2rem;
  margin-right: -2rem;
}

.-mx-9 {
  margin-left: -2.25rem;
  margin-right: -2.25rem;
}

.-mx-10 {
  margin-left: -2.5rem;
  margin-right: -2.5rem;
}

.-mx-11 {
  margin-left: -2.75rem;
  margin-right: -2.75rem;
}

.-mx-12 {
  margin-left: -3rem;
  margin-right: -3rem;
}

.-mx-14 {
  margin-left: -3.5rem;
  margin-right: -3.5rem;
}

.-mx-16 {
  margin-left: -4rem;
  margin-right: -4rem;
}

.-mx-18 {
  margin-left: -4.5rem;
  margin-right: -4.5rem;
}

.-mx-20 {
  margin-left: -5rem;
  margin-right: -5rem;
}

.-mx-24 {
  margin-left: -6rem;
  margin-right: -6rem;
}

.-mx-28 {
  margin-left: -7rem;
  margin-right: -7rem;
}

.-mx-32 {
  margin-left: -8rem;
  margin-right: -8rem;
}

.-mx-36 {
  margin-left: -9rem;
  margin-right: -9rem;
}

.-mx-40 {
  margin-left: -10rem;
  margin-right: -10rem;
}

.-mx-44 {
  margin-left: -11rem;
  margin-right: -11rem;
}

.-mx-48 {
  margin-left: -12rem;
  margin-right: -12rem;
}

.-mx-52 {
  margin-left: -13rem;
  margin-right: -13rem;
}

.-mx-56 {
  margin-left: -14rem;
  margin-right: -14rem;
}

.-mx-60 {
  margin-left: -15rem;
  margin-right: -15rem;
}

.-mx-64 {
  margin-left: -16rem;
  margin-right: -16rem;
}

.-mx-72 {
  margin-left: -18rem;
  margin-right: -18rem;
}

.-mx-80 {
  margin-left: -20rem;
  margin-right: -20rem;
}

.-mx-96 {
  margin-left: -24rem;
  margin-right: -24rem;
}

.my-px {
  margin-top: 0.0625rem;
  margin-bottom: 0.0625rem;
}

.my-0 {
  margin-top: 0;
  margin-bottom: 0;
}

.my-none {
  margin-top: 0;
  margin-bottom: 0;
}

.my-0\.5 {
  margin-top: 0.125rem;
  margin-bottom: 0.125rem;
}

.my-1 {
  margin-top: 0.25rem;
  margin-bottom: 0.25rem;
}

.my-1\.5 {
  margin-top: 0.375rem;
  margin-bottom: 0.375rem;
}

.my-2 {
  margin-top: 0.5rem;
  margin-bottom: 0.5rem;
}

.my-2\.5 {
  margin-top: 0.625rem;
  margin-bottom: 0.625rem;
}

.my-3 {
  margin-top: 0.75rem;
  margin-bottom: 0.75rem;
}

.my-3\.5 {
  margin-top: 0.875rem;
  margin-bottom: 0.875rem;
}

.my-4 {
  margin-top: 1rem;
  margin-bottom: 1rem;
}

.my-5 {
  margin-top: 1.25rem;
  margin-bottom: 1.25rem;
}

.my-6 {
  margin-top: 1.5rem;
  margin-bottom: 1.5rem;
}

.my-7 {
  margin-top: 1.75rem;
  margin-bottom: 1.75rem;
}

.my-8 {
  margin-top: 2rem;
  margin-bottom: 2rem;
}

.my-9 {
  margin-top: 2.25rem;
  margin-bottom: 2.25rem;
}

.my-10 {
  margin-top: 2.5rem;
  margin-bottom: 2.5rem;
}

.my-11 {
  margin-top: 2.75rem;
  margin-bottom: 2.75rem;
}

.my-12 {
  margin-top: 3rem;
  margin-bottom: 3rem;
}

.my-14 {
  margin-top: 3.5rem;
  margin-bottom: 3.5rem;
}

.my-16 {
  margin-top: 4rem;
  margin-bottom: 4rem;
}

.my-18 {
  margin-top: 4.5rem;
  margin-bottom: 4.5rem;
}

.my-20 {
  margin-top: 5rem;
  margin-bottom: 5rem;
}

.my-24 {
  margin-top: 6rem;
  margin-bottom: 6rem;
}

.my-28 {
  margin-top: 7rem;
  margin-bottom: 7rem;
}

.my-32 {
  margin-top: 8rem;
  margin-bottom: 8rem;
}

.my-36 {
  margin-top: 9rem;
  margin-bottom: 9rem;
}

.my-40 {
  margin-top: 10rem;
  margin-bottom: 10rem;
}

.my-44 {
  margin-top: 11rem;
  margin-bottom: 11rem;
}

.my-48 {
  margin-top: 12rem;
  margin-bottom: 12rem;
}

.my-52 {
  margin-top: 13rem;
  margin-bottom: 13rem;
}

.my-56 {
  margin-top: 14rem;
  margin-bottom: 14rem;
}

.my-60 {
  margin-top: 15rem;
  margin-bottom: 15rem;
}

.my-64 {
  margin-top: 16rem;
  margin-bottom: 16rem;
}

.my-72 {
  margin-top: 18rem;
  margin-bottom: 18rem;
}

.my-80 {
  margin-top: 20rem;
  margin-bottom: 20rem;
}

.my-96 {
  margin-top: 24rem;
  margin-bottom: 24rem;
}

.my-auto {
  margin-top: auto;
  margin-bottom: auto;
}

.my-auto {
  margin-top: auto;
  margin-bottom: auto;
}

.-my-px {
  margin-top: -0.0625rem;
  margin-bottom: -0.0625rem;
}

.-my-0 {
  margin-top: 0;
  margin-bottom: 0;
}

.-my-none {
  margin-top: 0;
  margin-bottom: 0;
}

.-my-0\.5 {
  margin-top: -0.125rem;
  margin-bottom: -0.125rem;
}

.-my-1 {
  margin-top: -0.25rem;
  margin-bottom: -0.25rem;
}

.-my-1\.5 {
  margin-top: -0.375rem;
  margin-bottom: -0.375rem;
}

.-my-2 {
  margin-top: -0.5rem;
  margin-bottom: -0.5rem;
}

.-my-2\.5 {
  margin-top: -0.625rem;
  margin-bottom: -0.625rem;
}

.-my-3 {
  margin-top: -0.75rem;
  margin-bottom: -0.75rem;
}

.-my-3\.5 {
  margin-top: -0.875rem;
  margin-bottom: -0.875rem;
}

.-my-4 {
  margin-top: -1rem;
  margin-bottom: -1rem;
}

.-my-5 {
  margin-top: -1.25rem;
  margin-bottom: -1.25rem;
}

.-my-6 {
  margin-top: -1.5rem;
  margin-bottom: -1.5rem;
}

.-my-7 {
  margin-top: -1.75rem;
  margin-bottom: -1.75rem;
}

.-my-8 {
  margin-top: -2rem;
  margin-bottom: -2rem;
}

.-my-9 {
  margin-top: -2.25rem;
  margin-bottom: -2.25rem;
}

.-my-10 {
  margin-top: -2.5rem;
  margin-bottom: -2.5rem;
}

.-my-11 {
  margin-top: -2.75rem;
  margin-bottom: -2.75rem;
}

.-my-12 {
  margin-top: -3rem;
  margin-bottom: -3rem;
}

.-my-14 {
  margin-top: -3.5rem;
  margin-bottom: -3.5rem;
}

.-my-16 {
  margin-top: -4rem;
  margin-bottom: -4rem;
}

.-my-18 {
  margin-top: -4.5rem;
  margin-bottom: -4.5rem;
}

.-my-20 {
  margin-top: -5rem;
  margin-bottom: -5rem;
}

.-my-24 {
  margin-top: -6rem;
  margin-bottom: -6rem;
}

.-my-28 {
  margin-top: -7rem;
  margin-bottom: -7rem;
}

.-my-32 {
  margin-top: -8rem;
  margin-bottom: -8rem;
}

.-my-36 {
  margin-top: -9rem;
  margin-bottom: -9rem;
}

.-my-40 {
  margin-top: -10rem;
  margin-bottom: -10rem;
}

.-my-44 {
  margin-top: -11rem;
  margin-bottom: -11rem;
}

.-my-48 {
  margin-top: -12rem;
  margin-bottom: -12rem;
}

.-my-52 {
  margin-top: -13rem;
  margin-bottom: -13rem;
}

.-my-56 {
  margin-top: -14rem;
  margin-bottom: -14rem;
}

.-my-60 {
  margin-top: -15rem;
  margin-bottom: -15rem;
}

.-my-64 {
  margin-top: -16rem;
  margin-bottom: -16rem;
}

.-my-72 {
  margin-top: -18rem;
  margin-bottom: -18rem;
}

.-my-80 {
  margin-top: -20rem;
  margin-bottom: -20rem;
}

.-my-96 {
  margin-top: -24rem;
  margin-bottom: -24rem;
}

.mt-px {
  margin-top: 0.0625rem;
}

.mt-0 {
  margin-top: 0;
}

.mt-none {
  margin-top: 0;
}

.mt-0\.5 {
  margin-top: 0.125rem;
}

.mt-1 {
  margin-top: 0.25rem;
}

.mt-1\.5 {
  margin-top: 0.375rem;
}

.mt-2 {
  margin-top: 0.5rem;
}

.mt-2\.5 {
  margin-top: 0.625rem;
}

.mt-3 {
  margin-top: 0.75rem;
}

.mt-3\.5 {
  margin-top: 0.875rem;
}

.mt-4 {
  margin-top: 1rem;
}

.mt-5 {
  margin-top: 1.25rem;
}

.mt-6 {
  margin-top: 1.5rem;
}

.mt-7 {
  margin-top: 1.75rem;
}

.mt-8 {
  margin-top: 2rem;
}

.mt-9 {
  margin-top: 2.25rem;
}

.mt-10 {
  margin-top: 2.5rem;
}

.mt-11 {
  margin-top: 2.75rem;
}

.mt-12 {
  margin-top: 3rem;
}

.mt-14 {
  margin-top: 3.5rem;
}

.mt-16 {
  margin-top: 4rem;
}

.mt-18 {
  margin-top: 4.5rem;
}

.mt-20 {
  margin-top: 5rem;
}

.mt-24 {
  margin-top: 6rem;
}

.mt-28 {
  margin-top: 7rem;
}

.mt-32 {
  margin-top: 8rem;
}

.mt-36 {
  margin-top: 9rem;
}

.mt-40 {
  margin-top: 10rem;
}

.mt-44 {
  margin-top: 11rem;
}

.mt-48 {
  margin-top: 12rem;
}

.mt-52 {
  margin-top: 13rem;
}

.mt-56 {
  margin-top: 14rem;
}

.mt-60 {
  margin-top: 15rem;
}

.mt-64 {
  margin-top: 16rem;
}

.mt-72 {
  margin-top: 18rem;
}

.mt-80 {
  margin-top: 20rem;
}

.mt-96 {
  margin-top: 24rem;
}

.mt-auto {
  margin-top: auto;
}

.-mt-px {
  margin-top: -0.0625rem;
}

.-mt-0 {
  margin-top: 0;
}

.-mt-none {
  margin-top: 0;
}

.-mt-0\.5 {
  margin-top: -0.125rem;
}

.-mt-1 {
  margin-top: -0.25rem;
}

.-mt-1\.5 {
  margin-top: -0.375rem;
}

.-mt-2 {
  margin-top: -0.5rem;
}

.-mt-2\.5 {
  margin-top: -0.625rem;
}

.-mt-3 {
  margin-top: -0.75rem;
}

.-mt-3\.5 {
  margin-top: -0.875rem;
}

.-mt-4 {
  margin-top: -1rem;
}

.-mt-5 {
  margin-top: -1.25rem;
}

.-mt-6 {
  margin-top: -1.5rem;
}

.-mt-7 {
  margin-top: -1.75rem;
}

.-mt-8 {
  margin-top: -2rem;
}

.-mt-9 {
  margin-top: -2.25rem;
}

.-mt-10 {
  margin-top: -2.5rem;
}

.-mt-11 {
  margin-top: -2.75rem;
}

.-mt-12 {
  margin-top: -3rem;
}

.-mt-14 {
  margin-top: -3.5rem;
}

.-mt-16 {
  margin-top: -4rem;
}

.-mt-18 {
  margin-top: -4.5rem;
}

.-mt-20 {
  margin-top: -5rem;
}

.-mt-24 {
  margin-top: -6rem;
}

.-mt-28 {
  margin-top: -7rem;
}

.-mt-32 {
  margin-top: -8rem;
}

.-mt-36 {
  margin-top: -9rem;
}

.-mt-40 {
  margin-top: -10rem;
}

.-mt-44 {
  margin-top: -11rem;
}

.-mt-48 {
  margin-top: -12rem;
}

.-mt-52 {
  margin-top: -13rem;
}

.-mt-56 {
  margin-top: -14rem;
}

.-mt-60 {
  margin-top: -15rem;
}

.-mt-64 {
  margin-top: -16rem;
}

.-mt-72 {
  margin-top: -18rem;
}

.-mt-80 {
  margin-top: -20rem;
}

.-mt-96 {
  margin-top: -24rem;
}

.mr-px {
  margin-right: 0.0625rem;
}

.mr-0 {
  margin-right: 0;
}

.mr-none {
  margin-right: 0;
}

.mr-0\.5 {
  margin-right: 0.125rem;
}

.mr-1 {
  margin-right: 0.25rem;
}

.mr-1\.5 {
  margin-right: 0.375rem;
}

.mr-2 {
  margin-right: 0.5rem;
}

.mr-2\.5 {
  margin-right: 0.625rem;
}

.mr-3 {
  margin-right: 0.75rem;
}

.mr-3\.5 {
  margin-right: 0.875rem;
}

.mr-4 {
  margin-right: 1rem;
}

.mr-5 {
  margin-right: 1.25rem;
}

.mr-6 {
  margin-right: 1.5rem;
}

.mr-7 {
  margin-right: 1.75rem;
}

.mr-8 {
  margin-right: 2rem;
}

.mr-9 {
  margin-right: 2.25rem;
}

.mr-10 {
  margin-right: 2.5rem;
}

.mr-11 {
  margin-right: 2.75rem;
}

.mr-12 {
  margin-right: 3rem;
}

.mr-14 {
  margin-right: 3.5rem;
}

.mr-16 {
  margin-right: 4rem;
}

.mr-18 {
  margin-right: 4.5rem;
}

.mr-20 {
  margin-right: 5rem;
}

.mr-24 {
  margin-right: 6rem;
}

.mr-28 {
  margin-right: 7rem;
}

.mr-32 {
  margin-right: 8rem;
}

.mr-36 {
  margin-right: 9rem;
}

.mr-40 {
  margin-right: 10rem;
}

.mr-44 {
  margin-right: 11rem;
}

.mr-48 {
  margin-right: 12rem;
}

.mr-52 {
  margin-right: 13rem;
}

.mr-56 {
  margin-right: 14rem;
}

.mr-60 {
  margin-right: 15rem;
}

.mr-64 {
  margin-right: 16rem;
}

.mr-72 {
  margin-right: 18rem;
}

.mr-80 {
  margin-right: 20rem;
}

.mr-96 {
  margin-right: 24rem;
}

.mr-auto {
  margin-right: auto;
}

.-mr-px {
  margin-right: -0.0625rem;
}

.-mr-0 {
  margin-right: 0;
}

.-mr-none {
  margin-right: 0;
}

.-mr-0\.5 {
  margin-right: -0.125rem;
}

.-mr-1 {
  margin-right: -0.25rem;
}

.-mr-1\.5 {
  margin-right: -0.375rem;
}

.-mr-2 {
  margin-right: -0.5rem;
}

.-mr-2\.5 {
  margin-right: -0.625rem;
}

.-mr-3 {
  margin-right: -0.75rem;
}

.-mr-3\.5 {
  margin-right: -0.875rem;
}

.-mr-4 {
  margin-right: -1rem;
}

.-mr-5 {
  margin-right: -1.25rem;
}

.-mr-6 {
  margin-right: -1.5rem;
}

.-mr-7 {
  margin-right: -1.75rem;
}

.-mr-8 {
  margin-right: -2rem;
}

.-mr-9 {
  margin-right: -2.25rem;
}

.-mr-10 {
  margin-right: -2.5rem;
}

.-mr-11 {
  margin-right: -2.75rem;
}

.-mr-12 {
  margin-right: -3rem;
}

.-mr-14 {
  margin-right: -3.5rem;
}

.-mr-16 {
  margin-right: -4rem;
}

.-mr-18 {
  margin-right: -4.5rem;
}

.-mr-20 {
  margin-right: -5rem;
}

.-mr-24 {
  margin-right: -6rem;
}

.-mr-28 {
  margin-right: -7rem;
}

.-mr-32 {
  margin-right: -8rem;
}

.-mr-36 {
  margin-right: -9rem;
}

.-mr-40 {
  margin-right: -10rem;
}

.-mr-44 {
  margin-right: -11rem;
}

.-mr-48 {
  margin-right: -12rem;
}

.-mr-52 {
  margin-right: -13rem;
}

.-mr-56 {
  margin-right: -14rem;
}

.-mr-60 {
  margin-right: -15rem;
}

.-mr-64 {
  margin-right: -16rem;
}

.-mr-72 {
  margin-right: -18rem;
}

.-mr-80 {
  margin-right: -20rem;
}

.-mr-96 {
  margin-right: -24rem;
}

.mb-px {
  margin-bottom: 0.0625rem;
}

.mb-0 {
  margin-bottom: 0;
}

.mb-none {
  margin-bottom: 0;
}

.mb-0\.5 {
  margin-bottom: 0.125rem;
}

.mb-1 {
  margin-bottom: 0.25rem;
}

.mb-1\.5 {
  margin-bottom: 0.375rem;
}

.mb-2 {
  margin-bottom: 0.5rem;
}

.mb-2\.5 {
  margin-bottom: 0.625rem;
}

.mb-3 {
  margin-bottom: 0.75rem;
}

.mb-3\.5 {
  margin-bottom: 0.875rem;
}

.mb-4 {
  margin-bottom: 1rem;
}

.mb-5 {
  margin-bottom: 1.25rem;
}

.mb-6 {
  margin-bottom: 1.5rem;
}

.mb-7 {
  margin-bottom: 1.75rem;
}

.mb-8 {
  margin-bottom: 2rem;
}

.mb-9 {
  margin-bottom: 2.25rem;
}

.mb-10 {
  margin-bottom: 2.5rem;
}

.mb-11 {
  margin-bottom: 2.75rem;
}

.mb-12 {
  margin-bottom: 3rem;
}

.mb-14 {
  margin-bottom: 3.5rem;
}

.mb-16 {
  margin-bottom: 4rem;
}

.mb-18 {
  margin-bottom: 4.5rem;
}

.mb-20 {
  margin-bottom: 5rem;
}

.mb-24 {
  margin-bottom: 6rem;
}

.mb-28 {
  margin-bottom: 7rem;
}

.mb-32 {
  margin-bottom: 8rem;
}

.mb-36 {
  margin-bottom: 9rem;
}

.mb-40 {
  margin-bottom: 10rem;
}

.mb-44 {
  margin-bottom: 11rem;
}

.mb-48 {
  margin-bottom: 12rem;
}

.mb-52 {
  margin-bottom: 13rem;
}

.mb-56 {
  margin-bottom: 14rem;
}

.mb-60 {
  margin-bottom: 15rem;
}

.mb-64 {
  margin-bottom: 16rem;
}

.mb-72 {
  margin-bottom: 18rem;
}

.mb-80 {
  margin-bottom: 20rem;
}

.mb-96 {
  margin-bottom: 24rem;
}

.mb-auto {
  margin-bottom: auto;
}

.-mb-px {
  margin-bottom: -0.0625rem;
}

.-mb-0 {
  margin-bottom: 0;
}

.-mb-none {
  margin-bottom: 0;
}

.-mb-0\.5 {
  margin-bottom: -0.125rem;
}

.-mb-1 {
  margin-bottom: -0.25rem;
}

.-mb-1\.5 {
  margin-bottom: -0.375rem;
}

.-mb-2 {
  margin-bottom: -0.5rem;
}

.-mb-2\.5 {
  margin-bottom: -0.625rem;
}

.-mb-3 {
  margin-bottom: -0.75rem;
}

.-mb-3\.5 {
  margin-bottom: -0.875rem;
}

.-mb-4 {
  margin-bottom: -1rem;
}

.-mb-5 {
  margin-bottom: -1.25rem;
}

.-mb-6 {
  margin-bottom: -1.5rem;
}

.-mb-7 {
  margin-bottom: -1.75rem;
}

.-mb-8 {
  margin-bottom: -2rem;
}

.-mb-9 {
  margin-bottom: -2.25rem;
}

.-mb-10 {
  margin-bottom: -2.5rem;
}

.-mb-11 {
  margin-bottom: -2.75rem;
}

.-mb-12 {
  margin-bottom: -3rem;
}

.-mb-14 {
  margin-bottom: -3.5rem;
}

.-mb-16 {
  margin-bottom: -4rem;
}

.-mb-18 {
  margin-bottom: -4.5rem;
}

.-mb-20 {
  margin-bottom: -5rem;
}

.-mb-24 {
  margin-bottom: -6rem;
}

.-mb-28 {
  margin-bottom: -7rem;
}

.-mb-32 {
  margin-bottom: -8rem;
}

.-mb-36 {
  margin-bottom: -9rem;
}

.-mb-40 {
  margin-bottom: -10rem;
}

.-mb-44 {
  margin-bottom: -11rem;
}

.-mb-48 {
  margin-bottom: -12rem;
}

.-mb-52 {
  margin-bottom: -13rem;
}

.-mb-56 {
  margin-bottom: -14rem;
}

.-mb-60 {
  margin-bottom: -15rem;
}

.-mb-64 {
  margin-bottom: -16rem;
}

.-mb-72 {
  margin-bottom: -18rem;
}

.-mb-80 {
  margin-bottom: -20rem;
}

.-mb-96 {
  margin-bottom: -24rem;
}

.ml-px {
  margin-left: 0.0625rem;
}

.ml-0 {
  margin-left: 0;
}

.ml-none {
  margin-left: 0;
}

.ml-0\.5 {
  margin-left: 0.125rem;
}

.ml-1 {
  margin-left: 0.25rem;
}

.ml-1\.5 {
  margin-left: 0.375rem;
}

.ml-2 {
  margin-left: 0.5rem;
}

.ml-2\.5 {
  margin-left: 0.625rem;
}

.ml-3 {
  margin-left: 0.75rem;
}

.ml-3\.5 {
  margin-left: 0.875rem;
}

.ml-4 {
  margin-left: 1rem;
}

.ml-5 {
  margin-left: 1.25rem;
}

.ml-6 {
  margin-left: 1.5rem;
}

.ml-7 {
  margin-left: 1.75rem;
}

.ml-8 {
  margin-left: 2rem;
}

.ml-9 {
  margin-left: 2.25rem;
}

.ml-10 {
  margin-left: 2.5rem;
}

.ml-11 {
  margin-left: 2.75rem;
}

.ml-12 {
  margin-left: 3rem;
}

.ml-14 {
  margin-left: 3.5rem;
}

.ml-16 {
  margin-left: 4rem;
}

.ml-18 {
  margin-left: 4.5rem;
}

.ml-20 {
  margin-left: 5rem;
}

.ml-24 {
  margin-left: 6rem;
}

.ml-28 {
  margin-left: 7rem;
}

.ml-32 {
  margin-left: 8rem;
}

.ml-36 {
  margin-left: 9rem;
}

.ml-40 {
  margin-left: 10rem;
}

.ml-44 {
  margin-left: 11rem;
}

.ml-48 {
  margin-left: 12rem;
}

.ml-52 {
  margin-left: 13rem;
}

.ml-56 {
  margin-left: 14rem;
}

.ml-60 {
  margin-left: 15rem;
}

.ml-64 {
  margin-left: 16rem;
}

.ml-72 {
  margin-left: 18rem;
}

.ml-80 {
  margin-left: 20rem;
}

.ml-96 {
  margin-left: 24rem;
}

.ml-auto {
  margin-left: auto;
}

.-ml-px {
  margin-left: -0.0625rem;
}

.-ml-0 {
  margin-left: 0;
}

.-ml-none {
  margin-left: 0;
}

.-ml-0\.5 {
  margin-left: -0.125rem;
}

.-ml-1 {
  margin-left: -0.25rem;
}

.-ml-1\.5 {
  margin-left: -0.375rem;
}

.-ml-2 {
  margin-left: -0.5rem;
}

.-ml-2\.5 {
  margin-left: -0.625rem;
}

.-ml-3 {
  margin-left: -0.75rem;
}

.-ml-3\.5 {
  margin-left: -0.875rem;
}

.-ml-4 {
  margin-left: -1rem;
}

.-ml-5 {
  margin-left: -1.25rem;
}

.-ml-6 {
  margin-left: -1.5rem;
}

.-ml-7 {
  margin-left: -1.75rem;
}

.-ml-8 {
  margin-left: -2rem;
}

.-ml-9 {
  margin-left: -2.25rem;
}

.-ml-10 {
  margin-left: -2.5rem;
}

.-ml-11 {
  margin-left: -2.75rem;
}

.-ml-12 {
  margin-left: -3rem;
}

.-ml-14 {
  margin-left: -3.5rem;
}

.-ml-16 {
  margin-left: -4rem;
}

.-ml-18 {
  margin-left: -4.5rem;
}

.-ml-20 {
  margin-left: -5rem;
}

.-ml-24 {
  margin-left: -6rem;
}

.-ml-28 {
  margin-left: -7rem;
}

.-ml-32 {
  margin-left: -8rem;
}

.-ml-36 {
  margin-left: -9rem;
}

.-ml-40 {
  margin-left: -10rem;
}

.-ml-44 {
  margin-left: -11rem;
}

.-ml-48 {
  margin-left: -12rem;
}

.-ml-52 {
  margin-left: -13rem;
}

.-ml-56 {
  margin-left: -14rem;
}

.-ml-60 {
  margin-left: -15rem;
}

.-ml-64 {
  margin-left: -16rem;
}

.-ml-72 {
  margin-left: -18rem;
}

.-ml-80 {
  margin-left: -20rem;
}

.-ml-96 {
  margin-left: -24rem;
}

@media (max-width: 768px) {
  .m\:m-px {
    margin: 0.0625rem;
  }

  .m\:m-0 {
    margin: 0;
  }

  .m\:m-none {
    margin: 0;
  }

  .m\:m-0\.5 {
    margin: 0.125rem;
  }

  .m\:m-1 {
    margin: 0.25rem;
  }

  .m\:m-1\.5 {
    margin: 0.375rem;
  }

  .m\:m-2 {
    margin: 0.5rem;
  }

  .m\:m-2\.5 {
    margin: 0.625rem;
  }

  .m\:m-3 {
    margin: 0.75rem;
  }

  .m\:m-3\.5 {
    margin: 0.875rem;
  }

  .m\:m-4 {
    margin: 1rem;
  }

  .m\:m-5 {
    margin: 1.25rem;
  }

  .m\:m-6 {
    margin: 1.5rem;
  }

  .m\:m-7 {
    margin: 1.75rem;
  }

  .m\:m-8 {
    margin: 2rem;
  }

  .m\:m-9 {
    margin: 2.25rem;
  }

  .m\:m-10 {
    margin: 2.5rem;
  }

  .m\:m-11 {
    margin: 2.75rem;
  }

  .m\:m-12 {
    margin: 3rem;
  }

  .m\:m-14 {
    margin: 3.5rem;
  }

  .m\:m-16 {
    margin: 4rem;
  }

  .m\:m-18 {
    margin: 4.5rem;
  }

  .m\:m-20 {
    margin: 5rem;
  }

  .m\:m-24 {
    margin: 6rem;
  }

  .m\:m-28 {
    margin: 7rem;
  }

  .m\:m-32 {
    margin: 8rem;
  }

  .m\:m-36 {
    margin: 9rem;
  }

  .m\:m-40 {
    margin: 10rem;
  }

  .m\:m-44 {
    margin: 11rem;
  }

  .m\:m-48 {
    margin: 12rem;
  }

  .m\:m-52 {
    margin: 13rem;
  }

  .m\:m-56 {
    margin: 14rem;
  }

  .m\:m-60 {
    margin: 15rem;
  }

  .m\:m-64 {
    margin: 16rem;
  }

  .m\:m-72 {
    margin: 18rem;
  }

  .m\:m-80 {
    margin: 20rem;
  }

  .m\:m-96 {
    margin: 24rem;
  }

  .m\:m-auto {
    margin: auto;
  }

  .m\:-m-px {
    margin: -0.0625rem;
  }

  .m\:-m-0 {
    margin: 0;
  }

  .m\:-m-none {
    margin: 0;
  }

  .m\:-m-0\.5 {
    margin: -0.125rem;
  }

  .m\:-m-1 {
    margin: -0.25rem;
  }

  .m\:-m-1\.5 {
    margin: -0.375rem;
  }

  .m\:-m-2 {
    margin: -0.5rem;
  }

  .m\:-m-2\.5 {
    margin: -0.625rem;
  }

  .m\:-m-3 {
    margin: -0.75rem;
  }

  .m\:-m-3\.5 {
    margin: -0.875rem;
  }

  .m\:-m-4 {
    margin: -1rem;
  }

  .m\:-m-5 {
    margin: -1.25rem;
  }

  .m\:-m-6 {
    margin: -1.5rem;
  }

  .m\:-m-7 {
    margin: -1.75rem;
  }

  .m\:-m-8 {
    margin: -2rem;
  }

  .m\:-m-9 {
    margin: -2.25rem;
  }

  .m\:-m-10 {
    margin: -2.5rem;
  }

  .m\:-m-11 {
    margin: -2.75rem;
  }

  .m\:-m-12 {
    margin: -3rem;
  }

  .m\:-m-14 {
    margin: -3.5rem;
  }

  .m\:-m-16 {
    margin: -4rem;
  }

  .m\:-m-18 {
    margin: -4.5rem;
  }

  .m\:-m-20 {
    margin: -5rem;
  }

  .m\:-m-24 {
    margin: -6rem;
  }

  .m\:-m-28 {
    margin: -7rem;
  }

  .m\:-m-32 {
    margin: -8rem;
  }

  .m\:-m-36 {
    margin: -9rem;
  }

  .m\:-m-40 {
    margin: -10rem;
  }

  .m\:-m-44 {
    margin: -11rem;
  }

  .m\:-m-48 {
    margin: -12rem;
  }

  .m\:-m-52 {
    margin: -13rem;
  }

  .m\:-m-56 {
    margin: -14rem;
  }

  .m\:-m-60 {
    margin: -15rem;
  }

  .m\:-m-64 {
    margin: -16rem;
  }

  .m\:-m-72 {
    margin: -18rem;
  }

  .m\:-m-80 {
    margin: -20rem;
  }

  .m\:-m-96 {
    margin: -24rem;
  }

  .m\:mx-px {
    margin-left: 0.0625rem;
    margin-right: 0.0625rem;
  }

  .m\:mx-0 {
    margin-left: 0;
    margin-right: 0;
  }

  .m\:mx-none {
    margin-left: 0;
    margin-right: 0;
  }

  .m\:mx-0\.5 {
    margin-left: 0.125rem;
    margin-right: 0.125rem;
  }

  .m\:mx-1 {
    margin-left: 0.25rem;
    margin-right: 0.25rem;
  }

  .m\:mx-1\.5 {
    margin-left: 0.375rem;
    margin-right: 0.375rem;
  }

  .m\:mx-2 {
    margin-left: 0.5rem;
    margin-right: 0.5rem;
  }

  .m\:mx-2\.5 {
    margin-left: 0.625rem;
    margin-right: 0.625rem;
  }

  .m\:mx-3 {
    margin-left: 0.75rem;
    margin-right: 0.75rem;
  }

  .m\:mx-3\.5 {
    margin-left: 0.875rem;
    margin-right: 0.875rem;
  }

  .m\:mx-4 {
    margin-left: 1rem;
    margin-right: 1rem;
  }

  .m\:mx-5 {
    margin-left: 1.25rem;
    margin-right: 1.25rem;
  }

  .m\:mx-6 {
    margin-left: 1.5rem;
    margin-right: 1.5rem;
  }

  .m\:mx-7 {
    margin-left: 1.75rem;
    margin-right: 1.75rem;
  }

  .m\:mx-8 {
    margin-left: 2rem;
    margin-right: 2rem;
  }

  .m\:mx-9 {
    margin-left: 2.25rem;
    margin-right: 2.25rem;
  }

  .m\:mx-10 {
    margin-left: 2.5rem;
    margin-right: 2.5rem;
  }

  .m\:mx-11 {
    margin-left: 2.75rem;
    margin-right: 2.75rem;
  }

  .m\:mx-12 {
    margin-left: 3rem;
    margin-right: 3rem;
  }

  .m\:mx-14 {
    margin-left: 3.5rem;
    margin-right: 3.5rem;
  }

  .m\:mx-16 {
    margin-left: 4rem;
    margin-right: 4rem;
  }

  .m\:mx-18 {
    margin-left: 4.5rem;
    margin-right: 4.5rem;
  }

  .m\:mx-20 {
    margin-left: 5rem;
    margin-right: 5rem;
  }

  .m\:mx-24 {
    margin-left: 6rem;
    margin-right: 6rem;
  }

  .m\:mx-28 {
    margin-left: 7rem;
    margin-right: 7rem;
  }

  .m\:mx-32 {
    margin-left: 8rem;
    margin-right: 8rem;
  }

  .m\:mx-36 {
    margin-left: 9rem;
    margin-right: 9rem;
  }

  .m\:mx-40 {
    margin-left: 10rem;
    margin-right: 10rem;
  }

  .m\:mx-44 {
    margin-left: 11rem;
    margin-right: 11rem;
  }

  .m\:mx-48 {
    margin-left: 12rem;
    margin-right: 12rem;
  }

  .m\:mx-52 {
    margin-left: 13rem;
    margin-right: 13rem;
  }

  .m\:mx-56 {
    margin-left: 14rem;
    margin-right: 14rem;
  }

  .m\:mx-60 {
    margin-left: 15rem;
    margin-right: 15rem;
  }

  .m\:mx-64 {
    margin-left: 16rem;
    margin-right: 16rem;
  }

  .m\:mx-72 {
    margin-left: 18rem;
    margin-right: 18rem;
  }

  .m\:mx-80 {
    margin-left: 20rem;
    margin-right: 20rem;
  }

  .m\:mx-96 {
    margin-left: 24rem;
    margin-right: 24rem;
  }

  .m\:mx-auto {
    margin-left: auto;
    margin-right: auto;
  }

  .m\:mx-auto {
    margin-left: auto;
    margin-right: auto;
  }

  .m\:-mx-px {
    margin-left: -0.0625rem;
    margin-right: -0.0625rem;
  }

  .m\:-mx-0 {
    margin-left: 0;
    margin-right: 0;
  }

  .m\:-mx-none {
    margin-left: 0;
    margin-right: 0;
  }

  .m\:-mx-0\.5 {
    margin-left: -0.125rem;
    margin-right: -0.125rem;
  }

  .m\:-mx-1 {
    margin-left: -0.25rem;
    margin-right: -0.25rem;
  }

  .m\:-mx-1\.5 {
    margin-left: -0.375rem;
    margin-right: -0.375rem;
  }

  .m\:-mx-2 {
    margin-left: -0.5rem;
    margin-right: -0.5rem;
  }

  .m\:-mx-2\.5 {
    margin-left: -0.625rem;
    margin-right: -0.625rem;
  }

  .m\:-mx-3 {
    margin-left: -0.75rem;
    margin-right: -0.75rem;
  }

  .m\:-mx-3\.5 {
    margin-left: -0.875rem;
    margin-right: -0.875rem;
  }

  .m\:-mx-4 {
    margin-left: -1rem;
    margin-right: -1rem;
  }

  .m\:-mx-5 {
    margin-left: -1.25rem;
    margin-right: -1.25rem;
  }

  .m\:-mx-6 {
    margin-left: -1.5rem;
    margin-right: -1.5rem;
  }

  .m\:-mx-7 {
    margin-left: -1.75rem;
    margin-right: -1.75rem;
  }

  .m\:-mx-8 {
    margin-left: -2rem;
    margin-right: -2rem;
  }

  .m\:-mx-9 {
    margin-left: -2.25rem;
    margin-right: -2.25rem;
  }

  .m\:-mx-10 {
    margin-left: -2.5rem;
    margin-right: -2.5rem;
  }

  .m\:-mx-11 {
    margin-left: -2.75rem;
    margin-right: -2.75rem;
  }

  .m\:-mx-12 {
    margin-left: -3rem;
    margin-right: -3rem;
  }

  .m\:-mx-14 {
    margin-left: -3.5rem;
    margin-right: -3.5rem;
  }

  .m\:-mx-16 {
    margin-left: -4rem;
    margin-right: -4rem;
  }

  .m\:-mx-18 {
    margin-left: -4.5rem;
    margin-right: -4.5rem;
  }

  .m\:-mx-20 {
    margin-left: -5rem;
    margin-right: -5rem;
  }

  .m\:-mx-24 {
    margin-left: -6rem;
    margin-right: -6rem;
  }

  .m\:-mx-28 {
    margin-left: -7rem;
    margin-right: -7rem;
  }

  .m\:-mx-32 {
    margin-left: -8rem;
    margin-right: -8rem;
  }

  .m\:-mx-36 {
    margin-left: -9rem;
    margin-right: -9rem;
  }

  .m\:-mx-40 {
    margin-left: -10rem;
    margin-right: -10rem;
  }

  .m\:-mx-44 {
    margin-left: -11rem;
    margin-right: -11rem;
  }

  .m\:-mx-48 {
    margin-left: -12rem;
    margin-right: -12rem;
  }

  .m\:-mx-52 {
    margin-left: -13rem;
    margin-right: -13rem;
  }

  .m\:-mx-56 {
    margin-left: -14rem;
    margin-right: -14rem;
  }

  .m\:-mx-60 {
    margin-left: -15rem;
    margin-right: -15rem;
  }

  .m\:-mx-64 {
    margin-left: -16rem;
    margin-right: -16rem;
  }

  .m\:-mx-72 {
    margin-left: -18rem;
    margin-right: -18rem;
  }

  .m\:-mx-80 {
    margin-left: -20rem;
    margin-right: -20rem;
  }

  .m\:-mx-96 {
    margin-left: -24rem;
    margin-right: -24rem;
  }

  .m\:my-px {
    margin-top: 0.0625rem;
    margin-bottom: 0.0625rem;
  }

  .m\:my-0 {
    margin-top: 0;
    margin-bottom: 0;
  }

  .m\:my-none {
    margin-top: 0;
    margin-bottom: 0;
  }

  .m\:my-0\.5 {
    margin-top: 0.125rem;
    margin-bottom: 0.125rem;
  }

  .m\:my-1 {
    margin-top: 0.25rem;
    margin-bottom: 0.25rem;
  }

  .m\:my-1\.5 {
    margin-top: 0.375rem;
    margin-bottom: 0.375rem;
  }

  .m\:my-2 {
    margin-top: 0.5rem;
    margin-bottom: 0.5rem;
  }

  .m\:my-2\.5 {
    margin-top: 0.625rem;
    margin-bottom: 0.625rem;
  }

  .m\:my-3 {
    margin-top: 0.75rem;
    margin-bottom: 0.75rem;
  }

  .m\:my-3\.5 {
    margin-top: 0.875rem;
    margin-bottom: 0.875rem;
  }

  .m\:my-4 {
    margin-top: 1rem;
    margin-bottom: 1rem;
  }

  .m\:my-5 {
    margin-top: 1.25rem;
    margin-bottom: 1.25rem;
  }

  .m\:my-6 {
    margin-top: 1.5rem;
    margin-bottom: 1.5rem;
  }

  .m\:my-7 {
    margin-top: 1.75rem;
    margin-bottom: 1.75rem;
  }

  .m\:my-8 {
    margin-top: 2rem;
    margin-bottom: 2rem;
  }

  .m\:my-9 {
    margin-top: 2.25rem;
    margin-bottom: 2.25rem;
  }

  .m\:my-10 {
    margin-top: 2.5rem;
    margin-bottom: 2.5rem;
  }

  .m\:my-11 {
    margin-top: 2.75rem;
    margin-bottom: 2.75rem;
  }

  .m\:my-12 {
    margin-top: 3rem;
    margin-bottom: 3rem;
  }

  .m\:my-14 {
    margin-top: 3.5rem;
    margin-bottom: 3.5rem;
  }

  .m\:my-16 {
    margin-top: 4rem;
    margin-bottom: 4rem;
  }

  .m\:my-18 {
    margin-top: 4.5rem;
    margin-bottom: 4.5rem;
  }

  .m\:my-20 {
    margin-top: 5rem;
    margin-bottom: 5rem;
  }

  .m\:my-24 {
    margin-top: 6rem;
    margin-bottom: 6rem;
  }

  .m\:my-28 {
    margin-top: 7rem;
    margin-bottom: 7rem;
  }

  .m\:my-32 {
    margin-top: 8rem;
    margin-bottom: 8rem;
  }

  .m\:my-36 {
    margin-top: 9rem;
    margin-bottom: 9rem;
  }

  .m\:my-40 {
    margin-top: 10rem;
    margin-bottom: 10rem;
  }

  .m\:my-44 {
    margin-top: 11rem;
    margin-bottom: 11rem;
  }

  .m\:my-48 {
    margin-top: 12rem;
    margin-bottom: 12rem;
  }

  .m\:my-52 {
    margin-top: 13rem;
    margin-bottom: 13rem;
  }

  .m\:my-56 {
    margin-top: 14rem;
    margin-bottom: 14rem;
  }

  .m\:my-60 {
    margin-top: 15rem;
    margin-bottom: 15rem;
  }

  .m\:my-64 {
    margin-top: 16rem;
    margin-bottom: 16rem;
  }

  .m\:my-72 {
    margin-top: 18rem;
    margin-bottom: 18rem;
  }

  .m\:my-80 {
    margin-top: 20rem;
    margin-bottom: 20rem;
  }

  .m\:my-96 {
    margin-top: 24rem;
    margin-bottom: 24rem;
  }

  .m\:my-auto {
    margin-top: auto;
    margin-bottom: auto;
  }

  .m\:my-auto {
    margin-top: auto;
    margin-bottom: auto;
  }

  .m\:-my-px {
    margin-top: -0.0625rem;
    margin-bottom: -0.0625rem;
  }

  .m\:-my-0 {
    margin-top: 0;
    margin-bottom: 0;
  }

  .m\:-my-none {
    margin-top: 0;
    margin-bottom: 0;
  }

  .m\:-my-0\.5 {
    margin-top: -0.125rem;
    margin-bottom: -0.125rem;
  }

  .m\:-my-1 {
    margin-top: -0.25rem;
    margin-bottom: -0.25rem;
  }

  .m\:-my-1\.5 {
    margin-top: -0.375rem;
    margin-bottom: -0.375rem;
  }

  .m\:-my-2 {
    margin-top: -0.5rem;
    margin-bottom: -0.5rem;
  }

  .m\:-my-2\.5 {
    margin-top: -0.625rem;
    margin-bottom: -0.625rem;
  }

  .m\:-my-3 {
    margin-top: -0.75rem;
    margin-bottom: -0.75rem;
  }

  .m\:-my-3\.5 {
    margin-top: -0.875rem;
    margin-bottom: -0.875rem;
  }

  .m\:-my-4 {
    margin-top: -1rem;
    margin-bottom: -1rem;
  }

  .m\:-my-5 {
    margin-top: -1.25rem;
    margin-bottom: -1.25rem;
  }

  .m\:-my-6 {
    margin-top: -1.5rem;
    margin-bottom: -1.5rem;
  }

  .m\:-my-7 {
    margin-top: -1.75rem;
    margin-bottom: -1.75rem;
  }

  .m\:-my-8 {
    margin-top: -2rem;
    margin-bottom: -2rem;
  }

  .m\:-my-9 {
    margin-top: -2.25rem;
    margin-bottom: -2.25rem;
  }

  .m\:-my-10 {
    margin-top: -2.5rem;
    margin-bottom: -2.5rem;
  }

  .m\:-my-11 {
    margin-top: -2.75rem;
    margin-bottom: -2.75rem;
  }

  .m\:-my-12 {
    margin-top: -3rem;
    margin-bottom: -3rem;
  }

  .m\:-my-14 {
    margin-top: -3.5rem;
    margin-bottom: -3.5rem;
  }

  .m\:-my-16 {
    margin-top: -4rem;
    margin-bottom: -4rem;
  }

  .m\:-my-18 {
    margin-top: -4.5rem;
    margin-bottom: -4.5rem;
  }

  .m\:-my-20 {
    margin-top: -5rem;
    margin-bottom: -5rem;
  }

  .m\:-my-24 {
    margin-top: -6rem;
    margin-bottom: -6rem;
  }

  .m\:-my-28 {
    margin-top: -7rem;
    margin-bottom: -7rem;
  }

  .m\:-my-32 {
    margin-top: -8rem;
    margin-bottom: -8rem;
  }

  .m\:-my-36 {
    margin-top: -9rem;
    margin-bottom: -9rem;
  }

  .m\:-my-40 {
    margin-top: -10rem;
    margin-bottom: -10rem;
  }

  .m\:-my-44 {
    margin-top: -11rem;
    margin-bottom: -11rem;
  }

  .m\:-my-48 {
    margin-top: -12rem;
    margin-bottom: -12rem;
  }

  .m\:-my-52 {
    margin-top: -13rem;
    margin-bottom: -13rem;
  }

  .m\:-my-56 {
    margin-top: -14rem;
    margin-bottom: -14rem;
  }

  .m\:-my-60 {
    margin-top: -15rem;
    margin-bottom: -15rem;
  }

  .m\:-my-64 {
    margin-top: -16rem;
    margin-bottom: -16rem;
  }

  .m\:-my-72 {
    margin-top: -18rem;
    margin-bottom: -18rem;
  }

  .m\:-my-80 {
    margin-top: -20rem;
    margin-bottom: -20rem;
  }

  .m\:-my-96 {
    margin-top: -24rem;
    margin-bottom: -24rem;
  }

  .m\:mt-px {
    margin-top: 0.0625rem;
  }

  .m\:mt-0 {
    margin-top: 0;
  }

  .m\:mt-none {
    margin-top: 0;
  }

  .m\:mt-0\.5 {
    margin-top: 0.125rem;
  }

  .m\:mt-1 {
    margin-top: 0.25rem;
  }

  .m\:mt-1\.5 {
    margin-top: 0.375rem;
  }

  .m\:mt-2 {
    margin-top: 0.5rem;
  }

  .m\:mt-2\.5 {
    margin-top: 0.625rem;
  }

  .m\:mt-3 {
    margin-top: 0.75rem;
  }

  .m\:mt-3\.5 {
    margin-top: 0.875rem;
  }

  .m\:mt-4 {
    margin-top: 1rem;
  }

  .m\:mt-5 {
    margin-top: 1.25rem;
  }

  .m\:mt-6 {
    margin-top: 1.5rem;
  }

  .m\:mt-7 {
    margin-top: 1.75rem;
  }

  .m\:mt-8 {
    margin-top: 2rem;
  }

  .m\:mt-9 {
    margin-top: 2.25rem;
  }

  .m\:mt-10 {
    margin-top: 2.5rem;
  }

  .m\:mt-11 {
    margin-top: 2.75rem;
  }

  .m\:mt-12 {
    margin-top: 3rem;
  }

  .m\:mt-14 {
    margin-top: 3.5rem;
  }

  .m\:mt-16 {
    margin-top: 4rem;
  }

  .m\:mt-18 {
    margin-top: 4.5rem;
  }

  .m\:mt-20 {
    margin-top: 5rem;
  }

  .m\:mt-24 {
    margin-top: 6rem;
  }

  .m\:mt-28 {
    margin-top: 7rem;
  }

  .m\:mt-32 {
    margin-top: 8rem;
  }

  .m\:mt-36 {
    margin-top: 9rem;
  }

  .m\:mt-40 {
    margin-top: 10rem;
  }

  .m\:mt-44 {
    margin-top: 11rem;
  }

  .m\:mt-48 {
    margin-top: 12rem;
  }

  .m\:mt-52 {
    margin-top: 13rem;
  }

  .m\:mt-56 {
    margin-top: 14rem;
  }

  .m\:mt-60 {
    margin-top: 15rem;
  }

  .m\:mt-64 {
    margin-top: 16rem;
  }

  .m\:mt-72 {
    margin-top: 18rem;
  }

  .m\:mt-80 {
    margin-top: 20rem;
  }

  .m\:mt-96 {
    margin-top: 24rem;
  }

  .m\:mt-auto {
    margin-top: auto;
  }

  .m\:-mt-px {
    margin-top: -0.0625rem;
  }

  .m\:-mt-0 {
    margin-top: 0;
  }

  .m\:-mt-none {
    margin-top: 0;
  }

  .m\:-mt-0\.5 {
    margin-top: -0.125rem;
  }

  .m\:-mt-1 {
    margin-top: -0.25rem;
  }

  .m\:-mt-1\.5 {
    margin-top: -0.375rem;
  }

  .m\:-mt-2 {
    margin-top: -0.5rem;
  }

  .m\:-mt-2\.5 {
    margin-top: -0.625rem;
  }

  .m\:-mt-3 {
    margin-top: -0.75rem;
  }

  .m\:-mt-3\.5 {
    margin-top: -0.875rem;
  }

  .m\:-mt-4 {
    margin-top: -1rem;
  }

  .m\:-mt-5 {
    margin-top: -1.25rem;
  }

  .m\:-mt-6 {
    margin-top: -1.5rem;
  }

  .m\:-mt-7 {
    margin-top: -1.75rem;
  }

  .m\:-mt-8 {
    margin-top: -2rem;
  }

  .m\:-mt-9 {
    margin-top: -2.25rem;
  }

  .m\:-mt-10 {
    margin-top: -2.5rem;
  }

  .m\:-mt-11 {
    margin-top: -2.75rem;
  }

  .m\:-mt-12 {
    margin-top: -3rem;
  }

  .m\:-mt-14 {
    margin-top: -3.5rem;
  }

  .m\:-mt-16 {
    margin-top: -4rem;
  }

  .m\:-mt-18 {
    margin-top: -4.5rem;
  }

  .m\:-mt-20 {
    margin-top: -5rem;
  }

  .m\:-mt-24 {
    margin-top: -6rem;
  }

  .m\:-mt-28 {
    margin-top: -7rem;
  }

  .m\:-mt-32 {
    margin-top: -8rem;
  }

  .m\:-mt-36 {
    margin-top: -9rem;
  }

  .m\:-mt-40 {
    margin-top: -10rem;
  }

  .m\:-mt-44 {
    margin-top: -11rem;
  }

  .m\:-mt-48 {
    margin-top: -12rem;
  }

  .m\:-mt-52 {
    margin-top: -13rem;
  }

  .m\:-mt-56 {
    margin-top: -14rem;
  }

  .m\:-mt-60 {
    margin-top: -15rem;
  }

  .m\:-mt-64 {
    margin-top: -16rem;
  }

  .m\:-mt-72 {
    margin-top: -18rem;
  }

  .m\:-mt-80 {
    margin-top: -20rem;
  }

  .m\:-mt-96 {
    margin-top: -24rem;
  }

  .m\:mr-px {
    margin-right: 0.0625rem;
  }

  .m\:mr-0 {
    margin-right: 0;
  }

  .m\:mr-none {
    margin-right: 0;
  }

  .m\:mr-0\.5 {
    margin-right: 0.125rem;
  }

  .m\:mr-1 {
    margin-right: 0.25rem;
  }

  .m\:mr-1\.5 {
    margin-right: 0.375rem;
  }

  .m\:mr-2 {
    margin-right: 0.5rem;
  }

  .m\:mr-2\.5 {
    margin-right: 0.625rem;
  }

  .m\:mr-3 {
    margin-right: 0.75rem;
  }

  .m\:mr-3\.5 {
    margin-right: 0.875rem;
  }

  .m\:mr-4 {
    margin-right: 1rem;
  }

  .m\:mr-5 {
    margin-right: 1.25rem;
  }

  .m\:mr-6 {
    margin-right: 1.5rem;
  }

  .m\:mr-7 {
    margin-right: 1.75rem;
  }

  .m\:mr-8 {
    margin-right: 2rem;
  }

  .m\:mr-9 {
    margin-right: 2.25rem;
  }

  .m\:mr-10 {
    margin-right: 2.5rem;
  }

  .m\:mr-11 {
    margin-right: 2.75rem;
  }

  .m\:mr-12 {
    margin-right: 3rem;
  }

  .m\:mr-14 {
    margin-right: 3.5rem;
  }

  .m\:mr-16 {
    margin-right: 4rem;
  }

  .m\:mr-18 {
    margin-right: 4.5rem;
  }

  .m\:mr-20 {
    margin-right: 5rem;
  }

  .m\:mr-24 {
    margin-right: 6rem;
  }

  .m\:mr-28 {
    margin-right: 7rem;
  }

  .m\:mr-32 {
    margin-right: 8rem;
  }

  .m\:mr-36 {
    margin-right: 9rem;
  }

  .m\:mr-40 {
    margin-right: 10rem;
  }

  .m\:mr-44 {
    margin-right: 11rem;
  }

  .m\:mr-48 {
    margin-right: 12rem;
  }

  .m\:mr-52 {
    margin-right: 13rem;
  }

  .m\:mr-56 {
    margin-right: 14rem;
  }

  .m\:mr-60 {
    margin-right: 15rem;
  }

  .m\:mr-64 {
    margin-right: 16rem;
  }

  .m\:mr-72 {
    margin-right: 18rem;
  }

  .m\:mr-80 {
    margin-right: 20rem;
  }

  .m\:mr-96 {
    margin-right: 24rem;
  }

  .m\:mr-auto {
    margin-right: auto;
  }

  .m\:-mr-px {
    margin-right: -0.0625rem;
  }

  .m\:-mr-0 {
    margin-right: 0;
  }

  .m\:-mr-none {
    margin-right: 0;
  }

  .m\:-mr-0\.5 {
    margin-right: -0.125rem;
  }

  .m\:-mr-1 {
    margin-right: -0.25rem;
  }

  .m\:-mr-1\.5 {
    margin-right: -0.375rem;
  }

  .m\:-mr-2 {
    margin-right: -0.5rem;
  }

  .m\:-mr-2\.5 {
    margin-right: -0.625rem;
  }

  .m\:-mr-3 {
    margin-right: -0.75rem;
  }

  .m\:-mr-3\.5 {
    margin-right: -0.875rem;
  }

  .m\:-mr-4 {
    margin-right: -1rem;
  }

  .m\:-mr-5 {
    margin-right: -1.25rem;
  }

  .m\:-mr-6 {
    margin-right: -1.5rem;
  }

  .m\:-mr-7 {
    margin-right: -1.75rem;
  }

  .m\:-mr-8 {
    margin-right: -2rem;
  }

  .m\:-mr-9 {
    margin-right: -2.25rem;
  }

  .m\:-mr-10 {
    margin-right: -2.5rem;
  }

  .m\:-mr-11 {
    margin-right: -2.75rem;
  }

  .m\:-mr-12 {
    margin-right: -3rem;
  }

  .m\:-mr-14 {
    margin-right: -3.5rem;
  }

  .m\:-mr-16 {
    margin-right: -4rem;
  }

  .m\:-mr-18 {
    margin-right: -4.5rem;
  }

  .m\:-mr-20 {
    margin-right: -5rem;
  }

  .m\:-mr-24 {
    margin-right: -6rem;
  }

  .m\:-mr-28 {
    margin-right: -7rem;
  }

  .m\:-mr-32 {
    margin-right: -8rem;
  }

  .m\:-mr-36 {
    margin-right: -9rem;
  }

  .m\:-mr-40 {
    margin-right: -10rem;
  }

  .m\:-mr-44 {
    margin-right: -11rem;
  }

  .m\:-mr-48 {
    margin-right: -12rem;
  }

  .m\:-mr-52 {
    margin-right: -13rem;
  }

  .m\:-mr-56 {
    margin-right: -14rem;
  }

  .m\:-mr-60 {
    margin-right: -15rem;
  }

  .m\:-mr-64 {
    margin-right: -16rem;
  }

  .m\:-mr-72 {
    margin-right: -18rem;
  }

  .m\:-mr-80 {
    margin-right: -20rem;
  }

  .m\:-mr-96 {
    margin-right: -24rem;
  }

  .m\:mb-px {
    margin-bottom: 0.0625rem;
  }

  .m\:mb-0 {
    margin-bottom: 0;
  }

  .m\:mb-none {
    margin-bottom: 0;
  }

  .m\:mb-0\.5 {
    margin-bottom: 0.125rem;
  }

  .m\:mb-1 {
    margin-bottom: 0.25rem;
  }

  .m\:mb-1\.5 {
    margin-bottom: 0.375rem;
  }

  .m\:mb-2 {
    margin-bottom: 0.5rem;
  }

  .m\:mb-2\.5 {
    margin-bottom: 0.625rem;
  }

  .m\:mb-3 {
    margin-bottom: 0.75rem;
  }

  .m\:mb-3\.5 {
    margin-bottom: 0.875rem;
  }

  .m\:mb-4 {
    margin-bottom: 1rem;
  }

  .m\:mb-5 {
    margin-bottom: 1.25rem;
  }

  .m\:mb-6 {
    margin-bottom: 1.5rem;
  }

  .m\:mb-7 {
    margin-bottom: 1.75rem;
  }

  .m\:mb-8 {
    margin-bottom: 2rem;
  }

  .m\:mb-9 {
    margin-bottom: 2.25rem;
  }

  .m\:mb-10 {
    margin-bottom: 2.5rem;
  }

  .m\:mb-11 {
    margin-bottom: 2.75rem;
  }

  .m\:mb-12 {
    margin-bottom: 3rem;
  }

  .m\:mb-14 {
    margin-bottom: 3.5rem;
  }

  .m\:mb-16 {
    margin-bottom: 4rem;
  }

  .m\:mb-18 {
    margin-bottom: 4.5rem;
  }

  .m\:mb-20 {
    margin-bottom: 5rem;
  }

  .m\:mb-24 {
    margin-bottom: 6rem;
  }

  .m\:mb-28 {
    margin-bottom: 7rem;
  }

  .m\:mb-32 {
    margin-bottom: 8rem;
  }

  .m\:mb-36 {
    margin-bottom: 9rem;
  }

  .m\:mb-40 {
    margin-bottom: 10rem;
  }

  .m\:mb-44 {
    margin-bottom: 11rem;
  }

  .m\:mb-48 {
    margin-bottom: 12rem;
  }

  .m\:mb-52 {
    margin-bottom: 13rem;
  }

  .m\:mb-56 {
    margin-bottom: 14rem;
  }

  .m\:mb-60 {
    margin-bottom: 15rem;
  }

  .m\:mb-64 {
    margin-bottom: 16rem;
  }

  .m\:mb-72 {
    margin-bottom: 18rem;
  }

  .m\:mb-80 {
    margin-bottom: 20rem;
  }

  .m\:mb-96 {
    margin-bottom: 24rem;
  }

  .m\:mb-auto {
    margin-bottom: auto;
  }

  .m\:-mb-px {
    margin-bottom: -0.0625rem;
  }

  .m\:-mb-0 {
    margin-bottom: 0;
  }

  .m\:-mb-none {
    margin-bottom: 0;
  }

  .m\:-mb-0\.5 {
    margin-bottom: -0.125rem;
  }

  .m\:-mb-1 {
    margin-bottom: -0.25rem;
  }

  .m\:-mb-1\.5 {
    margin-bottom: -0.375rem;
  }

  .m\:-mb-2 {
    margin-bottom: -0.5rem;
  }

  .m\:-mb-2\.5 {
    margin-bottom: -0.625rem;
  }

  .m\:-mb-3 {
    margin-bottom: -0.75rem;
  }

  .m\:-mb-3\.5 {
    margin-bottom: -0.875rem;
  }

  .m\:-mb-4 {
    margin-bottom: -1rem;
  }

  .m\:-mb-5 {
    margin-bottom: -1.25rem;
  }

  .m\:-mb-6 {
    margin-bottom: -1.5rem;
  }

  .m\:-mb-7 {
    margin-bottom: -1.75rem;
  }

  .m\:-mb-8 {
    margin-bottom: -2rem;
  }

  .m\:-mb-9 {
    margin-bottom: -2.25rem;
  }

  .m\:-mb-10 {
    margin-bottom: -2.5rem;
  }

  .m\:-mb-11 {
    margin-bottom: -2.75rem;
  }

  .m\:-mb-12 {
    margin-bottom: -3rem;
  }

  .m\:-mb-14 {
    margin-bottom: -3.5rem;
  }

  .m\:-mb-16 {
    margin-bottom: -4rem;
  }

  .m\:-mb-18 {
    margin-bottom: -4.5rem;
  }

  .m\:-mb-20 {
    margin-bottom: -5rem;
  }

  .m\:-mb-24 {
    margin-bottom: -6rem;
  }

  .m\:-mb-28 {
    margin-bottom: -7rem;
  }

  .m\:-mb-32 {
    margin-bottom: -8rem;
  }

  .m\:-mb-36 {
    margin-bottom: -9rem;
  }

  .m\:-mb-40 {
    margin-bottom: -10rem;
  }

  .m\:-mb-44 {
    margin-bottom: -11rem;
  }

  .m\:-mb-48 {
    margin-bottom: -12rem;
  }

  .m\:-mb-52 {
    margin-bottom: -13rem;
  }

  .m\:-mb-56 {
    margin-bottom: -14rem;
  }

  .m\:-mb-60 {
    margin-bottom: -15rem;
  }

  .m\:-mb-64 {
    margin-bottom: -16rem;
  }

  .m\:-mb-72 {
    margin-bottom: -18rem;
  }

  .m\:-mb-80 {
    margin-bottom: -20rem;
  }

  .m\:-mb-96 {
    margin-bottom: -24rem;
  }

  .m\:ml-px {
    margin-left: 0.0625rem;
  }

  .m\:ml-0 {
    margin-left: 0;
  }

  .m\:ml-none {
    margin-left: 0;
  }

  .m\:ml-0\.5 {
    margin-left: 0.125rem;
  }

  .m\:ml-1 {
    margin-left: 0.25rem;
  }

  .m\:ml-1\.5 {
    margin-left: 0.375rem;
  }

  .m\:ml-2 {
    margin-left: 0.5rem;
  }

  .m\:ml-2\.5 {
    margin-left: 0.625rem;
  }

  .m\:ml-3 {
    margin-left: 0.75rem;
  }

  .m\:ml-3\.5 {
    margin-left: 0.875rem;
  }

  .m\:ml-4 {
    margin-left: 1rem;
  }

  .m\:ml-5 {
    margin-left: 1.25rem;
  }

  .m\:ml-6 {
    margin-left: 1.5rem;
  }

  .m\:ml-7 {
    margin-left: 1.75rem;
  }

  .m\:ml-8 {
    margin-left: 2rem;
  }

  .m\:ml-9 {
    margin-left: 2.25rem;
  }

  .m\:ml-10 {
    margin-left: 2.5rem;
  }

  .m\:ml-11 {
    margin-left: 2.75rem;
  }

  .m\:ml-12 {
    margin-left: 3rem;
  }

  .m\:ml-14 {
    margin-left: 3.5rem;
  }

  .m\:ml-16 {
    margin-left: 4rem;
  }

  .m\:ml-18 {
    margin-left: 4.5rem;
  }

  .m\:ml-20 {
    margin-left: 5rem;
  }

  .m\:ml-24 {
    margin-left: 6rem;
  }

  .m\:ml-28 {
    margin-left: 7rem;
  }

  .m\:ml-32 {
    margin-left: 8rem;
  }

  .m\:ml-36 {
    margin-left: 9rem;
  }

  .m\:ml-40 {
    margin-left: 10rem;
  }

  .m\:ml-44 {
    margin-left: 11rem;
  }

  .m\:ml-48 {
    margin-left: 12rem;
  }

  .m\:ml-52 {
    margin-left: 13rem;
  }

  .m\:ml-56 {
    margin-left: 14rem;
  }

  .m\:ml-60 {
    margin-left: 15rem;
  }

  .m\:ml-64 {
    margin-left: 16rem;
  }

  .m\:ml-72 {
    margin-left: 18rem;
  }

  .m\:ml-80 {
    margin-left: 20rem;
  }

  .m\:ml-96 {
    margin-left: 24rem;
  }

  .m\:ml-auto {
    margin-left: auto;
  }

  .m\:-ml-px {
    margin-left: -0.0625rem;
  }

  .m\:-ml-0 {
    margin-left: 0;
  }

  .m\:-ml-none {
    margin-left: 0;
  }

  .m\:-ml-0\.5 {
    margin-left: -0.125rem;
  }

  .m\:-ml-1 {
    margin-left: -0.25rem;
  }

  .m\:-ml-1\.5 {
    margin-left: -0.375rem;
  }

  .m\:-ml-2 {
    margin-left: -0.5rem;
  }

  .m\:-ml-2\.5 {
    margin-left: -0.625rem;
  }

  .m\:-ml-3 {
    margin-left: -0.75rem;
  }

  .m\:-ml-3\.5 {
    margin-left: -0.875rem;
  }

  .m\:-ml-4 {
    margin-left: -1rem;
  }

  .m\:-ml-5 {
    margin-left: -1.25rem;
  }

  .m\:-ml-6 {
    margin-left: -1.5rem;
  }

  .m\:-ml-7 {
    margin-left: -1.75rem;
  }

  .m\:-ml-8 {
    margin-left: -2rem;
  }

  .m\:-ml-9 {
    margin-left: -2.25rem;
  }

  .m\:-ml-10 {
    margin-left: -2.5rem;
  }

  .m\:-ml-11 {
    margin-left: -2.75rem;
  }

  .m\:-ml-12 {
    margin-left: -3rem;
  }

  .m\:-ml-14 {
    margin-left: -3.5rem;
  }

  .m\:-ml-16 {
    margin-left: -4rem;
  }

  .m\:-ml-18 {
    margin-left: -4.5rem;
  }

  .m\:-ml-20 {
    margin-left: -5rem;
  }

  .m\:-ml-24 {
    margin-left: -6rem;
  }

  .m\:-ml-28 {
    margin-left: -7rem;
  }

  .m\:-ml-32 {
    margin-left: -8rem;
  }

  .m\:-ml-36 {
    margin-left: -9rem;
  }

  .m\:-ml-40 {
    margin-left: -10rem;
  }

  .m\:-ml-44 {
    margin-left: -11rem;
  }

  .m\:-ml-48 {
    margin-left: -12rem;
  }

  .m\:-ml-52 {
    margin-left: -13rem;
  }

  .m\:-ml-56 {
    margin-left: -14rem;
  }

  .m\:-ml-60 {
    margin-left: -15rem;
  }

  .m\:-ml-64 {
    margin-left: -16rem;
  }

  .m\:-ml-72 {
    margin-left: -18rem;
  }

  .m\:-ml-80 {
    margin-left: -20rem;
  }

  .m\:-ml-96 {
    margin-left: -24rem;
  }
}
@media (min-width: 769px) {
  .pc\:m-px {
    margin: 0.0625rem;
  }

  .pc\:m-0 {
    margin: 0;
  }

  .pc\:m-none {
    margin: 0;
  }

  .pc\:m-0\.5 {
    margin: 0.125rem;
  }

  .pc\:m-1 {
    margin: 0.25rem;
  }

  .pc\:m-1\.5 {
    margin: 0.375rem;
  }

  .pc\:m-2 {
    margin: 0.5rem;
  }

  .pc\:m-2\.5 {
    margin: 0.625rem;
  }

  .pc\:m-3 {
    margin: 0.75rem;
  }

  .pc\:m-3\.5 {
    margin: 0.875rem;
  }

  .pc\:m-4 {
    margin: 1rem;
  }

  .pc\:m-5 {
    margin: 1.25rem;
  }

  .pc\:m-6 {
    margin: 1.5rem;
  }

  .pc\:m-7 {
    margin: 1.75rem;
  }

  .pc\:m-8 {
    margin: 2rem;
  }

  .pc\:m-9 {
    margin: 2.25rem;
  }

  .pc\:m-10 {
    margin: 2.5rem;
  }

  .pc\:m-11 {
    margin: 2.75rem;
  }

  .pc\:m-12 {
    margin: 3rem;
  }

  .pc\:m-14 {
    margin: 3.5rem;
  }

  .pc\:m-16 {
    margin: 4rem;
  }

  .pc\:m-18 {
    margin: 4.5rem;
  }

  .pc\:m-20 {
    margin: 5rem;
  }

  .pc\:m-24 {
    margin: 6rem;
  }

  .pc\:m-28 {
    margin: 7rem;
  }

  .pc\:m-32 {
    margin: 8rem;
  }

  .pc\:m-36 {
    margin: 9rem;
  }

  .pc\:m-40 {
    margin: 10rem;
  }

  .pc\:m-44 {
    margin: 11rem;
  }

  .pc\:m-48 {
    margin: 12rem;
  }

  .pc\:m-52 {
    margin: 13rem;
  }

  .pc\:m-56 {
    margin: 14rem;
  }

  .pc\:m-60 {
    margin: 15rem;
  }

  .pc\:m-64 {
    margin: 16rem;
  }

  .pc\:m-72 {
    margin: 18rem;
  }

  .pc\:m-80 {
    margin: 20rem;
  }

  .pc\:m-96 {
    margin: 24rem;
  }

  .pc\:m-auto {
    margin: auto;
  }

  .pc\:-m-px {
    margin: -0.0625rem;
  }

  .pc\:-m-0 {
    margin: 0;
  }

  .pc\:-m-none {
    margin: 0;
  }

  .pc\:-m-0\.5 {
    margin: -0.125rem;
  }

  .pc\:-m-1 {
    margin: -0.25rem;
  }

  .pc\:-m-1\.5 {
    margin: -0.375rem;
  }

  .pc\:-m-2 {
    margin: -0.5rem;
  }

  .pc\:-m-2\.5 {
    margin: -0.625rem;
  }

  .pc\:-m-3 {
    margin: -0.75rem;
  }

  .pc\:-m-3\.5 {
    margin: -0.875rem;
  }

  .pc\:-m-4 {
    margin: -1rem;
  }

  .pc\:-m-5 {
    margin: -1.25rem;
  }

  .pc\:-m-6 {
    margin: -1.5rem;
  }

  .pc\:-m-7 {
    margin: -1.75rem;
  }

  .pc\:-m-8 {
    margin: -2rem;
  }

  .pc\:-m-9 {
    margin: -2.25rem;
  }

  .pc\:-m-10 {
    margin: -2.5rem;
  }

  .pc\:-m-11 {
    margin: -2.75rem;
  }

  .pc\:-m-12 {
    margin: -3rem;
  }

  .pc\:-m-14 {
    margin: -3.5rem;
  }

  .pc\:-m-16 {
    margin: -4rem;
  }

  .pc\:-m-18 {
    margin: -4.5rem;
  }

  .pc\:-m-20 {
    margin: -5rem;
  }

  .pc\:-m-24 {
    margin: -6rem;
  }

  .pc\:-m-28 {
    margin: -7rem;
  }

  .pc\:-m-32 {
    margin: -8rem;
  }

  .pc\:-m-36 {
    margin: -9rem;
  }

  .pc\:-m-40 {
    margin: -10rem;
  }

  .pc\:-m-44 {
    margin: -11rem;
  }

  .pc\:-m-48 {
    margin: -12rem;
  }

  .pc\:-m-52 {
    margin: -13rem;
  }

  .pc\:-m-56 {
    margin: -14rem;
  }

  .pc\:-m-60 {
    margin: -15rem;
  }

  .pc\:-m-64 {
    margin: -16rem;
  }

  .pc\:-m-72 {
    margin: -18rem;
  }

  .pc\:-m-80 {
    margin: -20rem;
  }

  .pc\:-m-96 {
    margin: -24rem;
  }

  .pc\:mx-px {
    margin-left: 0.0625rem;
    margin-right: 0.0625rem;
  }

  .pc\:mx-0 {
    margin-left: 0;
    margin-right: 0;
  }

  .pc\:mx-none {
    margin-left: 0;
    margin-right: 0;
  }

  .pc\:mx-0\.5 {
    margin-left: 0.125rem;
    margin-right: 0.125rem;
  }

  .pc\:mx-1 {
    margin-left: 0.25rem;
    margin-right: 0.25rem;
  }

  .pc\:mx-1\.5 {
    margin-left: 0.375rem;
    margin-right: 0.375rem;
  }

  .pc\:mx-2 {
    margin-left: 0.5rem;
    margin-right: 0.5rem;
  }

  .pc\:mx-2\.5 {
    margin-left: 0.625rem;
    margin-right: 0.625rem;
  }

  .pc\:mx-3 {
    margin-left: 0.75rem;
    margin-right: 0.75rem;
  }

  .pc\:mx-3\.5 {
    margin-left: 0.875rem;
    margin-right: 0.875rem;
  }

  .pc\:mx-4 {
    margin-left: 1rem;
    margin-right: 1rem;
  }

  .pc\:mx-5 {
    margin-left: 1.25rem;
    margin-right: 1.25rem;
  }

  .pc\:mx-6 {
    margin-left: 1.5rem;
    margin-right: 1.5rem;
  }

  .pc\:mx-7 {
    margin-left: 1.75rem;
    margin-right: 1.75rem;
  }

  .pc\:mx-8 {
    margin-left: 2rem;
    margin-right: 2rem;
  }

  .pc\:mx-9 {
    margin-left: 2.25rem;
    margin-right: 2.25rem;
  }

  .pc\:mx-10 {
    margin-left: 2.5rem;
    margin-right: 2.5rem;
  }

  .pc\:mx-11 {
    margin-left: 2.75rem;
    margin-right: 2.75rem;
  }

  .pc\:mx-12 {
    margin-left: 3rem;
    margin-right: 3rem;
  }

  .pc\:mx-14 {
    margin-left: 3.5rem;
    margin-right: 3.5rem;
  }

  .pc\:mx-16 {
    margin-left: 4rem;
    margin-right: 4rem;
  }

  .pc\:mx-18 {
    margin-left: 4.5rem;
    margin-right: 4.5rem;
  }

  .pc\:mx-20 {
    margin-left: 5rem;
    margin-right: 5rem;
  }

  .pc\:mx-24 {
    margin-left: 6rem;
    margin-right: 6rem;
  }

  .pc\:mx-28 {
    margin-left: 7rem;
    margin-right: 7rem;
  }

  .pc\:mx-32 {
    margin-left: 8rem;
    margin-right: 8rem;
  }

  .pc\:mx-36 {
    margin-left: 9rem;
    margin-right: 9rem;
  }

  .pc\:mx-40 {
    margin-left: 10rem;
    margin-right: 10rem;
  }

  .pc\:mx-44 {
    margin-left: 11rem;
    margin-right: 11rem;
  }

  .pc\:mx-48 {
    margin-left: 12rem;
    margin-right: 12rem;
  }

  .pc\:mx-52 {
    margin-left: 13rem;
    margin-right: 13rem;
  }

  .pc\:mx-56 {
    margin-left: 14rem;
    margin-right: 14rem;
  }

  .pc\:mx-60 {
    margin-left: 15rem;
    margin-right: 15rem;
  }

  .pc\:mx-64 {
    margin-left: 16rem;
    margin-right: 16rem;
  }

  .pc\:mx-72 {
    margin-left: 18rem;
    margin-right: 18rem;
  }

  .pc\:mx-80 {
    margin-left: 20rem;
    margin-right: 20rem;
  }

  .pc\:mx-96 {
    margin-left: 24rem;
    margin-right: 24rem;
  }

  .pc\:mx-auto {
    margin-left: auto;
    margin-right: auto;
  }

  .pc\:mx-auto {
    margin-left: auto;
    margin-right: auto;
  }

  .pc\:-mx-px {
    margin-left: -0.0625rem;
    margin-right: -0.0625rem;
  }

  .pc\:-mx-0 {
    margin-left: 0;
    margin-right: 0;
  }

  .pc\:-mx-none {
    margin-left: 0;
    margin-right: 0;
  }

  .pc\:-mx-0\.5 {
    margin-left: -0.125rem;
    margin-right: -0.125rem;
  }

  .pc\:-mx-1 {
    margin-left: -0.25rem;
    margin-right: -0.25rem;
  }

  .pc\:-mx-1\.5 {
    margin-left: -0.375rem;
    margin-right: -0.375rem;
  }

  .pc\:-mx-2 {
    margin-left: -0.5rem;
    margin-right: -0.5rem;
  }

  .pc\:-mx-2\.5 {
    margin-left: -0.625rem;
    margin-right: -0.625rem;
  }

  .pc\:-mx-3 {
    margin-left: -0.75rem;
    margin-right: -0.75rem;
  }

  .pc\:-mx-3\.5 {
    margin-left: -0.875rem;
    margin-right: -0.875rem;
  }

  .pc\:-mx-4 {
    margin-left: -1rem;
    margin-right: -1rem;
  }

  .pc\:-mx-5 {
    margin-left: -1.25rem;
    margin-right: -1.25rem;
  }

  .pc\:-mx-6 {
    margin-left: -1.5rem;
    margin-right: -1.5rem;
  }

  .pc\:-mx-7 {
    margin-left: -1.75rem;
    margin-right: -1.75rem;
  }

  .pc\:-mx-8 {
    margin-left: -2rem;
    margin-right: -2rem;
  }

  .pc\:-mx-9 {
    margin-left: -2.25rem;
    margin-right: -2.25rem;
  }

  .pc\:-mx-10 {
    margin-left: -2.5rem;
    margin-right: -2.5rem;
  }

  .pc\:-mx-11 {
    margin-left: -2.75rem;
    margin-right: -2.75rem;
  }

  .pc\:-mx-12 {
    margin-left: -3rem;
    margin-right: -3rem;
  }

  .pc\:-mx-14 {
    margin-left: -3.5rem;
    margin-right: -3.5rem;
  }

  .pc\:-mx-16 {
    margin-left: -4rem;
    margin-right: -4rem;
  }

  .pc\:-mx-18 {
    margin-left: -4.5rem;
    margin-right: -4.5rem;
  }

  .pc\:-mx-20 {
    margin-left: -5rem;
    margin-right: -5rem;
  }

  .pc\:-mx-24 {
    margin-left: -6rem;
    margin-right: -6rem;
  }

  .pc\:-mx-28 {
    margin-left: -7rem;
    margin-right: -7rem;
  }

  .pc\:-mx-32 {
    margin-left: -8rem;
    margin-right: -8rem;
  }

  .pc\:-mx-36 {
    margin-left: -9rem;
    margin-right: -9rem;
  }

  .pc\:-mx-40 {
    margin-left: -10rem;
    margin-right: -10rem;
  }

  .pc\:-mx-44 {
    margin-left: -11rem;
    margin-right: -11rem;
  }

  .pc\:-mx-48 {
    margin-left: -12rem;
    margin-right: -12rem;
  }

  .pc\:-mx-52 {
    margin-left: -13rem;
    margin-right: -13rem;
  }

  .pc\:-mx-56 {
    margin-left: -14rem;
    margin-right: -14rem;
  }

  .pc\:-mx-60 {
    margin-left: -15rem;
    margin-right: -15rem;
  }

  .pc\:-mx-64 {
    margin-left: -16rem;
    margin-right: -16rem;
  }

  .pc\:-mx-72 {
    margin-left: -18rem;
    margin-right: -18rem;
  }

  .pc\:-mx-80 {
    margin-left: -20rem;
    margin-right: -20rem;
  }

  .pc\:-mx-96 {
    margin-left: -24rem;
    margin-right: -24rem;
  }

  .pc\:my-px {
    margin-top: 0.0625rem;
    margin-bottom: 0.0625rem;
  }

  .pc\:my-0 {
    margin-top: 0;
    margin-bottom: 0;
  }

  .pc\:my-none {
    margin-top: 0;
    margin-bottom: 0;
  }

  .pc\:my-0\.5 {
    margin-top: 0.125rem;
    margin-bottom: 0.125rem;
  }

  .pc\:my-1 {
    margin-top: 0.25rem;
    margin-bottom: 0.25rem;
  }

  .pc\:my-1\.5 {
    margin-top: 0.375rem;
    margin-bottom: 0.375rem;
  }

  .pc\:my-2 {
    margin-top: 0.5rem;
    margin-bottom: 0.5rem;
  }

  .pc\:my-2\.5 {
    margin-top: 0.625rem;
    margin-bottom: 0.625rem;
  }

  .pc\:my-3 {
    margin-top: 0.75rem;
    margin-bottom: 0.75rem;
  }

  .pc\:my-3\.5 {
    margin-top: 0.875rem;
    margin-bottom: 0.875rem;
  }

  .pc\:my-4 {
    margin-top: 1rem;
    margin-bottom: 1rem;
  }

  .pc\:my-5 {
    margin-top: 1.25rem;
    margin-bottom: 1.25rem;
  }

  .pc\:my-6 {
    margin-top: 1.5rem;
    margin-bottom: 1.5rem;
  }

  .pc\:my-7 {
    margin-top: 1.75rem;
    margin-bottom: 1.75rem;
  }

  .pc\:my-8 {
    margin-top: 2rem;
    margin-bottom: 2rem;
  }

  .pc\:my-9 {
    margin-top: 2.25rem;
    margin-bottom: 2.25rem;
  }

  .pc\:my-10 {
    margin-top: 2.5rem;
    margin-bottom: 2.5rem;
  }

  .pc\:my-11 {
    margin-top: 2.75rem;
    margin-bottom: 2.75rem;
  }

  .pc\:my-12 {
    margin-top: 3rem;
    margin-bottom: 3rem;
  }

  .pc\:my-14 {
    margin-top: 3.5rem;
    margin-bottom: 3.5rem;
  }

  .pc\:my-16 {
    margin-top: 4rem;
    margin-bottom: 4rem;
  }

  .pc\:my-18 {
    margin-top: 4.5rem;
    margin-bottom: 4.5rem;
  }

  .pc\:my-20 {
    margin-top: 5rem;
    margin-bottom: 5rem;
  }

  .pc\:my-24 {
    margin-top: 6rem;
    margin-bottom: 6rem;
  }

  .pc\:my-28 {
    margin-top: 7rem;
    margin-bottom: 7rem;
  }

  .pc\:my-32 {
    margin-top: 8rem;
    margin-bottom: 8rem;
  }

  .pc\:my-36 {
    margin-top: 9rem;
    margin-bottom: 9rem;
  }

  .pc\:my-40 {
    margin-top: 10rem;
    margin-bottom: 10rem;
  }

  .pc\:my-44 {
    margin-top: 11rem;
    margin-bottom: 11rem;
  }

  .pc\:my-48 {
    margin-top: 12rem;
    margin-bottom: 12rem;
  }

  .pc\:my-52 {
    margin-top: 13rem;
    margin-bottom: 13rem;
  }

  .pc\:my-56 {
    margin-top: 14rem;
    margin-bottom: 14rem;
  }

  .pc\:my-60 {
    margin-top: 15rem;
    margin-bottom: 15rem;
  }

  .pc\:my-64 {
    margin-top: 16rem;
    margin-bottom: 16rem;
  }

  .pc\:my-72 {
    margin-top: 18rem;
    margin-bottom: 18rem;
  }

  .pc\:my-80 {
    margin-top: 20rem;
    margin-bottom: 20rem;
  }

  .pc\:my-96 {
    margin-top: 24rem;
    margin-bottom: 24rem;
  }

  .pc\:my-auto {
    margin-top: auto;
    margin-bottom: auto;
  }

  .pc\:my-auto {
    margin-top: auto;
    margin-bottom: auto;
  }

  .pc\:-my-px {
    margin-top: -0.0625rem;
    margin-bottom: -0.0625rem;
  }

  .pc\:-my-0 {
    margin-top: 0;
    margin-bottom: 0;
  }

  .pc\:-my-none {
    margin-top: 0;
    margin-bottom: 0;
  }

  .pc\:-my-0\.5 {
    margin-top: -0.125rem;
    margin-bottom: -0.125rem;
  }

  .pc\:-my-1 {
    margin-top: -0.25rem;
    margin-bottom: -0.25rem;
  }

  .pc\:-my-1\.5 {
    margin-top: -0.375rem;
    margin-bottom: -0.375rem;
  }

  .pc\:-my-2 {
    margin-top: -0.5rem;
    margin-bottom: -0.5rem;
  }

  .pc\:-my-2\.5 {
    margin-top: -0.625rem;
    margin-bottom: -0.625rem;
  }

  .pc\:-my-3 {
    margin-top: -0.75rem;
    margin-bottom: -0.75rem;
  }

  .pc\:-my-3\.5 {
    margin-top: -0.875rem;
    margin-bottom: -0.875rem;
  }

  .pc\:-my-4 {
    margin-top: -1rem;
    margin-bottom: -1rem;
  }

  .pc\:-my-5 {
    margin-top: -1.25rem;
    margin-bottom: -1.25rem;
  }

  .pc\:-my-6 {
    margin-top: -1.5rem;
    margin-bottom: -1.5rem;
  }

  .pc\:-my-7 {
    margin-top: -1.75rem;
    margin-bottom: -1.75rem;
  }

  .pc\:-my-8 {
    margin-top: -2rem;
    margin-bottom: -2rem;
  }

  .pc\:-my-9 {
    margin-top: -2.25rem;
    margin-bottom: -2.25rem;
  }

  .pc\:-my-10 {
    margin-top: -2.5rem;
    margin-bottom: -2.5rem;
  }

  .pc\:-my-11 {
    margin-top: -2.75rem;
    margin-bottom: -2.75rem;
  }

  .pc\:-my-12 {
    margin-top: -3rem;
    margin-bottom: -3rem;
  }

  .pc\:-my-14 {
    margin-top: -3.5rem;
    margin-bottom: -3.5rem;
  }

  .pc\:-my-16 {
    margin-top: -4rem;
    margin-bottom: -4rem;
  }

  .pc\:-my-18 {
    margin-top: -4.5rem;
    margin-bottom: -4.5rem;
  }

  .pc\:-my-20 {
    margin-top: -5rem;
    margin-bottom: -5rem;
  }

  .pc\:-my-24 {
    margin-top: -6rem;
    margin-bottom: -6rem;
  }

  .pc\:-my-28 {
    margin-top: -7rem;
    margin-bottom: -7rem;
  }

  .pc\:-my-32 {
    margin-top: -8rem;
    margin-bottom: -8rem;
  }

  .pc\:-my-36 {
    margin-top: -9rem;
    margin-bottom: -9rem;
  }

  .pc\:-my-40 {
    margin-top: -10rem;
    margin-bottom: -10rem;
  }

  .pc\:-my-44 {
    margin-top: -11rem;
    margin-bottom: -11rem;
  }

  .pc\:-my-48 {
    margin-top: -12rem;
    margin-bottom: -12rem;
  }

  .pc\:-my-52 {
    margin-top: -13rem;
    margin-bottom: -13rem;
  }

  .pc\:-my-56 {
    margin-top: -14rem;
    margin-bottom: -14rem;
  }

  .pc\:-my-60 {
    margin-top: -15rem;
    margin-bottom: -15rem;
  }

  .pc\:-my-64 {
    margin-top: -16rem;
    margin-bottom: -16rem;
  }

  .pc\:-my-72 {
    margin-top: -18rem;
    margin-bottom: -18rem;
  }

  .pc\:-my-80 {
    margin-top: -20rem;
    margin-bottom: -20rem;
  }

  .pc\:-my-96 {
    margin-top: -24rem;
    margin-bottom: -24rem;
  }

  .pc\:mt-px {
    margin-top: 0.0625rem;
  }

  .pc\:mt-0 {
    margin-top: 0;
  }

  .pc\:mt-none {
    margin-top: 0;
  }

  .pc\:mt-0\.5 {
    margin-top: 0.125rem;
  }

  .pc\:mt-1 {
    margin-top: 0.25rem;
  }

  .pc\:mt-1\.5 {
    margin-top: 0.375rem;
  }

  .pc\:mt-2 {
    margin-top: 0.5rem;
  }

  .pc\:mt-2\.5 {
    margin-top: 0.625rem;
  }

  .pc\:mt-3 {
    margin-top: 0.75rem;
  }

  .pc\:mt-3\.5 {
    margin-top: 0.875rem;
  }

  .pc\:mt-4 {
    margin-top: 1rem;
  }

  .pc\:mt-5 {
    margin-top: 1.25rem;
  }

  .pc\:mt-6 {
    margin-top: 1.5rem;
  }

  .pc\:mt-7 {
    margin-top: 1.75rem;
  }

  .pc\:mt-8 {
    margin-top: 2rem;
  }

  .pc\:mt-9 {
    margin-top: 2.25rem;
  }

  .pc\:mt-10 {
    margin-top: 2.5rem;
  }

  .pc\:mt-11 {
    margin-top: 2.75rem;
  }

  .pc\:mt-12 {
    margin-top: 3rem;
  }

  .pc\:mt-14 {
    margin-top: 3.5rem;
  }

  .pc\:mt-16 {
    margin-top: 4rem;
  }

  .pc\:mt-18 {
    margin-top: 4.5rem;
  }

  .pc\:mt-20 {
    margin-top: 5rem;
  }

  .pc\:mt-24 {
    margin-top: 6rem;
  }

  .pc\:mt-28 {
    margin-top: 7rem;
  }

  .pc\:mt-32 {
    margin-top: 8rem;
  }

  .pc\:mt-36 {
    margin-top: 9rem;
  }

  .pc\:mt-40 {
    margin-top: 10rem;
  }

  .pc\:mt-44 {
    margin-top: 11rem;
  }

  .pc\:mt-48 {
    margin-top: 12rem;
  }

  .pc\:mt-52 {
    margin-top: 13rem;
  }

  .pc\:mt-56 {
    margin-top: 14rem;
  }

  .pc\:mt-60 {
    margin-top: 15rem;
  }

  .pc\:mt-64 {
    margin-top: 16rem;
  }

  .pc\:mt-72 {
    margin-top: 18rem;
  }

  .pc\:mt-80 {
    margin-top: 20rem;
  }

  .pc\:mt-96 {
    margin-top: 24rem;
  }

  .pc\:mt-auto {
    margin-top: auto;
  }

  .pc\:-mt-px {
    margin-top: -0.0625rem;
  }

  .pc\:-mt-0 {
    margin-top: 0;
  }

  .pc\:-mt-none {
    margin-top: 0;
  }

  .pc\:-mt-0\.5 {
    margin-top: -0.125rem;
  }

  .pc\:-mt-1 {
    margin-top: -0.25rem;
  }

  .pc\:-mt-1\.5 {
    margin-top: -0.375rem;
  }

  .pc\:-mt-2 {
    margin-top: -0.5rem;
  }

  .pc\:-mt-2\.5 {
    margin-top: -0.625rem;
  }

  .pc\:-mt-3 {
    margin-top: -0.75rem;
  }

  .pc\:-mt-3\.5 {
    margin-top: -0.875rem;
  }

  .pc\:-mt-4 {
    margin-top: -1rem;
  }

  .pc\:-mt-5 {
    margin-top: -1.25rem;
  }

  .pc\:-mt-6 {
    margin-top: -1.5rem;
  }

  .pc\:-mt-7 {
    margin-top: -1.75rem;
  }

  .pc\:-mt-8 {
    margin-top: -2rem;
  }

  .pc\:-mt-9 {
    margin-top: -2.25rem;
  }

  .pc\:-mt-10 {
    margin-top: -2.5rem;
  }

  .pc\:-mt-11 {
    margin-top: -2.75rem;
  }

  .pc\:-mt-12 {
    margin-top: -3rem;
  }

  .pc\:-mt-14 {
    margin-top: -3.5rem;
  }

  .pc\:-mt-16 {
    margin-top: -4rem;
  }

  .pc\:-mt-18 {
    margin-top: -4.5rem;
  }

  .pc\:-mt-20 {
    margin-top: -5rem;
  }

  .pc\:-mt-24 {
    margin-top: -6rem;
  }

  .pc\:-mt-28 {
    margin-top: -7rem;
  }

  .pc\:-mt-32 {
    margin-top: -8rem;
  }

  .pc\:-mt-36 {
    margin-top: -9rem;
  }

  .pc\:-mt-40 {
    margin-top: -10rem;
  }

  .pc\:-mt-44 {
    margin-top: -11rem;
  }

  .pc\:-mt-48 {
    margin-top: -12rem;
  }

  .pc\:-mt-52 {
    margin-top: -13rem;
  }

  .pc\:-mt-56 {
    margin-top: -14rem;
  }

  .pc\:-mt-60 {
    margin-top: -15rem;
  }

  .pc\:-mt-64 {
    margin-top: -16rem;
  }

  .pc\:-mt-72 {
    margin-top: -18rem;
  }

  .pc\:-mt-80 {
    margin-top: -20rem;
  }

  .pc\:-mt-96 {
    margin-top: -24rem;
  }

  .pc\:mr-px {
    margin-right: 0.0625rem;
  }

  .pc\:mr-0 {
    margin-right: 0;
  }

  .pc\:mr-none {
    margin-right: 0;
  }

  .pc\:mr-0\.5 {
    margin-right: 0.125rem;
  }

  .pc\:mr-1 {
    margin-right: 0.25rem;
  }

  .pc\:mr-1\.5 {
    margin-right: 0.375rem;
  }

  .pc\:mr-2 {
    margin-right: 0.5rem;
  }

  .pc\:mr-2\.5 {
    margin-right: 0.625rem;
  }

  .pc\:mr-3 {
    margin-right: 0.75rem;
  }

  .pc\:mr-3\.5 {
    margin-right: 0.875rem;
  }

  .pc\:mr-4 {
    margin-right: 1rem;
  }

  .pc\:mr-5 {
    margin-right: 1.25rem;
  }

  .pc\:mr-6 {
    margin-right: 1.5rem;
  }

  .pc\:mr-7 {
    margin-right: 1.75rem;
  }

  .pc\:mr-8 {
    margin-right: 2rem;
  }

  .pc\:mr-9 {
    margin-right: 2.25rem;
  }

  .pc\:mr-10 {
    margin-right: 2.5rem;
  }

  .pc\:mr-11 {
    margin-right: 2.75rem;
  }

  .pc\:mr-12 {
    margin-right: 3rem;
  }

  .pc\:mr-14 {
    margin-right: 3.5rem;
  }

  .pc\:mr-16 {
    margin-right: 4rem;
  }

  .pc\:mr-18 {
    margin-right: 4.5rem;
  }

  .pc\:mr-20 {
    margin-right: 5rem;
  }

  .pc\:mr-24 {
    margin-right: 6rem;
  }

  .pc\:mr-28 {
    margin-right: 7rem;
  }

  .pc\:mr-32 {
    margin-right: 8rem;
  }

  .pc\:mr-36 {
    margin-right: 9rem;
  }

  .pc\:mr-40 {
    margin-right: 10rem;
  }

  .pc\:mr-44 {
    margin-right: 11rem;
  }

  .pc\:mr-48 {
    margin-right: 12rem;
  }

  .pc\:mr-52 {
    margin-right: 13rem;
  }

  .pc\:mr-56 {
    margin-right: 14rem;
  }

  .pc\:mr-60 {
    margin-right: 15rem;
  }

  .pc\:mr-64 {
    margin-right: 16rem;
  }

  .pc\:mr-72 {
    margin-right: 18rem;
  }

  .pc\:mr-80 {
    margin-right: 20rem;
  }

  .pc\:mr-96 {
    margin-right: 24rem;
  }

  .pc\:mr-auto {
    margin-right: auto;
  }

  .pc\:-mr-px {
    margin-right: -0.0625rem;
  }

  .pc\:-mr-0 {
    margin-right: 0;
  }

  .pc\:-mr-none {
    margin-right: 0;
  }

  .pc\:-mr-0\.5 {
    margin-right: -0.125rem;
  }

  .pc\:-mr-1 {
    margin-right: -0.25rem;
  }

  .pc\:-mr-1\.5 {
    margin-right: -0.375rem;
  }

  .pc\:-mr-2 {
    margin-right: -0.5rem;
  }

  .pc\:-mr-2\.5 {
    margin-right: -0.625rem;
  }

  .pc\:-mr-3 {
    margin-right: -0.75rem;
  }

  .pc\:-mr-3\.5 {
    margin-right: -0.875rem;
  }

  .pc\:-mr-4 {
    margin-right: -1rem;
  }

  .pc\:-mr-5 {
    margin-right: -1.25rem;
  }

  .pc\:-mr-6 {
    margin-right: -1.5rem;
  }

  .pc\:-mr-7 {
    margin-right: -1.75rem;
  }

  .pc\:-mr-8 {
    margin-right: -2rem;
  }

  .pc\:-mr-9 {
    margin-right: -2.25rem;
  }

  .pc\:-mr-10 {
    margin-right: -2.5rem;
  }

  .pc\:-mr-11 {
    margin-right: -2.75rem;
  }

  .pc\:-mr-12 {
    margin-right: -3rem;
  }

  .pc\:-mr-14 {
    margin-right: -3.5rem;
  }

  .pc\:-mr-16 {
    margin-right: -4rem;
  }

  .pc\:-mr-18 {
    margin-right: -4.5rem;
  }

  .pc\:-mr-20 {
    margin-right: -5rem;
  }

  .pc\:-mr-24 {
    margin-right: -6rem;
  }

  .pc\:-mr-28 {
    margin-right: -7rem;
  }

  .pc\:-mr-32 {
    margin-right: -8rem;
  }

  .pc\:-mr-36 {
    margin-right: -9rem;
  }

  .pc\:-mr-40 {
    margin-right: -10rem;
  }

  .pc\:-mr-44 {
    margin-right: -11rem;
  }

  .pc\:-mr-48 {
    margin-right: -12rem;
  }

  .pc\:-mr-52 {
    margin-right: -13rem;
  }

  .pc\:-mr-56 {
    margin-right: -14rem;
  }

  .pc\:-mr-60 {
    margin-right: -15rem;
  }

  .pc\:-mr-64 {
    margin-right: -16rem;
  }

  .pc\:-mr-72 {
    margin-right: -18rem;
  }

  .pc\:-mr-80 {
    margin-right: -20rem;
  }

  .pc\:-mr-96 {
    margin-right: -24rem;
  }

  .pc\:mb-px {
    margin-bottom: 0.0625rem;
  }

  .pc\:mb-0 {
    margin-bottom: 0;
  }

  .pc\:mb-none {
    margin-bottom: 0;
  }

  .pc\:mb-0\.5 {
    margin-bottom: 0.125rem;
  }

  .pc\:mb-1 {
    margin-bottom: 0.25rem;
  }

  .pc\:mb-1\.5 {
    margin-bottom: 0.375rem;
  }

  .pc\:mb-2 {
    margin-bottom: 0.5rem;
  }

  .pc\:mb-2\.5 {
    margin-bottom: 0.625rem;
  }

  .pc\:mb-3 {
    margin-bottom: 0.75rem;
  }

  .pc\:mb-3\.5 {
    margin-bottom: 0.875rem;
  }

  .pc\:mb-4 {
    margin-bottom: 1rem;
  }

  .pc\:mb-5 {
    margin-bottom: 1.25rem;
  }

  .pc\:mb-6 {
    margin-bottom: 1.5rem;
  }

  .pc\:mb-7 {
    margin-bottom: 1.75rem;
  }

  .pc\:mb-8 {
    margin-bottom: 2rem;
  }

  .pc\:mb-9 {
    margin-bottom: 2.25rem;
  }

  .pc\:mb-10 {
    margin-bottom: 2.5rem;
  }

  .pc\:mb-11 {
    margin-bottom: 2.75rem;
  }

  .pc\:mb-12 {
    margin-bottom: 3rem;
  }

  .pc\:mb-14 {
    margin-bottom: 3.5rem;
  }

  .pc\:mb-16 {
    margin-bottom: 4rem;
  }

  .pc\:mb-18 {
    margin-bottom: 4.5rem;
  }

  .pc\:mb-20 {
    margin-bottom: 5rem;
  }

  .pc\:mb-24 {
    margin-bottom: 6rem;
  }

  .pc\:mb-28 {
    margin-bottom: 7rem;
  }

  .pc\:mb-32 {
    margin-bottom: 8rem;
  }

  .pc\:mb-36 {
    margin-bottom: 9rem;
  }

  .pc\:mb-40 {
    margin-bottom: 10rem;
  }

  .pc\:mb-44 {
    margin-bottom: 11rem;
  }

  .pc\:mb-48 {
    margin-bottom: 12rem;
  }

  .pc\:mb-52 {
    margin-bottom: 13rem;
  }

  .pc\:mb-56 {
    margin-bottom: 14rem;
  }

  .pc\:mb-60 {
    margin-bottom: 15rem;
  }

  .pc\:mb-64 {
    margin-bottom: 16rem;
  }

  .pc\:mb-72 {
    margin-bottom: 18rem;
  }

  .pc\:mb-80 {
    margin-bottom: 20rem;
  }

  .pc\:mb-96 {
    margin-bottom: 24rem;
  }

  .pc\:mb-auto {
    margin-bottom: auto;
  }

  .pc\:-mb-px {
    margin-bottom: -0.0625rem;
  }

  .pc\:-mb-0 {
    margin-bottom: 0;
  }

  .pc\:-mb-none {
    margin-bottom: 0;
  }

  .pc\:-mb-0\.5 {
    margin-bottom: -0.125rem;
  }

  .pc\:-mb-1 {
    margin-bottom: -0.25rem;
  }

  .pc\:-mb-1\.5 {
    margin-bottom: -0.375rem;
  }

  .pc\:-mb-2 {
    margin-bottom: -0.5rem;
  }

  .pc\:-mb-2\.5 {
    margin-bottom: -0.625rem;
  }

  .pc\:-mb-3 {
    margin-bottom: -0.75rem;
  }

  .pc\:-mb-3\.5 {
    margin-bottom: -0.875rem;
  }

  .pc\:-mb-4 {
    margin-bottom: -1rem;
  }

  .pc\:-mb-5 {
    margin-bottom: -1.25rem;
  }

  .pc\:-mb-6 {
    margin-bottom: -1.5rem;
  }

  .pc\:-mb-7 {
    margin-bottom: -1.75rem;
  }

  .pc\:-mb-8 {
    margin-bottom: -2rem;
  }

  .pc\:-mb-9 {
    margin-bottom: -2.25rem;
  }

  .pc\:-mb-10 {
    margin-bottom: -2.5rem;
  }

  .pc\:-mb-11 {
    margin-bottom: -2.75rem;
  }

  .pc\:-mb-12 {
    margin-bottom: -3rem;
  }

  .pc\:-mb-14 {
    margin-bottom: -3.5rem;
  }

  .pc\:-mb-16 {
    margin-bottom: -4rem;
  }

  .pc\:-mb-18 {
    margin-bottom: -4.5rem;
  }

  .pc\:-mb-20 {
    margin-bottom: -5rem;
  }

  .pc\:-mb-24 {
    margin-bottom: -6rem;
  }

  .pc\:-mb-28 {
    margin-bottom: -7rem;
  }

  .pc\:-mb-32 {
    margin-bottom: -8rem;
  }

  .pc\:-mb-36 {
    margin-bottom: -9rem;
  }

  .pc\:-mb-40 {
    margin-bottom: -10rem;
  }

  .pc\:-mb-44 {
    margin-bottom: -11rem;
  }

  .pc\:-mb-48 {
    margin-bottom: -12rem;
  }

  .pc\:-mb-52 {
    margin-bottom: -13rem;
  }

  .pc\:-mb-56 {
    margin-bottom: -14rem;
  }

  .pc\:-mb-60 {
    margin-bottom: -15rem;
  }

  .pc\:-mb-64 {
    margin-bottom: -16rem;
  }

  .pc\:-mb-72 {
    margin-bottom: -18rem;
  }

  .pc\:-mb-80 {
    margin-bottom: -20rem;
  }

  .pc\:-mb-96 {
    margin-bottom: -24rem;
  }

  .pc\:ml-px {
    margin-left: 0.0625rem;
  }

  .pc\:ml-0 {
    margin-left: 0;
  }

  .pc\:ml-none {
    margin-left: 0;
  }

  .pc\:ml-0\.5 {
    margin-left: 0.125rem;
  }

  .pc\:ml-1 {
    margin-left: 0.25rem;
  }

  .pc\:ml-1\.5 {
    margin-left: 0.375rem;
  }

  .pc\:ml-2 {
    margin-left: 0.5rem;
  }

  .pc\:ml-2\.5 {
    margin-left: 0.625rem;
  }

  .pc\:ml-3 {
    margin-left: 0.75rem;
  }

  .pc\:ml-3\.5 {
    margin-left: 0.875rem;
  }

  .pc\:ml-4 {
    margin-left: 1rem;
  }

  .pc\:ml-5 {
    margin-left: 1.25rem;
  }

  .pc\:ml-6 {
    margin-left: 1.5rem;
  }

  .pc\:ml-7 {
    margin-left: 1.75rem;
  }

  .pc\:ml-8 {
    margin-left: 2rem;
  }

  .pc\:ml-9 {
    margin-left: 2.25rem;
  }

  .pc\:ml-10 {
    margin-left: 2.5rem;
  }

  .pc\:ml-11 {
    margin-left: 2.75rem;
  }

  .pc\:ml-12 {
    margin-left: 3rem;
  }

  .pc\:ml-14 {
    margin-left: 3.5rem;
  }

  .pc\:ml-16 {
    margin-left: 4rem;
  }

  .pc\:ml-18 {
    margin-left: 4.5rem;
  }

  .pc\:ml-20 {
    margin-left: 5rem;
  }

  .pc\:ml-24 {
    margin-left: 6rem;
  }

  .pc\:ml-28 {
    margin-left: 7rem;
  }

  .pc\:ml-32 {
    margin-left: 8rem;
  }

  .pc\:ml-36 {
    margin-left: 9rem;
  }

  .pc\:ml-40 {
    margin-left: 10rem;
  }

  .pc\:ml-44 {
    margin-left: 11rem;
  }

  .pc\:ml-48 {
    margin-left: 12rem;
  }

  .pc\:ml-52 {
    margin-left: 13rem;
  }

  .pc\:ml-56 {
    margin-left: 14rem;
  }

  .pc\:ml-60 {
    margin-left: 15rem;
  }

  .pc\:ml-64 {
    margin-left: 16rem;
  }

  .pc\:ml-72 {
    margin-left: 18rem;
  }

  .pc\:ml-80 {
    margin-left: 20rem;
  }

  .pc\:ml-96 {
    margin-left: 24rem;
  }

  .pc\:ml-auto {
    margin-left: auto;
  }

  .pc\:-ml-px {
    margin-left: -0.0625rem;
  }

  .pc\:-ml-0 {
    margin-left: 0;
  }

  .pc\:-ml-none {
    margin-left: 0;
  }

  .pc\:-ml-0\.5 {
    margin-left: -0.125rem;
  }

  .pc\:-ml-1 {
    margin-left: -0.25rem;
  }

  .pc\:-ml-1\.5 {
    margin-left: -0.375rem;
  }

  .pc\:-ml-2 {
    margin-left: -0.5rem;
  }

  .pc\:-ml-2\.5 {
    margin-left: -0.625rem;
  }

  .pc\:-ml-3 {
    margin-left: -0.75rem;
  }

  .pc\:-ml-3\.5 {
    margin-left: -0.875rem;
  }

  .pc\:-ml-4 {
    margin-left: -1rem;
  }

  .pc\:-ml-5 {
    margin-left: -1.25rem;
  }

  .pc\:-ml-6 {
    margin-left: -1.5rem;
  }

  .pc\:-ml-7 {
    margin-left: -1.75rem;
  }

  .pc\:-ml-8 {
    margin-left: -2rem;
  }

  .pc\:-ml-9 {
    margin-left: -2.25rem;
  }

  .pc\:-ml-10 {
    margin-left: -2.5rem;
  }

  .pc\:-ml-11 {
    margin-left: -2.75rem;
  }

  .pc\:-ml-12 {
    margin-left: -3rem;
  }

  .pc\:-ml-14 {
    margin-left: -3.5rem;
  }

  .pc\:-ml-16 {
    margin-left: -4rem;
  }

  .pc\:-ml-18 {
    margin-left: -4.5rem;
  }

  .pc\:-ml-20 {
    margin-left: -5rem;
  }

  .pc\:-ml-24 {
    margin-left: -6rem;
  }

  .pc\:-ml-28 {
    margin-left: -7rem;
  }

  .pc\:-ml-32 {
    margin-left: -8rem;
  }

  .pc\:-ml-36 {
    margin-left: -9rem;
  }

  .pc\:-ml-40 {
    margin-left: -10rem;
  }

  .pc\:-ml-44 {
    margin-left: -11rem;
  }

  .pc\:-ml-48 {
    margin-left: -12rem;
  }

  .pc\:-ml-52 {
    margin-left: -13rem;
  }

  .pc\:-ml-56 {
    margin-left: -14rem;
  }

  .pc\:-ml-60 {
    margin-left: -15rem;
  }

  .pc\:-ml-64 {
    margin-left: -16rem;
  }

  .pc\:-ml-72 {
    margin-left: -18rem;
  }

  .pc\:-ml-80 {
    margin-left: -20rem;
  }

  .pc\:-ml-96 {
    margin-left: -24rem;
  }
}
/*!markdown

---
title: Padding
---

| Class       | Properties               |
| ----------- | ------------------------ |
| p-px | padding: 0.0625rem |
| p-0 | padding: 0 |
| p-none | padding: 0 |
| p-0\.5 | padding: 0.125rem |
| p-1 | padding: 0.25rem |
| p-1\.5 | padding: 0.375rem |
| p-2 | padding: 0.5rem |
| p-2\.5 | padding: 0.625rem |
| p-3 | padding: 0.75rem |
| p-3\.5 | padding: 0.875rem |
| p-4 | padding: 1rem |
| p-5 | padding: 1.25rem |
| p-6 | padding: 1.5rem |
| p-7 | padding: 1.75rem |
| p-8 | padding: 2rem |
| p-9 | padding: 2.25rem |
| p-10 | padding: 2.5rem |
| p-11 | padding: 2.75rem |
| p-12 | padding: 3rem |
| p-14 | padding: 3.5rem |
| p-16 | padding: 4rem |
| p-18 | padding: 4.5rem |
| p-20 | padding: 5rem |
| p-24 | padding: 6rem |
| p-28 | padding: 7rem |
| p-32 | padding: 8rem |
| p-36 | padding: 9rem |
| p-40 | padding: 10rem |
| p-44 | padding: 11rem |
| p-48 | padding: 12rem |
| p-52 | padding: 13rem |
| p-56 | padding: 14rem |
| p-60 | padding: 15rem |
| p-64 | padding: 16rem |
| p-72 | padding: 18rem |
| p-80 | padding: 20rem |
| p-96 | padding: 24rem |
| px-px | padding-left: 0.0625rem; padding-right: 0.0625rem |
| px-0 | padding-left: 0; padding-right: 0 |
| px-none | padding-left: 0; padding-right: 0 |
| px-0\.5 | padding-left: 0.125rem; padding-right: 0.125rem |
| px-1 | padding-left: 0.25rem; padding-right: 0.25rem |
| px-1\.5 | padding-left: 0.375rem; padding-right: 0.375rem |
| px-2 | padding-left: 0.5rem; padding-right: 0.5rem |
| px-2\.5 | padding-left: 0.625rem; padding-right: 0.625rem |
| px-3 | padding-left: 0.75rem; padding-right: 0.75rem |
| px-3\.5 | padding-left: 0.875rem; padding-right: 0.875rem |
| px-4 | padding-left: 1rem; padding-right: 1rem |
| px-5 | padding-left: 1.25rem; padding-right: 1.25rem |
| px-6 | padding-left: 1.5rem; padding-right: 1.5rem |
| px-7 | padding-left: 1.75rem; padding-right: 1.75rem |
| px-8 | padding-left: 2rem; padding-right: 2rem |
| px-9 | padding-left: 2.25rem; padding-right: 2.25rem |
| px-10 | padding-left: 2.5rem; padding-right: 2.5rem |
| px-11 | padding-left: 2.75rem; padding-right: 2.75rem |
| px-12 | padding-left: 3rem; padding-right: 3rem |
| px-14 | padding-left: 3.5rem; padding-right: 3.5rem |
| px-16 | padding-left: 4rem; padding-right: 4rem |
| px-18 | padding-left: 4.5rem; padding-right: 4.5rem |
| px-20 | padding-left: 5rem; padding-right: 5rem |
| px-24 | padding-left: 6rem; padding-right: 6rem |
| px-28 | padding-left: 7rem; padding-right: 7rem |
| px-32 | padding-left: 8rem; padding-right: 8rem |
| px-36 | padding-left: 9rem; padding-right: 9rem |
| px-40 | padding-left: 10rem; padding-right: 10rem |
| px-44 | padding-left: 11rem; padding-right: 11rem |
| px-48 | padding-left: 12rem; padding-right: 12rem |
| px-52 | padding-left: 13rem; padding-right: 13rem |
| px-56 | padding-left: 14rem; padding-right: 14rem |
| px-60 | padding-left: 15rem; padding-right: 15rem |
| px-64 | padding-left: 16rem; padding-right: 16rem |
| px-72 | padding-left: 18rem; padding-right: 18rem |
| px-80 | padding-left: 20rem; padding-right: 20rem |
| px-96 | padding-left: 24rem; padding-right: 24rem |
| py-px | padding-top: 0.0625rem; padding-bottom: 0.0625rem |
| py-0 | padding-top: 0; padding-bottom: 0 |
| py-none | padding-top: 0; padding-bottom: 0 |
| py-0\.5 | padding-top: 0.125rem; padding-bottom: 0.125rem |
| py-1 | padding-top: 0.25rem; padding-bottom: 0.25rem |
| py-1\.5 | padding-top: 0.375rem; padding-bottom: 0.375rem |
| py-2 | padding-top: 0.5rem; padding-bottom: 0.5rem |
| py-2\.5 | padding-top: 0.625rem; padding-bottom: 0.625rem |
| py-3 | padding-top: 0.75rem; padding-bottom: 0.75rem |
| py-3\.5 | padding-top: 0.875rem; padding-bottom: 0.875rem |
| py-4 | padding-top: 1rem; padding-bottom: 1rem |
| py-5 | padding-top: 1.25rem; padding-bottom: 1.25rem |
| py-6 | padding-top: 1.5rem; padding-bottom: 1.5rem |
| py-7 | padding-top: 1.75rem; padding-bottom: 1.75rem |
| py-8 | padding-top: 2rem; padding-bottom: 2rem |
| py-9 | padding-top: 2.25rem; padding-bottom: 2.25rem |
| py-10 | padding-top: 2.5rem; padding-bottom: 2.5rem |
| py-11 | padding-top: 2.75rem; padding-bottom: 2.75rem |
| py-12 | padding-top: 3rem; padding-bottom: 3rem |
| py-14 | padding-top: 3.5rem; padding-bottom: 3.5rem |
| py-16 | padding-top: 4rem; padding-bottom: 4rem |
| py-18 | padding-top: 4.5rem; padding-bottom: 4.5rem |
| py-20 | padding-top: 5rem; padding-bottom: 5rem |
| py-24 | padding-top: 6rem; padding-bottom: 6rem |
| py-28 | padding-top: 7rem; padding-bottom: 7rem |
| py-32 | padding-top: 8rem; padding-bottom: 8rem |
| py-36 | padding-top: 9rem; padding-bottom: 9rem |
| py-40 | padding-top: 10rem; padding-bottom: 10rem |
| py-44 | padding-top: 11rem; padding-bottom: 11rem |
| py-48 | padding-top: 12rem; padding-bottom: 12rem |
| py-52 | padding-top: 13rem; padding-bottom: 13rem |
| py-56 | padding-top: 14rem; padding-bottom: 14rem |
| py-60 | padding-top: 15rem; padding-bottom: 15rem |
| py-64 | padding-top: 16rem; padding-bottom: 16rem |
| py-72 | padding-top: 18rem; padding-bottom: 18rem |
| py-80 | padding-top: 20rem; padding-bottom: 20rem |
| py-96 | padding-top: 24rem; padding-bottom: 24rem |
| pt-px | padding-top: 0.0625rem |
| pt-0 | padding-top: 0 |
| pt-none | padding-top: 0 |
| pt-0\.5 | padding-top: 0.125rem |
| pt-1 | padding-top: 0.25rem |
| pt-1\.5 | padding-top: 0.375rem |
| pt-2 | padding-top: 0.5rem |
| pt-2\.5 | padding-top: 0.625rem |
| pt-3 | padding-top: 0.75rem |
| pt-3\.5 | padding-top: 0.875rem |
| pt-4 | padding-top: 1rem |
| pt-5 | padding-top: 1.25rem |
| pt-6 | padding-top: 1.5rem |
| pt-7 | padding-top: 1.75rem |
| pt-8 | padding-top: 2rem |
| pt-9 | padding-top: 2.25rem |
| pt-10 | padding-top: 2.5rem |
| pt-11 | padding-top: 2.75rem |
| pt-12 | padding-top: 3rem |
| pt-14 | padding-top: 3.5rem |
| pt-16 | padding-top: 4rem |
| pt-18 | padding-top: 4.5rem |
| pt-20 | padding-top: 5rem |
| pt-24 | padding-top: 6rem |
| pt-28 | padding-top: 7rem |
| pt-32 | padding-top: 8rem |
| pt-36 | padding-top: 9rem |
| pt-40 | padding-top: 10rem |
| pt-44 | padding-top: 11rem |
| pt-48 | padding-top: 12rem |
| pt-52 | padding-top: 13rem |
| pt-56 | padding-top: 14rem |
| pt-60 | padding-top: 15rem |
| pt-64 | padding-top: 16rem |
| pt-72 | padding-top: 18rem |
| pt-80 | padding-top: 20rem |
| pt-96 | padding-top: 24rem |
| pr-px | padding-right: 0.0625rem |
| pr-0 | padding-right: 0 |
| pr-none | padding-right: 0 |
| pr-0\.5 | padding-right: 0.125rem |
| pr-1 | padding-right: 0.25rem |
| pr-1\.5 | padding-right: 0.375rem |
| pr-2 | padding-right: 0.5rem |
| pr-2\.5 | padding-right: 0.625rem |
| pr-3 | padding-right: 0.75rem |
| pr-3\.5 | padding-right: 0.875rem |
| pr-4 | padding-right: 1rem |
| pr-5 | padding-right: 1.25rem |
| pr-6 | padding-right: 1.5rem |
| pr-7 | padding-right: 1.75rem |
| pr-8 | padding-right: 2rem |
| pr-9 | padding-right: 2.25rem |
| pr-10 | padding-right: 2.5rem |
| pr-11 | padding-right: 2.75rem |
| pr-12 | padding-right: 3rem |
| pr-14 | padding-right: 3.5rem |
| pr-16 | padding-right: 4rem |
| pr-18 | padding-right: 4.5rem |
| pr-20 | padding-right: 5rem |
| pr-24 | padding-right: 6rem |
| pr-28 | padding-right: 7rem |
| pr-32 | padding-right: 8rem |
| pr-36 | padding-right: 9rem |
| pr-40 | padding-right: 10rem |
| pr-44 | padding-right: 11rem |
| pr-48 | padding-right: 12rem |
| pr-52 | padding-right: 13rem |
| pr-56 | padding-right: 14rem |
| pr-60 | padding-right: 15rem |
| pr-64 | padding-right: 16rem |
| pr-72 | padding-right: 18rem |
| pr-80 | padding-right: 20rem |
| pr-96 | padding-right: 24rem |
| pb-px | padding-bottom: 0.0625rem |
| pb-0 | padding-bottom: 0 |
| pb-none | padding-bottom: 0 |
| pb-0\.5 | padding-bottom: 0.125rem |
| pb-1 | padding-bottom: 0.25rem |
| pb-1\.5 | padding-bottom: 0.375rem |
| pb-2 | padding-bottom: 0.5rem |
| pb-2\.5 | padding-bottom: 0.625rem |
| pb-3 | padding-bottom: 0.75rem |
| pb-3\.5 | padding-bottom: 0.875rem |
| pb-4 | padding-bottom: 1rem |
| pb-5 | padding-bottom: 1.25rem |
| pb-6 | padding-bottom: 1.5rem |
| pb-7 | padding-bottom: 1.75rem |
| pb-8 | padding-bottom: 2rem |
| pb-9 | padding-bottom: 2.25rem |
| pb-10 | padding-bottom: 2.5rem |
| pb-11 | padding-bottom: 2.75rem |
| pb-12 | padding-bottom: 3rem |
| pb-14 | padding-bottom: 3.5rem |
| pb-16 | padding-bottom: 4rem |
| pb-18 | padding-bottom: 4.5rem |
| pb-20 | padding-bottom: 5rem |
| pb-24 | padding-bottom: 6rem |
| pb-28 | padding-bottom: 7rem |
| pb-32 | padding-bottom: 8rem |
| pb-36 | padding-bottom: 9rem |
| pb-40 | padding-bottom: 10rem |
| pb-44 | padding-bottom: 11rem |
| pb-48 | padding-bottom: 12rem |
| pb-52 | padding-bottom: 13rem |
| pb-56 | padding-bottom: 14rem |
| pb-60 | padding-bottom: 15rem |
| pb-64 | padding-bottom: 16rem |
| pb-72 | padding-bottom: 18rem |
| pb-80 | padding-bottom: 20rem |
| pb-96 | padding-bottom: 24rem |
| pl-px | padding-left: 0.0625rem |
| pl-0 | padding-left: 0 |
| pl-none | padding-left: 0 |
| pl-0\.5 | padding-left: 0.125rem |
| pl-1 | padding-left: 0.25rem |
| pl-1\.5 | padding-left: 0.375rem |
| pl-2 | padding-left: 0.5rem |
| pl-2\.5 | padding-left: 0.625rem |
| pl-3 | padding-left: 0.75rem |
| pl-3\.5 | padding-left: 0.875rem |
| pl-4 | padding-left: 1rem |
| pl-5 | padding-left: 1.25rem |
| pl-6 | padding-left: 1.5rem |
| pl-7 | padding-left: 1.75rem |
| pl-8 | padding-left: 2rem |
| pl-9 | padding-left: 2.25rem |
| pl-10 | padding-left: 2.5rem |
| pl-11 | padding-left: 2.75rem |
| pl-12 | padding-left: 3rem |
| pl-14 | padding-left: 3.5rem |
| pl-16 | padding-left: 4rem |
| pl-18 | padding-left: 4.5rem |
| pl-20 | padding-left: 5rem |
| pl-24 | padding-left: 6rem |
| pl-28 | padding-left: 7rem |
| pl-32 | padding-left: 8rem |
| pl-36 | padding-left: 9rem |
| pl-40 | padding-left: 10rem |
| pl-44 | padding-left: 11rem |
| pl-48 | padding-left: 12rem |
| pl-52 | padding-left: 13rem |
| pl-56 | padding-left: 14rem |
| pl-60 | padding-left: 15rem |
| pl-64 | padding-left: 16rem |
| pl-72 | padding-left: 18rem |
| pl-80 | padding-left: 20rem |
| pl-96 | padding-left: 24rem |



*/
.p-px {
  padding: 0.0625rem;
}

.p-0 {
  padding: 0;
}

.p-none {
  padding: 0;
}

.p-0\.5 {
  padding: 0.125rem;
}

.p-1 {
  padding: 0.25rem;
}

.p-1\.5 {
  padding: 0.375rem;
}

.p-2 {
  padding: 0.5rem;
}

.p-2\.5 {
  padding: 0.625rem;
}

.p-3 {
  padding: 0.75rem;
}

.p-3\.5 {
  padding: 0.875rem;
}

.p-4 {
  padding: 1rem;
}

.p-5 {
  padding: 1.25rem;
}

.p-6 {
  padding: 1.5rem;
}

.p-7 {
  padding: 1.75rem;
}

.p-8 {
  padding: 2rem;
}

.p-9 {
  padding: 2.25rem;
}

.p-10 {
  padding: 2.5rem;
}

.p-11 {
  padding: 2.75rem;
}

.p-12 {
  padding: 3rem;
}

.p-14 {
  padding: 3.5rem;
}

.p-16 {
  padding: 4rem;
}

.p-18 {
  padding: 4.5rem;
}

.p-20 {
  padding: 5rem;
}

.p-24 {
  padding: 6rem;
}

.p-28 {
  padding: 7rem;
}

.p-32 {
  padding: 8rem;
}

.p-36 {
  padding: 9rem;
}

.p-40 {
  padding: 10rem;
}

.p-44 {
  padding: 11rem;
}

.p-48 {
  padding: 12rem;
}

.p-52 {
  padding: 13rem;
}

.p-56 {
  padding: 14rem;
}

.p-60 {
  padding: 15rem;
}

.p-64 {
  padding: 16rem;
}

.p-72 {
  padding: 18rem;
}

.p-80 {
  padding: 20rem;
}

.p-96 {
  padding: 24rem;
}

.px-px {
  padding-left: 0.0625rem;
  padding-right: 0.0625rem;
}

.px-0 {
  padding-left: 0;
  padding-right: 0;
}

.px-none {
  padding-left: 0;
  padding-right: 0;
}

.px-0\.5 {
  padding-left: 0.125rem;
  padding-right: 0.125rem;
}

.px-1 {
  padding-left: 0.25rem;
  padding-right: 0.25rem;
}

.px-1\.5 {
  padding-left: 0.375rem;
  padding-right: 0.375rem;
}

.px-2 {
  padding-left: 0.5rem;
  padding-right: 0.5rem;
}

.px-2\.5 {
  padding-left: 0.625rem;
  padding-right: 0.625rem;
}

.px-3 {
  padding-left: 0.75rem;
  padding-right: 0.75rem;
}

.px-3\.5 {
  padding-left: 0.875rem;
  padding-right: 0.875rem;
}

.px-4 {
  padding-left: 1rem;
  padding-right: 1rem;
}

.px-5 {
  padding-left: 1.25rem;
  padding-right: 1.25rem;
}

.px-6 {
  padding-left: 1.5rem;
  padding-right: 1.5rem;
}

.px-7 {
  padding-left: 1.75rem;
  padding-right: 1.75rem;
}

.px-8 {
  padding-left: 2rem;
  padding-right: 2rem;
}

.px-9 {
  padding-left: 2.25rem;
  padding-right: 2.25rem;
}

.px-10 {
  padding-left: 2.5rem;
  padding-right: 2.5rem;
}

.px-11 {
  padding-left: 2.75rem;
  padding-right: 2.75rem;
}

.px-12 {
  padding-left: 3rem;
  padding-right: 3rem;
}

.px-14 {
  padding-left: 3.5rem;
  padding-right: 3.5rem;
}

.px-16 {
  padding-left: 4rem;
  padding-right: 4rem;
}

.px-18 {
  padding-left: 4.5rem;
  padding-right: 4.5rem;
}

.px-20 {
  padding-left: 5rem;
  padding-right: 5rem;
}

.px-24 {
  padding-left: 6rem;
  padding-right: 6rem;
}

.px-28 {
  padding-left: 7rem;
  padding-right: 7rem;
}

.px-32 {
  padding-left: 8rem;
  padding-right: 8rem;
}

.px-36 {
  padding-left: 9rem;
  padding-right: 9rem;
}

.px-40 {
  padding-left: 10rem;
  padding-right: 10rem;
}

.px-44 {
  padding-left: 11rem;
  padding-right: 11rem;
}

.px-48 {
  padding-left: 12rem;
  padding-right: 12rem;
}

.px-52 {
  padding-left: 13rem;
  padding-right: 13rem;
}

.px-56 {
  padding-left: 14rem;
  padding-right: 14rem;
}

.px-60 {
  padding-left: 15rem;
  padding-right: 15rem;
}

.px-64 {
  padding-left: 16rem;
  padding-right: 16rem;
}

.px-72 {
  padding-left: 18rem;
  padding-right: 18rem;
}

.px-80 {
  padding-left: 20rem;
  padding-right: 20rem;
}

.px-96 {
  padding-left: 24rem;
  padding-right: 24rem;
}

.py-px {
  padding-top: 0.0625rem;
  padding-bottom: 0.0625rem;
}

.py-0 {
  padding-top: 0;
  padding-bottom: 0;
}

.py-none {
  padding-top: 0;
  padding-bottom: 0;
}

.py-0\.5 {
  padding-top: 0.125rem;
  padding-bottom: 0.125rem;
}

.py-1 {
  padding-top: 0.25rem;
  padding-bottom: 0.25rem;
}

.py-1\.5 {
  padding-top: 0.375rem;
  padding-bottom: 0.375rem;
}

.py-2 {
  padding-top: 0.5rem;
  padding-bottom: 0.5rem;
}

.py-2\.5 {
  padding-top: 0.625rem;
  padding-bottom: 0.625rem;
}

.py-3 {
  padding-top: 0.75rem;
  padding-bottom: 0.75rem;
}

.py-3\.5 {
  padding-top: 0.875rem;
  padding-bottom: 0.875rem;
}

.py-4 {
  padding-top: 1rem;
  padding-bottom: 1rem;
}

.py-5 {
  padding-top: 1.25rem;
  padding-bottom: 1.25rem;
}

.py-6 {
  padding-top: 1.5rem;
  padding-bottom: 1.5rem;
}

.py-7 {
  padding-top: 1.75rem;
  padding-bottom: 1.75rem;
}

.py-8 {
  padding-top: 2rem;
  padding-bottom: 2rem;
}

.py-9 {
  padding-top: 2.25rem;
  padding-bottom: 2.25rem;
}

.py-10 {
  padding-top: 2.5rem;
  padding-bottom: 2.5rem;
}

.py-11 {
  padding-top: 2.75rem;
  padding-bottom: 2.75rem;
}

.py-12 {
  padding-top: 3rem;
  padding-bottom: 3rem;
}

.py-14 {
  padding-top: 3.5rem;
  padding-bottom: 3.5rem;
}

.py-16 {
  padding-top: 4rem;
  padding-bottom: 4rem;
}

.py-18 {
  padding-top: 4.5rem;
  padding-bottom: 4.5rem;
}

.py-20 {
  padding-top: 5rem;
  padding-bottom: 5rem;
}

.py-24 {
  padding-top: 6rem;
  padding-bottom: 6rem;
}

.py-28 {
  padding-top: 7rem;
  padding-bottom: 7rem;
}

.py-32 {
  padding-top: 8rem;
  padding-bottom: 8rem;
}

.py-36 {
  padding-top: 9rem;
  padding-bottom: 9rem;
}

.py-40 {
  padding-top: 10rem;
  padding-bottom: 10rem;
}

.py-44 {
  padding-top: 11rem;
  padding-bottom: 11rem;
}

.py-48 {
  padding-top: 12rem;
  padding-bottom: 12rem;
}

.py-52 {
  padding-top: 13rem;
  padding-bottom: 13rem;
}

.py-56 {
  padding-top: 14rem;
  padding-bottom: 14rem;
}

.py-60 {
  padding-top: 15rem;
  padding-bottom: 15rem;
}

.py-64 {
  padding-top: 16rem;
  padding-bottom: 16rem;
}

.py-72 {
  padding-top: 18rem;
  padding-bottom: 18rem;
}

.py-80 {
  padding-top: 20rem;
  padding-bottom: 20rem;
}

.py-96 {
  padding-top: 24rem;
  padding-bottom: 24rem;
}

.pt-px {
  padding-top: 0.0625rem;
}

.pt-0 {
  padding-top: 0;
}

.pt-none {
  padding-top: 0;
}

.pt-0\.5 {
  padding-top: 0.125rem;
}

.pt-1 {
  padding-top: 0.25rem;
}

.pt-1\.5 {
  padding-top: 0.375rem;
}

.pt-2 {
  padding-top: 0.5rem;
}

.pt-2\.5 {
  padding-top: 0.625rem;
}

.pt-3 {
  padding-top: 0.75rem;
}

.pt-3\.5 {
  padding-top: 0.875rem;
}

.pt-4 {
  padding-top: 1rem;
}

.pt-5 {
  padding-top: 1.25rem;
}

.pt-6 {
  padding-top: 1.5rem;
}

.pt-7 {
  padding-top: 1.75rem;
}

.pt-8 {
  padding-top: 2rem;
}

.pt-9 {
  padding-top: 2.25rem;
}

.pt-10 {
  padding-top: 2.5rem;
}

.pt-11 {
  padding-top: 2.75rem;
}

.pt-12 {
  padding-top: 3rem;
}

.pt-14 {
  padding-top: 3.5rem;
}

.pt-16 {
  padding-top: 4rem;
}

.pt-18 {
  padding-top: 4.5rem;
}

.pt-20 {
  padding-top: 5rem;
}

.pt-24 {
  padding-top: 6rem;
}

.pt-28 {
  padding-top: 7rem;
}

.pt-32 {
  padding-top: 8rem;
}

.pt-36 {
  padding-top: 9rem;
}

.pt-40 {
  padding-top: 10rem;
}

.pt-44 {
  padding-top: 11rem;
}

.pt-48 {
  padding-top: 12rem;
}

.pt-52 {
  padding-top: 13rem;
}

.pt-56 {
  padding-top: 14rem;
}

.pt-60 {
  padding-top: 15rem;
}

.pt-64 {
  padding-top: 16rem;
}

.pt-72 {
  padding-top: 18rem;
}

.pt-80 {
  padding-top: 20rem;
}

.pt-96 {
  padding-top: 24rem;
}

.pr-px {
  padding-right: 0.0625rem;
}

.pr-0 {
  padding-right: 0;
}

.pr-none {
  padding-right: 0;
}

.pr-0\.5 {
  padding-right: 0.125rem;
}

.pr-1 {
  padding-right: 0.25rem;
}

.pr-1\.5 {
  padding-right: 0.375rem;
}

.pr-2 {
  padding-right: 0.5rem;
}

.pr-2\.5 {
  padding-right: 0.625rem;
}

.pr-3 {
  padding-right: 0.75rem;
}

.pr-3\.5 {
  padding-right: 0.875rem;
}

.pr-4 {
  padding-right: 1rem;
}

.pr-5 {
  padding-right: 1.25rem;
}

.pr-6 {
  padding-right: 1.5rem;
}

.pr-7 {
  padding-right: 1.75rem;
}

.pr-8 {
  padding-right: 2rem;
}

.pr-9 {
  padding-right: 2.25rem;
}

.pr-10 {
  padding-right: 2.5rem;
}

.pr-11 {
  padding-right: 2.75rem;
}

.pr-12 {
  padding-right: 3rem;
}

.pr-14 {
  padding-right: 3.5rem;
}

.pr-16 {
  padding-right: 4rem;
}

.pr-18 {
  padding-right: 4.5rem;
}

.pr-20 {
  padding-right: 5rem;
}

.pr-24 {
  padding-right: 6rem;
}

.pr-28 {
  padding-right: 7rem;
}

.pr-32 {
  padding-right: 8rem;
}

.pr-36 {
  padding-right: 9rem;
}

.pr-40 {
  padding-right: 10rem;
}

.pr-44 {
  padding-right: 11rem;
}

.pr-48 {
  padding-right: 12rem;
}

.pr-52 {
  padding-right: 13rem;
}

.pr-56 {
  padding-right: 14rem;
}

.pr-60 {
  padding-right: 15rem;
}

.pr-64 {
  padding-right: 16rem;
}

.pr-72 {
  padding-right: 18rem;
}

.pr-80 {
  padding-right: 20rem;
}

.pr-96 {
  padding-right: 24rem;
}

.pb-px {
  padding-bottom: 0.0625rem;
}

.pb-0 {
  padding-bottom: 0;
}

.pb-none {
  padding-bottom: 0;
}

.pb-0\.5 {
  padding-bottom: 0.125rem;
}

.pb-1 {
  padding-bottom: 0.25rem;
}

.pb-1\.5 {
  padding-bottom: 0.375rem;
}

.pb-2 {
  padding-bottom: 0.5rem;
}

.pb-2\.5 {
  padding-bottom: 0.625rem;
}

.pb-3 {
  padding-bottom: 0.75rem;
}

.pb-3\.5 {
  padding-bottom: 0.875rem;
}

.pb-4 {
  padding-bottom: 1rem;
}

.pb-5 {
  padding-bottom: 1.25rem;
}

.pb-6 {
  padding-bottom: 1.5rem;
}

.pb-7 {
  padding-bottom: 1.75rem;
}

.pb-8 {
  padding-bottom: 2rem;
}

.pb-9 {
  padding-bottom: 2.25rem;
}

.pb-10 {
  padding-bottom: 2.5rem;
}

.pb-11 {
  padding-bottom: 2.75rem;
}

.pb-12 {
  padding-bottom: 3rem;
}

.pb-14 {
  padding-bottom: 3.5rem;
}

.pb-16 {
  padding-bottom: 4rem;
}

.pb-18 {
  padding-bottom: 4.5rem;
}

.pb-20 {
  padding-bottom: 5rem;
}

.pb-24 {
  padding-bottom: 6rem;
}

.pb-28 {
  padding-bottom: 7rem;
}

.pb-32 {
  padding-bottom: 8rem;
}

.pb-36 {
  padding-bottom: 9rem;
}

.pb-40 {
  padding-bottom: 10rem;
}

.pb-44 {
  padding-bottom: 11rem;
}

.pb-48 {
  padding-bottom: 12rem;
}

.pb-52 {
  padding-bottom: 13rem;
}

.pb-56 {
  padding-bottom: 14rem;
}

.pb-60 {
  padding-bottom: 15rem;
}

.pb-64 {
  padding-bottom: 16rem;
}

.pb-72 {
  padding-bottom: 18rem;
}

.pb-80 {
  padding-bottom: 20rem;
}

.pb-96 {
  padding-bottom: 24rem;
}

.pl-px {
  padding-left: 0.0625rem;
}

.pl-0 {
  padding-left: 0;
}

.pl-none {
  padding-left: 0;
}

.pl-0\.5 {
  padding-left: 0.125rem;
}

.pl-1 {
  padding-left: 0.25rem;
}

.pl-1\.5 {
  padding-left: 0.375rem;
}

.pl-2 {
  padding-left: 0.5rem;
}

.pl-2\.5 {
  padding-left: 0.625rem;
}

.pl-3 {
  padding-left: 0.75rem;
}

.pl-3\.5 {
  padding-left: 0.875rem;
}

.pl-4 {
  padding-left: 1rem;
}

.pl-5 {
  padding-left: 1.25rem;
}

.pl-6 {
  padding-left: 1.5rem;
}

.pl-7 {
  padding-left: 1.75rem;
}

.pl-8 {
  padding-left: 2rem;
}

.pl-9 {
  padding-left: 2.25rem;
}

.pl-10 {
  padding-left: 2.5rem;
}

.pl-11 {
  padding-left: 2.75rem;
}

.pl-12 {
  padding-left: 3rem;
}

.pl-14 {
  padding-left: 3.5rem;
}

.pl-16 {
  padding-left: 4rem;
}

.pl-18 {
  padding-left: 4.5rem;
}

.pl-20 {
  padding-left: 5rem;
}

.pl-24 {
  padding-left: 6rem;
}

.pl-28 {
  padding-left: 7rem;
}

.pl-32 {
  padding-left: 8rem;
}

.pl-36 {
  padding-left: 9rem;
}

.pl-40 {
  padding-left: 10rem;
}

.pl-44 {
  padding-left: 11rem;
}

.pl-48 {
  padding-left: 12rem;
}

.pl-52 {
  padding-left: 13rem;
}

.pl-56 {
  padding-left: 14rem;
}

.pl-60 {
  padding-left: 15rem;
}

.pl-64 {
  padding-left: 16rem;
}

.pl-72 {
  padding-left: 18rem;
}

.pl-80 {
  padding-left: 20rem;
}

.pl-96 {
  padding-left: 24rem;
}

@media (max-width: 768px) {
  .m\:p-px {
    padding: 0.0625rem;
  }

  .m\:p-0 {
    padding: 0;
  }

  .m\:p-none {
    padding: 0;
  }

  .m\:p-0\.5 {
    padding: 0.125rem;
  }

  .m\:p-1 {
    padding: 0.25rem;
  }

  .m\:p-1\.5 {
    padding: 0.375rem;
  }

  .m\:p-2 {
    padding: 0.5rem;
  }

  .m\:p-2\.5 {
    padding: 0.625rem;
  }

  .m\:p-3 {
    padding: 0.75rem;
  }

  .m\:p-3\.5 {
    padding: 0.875rem;
  }

  .m\:p-4 {
    padding: 1rem;
  }

  .m\:p-5 {
    padding: 1.25rem;
  }

  .m\:p-6 {
    padding: 1.5rem;
  }

  .m\:p-7 {
    padding: 1.75rem;
  }

  .m\:p-8 {
    padding: 2rem;
  }

  .m\:p-9 {
    padding: 2.25rem;
  }

  .m\:p-10 {
    padding: 2.5rem;
  }

  .m\:p-11 {
    padding: 2.75rem;
  }

  .m\:p-12 {
    padding: 3rem;
  }

  .m\:p-14 {
    padding: 3.5rem;
  }

  .m\:p-16 {
    padding: 4rem;
  }

  .m\:p-18 {
    padding: 4.5rem;
  }

  .m\:p-20 {
    padding: 5rem;
  }

  .m\:p-24 {
    padding: 6rem;
  }

  .m\:p-28 {
    padding: 7rem;
  }

  .m\:p-32 {
    padding: 8rem;
  }

  .m\:p-36 {
    padding: 9rem;
  }

  .m\:p-40 {
    padding: 10rem;
  }

  .m\:p-44 {
    padding: 11rem;
  }

  .m\:p-48 {
    padding: 12rem;
  }

  .m\:p-52 {
    padding: 13rem;
  }

  .m\:p-56 {
    padding: 14rem;
  }

  .m\:p-60 {
    padding: 15rem;
  }

  .m\:p-64 {
    padding: 16rem;
  }

  .m\:p-72 {
    padding: 18rem;
  }

  .m\:p-80 {
    padding: 20rem;
  }

  .m\:p-96 {
    padding: 24rem;
  }

  .m\:px-px {
    padding-left: 0.0625rem;
    padding-right: 0.0625rem;
  }

  .m\:px-0 {
    padding-left: 0;
    padding-right: 0;
  }

  .m\:px-none {
    padding-left: 0;
    padding-right: 0;
  }

  .m\:px-0\.5 {
    padding-left: 0.125rem;
    padding-right: 0.125rem;
  }

  .m\:px-1 {
    padding-left: 0.25rem;
    padding-right: 0.25rem;
  }

  .m\:px-1\.5 {
    padding-left: 0.375rem;
    padding-right: 0.375rem;
  }

  .m\:px-2 {
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .m\:px-2\.5 {
    padding-left: 0.625rem;
    padding-right: 0.625rem;
  }

  .m\:px-3 {
    padding-left: 0.75rem;
    padding-right: 0.75rem;
  }

  .m\:px-3\.5 {
    padding-left: 0.875rem;
    padding-right: 0.875rem;
  }

  .m\:px-4 {
    padding-left: 1rem;
    padding-right: 1rem;
  }

  .m\:px-5 {
    padding-left: 1.25rem;
    padding-right: 1.25rem;
  }

  .m\:px-6 {
    padding-left: 1.5rem;
    padding-right: 1.5rem;
  }

  .m\:px-7 {
    padding-left: 1.75rem;
    padding-right: 1.75rem;
  }

  .m\:px-8 {
    padding-left: 2rem;
    padding-right: 2rem;
  }

  .m\:px-9 {
    padding-left: 2.25rem;
    padding-right: 2.25rem;
  }

  .m\:px-10 {
    padding-left: 2.5rem;
    padding-right: 2.5rem;
  }

  .m\:px-11 {
    padding-left: 2.75rem;
    padding-right: 2.75rem;
  }

  .m\:px-12 {
    padding-left: 3rem;
    padding-right: 3rem;
  }

  .m\:px-14 {
    padding-left: 3.5rem;
    padding-right: 3.5rem;
  }

  .m\:px-16 {
    padding-left: 4rem;
    padding-right: 4rem;
  }

  .m\:px-18 {
    padding-left: 4.5rem;
    padding-right: 4.5rem;
  }

  .m\:px-20 {
    padding-left: 5rem;
    padding-right: 5rem;
  }

  .m\:px-24 {
    padding-left: 6rem;
    padding-right: 6rem;
  }

  .m\:px-28 {
    padding-left: 7rem;
    padding-right: 7rem;
  }

  .m\:px-32 {
    padding-left: 8rem;
    padding-right: 8rem;
  }

  .m\:px-36 {
    padding-left: 9rem;
    padding-right: 9rem;
  }

  .m\:px-40 {
    padding-left: 10rem;
    padding-right: 10rem;
  }

  .m\:px-44 {
    padding-left: 11rem;
    padding-right: 11rem;
  }

  .m\:px-48 {
    padding-left: 12rem;
    padding-right: 12rem;
  }

  .m\:px-52 {
    padding-left: 13rem;
    padding-right: 13rem;
  }

  .m\:px-56 {
    padding-left: 14rem;
    padding-right: 14rem;
  }

  .m\:px-60 {
    padding-left: 15rem;
    padding-right: 15rem;
  }

  .m\:px-64 {
    padding-left: 16rem;
    padding-right: 16rem;
  }

  .m\:px-72 {
    padding-left: 18rem;
    padding-right: 18rem;
  }

  .m\:px-80 {
    padding-left: 20rem;
    padding-right: 20rem;
  }

  .m\:px-96 {
    padding-left: 24rem;
    padding-right: 24rem;
  }

  .m\:py-px {
    padding-top: 0.0625rem;
    padding-bottom: 0.0625rem;
  }

  .m\:py-0 {
    padding-top: 0;
    padding-bottom: 0;
  }

  .m\:py-none {
    padding-top: 0;
    padding-bottom: 0;
  }

  .m\:py-0\.5 {
    padding-top: 0.125rem;
    padding-bottom: 0.125rem;
  }

  .m\:py-1 {
    padding-top: 0.25rem;
    padding-bottom: 0.25rem;
  }

  .m\:py-1\.5 {
    padding-top: 0.375rem;
    padding-bottom: 0.375rem;
  }

  .m\:py-2 {
    padding-top: 0.5rem;
    padding-bottom: 0.5rem;
  }

  .m\:py-2\.5 {
    padding-top: 0.625rem;
    padding-bottom: 0.625rem;
  }

  .m\:py-3 {
    padding-top: 0.75rem;
    padding-bottom: 0.75rem;
  }

  .m\:py-3\.5 {
    padding-top: 0.875rem;
    padding-bottom: 0.875rem;
  }

  .m\:py-4 {
    padding-top: 1rem;
    padding-bottom: 1rem;
  }

  .m\:py-5 {
    padding-top: 1.25rem;
    padding-bottom: 1.25rem;
  }

  .m\:py-6 {
    padding-top: 1.5rem;
    padding-bottom: 1.5rem;
  }

  .m\:py-7 {
    padding-top: 1.75rem;
    padding-bottom: 1.75rem;
  }

  .m\:py-8 {
    padding-top: 2rem;
    padding-bottom: 2rem;
  }

  .m\:py-9 {
    padding-top: 2.25rem;
    padding-bottom: 2.25rem;
  }

  .m\:py-10 {
    padding-top: 2.5rem;
    padding-bottom: 2.5rem;
  }

  .m\:py-11 {
    padding-top: 2.75rem;
    padding-bottom: 2.75rem;
  }

  .m\:py-12 {
    padding-top: 3rem;
    padding-bottom: 3rem;
  }

  .m\:py-14 {
    padding-top: 3.5rem;
    padding-bottom: 3.5rem;
  }

  .m\:py-16 {
    padding-top: 4rem;
    padding-bottom: 4rem;
  }

  .m\:py-18 {
    padding-top: 4.5rem;
    padding-bottom: 4.5rem;
  }

  .m\:py-20 {
    padding-top: 5rem;
    padding-bottom: 5rem;
  }

  .m\:py-24 {
    padding-top: 6rem;
    padding-bottom: 6rem;
  }

  .m\:py-28 {
    padding-top: 7rem;
    padding-bottom: 7rem;
  }

  .m\:py-32 {
    padding-top: 8rem;
    padding-bottom: 8rem;
  }

  .m\:py-36 {
    padding-top: 9rem;
    padding-bottom: 9rem;
  }

  .m\:py-40 {
    padding-top: 10rem;
    padding-bottom: 10rem;
  }

  .m\:py-44 {
    padding-top: 11rem;
    padding-bottom: 11rem;
  }

  .m\:py-48 {
    padding-top: 12rem;
    padding-bottom: 12rem;
  }

  .m\:py-52 {
    padding-top: 13rem;
    padding-bottom: 13rem;
  }

  .m\:py-56 {
    padding-top: 14rem;
    padding-bottom: 14rem;
  }

  .m\:py-60 {
    padding-top: 15rem;
    padding-bottom: 15rem;
  }

  .m\:py-64 {
    padding-top: 16rem;
    padding-bottom: 16rem;
  }

  .m\:py-72 {
    padding-top: 18rem;
    padding-bottom: 18rem;
  }

  .m\:py-80 {
    padding-top: 20rem;
    padding-bottom: 20rem;
  }

  .m\:py-96 {
    padding-top: 24rem;
    padding-bottom: 24rem;
  }

  .m\:pt-px {
    padding-top: 0.0625rem;
  }

  .m\:pt-0 {
    padding-top: 0;
  }

  .m\:pt-none {
    padding-top: 0;
  }

  .m\:pt-0\.5 {
    padding-top: 0.125rem;
  }

  .m\:pt-1 {
    padding-top: 0.25rem;
  }

  .m\:pt-1\.5 {
    padding-top: 0.375rem;
  }

  .m\:pt-2 {
    padding-top: 0.5rem;
  }

  .m\:pt-2\.5 {
    padding-top: 0.625rem;
  }

  .m\:pt-3 {
    padding-top: 0.75rem;
  }

  .m\:pt-3\.5 {
    padding-top: 0.875rem;
  }

  .m\:pt-4 {
    padding-top: 1rem;
  }

  .m\:pt-5 {
    padding-top: 1.25rem;
  }

  .m\:pt-6 {
    padding-top: 1.5rem;
  }

  .m\:pt-7 {
    padding-top: 1.75rem;
  }

  .m\:pt-8 {
    padding-top: 2rem;
  }

  .m\:pt-9 {
    padding-top: 2.25rem;
  }

  .m\:pt-10 {
    padding-top: 2.5rem;
  }

  .m\:pt-11 {
    padding-top: 2.75rem;
  }

  .m\:pt-12 {
    padding-top: 3rem;
  }

  .m\:pt-14 {
    padding-top: 3.5rem;
  }

  .m\:pt-16 {
    padding-top: 4rem;
  }

  .m\:pt-18 {
    padding-top: 4.5rem;
  }

  .m\:pt-20 {
    padding-top: 5rem;
  }

  .m\:pt-24 {
    padding-top: 6rem;
  }

  .m\:pt-28 {
    padding-top: 7rem;
  }

  .m\:pt-32 {
    padding-top: 8rem;
  }

  .m\:pt-36 {
    padding-top: 9rem;
  }

  .m\:pt-40 {
    padding-top: 10rem;
  }

  .m\:pt-44 {
    padding-top: 11rem;
  }

  .m\:pt-48 {
    padding-top: 12rem;
  }

  .m\:pt-52 {
    padding-top: 13rem;
  }

  .m\:pt-56 {
    padding-top: 14rem;
  }

  .m\:pt-60 {
    padding-top: 15rem;
  }

  .m\:pt-64 {
    padding-top: 16rem;
  }

  .m\:pt-72 {
    padding-top: 18rem;
  }

  .m\:pt-80 {
    padding-top: 20rem;
  }

  .m\:pt-96 {
    padding-top: 24rem;
  }

  .m\:pr-px {
    padding-right: 0.0625rem;
  }

  .m\:pr-0 {
    padding-right: 0;
  }

  .m\:pr-none {
    padding-right: 0;
  }

  .m\:pr-0\.5 {
    padding-right: 0.125rem;
  }

  .m\:pr-1 {
    padding-right: 0.25rem;
  }

  .m\:pr-1\.5 {
    padding-right: 0.375rem;
  }

  .m\:pr-2 {
    padding-right: 0.5rem;
  }

  .m\:pr-2\.5 {
    padding-right: 0.625rem;
  }

  .m\:pr-3 {
    padding-right: 0.75rem;
  }

  .m\:pr-3\.5 {
    padding-right: 0.875rem;
  }

  .m\:pr-4 {
    padding-right: 1rem;
  }

  .m\:pr-5 {
    padding-right: 1.25rem;
  }

  .m\:pr-6 {
    padding-right: 1.5rem;
  }

  .m\:pr-7 {
    padding-right: 1.75rem;
  }

  .m\:pr-8 {
    padding-right: 2rem;
  }

  .m\:pr-9 {
    padding-right: 2.25rem;
  }

  .m\:pr-10 {
    padding-right: 2.5rem;
  }

  .m\:pr-11 {
    padding-right: 2.75rem;
  }

  .m\:pr-12 {
    padding-right: 3rem;
  }

  .m\:pr-14 {
    padding-right: 3.5rem;
  }

  .m\:pr-16 {
    padding-right: 4rem;
  }

  .m\:pr-18 {
    padding-right: 4.5rem;
  }

  .m\:pr-20 {
    padding-right: 5rem;
  }

  .m\:pr-24 {
    padding-right: 6rem;
  }

  .m\:pr-28 {
    padding-right: 7rem;
  }

  .m\:pr-32 {
    padding-right: 8rem;
  }

  .m\:pr-36 {
    padding-right: 9rem;
  }

  .m\:pr-40 {
    padding-right: 10rem;
  }

  .m\:pr-44 {
    padding-right: 11rem;
  }

  .m\:pr-48 {
    padding-right: 12rem;
  }

  .m\:pr-52 {
    padding-right: 13rem;
  }

  .m\:pr-56 {
    padding-right: 14rem;
  }

  .m\:pr-60 {
    padding-right: 15rem;
  }

  .m\:pr-64 {
    padding-right: 16rem;
  }

  .m\:pr-72 {
    padding-right: 18rem;
  }

  .m\:pr-80 {
    padding-right: 20rem;
  }

  .m\:pr-96 {
    padding-right: 24rem;
  }

  .m\:pb-px {
    padding-bottom: 0.0625rem;
  }

  .m\:pb-0 {
    padding-bottom: 0;
  }

  .m\:pb-none {
    padding-bottom: 0;
  }

  .m\:pb-0\.5 {
    padding-bottom: 0.125rem;
  }

  .m\:pb-1 {
    padding-bottom: 0.25rem;
  }

  .m\:pb-1\.5 {
    padding-bottom: 0.375rem;
  }

  .m\:pb-2 {
    padding-bottom: 0.5rem;
  }

  .m\:pb-2\.5 {
    padding-bottom: 0.625rem;
  }

  .m\:pb-3 {
    padding-bottom: 0.75rem;
  }

  .m\:pb-3\.5 {
    padding-bottom: 0.875rem;
  }

  .m\:pb-4 {
    padding-bottom: 1rem;
  }

  .m\:pb-5 {
    padding-bottom: 1.25rem;
  }

  .m\:pb-6 {
    padding-bottom: 1.5rem;
  }

  .m\:pb-7 {
    padding-bottom: 1.75rem;
  }

  .m\:pb-8 {
    padding-bottom: 2rem;
  }

  .m\:pb-9 {
    padding-bottom: 2.25rem;
  }

  .m\:pb-10 {
    padding-bottom: 2.5rem;
  }

  .m\:pb-11 {
    padding-bottom: 2.75rem;
  }

  .m\:pb-12 {
    padding-bottom: 3rem;
  }

  .m\:pb-14 {
    padding-bottom: 3.5rem;
  }

  .m\:pb-16 {
    padding-bottom: 4rem;
  }

  .m\:pb-18 {
    padding-bottom: 4.5rem;
  }

  .m\:pb-20 {
    padding-bottom: 5rem;
  }

  .m\:pb-24 {
    padding-bottom: 6rem;
  }

  .m\:pb-28 {
    padding-bottom: 7rem;
  }

  .m\:pb-32 {
    padding-bottom: 8rem;
  }

  .m\:pb-36 {
    padding-bottom: 9rem;
  }

  .m\:pb-40 {
    padding-bottom: 10rem;
  }

  .m\:pb-44 {
    padding-bottom: 11rem;
  }

  .m\:pb-48 {
    padding-bottom: 12rem;
  }

  .m\:pb-52 {
    padding-bottom: 13rem;
  }

  .m\:pb-56 {
    padding-bottom: 14rem;
  }

  .m\:pb-60 {
    padding-bottom: 15rem;
  }

  .m\:pb-64 {
    padding-bottom: 16rem;
  }

  .m\:pb-72 {
    padding-bottom: 18rem;
  }

  .m\:pb-80 {
    padding-bottom: 20rem;
  }

  .m\:pb-96 {
    padding-bottom: 24rem;
  }

  .m\:pl-px {
    padding-left: 0.0625rem;
  }

  .m\:pl-0 {
    padding-left: 0;
  }

  .m\:pl-none {
    padding-left: 0;
  }

  .m\:pl-0\.5 {
    padding-left: 0.125rem;
  }

  .m\:pl-1 {
    padding-left: 0.25rem;
  }

  .m\:pl-1\.5 {
    padding-left: 0.375rem;
  }

  .m\:pl-2 {
    padding-left: 0.5rem;
  }

  .m\:pl-2\.5 {
    padding-left: 0.625rem;
  }

  .m\:pl-3 {
    padding-left: 0.75rem;
  }

  .m\:pl-3\.5 {
    padding-left: 0.875rem;
  }

  .m\:pl-4 {
    padding-left: 1rem;
  }

  .m\:pl-5 {
    padding-left: 1.25rem;
  }

  .m\:pl-6 {
    padding-left: 1.5rem;
  }

  .m\:pl-7 {
    padding-left: 1.75rem;
  }

  .m\:pl-8 {
    padding-left: 2rem;
  }

  .m\:pl-9 {
    padding-left: 2.25rem;
  }

  .m\:pl-10 {
    padding-left: 2.5rem;
  }

  .m\:pl-11 {
    padding-left: 2.75rem;
  }

  .m\:pl-12 {
    padding-left: 3rem;
  }

  .m\:pl-14 {
    padding-left: 3.5rem;
  }

  .m\:pl-16 {
    padding-left: 4rem;
  }

  .m\:pl-18 {
    padding-left: 4.5rem;
  }

  .m\:pl-20 {
    padding-left: 5rem;
  }

  .m\:pl-24 {
    padding-left: 6rem;
  }

  .m\:pl-28 {
    padding-left: 7rem;
  }

  .m\:pl-32 {
    padding-left: 8rem;
  }

  .m\:pl-36 {
    padding-left: 9rem;
  }

  .m\:pl-40 {
    padding-left: 10rem;
  }

  .m\:pl-44 {
    padding-left: 11rem;
  }

  .m\:pl-48 {
    padding-left: 12rem;
  }

  .m\:pl-52 {
    padding-left: 13rem;
  }

  .m\:pl-56 {
    padding-left: 14rem;
  }

  .m\:pl-60 {
    padding-left: 15rem;
  }

  .m\:pl-64 {
    padding-left: 16rem;
  }

  .m\:pl-72 {
    padding-left: 18rem;
  }

  .m\:pl-80 {
    padding-left: 20rem;
  }

  .m\:pl-96 {
    padding-left: 24rem;
  }
}
@media (min-width: 769px) {
  .pc\:p-px {
    padding: 0.0625rem;
  }

  .pc\:p-0 {
    padding: 0;
  }

  .pc\:p-none {
    padding: 0;
  }

  .pc\:p-0\.5 {
    padding: 0.125rem;
  }

  .pc\:p-1 {
    padding: 0.25rem;
  }

  .pc\:p-1\.5 {
    padding: 0.375rem;
  }

  .pc\:p-2 {
    padding: 0.5rem;
  }

  .pc\:p-2\.5 {
    padding: 0.625rem;
  }

  .pc\:p-3 {
    padding: 0.75rem;
  }

  .pc\:p-3\.5 {
    padding: 0.875rem;
  }

  .pc\:p-4 {
    padding: 1rem;
  }

  .pc\:p-5 {
    padding: 1.25rem;
  }

  .pc\:p-6 {
    padding: 1.5rem;
  }

  .pc\:p-7 {
    padding: 1.75rem;
  }

  .pc\:p-8 {
    padding: 2rem;
  }

  .pc\:p-9 {
    padding: 2.25rem;
  }

  .pc\:p-10 {
    padding: 2.5rem;
  }

  .pc\:p-11 {
    padding: 2.75rem;
  }

  .pc\:p-12 {
    padding: 3rem;
  }

  .pc\:p-14 {
    padding: 3.5rem;
  }

  .pc\:p-16 {
    padding: 4rem;
  }

  .pc\:p-18 {
    padding: 4.5rem;
  }

  .pc\:p-20 {
    padding: 5rem;
  }

  .pc\:p-24 {
    padding: 6rem;
  }

  .pc\:p-28 {
    padding: 7rem;
  }

  .pc\:p-32 {
    padding: 8rem;
  }

  .pc\:p-36 {
    padding: 9rem;
  }

  .pc\:p-40 {
    padding: 10rem;
  }

  .pc\:p-44 {
    padding: 11rem;
  }

  .pc\:p-48 {
    padding: 12rem;
  }

  .pc\:p-52 {
    padding: 13rem;
  }

  .pc\:p-56 {
    padding: 14rem;
  }

  .pc\:p-60 {
    padding: 15rem;
  }

  .pc\:p-64 {
    padding: 16rem;
  }

  .pc\:p-72 {
    padding: 18rem;
  }

  .pc\:p-80 {
    padding: 20rem;
  }

  .pc\:p-96 {
    padding: 24rem;
  }

  .pc\:px-px {
    padding-left: 0.0625rem;
    padding-right: 0.0625rem;
  }

  .pc\:px-0 {
    padding-left: 0;
    padding-right: 0;
  }

  .pc\:px-none {
    padding-left: 0;
    padding-right: 0;
  }

  .pc\:px-0\.5 {
    padding-left: 0.125rem;
    padding-right: 0.125rem;
  }

  .pc\:px-1 {
    padding-left: 0.25rem;
    padding-right: 0.25rem;
  }

  .pc\:px-1\.5 {
    padding-left: 0.375rem;
    padding-right: 0.375rem;
  }

  .pc\:px-2 {
    padding-left: 0.5rem;
    padding-right: 0.5rem;
  }

  .pc\:px-2\.5 {
    padding-left: 0.625rem;
    padding-right: 0.625rem;
  }

  .pc\:px-3 {
    padding-left: 0.75rem;
    padding-right: 0.75rem;
  }

  .pc\:px-3\.5 {
    padding-left: 0.875rem;
    padding-right: 0.875rem;
  }

  .pc\:px-4 {
    padding-left: 1rem;
    padding-right: 1rem;
  }

  .pc\:px-5 {
    padding-left: 1.25rem;
    padding-right: 1.25rem;
  }

  .pc\:px-6 {
    padding-left: 1.5rem;
    padding-right: 1.5rem;
  }

  .pc\:px-7 {
    padding-left: 1.75rem;
    padding-right: 1.75rem;
  }

  .pc\:px-8 {
    padding-left: 2rem;
    padding-right: 2rem;
  }

  .pc\:px-9 {
    padding-left: 2.25rem;
    padding-right: 2.25rem;
  }

  .pc\:px-10 {
    padding-left: 2.5rem;
    padding-right: 2.5rem;
  }

  .pc\:px-11 {
    padding-left: 2.75rem;
    padding-right: 2.75rem;
  }

  .pc\:px-12 {
    padding-left: 3rem;
    padding-right: 3rem;
  }

  .pc\:px-14 {
    padding-left: 3.5rem;
    padding-right: 3.5rem;
  }

  .pc\:px-16 {
    padding-left: 4rem;
    padding-right: 4rem;
  }

  .pc\:px-18 {
    padding-left: 4.5rem;
    padding-right: 4.5rem;
  }

  .pc\:px-20 {
    padding-left: 5rem;
    padding-right: 5rem;
  }

  .pc\:px-24 {
    padding-left: 6rem;
    padding-right: 6rem;
  }

  .pc\:px-28 {
    padding-left: 7rem;
    padding-right: 7rem;
  }

  .pc\:px-32 {
    padding-left: 8rem;
    padding-right: 8rem;
  }

  .pc\:px-36 {
    padding-left: 9rem;
    padding-right: 9rem;
  }

  .pc\:px-40 {
    padding-left: 10rem;
    padding-right: 10rem;
  }

  .pc\:px-44 {
    padding-left: 11rem;
    padding-right: 11rem;
  }

  .pc\:px-48 {
    padding-left: 12rem;
    padding-right: 12rem;
  }

  .pc\:px-52 {
    padding-left: 13rem;
    padding-right: 13rem;
  }

  .pc\:px-56 {
    padding-left: 14rem;
    padding-right: 14rem;
  }

  .pc\:px-60 {
    padding-left: 15rem;
    padding-right: 15rem;
  }

  .pc\:px-64 {
    padding-left: 16rem;
    padding-right: 16rem;
  }

  .pc\:px-72 {
    padding-left: 18rem;
    padding-right: 18rem;
  }

  .pc\:px-80 {
    padding-left: 20rem;
    padding-right: 20rem;
  }

  .pc\:px-96 {
    padding-left: 24rem;
    padding-right: 24rem;
  }

  .pc\:py-px {
    padding-top: 0.0625rem;
    padding-bottom: 0.0625rem;
  }

  .pc\:py-0 {
    padding-top: 0;
    padding-bottom: 0;
  }

  .pc\:py-none {
    padding-top: 0;
    padding-bottom: 0;
  }

  .pc\:py-0\.5 {
    padding-top: 0.125rem;
    padding-bottom: 0.125rem;
  }

  .pc\:py-1 {
    padding-top: 0.25rem;
    padding-bottom: 0.25rem;
  }

  .pc\:py-1\.5 {
    padding-top: 0.375rem;
    padding-bottom: 0.375rem;
  }

  .pc\:py-2 {
    padding-top: 0.5rem;
    padding-bottom: 0.5rem;
  }

  .pc\:py-2\.5 {
    padding-top: 0.625rem;
    padding-bottom: 0.625rem;
  }

  .pc\:py-3 {
    padding-top: 0.75rem;
    padding-bottom: 0.75rem;
  }

  .pc\:py-3\.5 {
    padding-top: 0.875rem;
    padding-bottom: 0.875rem;
  }

  .pc\:py-4 {
    padding-top: 1rem;
    padding-bottom: 1rem;
  }

  .pc\:py-5 {
    padding-top: 1.25rem;
    padding-bottom: 1.25rem;
  }

  .pc\:py-6 {
    padding-top: 1.5rem;
    padding-bottom: 1.5rem;
  }

  .pc\:py-7 {
    padding-top: 1.75rem;
    padding-bottom: 1.75rem;
  }

  .pc\:py-8 {
    padding-top: 2rem;
    padding-bottom: 2rem;
  }

  .pc\:py-9 {
    padding-top: 2.25rem;
    padding-bottom: 2.25rem;
  }

  .pc\:py-10 {
    padding-top: 2.5rem;
    padding-bottom: 2.5rem;
  }

  .pc\:py-11 {
    padding-top: 2.75rem;
    padding-bottom: 2.75rem;
  }

  .pc\:py-12 {
    padding-top: 3rem;
    padding-bottom: 3rem;
  }

  .pc\:py-14 {
    padding-top: 3.5rem;
    padding-bottom: 3.5rem;
  }

  .pc\:py-16 {
    padding-top: 4rem;
    padding-bottom: 4rem;
  }

  .pc\:py-18 {
    padding-top: 4.5rem;
    padding-bottom: 4.5rem;
  }

  .pc\:py-20 {
    padding-top: 5rem;
    padding-bottom: 5rem;
  }

  .pc\:py-24 {
    padding-top: 6rem;
    padding-bottom: 6rem;
  }

  .pc\:py-28 {
    padding-top: 7rem;
    padding-bottom: 7rem;
  }

  .pc\:py-32 {
    padding-top: 8rem;
    padding-bottom: 8rem;
  }

  .pc\:py-36 {
    padding-top: 9rem;
    padding-bottom: 9rem;
  }

  .pc\:py-40 {
    padding-top: 10rem;
    padding-bottom: 10rem;
  }

  .pc\:py-44 {
    padding-top: 11rem;
    padding-bottom: 11rem;
  }

  .pc\:py-48 {
    padding-top: 12rem;
    padding-bottom: 12rem;
  }

  .pc\:py-52 {
    padding-top: 13rem;
    padding-bottom: 13rem;
  }

  .pc\:py-56 {
    padding-top: 14rem;
    padding-bottom: 14rem;
  }

  .pc\:py-60 {
    padding-top: 15rem;
    padding-bottom: 15rem;
  }

  .pc\:py-64 {
    padding-top: 16rem;
    padding-bottom: 16rem;
  }

  .pc\:py-72 {
    padding-top: 18rem;
    padding-bottom: 18rem;
  }

  .pc\:py-80 {
    padding-top: 20rem;
    padding-bottom: 20rem;
  }

  .pc\:py-96 {
    padding-top: 24rem;
    padding-bottom: 24rem;
  }

  .pc\:pt-px {
    padding-top: 0.0625rem;
  }

  .pc\:pt-0 {
    padding-top: 0;
  }

  .pc\:pt-none {
    padding-top: 0;
  }

  .pc\:pt-0\.5 {
    padding-top: 0.125rem;
  }

  .pc\:pt-1 {
    padding-top: 0.25rem;
  }

  .pc\:pt-1\.5 {
    padding-top: 0.375rem;
  }

  .pc\:pt-2 {
    padding-top: 0.5rem;
  }

  .pc\:pt-2\.5 {
    padding-top: 0.625rem;
  }

  .pc\:pt-3 {
    padding-top: 0.75rem;
  }

  .pc\:pt-3\.5 {
    padding-top: 0.875rem;
  }

  .pc\:pt-4 {
    padding-top: 1rem;
  }

  .pc\:pt-5 {
    padding-top: 1.25rem;
  }

  .pc\:pt-6 {
    padding-top: 1.5rem;
  }

  .pc\:pt-7 {
    padding-top: 1.75rem;
  }

  .pc\:pt-8 {
    padding-top: 2rem;
  }

  .pc\:pt-9 {
    padding-top: 2.25rem;
  }

  .pc\:pt-10 {
    padding-top: 2.5rem;
  }

  .pc\:pt-11 {
    padding-top: 2.75rem;
  }

  .pc\:pt-12 {
    padding-top: 3rem;
  }

  .pc\:pt-14 {
    padding-top: 3.5rem;
  }

  .pc\:pt-16 {
    padding-top: 4rem;
  }

  .pc\:pt-18 {
    padding-top: 4.5rem;
  }

  .pc\:pt-20 {
    padding-top: 5rem;
  }

  .pc\:pt-24 {
    padding-top: 6rem;
  }

  .pc\:pt-28 {
    padding-top: 7rem;
  }

  .pc\:pt-32 {
    padding-top: 8rem;
  }

  .pc\:pt-36 {
    padding-top: 9rem;
  }

  .pc\:pt-40 {
    padding-top: 10rem;
  }

  .pc\:pt-44 {
    padding-top: 11rem;
  }

  .pc\:pt-48 {
    padding-top: 12rem;
  }

  .pc\:pt-52 {
    padding-top: 13rem;
  }

  .pc\:pt-56 {
    padding-top: 14rem;
  }

  .pc\:pt-60 {
    padding-top: 15rem;
  }

  .pc\:pt-64 {
    padding-top: 16rem;
  }

  .pc\:pt-72 {
    padding-top: 18rem;
  }

  .pc\:pt-80 {
    padding-top: 20rem;
  }

  .pc\:pt-96 {
    padding-top: 24rem;
  }

  .pc\:pr-px {
    padding-right: 0.0625rem;
  }

  .pc\:pr-0 {
    padding-right: 0;
  }

  .pc\:pr-none {
    padding-right: 0;
  }

  .pc\:pr-0\.5 {
    padding-right: 0.125rem;
  }

  .pc\:pr-1 {
    padding-right: 0.25rem;
  }

  .pc\:pr-1\.5 {
    padding-right: 0.375rem;
  }

  .pc\:pr-2 {
    padding-right: 0.5rem;
  }

  .pc\:pr-2\.5 {
    padding-right: 0.625rem;
  }

  .pc\:pr-3 {
    padding-right: 0.75rem;
  }

  .pc\:pr-3\.5 {
    padding-right: 0.875rem;
  }

  .pc\:pr-4 {
    padding-right: 1rem;
  }

  .pc\:pr-5 {
    padding-right: 1.25rem;
  }

  .pc\:pr-6 {
    padding-right: 1.5rem;
  }

  .pc\:pr-7 {
    padding-right: 1.75rem;
  }

  .pc\:pr-8 {
    padding-right: 2rem;
  }

  .pc\:pr-9 {
    padding-right: 2.25rem;
  }

  .pc\:pr-10 {
    padding-right: 2.5rem;
  }

  .pc\:pr-11 {
    padding-right: 2.75rem;
  }

  .pc\:pr-12 {
    padding-right: 3rem;
  }

  .pc\:pr-14 {
    padding-right: 3.5rem;
  }

  .pc\:pr-16 {
    padding-right: 4rem;
  }

  .pc\:pr-18 {
    padding-right: 4.5rem;
  }

  .pc\:pr-20 {
    padding-right: 5rem;
  }

  .pc\:pr-24 {
    padding-right: 6rem;
  }

  .pc\:pr-28 {
    padding-right: 7rem;
  }

  .pc\:pr-32 {
    padding-right: 8rem;
  }

  .pc\:pr-36 {
    padding-right: 9rem;
  }

  .pc\:pr-40 {
    padding-right: 10rem;
  }

  .pc\:pr-44 {
    padding-right: 11rem;
  }

  .pc\:pr-48 {
    padding-right: 12rem;
  }

  .pc\:pr-52 {
    padding-right: 13rem;
  }

  .pc\:pr-56 {
    padding-right: 14rem;
  }

  .pc\:pr-60 {
    padding-right: 15rem;
  }

  .pc\:pr-64 {
    padding-right: 16rem;
  }

  .pc\:pr-72 {
    padding-right: 18rem;
  }

  .pc\:pr-80 {
    padding-right: 20rem;
  }

  .pc\:pr-96 {
    padding-right: 24rem;
  }

  .pc\:pb-px {
    padding-bottom: 0.0625rem;
  }

  .pc\:pb-0 {
    padding-bottom: 0;
  }

  .pc\:pb-none {
    padding-bottom: 0;
  }

  .pc\:pb-0\.5 {
    padding-bottom: 0.125rem;
  }

  .pc\:pb-1 {
    padding-bottom: 0.25rem;
  }

  .pc\:pb-1\.5 {
    padding-bottom: 0.375rem;
  }

  .pc\:pb-2 {
    padding-bottom: 0.5rem;
  }

  .pc\:pb-2\.5 {
    padding-bottom: 0.625rem;
  }

  .pc\:pb-3 {
    padding-bottom: 0.75rem;
  }

  .pc\:pb-3\.5 {
    padding-bottom: 0.875rem;
  }

  .pc\:pb-4 {
    padding-bottom: 1rem;
  }

  .pc\:pb-5 {
    padding-bottom: 1.25rem;
  }

  .pc\:pb-6 {
    padding-bottom: 1.5rem;
  }

  .pc\:pb-7 {
    padding-bottom: 1.75rem;
  }

  .pc\:pb-8 {
    padding-bottom: 2rem;
  }

  .pc\:pb-9 {
    padding-bottom: 2.25rem;
  }

  .pc\:pb-10 {
    padding-bottom: 2.5rem;
  }

  .pc\:pb-11 {
    padding-bottom: 2.75rem;
  }

  .pc\:pb-12 {
    padding-bottom: 3rem;
  }

  .pc\:pb-14 {
    padding-bottom: 3.5rem;
  }

  .pc\:pb-16 {
    padding-bottom: 4rem;
  }

  .pc\:pb-18 {
    padding-bottom: 4.5rem;
  }

  .pc\:pb-20 {
    padding-bottom: 5rem;
  }

  .pc\:pb-24 {
    padding-bottom: 6rem;
  }

  .pc\:pb-28 {
    padding-bottom: 7rem;
  }

  .pc\:pb-32 {
    padding-bottom: 8rem;
  }

  .pc\:pb-36 {
    padding-bottom: 9rem;
  }

  .pc\:pb-40 {
    padding-bottom: 10rem;
  }

  .pc\:pb-44 {
    padding-bottom: 11rem;
  }

  .pc\:pb-48 {
    padding-bottom: 12rem;
  }

  .pc\:pb-52 {
    padding-bottom: 13rem;
  }

  .pc\:pb-56 {
    padding-bottom: 14rem;
  }

  .pc\:pb-60 {
    padding-bottom: 15rem;
  }

  .pc\:pb-64 {
    padding-bottom: 16rem;
  }

  .pc\:pb-72 {
    padding-bottom: 18rem;
  }

  .pc\:pb-80 {
    padding-bottom: 20rem;
  }

  .pc\:pb-96 {
    padding-bottom: 24rem;
  }

  .pc\:pl-px {
    padding-left: 0.0625rem;
  }

  .pc\:pl-0 {
    padding-left: 0;
  }

  .pc\:pl-none {
    padding-left: 0;
  }

  .pc\:pl-0\.5 {
    padding-left: 0.125rem;
  }

  .pc\:pl-1 {
    padding-left: 0.25rem;
  }

  .pc\:pl-1\.5 {
    padding-left: 0.375rem;
  }

  .pc\:pl-2 {
    padding-left: 0.5rem;
  }

  .pc\:pl-2\.5 {
    padding-left: 0.625rem;
  }

  .pc\:pl-3 {
    padding-left: 0.75rem;
  }

  .pc\:pl-3\.5 {
    padding-left: 0.875rem;
  }

  .pc\:pl-4 {
    padding-left: 1rem;
  }

  .pc\:pl-5 {
    padding-left: 1.25rem;
  }

  .pc\:pl-6 {
    padding-left: 1.5rem;
  }

  .pc\:pl-7 {
    padding-left: 1.75rem;
  }

  .pc\:pl-8 {
    padding-left: 2rem;
  }

  .pc\:pl-9 {
    padding-left: 2.25rem;
  }

  .pc\:pl-10 {
    padding-left: 2.5rem;
  }

  .pc\:pl-11 {
    padding-left: 2.75rem;
  }

  .pc\:pl-12 {
    padding-left: 3rem;
  }

  .pc\:pl-14 {
    padding-left: 3.5rem;
  }

  .pc\:pl-16 {
    padding-left: 4rem;
  }

  .pc\:pl-18 {
    padding-left: 4.5rem;
  }

  .pc\:pl-20 {
    padding-left: 5rem;
  }

  .pc\:pl-24 {
    padding-left: 6rem;
  }

  .pc\:pl-28 {
    padding-left: 7rem;
  }

  .pc\:pl-32 {
    padding-left: 8rem;
  }

  .pc\:pl-36 {
    padding-left: 9rem;
  }

  .pc\:pl-40 {
    padding-left: 10rem;
  }

  .pc\:pl-44 {
    padding-left: 11rem;
  }

  .pc\:pl-48 {
    padding-left: 12rem;
  }

  .pc\:pl-52 {
    padding-left: 13rem;
  }

  .pc\:pl-56 {
    padding-left: 14rem;
  }

  .pc\:pl-60 {
    padding-left: 15rem;
  }

  .pc\:pl-64 {
    padding-left: 16rem;
  }

  .pc\:pl-72 {
    padding-left: 18rem;
  }

  .pc\:pl-80 {
    padding-left: 20rem;
  }

  .pc\:pl-96 {
    padding-left: 24rem;
  }
}
/*!markdown

---
title: Space Between
---


| Class       | Properties               |
| ----------- | ------------------------ |
| space-x-px | margin-left: 0.0625rem |
| space-x-px.space-x-reverse | margin-right: 0.0625rem |
| space-x-0 | margin-left: 0 |
| space-x-0.space-x-reverse | margin-right: 0 |
| space-x-none | margin-left: 0 |
| space-x-none.space-x-reverse | margin-right: 0 |
| space-x-0\.5 | margin-left: 0.125rem |
| space-x-0\.5.space-x-reverse | margin-right: 0.125rem |
| space-x-1 | margin-left: 0.25rem |
| space-x-1.space-x-reverse | margin-right: 0.25rem |
| space-x-1\.5 | margin-left: 0.375rem |
| space-x-1\.5.space-x-reverse | margin-right: 0.375rem |
| space-x-2 | margin-left: 0.5rem |
| space-x-2.space-x-reverse | margin-right: 0.5rem |
| space-x-2\.5 | margin-left: 0.625rem |
| space-x-2\.5.space-x-reverse | margin-right: 0.625rem |
| space-x-3 | margin-left: 0.75rem |
| space-x-3.space-x-reverse | margin-right: 0.75rem |
| space-x-3\.5 | margin-left: 0.875rem |
| space-x-3\.5.space-x-reverse | margin-right: 0.875rem |
| space-x-4 | margin-left: 1rem |
| space-x-4.space-x-reverse | margin-right: 1rem |
| space-x-5 | margin-left: 1.25rem |
| space-x-5.space-x-reverse | margin-right: 1.25rem |
| space-x-6 | margin-left: 1.5rem |
| space-x-6.space-x-reverse | margin-right: 1.5rem |
| space-x-7 | margin-left: 1.75rem |
| space-x-7.space-x-reverse | margin-right: 1.75rem |
| space-x-8 | margin-left: 2rem |
| space-x-8.space-x-reverse | margin-right: 2rem |
| space-x-9 | margin-left: 2.25rem |
| space-x-9.space-x-reverse | margin-right: 2.25rem |
| space-x-10 | margin-left: 2.5rem |
| space-x-10.space-x-reverse | margin-right: 2.5rem |
| space-x-11 | margin-left: 2.75rem |
| space-x-11.space-x-reverse | margin-right: 2.75rem |
| space-x-12 | margin-left: 3rem |
| space-x-12.space-x-reverse | margin-right: 3rem |
| space-x-14 | margin-left: 3.5rem |
| space-x-14.space-x-reverse | margin-right: 3.5rem |
| space-x-16 | margin-left: 4rem |
| space-x-16.space-x-reverse | margin-right: 4rem |
| space-x-18 | margin-left: 4.5rem |
| space-x-18.space-x-reverse | margin-right: 4.5rem |
| space-x-20 | margin-left: 5rem |
| space-x-20.space-x-reverse | margin-right: 5rem |
| space-x-24 | margin-left: 6rem |
| space-x-24.space-x-reverse | margin-right: 6rem |
| space-x-28 | margin-left: 7rem |
| space-x-28.space-x-reverse | margin-right: 7rem |
| space-x-32 | margin-left: 8rem |
| space-x-32.space-x-reverse | margin-right: 8rem |
| space-x-36 | margin-left: 9rem |
| space-x-36.space-x-reverse | margin-right: 9rem |
| space-x-40 | margin-left: 10rem |
| space-x-40.space-x-reverse | margin-right: 10rem |
| space-x-44 | margin-left: 11rem |
| space-x-44.space-x-reverse | margin-right: 11rem |
| space-x-48 | margin-left: 12rem |
| space-x-48.space-x-reverse | margin-right: 12rem |
| space-x-52 | margin-left: 13rem |
| space-x-52.space-x-reverse | margin-right: 13rem |
| space-x-56 | margin-left: 14rem |
| space-x-56.space-x-reverse | margin-right: 14rem |
| space-x-60 | margin-left: 15rem |
| space-x-60.space-x-reverse | margin-right: 15rem |
| space-x-64 | margin-left: 16rem |
| space-x-64.space-x-reverse | margin-right: 16rem |
| space-x-72 | margin-left: 18rem |
| space-x-72.space-x-reverse | margin-right: 18rem |
| space-x-80 | margin-left: 20rem |
| space-x-80.space-x-reverse | margin-right: 20rem |
| space-x-96 | margin-left: 24rem |
| space-x-96.space-x-reverse | margin-right: 24rem |
| space-y-px | margin-top: 0.0625rem |
| space-y-px.space-y-reverse | margin-bottom: 0.0625rem |
| space-y-0 | margin-top: 0 |
| space-y-0.space-y-reverse | margin-bottom: 0 |
| space-y-none | margin-top: 0 |
| space-y-none.space-y-reverse | margin-bottom: 0 |
| space-y-0\.5 | margin-top: 0.125rem |
| space-y-0\.5.space-y-reverse | margin-bottom: 0.125rem |
| space-y-1 | margin-top: 0.25rem |
| space-y-1.space-y-reverse | margin-bottom: 0.25rem |
| space-y-1\.5 | margin-top: 0.375rem |
| space-y-1\.5.space-y-reverse | margin-bottom: 0.375rem |
| space-y-2 | margin-top: 0.5rem |
| space-y-2.space-y-reverse | margin-bottom: 0.5rem |
| space-y-2\.5 | margin-top: 0.625rem |
| space-y-2\.5.space-y-reverse | margin-bottom: 0.625rem |
| space-y-3 | margin-top: 0.75rem |
| space-y-3.space-y-reverse | margin-bottom: 0.75rem |
| space-y-3\.5 | margin-top: 0.875rem |
| space-y-3\.5.space-y-reverse | margin-bottom: 0.875rem |
| space-y-4 | margin-top: 1rem |
| space-y-4.space-y-reverse | margin-bottom: 1rem |
| space-y-5 | margin-top: 1.25rem |
| space-y-5.space-y-reverse | margin-bottom: 1.25rem |
| space-y-6 | margin-top: 1.5rem |
| space-y-6.space-y-reverse | margin-bottom: 1.5rem |
| space-y-7 | margin-top: 1.75rem |
| space-y-7.space-y-reverse | margin-bottom: 1.75rem |
| space-y-8 | margin-top: 2rem |
| space-y-8.space-y-reverse | margin-bottom: 2rem |
| space-y-9 | margin-top: 2.25rem |
| space-y-9.space-y-reverse | margin-bottom: 2.25rem |
| space-y-10 | margin-top: 2.5rem |
| space-y-10.space-y-reverse | margin-bottom: 2.5rem |
| space-y-11 | margin-top: 2.75rem |
| space-y-11.space-y-reverse | margin-bottom: 2.75rem |
| space-y-12 | margin-top: 3rem |
| space-y-12.space-y-reverse | margin-bottom: 3rem |
| space-y-14 | margin-top: 3.5rem |
| space-y-14.space-y-reverse | margin-bottom: 3.5rem |
| space-y-16 | margin-top: 4rem |
| space-y-16.space-y-reverse | margin-bottom: 4rem |
| space-y-18 | margin-top: 4.5rem |
| space-y-18.space-y-reverse | margin-bottom: 4.5rem |
| space-y-20 | margin-top: 5rem |
| space-y-20.space-y-reverse | margin-bottom: 5rem |
| space-y-24 | margin-top: 6rem |
| space-y-24.space-y-reverse | margin-bottom: 6rem |
| space-y-28 | margin-top: 7rem |
| space-y-28.space-y-reverse | margin-bottom: 7rem |
| space-y-32 | margin-top: 8rem |
| space-y-32.space-y-reverse | margin-bottom: 8rem |
| space-y-36 | margin-top: 9rem |
| space-y-36.space-y-reverse | margin-bottom: 9rem |
| space-y-40 | margin-top: 10rem |
| space-y-40.space-y-reverse | margin-bottom: 10rem |
| space-y-44 | margin-top: 11rem |
| space-y-44.space-y-reverse | margin-bottom: 11rem |
| space-y-48 | margin-top: 12rem |
| space-y-48.space-y-reverse | margin-bottom: 12rem |
| space-y-52 | margin-top: 13rem |
| space-y-52.space-y-reverse | margin-bottom: 13rem |
| space-y-56 | margin-top: 14rem |
| space-y-56.space-y-reverse | margin-bottom: 14rem |
| space-y-60 | margin-top: 15rem |
| space-y-60.space-y-reverse | margin-bottom: 15rem |
| space-y-64 | margin-top: 16rem |
| space-y-64.space-y-reverse | margin-bottom: 16rem |
| space-y-72 | margin-top: 18rem |
| space-y-72.space-y-reverse | margin-bottom: 18rem |
| space-y-80 | margin-top: 20rem |
| space-y-80.space-y-reverse | margin-bottom: 20rem |
| space-y-96 | margin-top: 24rem |
| space-y-96.space-y-reverse | margin-bottom: 24rem |



*/
.space-x-px > :not([hidden]) ~ :not([hidden]) {
  margin-left: 0.0625rem;
}
.space-x-px.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 0.0625rem;
}

.space-x-0 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 0;
}
.space-x-0.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 0;
}

.space-x-none > :not([hidden]) ~ :not([hidden]) {
  margin-left: 0;
}
.space-x-none.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 0;
}

.space-x-0\.5 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 0.125rem;
}
.space-x-0\.5.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 0.125rem;
}

.space-x-1 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 0.25rem;
}
.space-x-1.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 0.25rem;
}

.space-x-1\.5 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 0.375rem;
}
.space-x-1\.5.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 0.375rem;
}

.space-x-2 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 0.5rem;
}
.space-x-2.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 0.5rem;
}

.space-x-2\.5 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 0.625rem;
}
.space-x-2\.5.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 0.625rem;
}

.space-x-3 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 0.75rem;
}
.space-x-3.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 0.75rem;
}

.space-x-3\.5 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 0.875rem;
}
.space-x-3\.5.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 0.875rem;
}

.space-x-4 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 1rem;
}
.space-x-4.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 1rem;
}

.space-x-5 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 1.25rem;
}
.space-x-5.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 1.25rem;
}

.space-x-6 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 1.5rem;
}
.space-x-6.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 1.5rem;
}

.space-x-7 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 1.75rem;
}
.space-x-7.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 1.75rem;
}

.space-x-8 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 2rem;
}
.space-x-8.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 2rem;
}

.space-x-9 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 2.25rem;
}
.space-x-9.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 2.25rem;
}

.space-x-10 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 2.5rem;
}
.space-x-10.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 2.5rem;
}

.space-x-11 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 2.75rem;
}
.space-x-11.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 2.75rem;
}

.space-x-12 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 3rem;
}
.space-x-12.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 3rem;
}

.space-x-14 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 3.5rem;
}
.space-x-14.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 3.5rem;
}

.space-x-16 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 4rem;
}
.space-x-16.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 4rem;
}

.space-x-18 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 4.5rem;
}
.space-x-18.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 4.5rem;
}

.space-x-20 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 5rem;
}
.space-x-20.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 5rem;
}

.space-x-24 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 6rem;
}
.space-x-24.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 6rem;
}

.space-x-28 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 7rem;
}
.space-x-28.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 7rem;
}

.space-x-32 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 8rem;
}
.space-x-32.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 8rem;
}

.space-x-36 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 9rem;
}
.space-x-36.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 9rem;
}

.space-x-40 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 10rem;
}
.space-x-40.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 10rem;
}

.space-x-44 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 11rem;
}
.space-x-44.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 11rem;
}

.space-x-48 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 12rem;
}
.space-x-48.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 12rem;
}

.space-x-52 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 13rem;
}
.space-x-52.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 13rem;
}

.space-x-56 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 14rem;
}
.space-x-56.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 14rem;
}

.space-x-60 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 15rem;
}
.space-x-60.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 15rem;
}

.space-x-64 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 16rem;
}
.space-x-64.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 16rem;
}

.space-x-72 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 18rem;
}
.space-x-72.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 18rem;
}

.space-x-80 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 20rem;
}
.space-x-80.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 20rem;
}

.space-x-96 > :not([hidden]) ~ :not([hidden]) {
  margin-left: 24rem;
}
.space-x-96.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-right: 24rem;
}

.space-y-px > :not([hidden]) ~ :not([hidden]) {
  margin-top: 0.0625rem;
}
.space-y-px.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 0.0625rem;
}

.space-y-0 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 0;
}
.space-y-0.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 0;
}

.space-y-none > :not([hidden]) ~ :not([hidden]) {
  margin-top: 0;
}
.space-y-none.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 0;
}

.space-y-0\.5 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 0.125rem;
}
.space-y-0\.5.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 0.125rem;
}

.space-y-1 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 0.25rem;
}
.space-y-1.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 0.25rem;
}

.space-y-1\.5 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 0.375rem;
}
.space-y-1\.5.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 0.375rem;
}

.space-y-2 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 0.5rem;
}
.space-y-2.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 0.5rem;
}

.space-y-2\.5 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 0.625rem;
}
.space-y-2\.5.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 0.625rem;
}

.space-y-3 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 0.75rem;
}
.space-y-3.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 0.75rem;
}

.space-y-3\.5 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 0.875rem;
}
.space-y-3\.5.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 0.875rem;
}

.space-y-4 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 1rem;
}
.space-y-4.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 1rem;
}

.space-y-5 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 1.25rem;
}
.space-y-5.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 1.25rem;
}

.space-y-6 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 1.5rem;
}
.space-y-6.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 1.5rem;
}

.space-y-7 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 1.75rem;
}
.space-y-7.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 1.75rem;
}

.space-y-8 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 2rem;
}
.space-y-8.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 2rem;
}

.space-y-9 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 2.25rem;
}
.space-y-9.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 2.25rem;
}

.space-y-10 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 2.5rem;
}
.space-y-10.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 2.5rem;
}

.space-y-11 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 2.75rem;
}
.space-y-11.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 2.75rem;
}

.space-y-12 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 3rem;
}
.space-y-12.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 3rem;
}

.space-y-14 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 3.5rem;
}
.space-y-14.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 3.5rem;
}

.space-y-16 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 4rem;
}
.space-y-16.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 4rem;
}

.space-y-18 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 4.5rem;
}
.space-y-18.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 4.5rem;
}

.space-y-20 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 5rem;
}
.space-y-20.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 5rem;
}

.space-y-24 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 6rem;
}
.space-y-24.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 6rem;
}

.space-y-28 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 7rem;
}
.space-y-28.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 7rem;
}

.space-y-32 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 8rem;
}
.space-y-32.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 8rem;
}

.space-y-36 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 9rem;
}
.space-y-36.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 9rem;
}

.space-y-40 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 10rem;
}
.space-y-40.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 10rem;
}

.space-y-44 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 11rem;
}
.space-y-44.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 11rem;
}

.space-y-48 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 12rem;
}
.space-y-48.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 12rem;
}

.space-y-52 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 13rem;
}
.space-y-52.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 13rem;
}

.space-y-56 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 14rem;
}
.space-y-56.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 14rem;
}

.space-y-60 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 15rem;
}
.space-y-60.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 15rem;
}

.space-y-64 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 16rem;
}
.space-y-64.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 16rem;
}

.space-y-72 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 18rem;
}
.space-y-72.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 18rem;
}

.space-y-80 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 20rem;
}
.space-y-80.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 20rem;
}

.space-y-96 > :not([hidden]) ~ :not([hidden]) {
  margin-top: 24rem;
}
.space-y-96.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
  margin-bottom: 24rem;
}

@media (max-width: 768px) {
  .m\:space-x-px > :not([hidden]) ~ :not([hidden]) {
    margin-left: 0.0625rem;
  }
  .m\:space-x-px.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 0.0625rem;
  }

  .m\:space-x-0 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 0;
  }
  .m\:space-x-0.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 0;
  }

  .m\:space-x-none > :not([hidden]) ~ :not([hidden]) {
    margin-left: 0;
  }
  .m\:space-x-none.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 0;
  }

  .m\:space-x-0\.5 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 0.125rem;
  }
  .m\:space-x-0\.5.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 0.125rem;
  }

  .m\:space-x-1 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 0.25rem;
  }
  .m\:space-x-1.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 0.25rem;
  }

  .m\:space-x-1\.5 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 0.375rem;
  }
  .m\:space-x-1\.5.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 0.375rem;
  }

  .m\:space-x-2 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 0.5rem;
  }
  .m\:space-x-2.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 0.5rem;
  }

  .m\:space-x-2\.5 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 0.625rem;
  }
  .m\:space-x-2\.5.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 0.625rem;
  }

  .m\:space-x-3 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 0.75rem;
  }
  .m\:space-x-3.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 0.75rem;
  }

  .m\:space-x-3\.5 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 0.875rem;
  }
  .m\:space-x-3\.5.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 0.875rem;
  }

  .m\:space-x-4 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 1rem;
  }
  .m\:space-x-4.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 1rem;
  }

  .m\:space-x-5 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 1.25rem;
  }
  .m\:space-x-5.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 1.25rem;
  }

  .m\:space-x-6 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 1.5rem;
  }
  .m\:space-x-6.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 1.5rem;
  }

  .m\:space-x-7 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 1.75rem;
  }
  .m\:space-x-7.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 1.75rem;
  }

  .m\:space-x-8 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 2rem;
  }
  .m\:space-x-8.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 2rem;
  }

  .m\:space-x-9 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 2.25rem;
  }
  .m\:space-x-9.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 2.25rem;
  }

  .m\:space-x-10 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 2.5rem;
  }
  .m\:space-x-10.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 2.5rem;
  }

  .m\:space-x-11 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 2.75rem;
  }
  .m\:space-x-11.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 2.75rem;
  }

  .m\:space-x-12 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 3rem;
  }
  .m\:space-x-12.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 3rem;
  }

  .m\:space-x-14 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 3.5rem;
  }
  .m\:space-x-14.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 3.5rem;
  }

  .m\:space-x-16 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 4rem;
  }
  .m\:space-x-16.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 4rem;
  }

  .m\:space-x-18 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 4.5rem;
  }
  .m\:space-x-18.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 4.5rem;
  }

  .m\:space-x-20 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 5rem;
  }
  .m\:space-x-20.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 5rem;
  }

  .m\:space-x-24 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 6rem;
  }
  .m\:space-x-24.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 6rem;
  }

  .m\:space-x-28 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 7rem;
  }
  .m\:space-x-28.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 7rem;
  }

  .m\:space-x-32 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 8rem;
  }
  .m\:space-x-32.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 8rem;
  }

  .m\:space-x-36 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 9rem;
  }
  .m\:space-x-36.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 9rem;
  }

  .m\:space-x-40 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 10rem;
  }
  .m\:space-x-40.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 10rem;
  }

  .m\:space-x-44 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 11rem;
  }
  .m\:space-x-44.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 11rem;
  }

  .m\:space-x-48 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 12rem;
  }
  .m\:space-x-48.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 12rem;
  }

  .m\:space-x-52 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 13rem;
  }
  .m\:space-x-52.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 13rem;
  }

  .m\:space-x-56 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 14rem;
  }
  .m\:space-x-56.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 14rem;
  }

  .m\:space-x-60 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 15rem;
  }
  .m\:space-x-60.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 15rem;
  }

  .m\:space-x-64 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 16rem;
  }
  .m\:space-x-64.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 16rem;
  }

  .m\:space-x-72 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 18rem;
  }
  .m\:space-x-72.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 18rem;
  }

  .m\:space-x-80 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 20rem;
  }
  .m\:space-x-80.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 20rem;
  }

  .m\:space-x-96 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 24rem;
  }
  .m\:space-x-96.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 24rem;
  }

  .m\:space-y-px > :not([hidden]) ~ :not([hidden]) {
    margin-top: 0.0625rem;
  }
  .m\:space-y-px.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 0.0625rem;
  }

  .m\:space-y-0 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 0;
  }
  .m\:space-y-0.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 0;
  }

  .m\:space-y-none > :not([hidden]) ~ :not([hidden]) {
    margin-top: 0;
  }
  .m\:space-y-none.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 0;
  }

  .m\:space-y-0\.5 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 0.125rem;
  }
  .m\:space-y-0\.5.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 0.125rem;
  }

  .m\:space-y-1 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 0.25rem;
  }
  .m\:space-y-1.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 0.25rem;
  }

  .m\:space-y-1\.5 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 0.375rem;
  }
  .m\:space-y-1\.5.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 0.375rem;
  }

  .m\:space-y-2 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 0.5rem;
  }
  .m\:space-y-2.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 0.5rem;
  }

  .m\:space-y-2\.5 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 0.625rem;
  }
  .m\:space-y-2\.5.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 0.625rem;
  }

  .m\:space-y-3 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 0.75rem;
  }
  .m\:space-y-3.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 0.75rem;
  }

  .m\:space-y-3\.5 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 0.875rem;
  }
  .m\:space-y-3\.5.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 0.875rem;
  }

  .m\:space-y-4 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 1rem;
  }
  .m\:space-y-4.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 1rem;
  }

  .m\:space-y-5 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 1.25rem;
  }
  .m\:space-y-5.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 1.25rem;
  }

  .m\:space-y-6 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 1.5rem;
  }
  .m\:space-y-6.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 1.5rem;
  }

  .m\:space-y-7 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 1.75rem;
  }
  .m\:space-y-7.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 1.75rem;
  }

  .m\:space-y-8 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 2rem;
  }
  .m\:space-y-8.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 2rem;
  }

  .m\:space-y-9 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 2.25rem;
  }
  .m\:space-y-9.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 2.25rem;
  }

  .m\:space-y-10 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 2.5rem;
  }
  .m\:space-y-10.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 2.5rem;
  }

  .m\:space-y-11 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 2.75rem;
  }
  .m\:space-y-11.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 2.75rem;
  }

  .m\:space-y-12 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 3rem;
  }
  .m\:space-y-12.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 3rem;
  }

  .m\:space-y-14 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 3.5rem;
  }
  .m\:space-y-14.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 3.5rem;
  }

  .m\:space-y-16 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 4rem;
  }
  .m\:space-y-16.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 4rem;
  }

  .m\:space-y-18 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 4.5rem;
  }
  .m\:space-y-18.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 4.5rem;
  }

  .m\:space-y-20 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 5rem;
  }
  .m\:space-y-20.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 5rem;
  }

  .m\:space-y-24 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 6rem;
  }
  .m\:space-y-24.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 6rem;
  }

  .m\:space-y-28 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 7rem;
  }
  .m\:space-y-28.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 7rem;
  }

  .m\:space-y-32 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 8rem;
  }
  .m\:space-y-32.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 8rem;
  }

  .m\:space-y-36 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 9rem;
  }
  .m\:space-y-36.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 9rem;
  }

  .m\:space-y-40 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 10rem;
  }
  .m\:space-y-40.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 10rem;
  }

  .m\:space-y-44 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 11rem;
  }
  .m\:space-y-44.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 11rem;
  }

  .m\:space-y-48 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 12rem;
  }
  .m\:space-y-48.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 12rem;
  }

  .m\:space-y-52 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 13rem;
  }
  .m\:space-y-52.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 13rem;
  }

  .m\:space-y-56 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 14rem;
  }
  .m\:space-y-56.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 14rem;
  }

  .m\:space-y-60 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 15rem;
  }
  .m\:space-y-60.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 15rem;
  }

  .m\:space-y-64 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 16rem;
  }
  .m\:space-y-64.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 16rem;
  }

  .m\:space-y-72 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 18rem;
  }
  .m\:space-y-72.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 18rem;
  }

  .m\:space-y-80 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 20rem;
  }
  .m\:space-y-80.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 20rem;
  }

  .m\:space-y-96 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 24rem;
  }
  .m\:space-y-96.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 24rem;
  }
}
@media (min-width: 769px) {
  .pc\:space-x-px > :not([hidden]) ~ :not([hidden]) {
    margin-left: 0.0625rem;
  }
  .pc\:space-x-px.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 0.0625rem;
  }

  .pc\:space-x-0 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 0;
  }
  .pc\:space-x-0.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 0;
  }

  .pc\:space-x-none > :not([hidden]) ~ :not([hidden]) {
    margin-left: 0;
  }
  .pc\:space-x-none.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 0;
  }

  .pc\:space-x-0\.5 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 0.125rem;
  }
  .pc\:space-x-0\.5.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 0.125rem;
  }

  .pc\:space-x-1 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 0.25rem;
  }
  .pc\:space-x-1.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 0.25rem;
  }

  .pc\:space-x-1\.5 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 0.375rem;
  }
  .pc\:space-x-1\.5.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 0.375rem;
  }

  .pc\:space-x-2 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 0.5rem;
  }
  .pc\:space-x-2.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 0.5rem;
  }

  .pc\:space-x-2\.5 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 0.625rem;
  }
  .pc\:space-x-2\.5.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 0.625rem;
  }

  .pc\:space-x-3 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 0.75rem;
  }
  .pc\:space-x-3.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 0.75rem;
  }

  .pc\:space-x-3\.5 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 0.875rem;
  }
  .pc\:space-x-3\.5.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 0.875rem;
  }

  .pc\:space-x-4 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 1rem;
  }
  .pc\:space-x-4.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 1rem;
  }

  .pc\:space-x-5 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 1.25rem;
  }
  .pc\:space-x-5.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 1.25rem;
  }

  .pc\:space-x-6 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 1.5rem;
  }
  .pc\:space-x-6.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 1.5rem;
  }

  .pc\:space-x-7 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 1.75rem;
  }
  .pc\:space-x-7.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 1.75rem;
  }

  .pc\:space-x-8 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 2rem;
  }
  .pc\:space-x-8.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 2rem;
  }

  .pc\:space-x-9 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 2.25rem;
  }
  .pc\:space-x-9.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 2.25rem;
  }

  .pc\:space-x-10 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 2.5rem;
  }
  .pc\:space-x-10.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 2.5rem;
  }

  .pc\:space-x-11 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 2.75rem;
  }
  .pc\:space-x-11.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 2.75rem;
  }

  .pc\:space-x-12 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 3rem;
  }
  .pc\:space-x-12.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 3rem;
  }

  .pc\:space-x-14 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 3.5rem;
  }
  .pc\:space-x-14.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 3.5rem;
  }

  .pc\:space-x-16 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 4rem;
  }
  .pc\:space-x-16.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 4rem;
  }

  .pc\:space-x-18 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 4.5rem;
  }
  .pc\:space-x-18.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 4.5rem;
  }

  .pc\:space-x-20 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 5rem;
  }
  .pc\:space-x-20.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 5rem;
  }

  .pc\:space-x-24 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 6rem;
  }
  .pc\:space-x-24.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 6rem;
  }

  .pc\:space-x-28 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 7rem;
  }
  .pc\:space-x-28.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 7rem;
  }

  .pc\:space-x-32 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 8rem;
  }
  .pc\:space-x-32.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 8rem;
  }

  .pc\:space-x-36 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 9rem;
  }
  .pc\:space-x-36.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 9rem;
  }

  .pc\:space-x-40 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 10rem;
  }
  .pc\:space-x-40.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 10rem;
  }

  .pc\:space-x-44 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 11rem;
  }
  .pc\:space-x-44.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 11rem;
  }

  .pc\:space-x-48 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 12rem;
  }
  .pc\:space-x-48.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 12rem;
  }

  .pc\:space-x-52 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 13rem;
  }
  .pc\:space-x-52.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 13rem;
  }

  .pc\:space-x-56 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 14rem;
  }
  .pc\:space-x-56.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 14rem;
  }

  .pc\:space-x-60 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 15rem;
  }
  .pc\:space-x-60.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 15rem;
  }

  .pc\:space-x-64 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 16rem;
  }
  .pc\:space-x-64.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 16rem;
  }

  .pc\:space-x-72 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 18rem;
  }
  .pc\:space-x-72.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 18rem;
  }

  .pc\:space-x-80 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 20rem;
  }
  .pc\:space-x-80.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 20rem;
  }

  .pc\:space-x-96 > :not([hidden]) ~ :not([hidden]) {
    margin-left: 24rem;
  }
  .pc\:space-x-96.space-x-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-right: 24rem;
  }

  .pc\:space-y-px > :not([hidden]) ~ :not([hidden]) {
    margin-top: 0.0625rem;
  }
  .pc\:space-y-px.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 0.0625rem;
  }

  .pc\:space-y-0 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 0;
  }
  .pc\:space-y-0.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 0;
  }

  .pc\:space-y-none > :not([hidden]) ~ :not([hidden]) {
    margin-top: 0;
  }
  .pc\:space-y-none.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 0;
  }

  .pc\:space-y-0\.5 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 0.125rem;
  }
  .pc\:space-y-0\.5.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 0.125rem;
  }

  .pc\:space-y-1 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 0.25rem;
  }
  .pc\:space-y-1.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 0.25rem;
  }

  .pc\:space-y-1\.5 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 0.375rem;
  }
  .pc\:space-y-1\.5.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 0.375rem;
  }

  .pc\:space-y-2 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 0.5rem;
  }
  .pc\:space-y-2.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 0.5rem;
  }

  .pc\:space-y-2\.5 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 0.625rem;
  }
  .pc\:space-y-2\.5.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 0.625rem;
  }

  .pc\:space-y-3 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 0.75rem;
  }
  .pc\:space-y-3.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 0.75rem;
  }

  .pc\:space-y-3\.5 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 0.875rem;
  }
  .pc\:space-y-3\.5.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 0.875rem;
  }

  .pc\:space-y-4 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 1rem;
  }
  .pc\:space-y-4.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 1rem;
  }

  .pc\:space-y-5 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 1.25rem;
  }
  .pc\:space-y-5.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 1.25rem;
  }

  .pc\:space-y-6 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 1.5rem;
  }
  .pc\:space-y-6.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 1.5rem;
  }

  .pc\:space-y-7 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 1.75rem;
  }
  .pc\:space-y-7.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 1.75rem;
  }

  .pc\:space-y-8 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 2rem;
  }
  .pc\:space-y-8.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 2rem;
  }

  .pc\:space-y-9 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 2.25rem;
  }
  .pc\:space-y-9.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 2.25rem;
  }

  .pc\:space-y-10 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 2.5rem;
  }
  .pc\:space-y-10.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 2.5rem;
  }

  .pc\:space-y-11 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 2.75rem;
  }
  .pc\:space-y-11.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 2.75rem;
  }

  .pc\:space-y-12 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 3rem;
  }
  .pc\:space-y-12.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 3rem;
  }

  .pc\:space-y-14 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 3.5rem;
  }
  .pc\:space-y-14.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 3.5rem;
  }

  .pc\:space-y-16 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 4rem;
  }
  .pc\:space-y-16.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 4rem;
  }

  .pc\:space-y-18 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 4.5rem;
  }
  .pc\:space-y-18.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 4.5rem;
  }

  .pc\:space-y-20 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 5rem;
  }
  .pc\:space-y-20.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 5rem;
  }

  .pc\:space-y-24 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 6rem;
  }
  .pc\:space-y-24.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 6rem;
  }

  .pc\:space-y-28 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 7rem;
  }
  .pc\:space-y-28.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 7rem;
  }

  .pc\:space-y-32 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 8rem;
  }
  .pc\:space-y-32.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 8rem;
  }

  .pc\:space-y-36 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 9rem;
  }
  .pc\:space-y-36.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 9rem;
  }

  .pc\:space-y-40 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 10rem;
  }
  .pc\:space-y-40.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 10rem;
  }

  .pc\:space-y-44 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 11rem;
  }
  .pc\:space-y-44.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 11rem;
  }

  .pc\:space-y-48 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 12rem;
  }
  .pc\:space-y-48.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 12rem;
  }

  .pc\:space-y-52 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 13rem;
  }
  .pc\:space-y-52.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 13rem;
  }

  .pc\:space-y-56 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 14rem;
  }
  .pc\:space-y-56.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 14rem;
  }

  .pc\:space-y-60 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 15rem;
  }
  .pc\:space-y-60.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 15rem;
  }

  .pc\:space-y-64 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 16rem;
  }
  .pc\:space-y-64.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 16rem;
  }

  .pc\:space-y-72 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 18rem;
  }
  .pc\:space-y-72.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 18rem;
  }

  .pc\:space-y-80 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 20rem;
  }
  .pc\:space-y-80.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 20rem;
  }

  .pc\:space-y-96 > :not([hidden]) ~ :not([hidden]) {
    margin-top: 24rem;
  }
  .pc\:space-y-96.space-y-reverse > :not([hidden]) ~ :not([hidden]) {
    margin-bottom: 24rem;
  }
}
/*!markdown

---
title: Width
---

| Class       | Properties               |
| ----------- | ------------------------ |
| w-px | width: 0.0625rem |
| w-0 | width: 0 |
| w-none | width: 0 |
| w-0\.5 | width: 0.125rem |
| w-1 | width: 0.25rem |
| w-1\.5 | width: 0.375rem |
| w-2 | width: 0.5rem |
| w-2\.5 | width: 0.625rem |
| w-3 | width: 0.75rem |
| w-3\.5 | width: 0.875rem |
| w-4 | width: 1rem |
| w-5 | width: 1.25rem |
| w-6 | width: 1.5rem |
| w-7 | width: 1.75rem |
| w-8 | width: 2rem |
| w-9 | width: 2.25rem |
| w-10 | width: 2.5rem |
| w-11 | width: 2.75rem |
| w-12 | width: 3rem |
| w-14 | width: 3.5rem |
| w-16 | width: 4rem |
| w-18 | width: 4.5rem |
| w-20 | width: 5rem |
| w-24 | width: 6rem |
| w-28 | width: 7rem |
| w-32 | width: 8rem |
| w-36 | width: 9rem |
| w-40 | width: 10rem |
| w-44 | width: 11rem |
| w-48 | width: 12rem |
| w-52 | width: 13rem |
| w-56 | width: 14rem |
| w-60 | width: 15rem |
| w-64 | width: 16rem |
| w-72 | width: 18rem |
| w-80 | width: 20rem |
| w-96 | width: 24rem |
| w-auto | width: auto |
| w-1x | width: 1em |
| w-2x | width: 2em |
| w-3x | width: 3em |
| w-1\/2 | width: 50% |
| w-1\/3 | width: 33.333333% |
| w-2\/3 | width: 66.666667% |
| w-1\/4 | width: 25% |
| w-2\/4 | width: 50% |
| w-3\/4 | width: 75% |
| w-1\/5 | width: 20% |
| w-2\/5 | width: 40% |
| w-3\/5 | width: 60% |
| w-4\/5 | width: 80% |
| w-1\/6 | width: 16.666667% |
| w-2\/6 | width: 33.333333% |
| w-3\/6 | width: 50% |
| w-4\/6 | width: 66.666667% |
| w-5\/6 | width: 83.333333% |
| w-1\/12 | width: 8.333333% |
| w-2\/12 | width: 16.666667% |
| w-3\/12 | width: 25% |
| w-4\/12 | width: 33.333333% |
| w-5\/12 | width: 41.666667% |
| w-6\/12 | width: 50% |
| w-7\/12 | width: 58.333333% |
| w-8\/12 | width: 66.666667% |
| w-9\/12 | width: 75% |
| w-10\/12 | width: 83.333333% |
| w-11\/12 | width: 91.666667% |
| w-full | width: 100% |
| w-screen | width: 100vw |
| w-min | width: min-content |
| w-max | width: max-content |
| min-w-0 | min-width: 0px |
| min-w-full | min-width: 100% |
| min-w-min | min-width: min-content |
| min-w-max | min-width: max-content |
| max-w-none | max-width: none |
| max-w-0 | max-width: 0rem |
| max-w-xs | max-width: 20rem |
| max-w-sm | max-width: 24rem |
| max-w-md | max-width: 28rem |
| max-w-lg | max-width: 32rem |
| max-w-xl | max-width: 36rem |
| max-w-2xl | max-width: 42rem |
| max-w-3xl | max-width: 48rem |
| max-w-4xl | max-width: 56rem |
| max-w-5xl | max-width: 64rem |
| max-w-6xl | max-width: 72rem |
| max-w-7xl | max-width: 80rem |
| max-w-full | max-width: 100% |
| max-w-min | max-width: min-content |
| max-w-max | max-width: max-content |
| max-w-prose | max-width: 65ch |


*/
.w-px {
  width: 0.0625rem;
}

.w-0 {
  width: 0;
}

.w-none {
  width: 0;
}

.w-0\.5 {
  width: 0.125rem;
}

.w-1 {
  width: 0.25rem;
}

.w-1\.5 {
  width: 0.375rem;
}

.w-2 {
  width: 0.5rem;
}

.w-2\.5 {
  width: 0.625rem;
}

.w-3 {
  width: 0.75rem;
}

.w-3\.5 {
  width: 0.875rem;
}

.w-4 {
  width: 1rem;
}

.w-5 {
  width: 1.25rem;
}

.w-6 {
  width: 1.5rem;
}

.w-7 {
  width: 1.75rem;
}

.w-8 {
  width: 2rem;
}

.w-9 {
  width: 2.25rem;
}

.w-10 {
  width: 2.5rem;
}

.w-11 {
  width: 2.75rem;
}

.w-12 {
  width: 3rem;
}

.w-14 {
  width: 3.5rem;
}

.w-16 {
  width: 4rem;
}

.w-18 {
  width: 4.5rem;
}

.w-20 {
  width: 5rem;
}

.w-24 {
  width: 6rem;
}

.w-28 {
  width: 7rem;
}

.w-32 {
  width: 8rem;
}

.w-36 {
  width: 9rem;
}

.w-40 {
  width: 10rem;
}

.w-44 {
  width: 11rem;
}

.w-48 {
  width: 12rem;
}

.w-52 {
  width: 13rem;
}

.w-56 {
  width: 14rem;
}

.w-60 {
  width: 15rem;
}

.w-64 {
  width: 16rem;
}

.w-72 {
  width: 18rem;
}

.w-80 {
  width: 20rem;
}

.w-96 {
  width: 24rem;
}

.w-auto {
  width: auto;
}

.w-1x {
  width: 1em;
}

.w-2x {
  width: 2em;
}

.w-3x {
  width: 3em;
}

.w-1\/2 {
  width: 50%;
}

.w-1\/3 {
  width: 33.333333%;
}

.w-2\/3 {
  width: 66.666667%;
}

.w-1\/4 {
  width: 25%;
}

.w-2\/4 {
  width: 50%;
}

.w-3\/4 {
  width: 75%;
}

.w-1\/5 {
  width: 20%;
}

.w-2\/5 {
  width: 40%;
}

.w-3\/5 {
  width: 60%;
}

.w-4\/5 {
  width: 80%;
}

.w-1\/6 {
  width: 16.666667%;
}

.w-2\/6 {
  width: 33.333333%;
}

.w-3\/6 {
  width: 50%;
}

.w-4\/6 {
  width: 66.666667%;
}

.w-5\/6 {
  width: 83.333333%;
}

.w-1\/12 {
  width: 8.333333%;
}

.w-2\/12 {
  width: 16.666667%;
}

.w-3\/12 {
  width: 25%;
}

.w-4\/12 {
  width: 33.333333%;
}

.w-5\/12 {
  width: 41.666667%;
}

.w-6\/12 {
  width: 50%;
}

.w-7\/12 {
  width: 58.333333%;
}

.w-8\/12 {
  width: 66.666667%;
}

.w-9\/12 {
  width: 75%;
}

.w-10\/12 {
  width: 83.333333%;
}

.w-11\/12 {
  width: 91.666667%;
}

.w-full {
  width: 100%;
}

.w-screen {
  width: 100vw;
}

.w-min {
  width: min-content;
}

.w-max {
  width: max-content;
}

.min-w-0 {
  min-width: 0px;
}

.min-w-full {
  min-width: 100%;
}

.min-w-min {
  min-width: min-content;
}

.min-w-max {
  min-width: max-content;
}

.max-w-none {
  max-width: none;
}

.max-w-0 {
  max-width: 0rem;
}

.max-w-xs {
  max-width: 20rem;
}

.max-w-sm {
  max-width: 24rem;
}

.max-w-md {
  max-width: 28rem;
}

.max-w-lg {
  max-width: 32rem;
}

.max-w-xl {
  max-width: 36rem;
}

.max-w-2xl {
  max-width: 42rem;
}

.max-w-3xl {
  max-width: 48rem;
}

.max-w-4xl {
  max-width: 56rem;
}

.max-w-5xl {
  max-width: 64rem;
}

.max-w-6xl {
  max-width: 72rem;
}

.max-w-7xl {
  max-width: 80rem;
}

.max-w-full {
  max-width: 100%;
}

.max-w-min {
  max-width: min-content;
}

.max-w-max {
  max-width: max-content;
}

.max-w-prose {
  max-width: 65ch;
}

@media (max-width: 768px) {
  .m\:w-px {
    width: 0.0625rem;
  }

  .m\:w-0 {
    width: 0;
  }

  .m\:w-none {
    width: 0;
  }

  .m\:w-0\.5 {
    width: 0.125rem;
  }

  .m\:w-1 {
    width: 0.25rem;
  }

  .m\:w-1\.5 {
    width: 0.375rem;
  }

  .m\:w-2 {
    width: 0.5rem;
  }

  .m\:w-2\.5 {
    width: 0.625rem;
  }

  .m\:w-3 {
    width: 0.75rem;
  }

  .m\:w-3\.5 {
    width: 0.875rem;
  }

  .m\:w-4 {
    width: 1rem;
  }

  .m\:w-5 {
    width: 1.25rem;
  }

  .m\:w-6 {
    width: 1.5rem;
  }

  .m\:w-7 {
    width: 1.75rem;
  }

  .m\:w-8 {
    width: 2rem;
  }

  .m\:w-9 {
    width: 2.25rem;
  }

  .m\:w-10 {
    width: 2.5rem;
  }

  .m\:w-11 {
    width: 2.75rem;
  }

  .m\:w-12 {
    width: 3rem;
  }

  .m\:w-14 {
    width: 3.5rem;
  }

  .m\:w-16 {
    width: 4rem;
  }

  .m\:w-18 {
    width: 4.5rem;
  }

  .m\:w-20 {
    width: 5rem;
  }

  .m\:w-24 {
    width: 6rem;
  }

  .m\:w-28 {
    width: 7rem;
  }

  .m\:w-32 {
    width: 8rem;
  }

  .m\:w-36 {
    width: 9rem;
  }

  .m\:w-40 {
    width: 10rem;
  }

  .m\:w-44 {
    width: 11rem;
  }

  .m\:w-48 {
    width: 12rem;
  }

  .m\:w-52 {
    width: 13rem;
  }

  .m\:w-56 {
    width: 14rem;
  }

  .m\:w-60 {
    width: 15rem;
  }

  .m\:w-64 {
    width: 16rem;
  }

  .m\:w-72 {
    width: 18rem;
  }

  .m\:w-80 {
    width: 20rem;
  }

  .m\:w-96 {
    width: 24rem;
  }

  .m\:w-auto {
    width: auto;
  }

  .m\:w-1x {
    width: 1em;
  }

  .m\:w-2x {
    width: 2em;
  }

  .m\:w-3x {
    width: 3em;
  }

  .m\:w-1\/2 {
    width: 50%;
  }

  .m\:w-1\/3 {
    width: 33.333333%;
  }

  .m\:w-2\/3 {
    width: 66.666667%;
  }

  .m\:w-1\/4 {
    width: 25%;
  }

  .m\:w-2\/4 {
    width: 50%;
  }

  .m\:w-3\/4 {
    width: 75%;
  }

  .m\:w-1\/5 {
    width: 20%;
  }

  .m\:w-2\/5 {
    width: 40%;
  }

  .m\:w-3\/5 {
    width: 60%;
  }

  .m\:w-4\/5 {
    width: 80%;
  }

  .m\:w-1\/6 {
    width: 16.666667%;
  }

  .m\:w-2\/6 {
    width: 33.333333%;
  }

  .m\:w-3\/6 {
    width: 50%;
  }

  .m\:w-4\/6 {
    width: 66.666667%;
  }

  .m\:w-5\/6 {
    width: 83.333333%;
  }

  .m\:w-1\/12 {
    width: 8.333333%;
  }

  .m\:w-2\/12 {
    width: 16.666667%;
  }

  .m\:w-3\/12 {
    width: 25%;
  }

  .m\:w-4\/12 {
    width: 33.333333%;
  }

  .m\:w-5\/12 {
    width: 41.666667%;
  }

  .m\:w-6\/12 {
    width: 50%;
  }

  .m\:w-7\/12 {
    width: 58.333333%;
  }

  .m\:w-8\/12 {
    width: 66.666667%;
  }

  .m\:w-9\/12 {
    width: 75%;
  }

  .m\:w-10\/12 {
    width: 83.333333%;
  }

  .m\:w-11\/12 {
    width: 91.666667%;
  }

  .m\:w-full {
    width: 100%;
  }

  .m\:w-screen {
    width: 100vw;
  }

  .m\:w-min {
    width: min-content;
  }

  .m\:w-max {
    width: max-content;
  }

  .m\:min-w-0 {
    min-width: 0px;
  }

  .m\:min-w-full {
    min-width: 100%;
  }

  .m\:min-w-min {
    min-width: min-content;
  }

  .m\:min-w-max {
    min-width: max-content;
  }

  .m\:max-w-none {
    max-width: none;
  }

  .m\:max-w-0 {
    max-width: 0rem;
  }

  .m\:max-w-xs {
    max-width: 20rem;
  }

  .m\:max-w-sm {
    max-width: 24rem;
  }

  .m\:max-w-md {
    max-width: 28rem;
  }

  .m\:max-w-lg {
    max-width: 32rem;
  }

  .m\:max-w-xl {
    max-width: 36rem;
  }

  .m\:max-w-2xl {
    max-width: 42rem;
  }

  .m\:max-w-3xl {
    max-width: 48rem;
  }

  .m\:max-w-4xl {
    max-width: 56rem;
  }

  .m\:max-w-5xl {
    max-width: 64rem;
  }

  .m\:max-w-6xl {
    max-width: 72rem;
  }

  .m\:max-w-7xl {
    max-width: 80rem;
  }

  .m\:max-w-full {
    max-width: 100%;
  }

  .m\:max-w-min {
    max-width: min-content;
  }

  .m\:max-w-max {
    max-width: max-content;
  }

  .m\:max-w-prose {
    max-width: 65ch;
  }
}
@media (min-width: 769px) {
  .pc\:w-px {
    width: 0.0625rem;
  }

  .pc\:w-0 {
    width: 0;
  }

  .pc\:w-none {
    width: 0;
  }

  .pc\:w-0\.5 {
    width: 0.125rem;
  }

  .pc\:w-1 {
    width: 0.25rem;
  }

  .pc\:w-1\.5 {
    width: 0.375rem;
  }

  .pc\:w-2 {
    width: 0.5rem;
  }

  .pc\:w-2\.5 {
    width: 0.625rem;
  }

  .pc\:w-3 {
    width: 0.75rem;
  }

  .pc\:w-3\.5 {
    width: 0.875rem;
  }

  .pc\:w-4 {
    width: 1rem;
  }

  .pc\:w-5 {
    width: 1.25rem;
  }

  .pc\:w-6 {
    width: 1.5rem;
  }

  .pc\:w-7 {
    width: 1.75rem;
  }

  .pc\:w-8 {
    width: 2rem;
  }

  .pc\:w-9 {
    width: 2.25rem;
  }

  .pc\:w-10 {
    width: 2.5rem;
  }

  .pc\:w-11 {
    width: 2.75rem;
  }

  .pc\:w-12 {
    width: 3rem;
  }

  .pc\:w-14 {
    width: 3.5rem;
  }

  .pc\:w-16 {
    width: 4rem;
  }

  .pc\:w-18 {
    width: 4.5rem;
  }

  .pc\:w-20 {
    width: 5rem;
  }

  .pc\:w-24 {
    width: 6rem;
  }

  .pc\:w-28 {
    width: 7rem;
  }

  .pc\:w-32 {
    width: 8rem;
  }

  .pc\:w-36 {
    width: 9rem;
  }

  .pc\:w-40 {
    width: 10rem;
  }

  .pc\:w-44 {
    width: 11rem;
  }

  .pc\:w-48 {
    width: 12rem;
  }

  .pc\:w-52 {
    width: 13rem;
  }

  .pc\:w-56 {
    width: 14rem;
  }

  .pc\:w-60 {
    width: 15rem;
  }

  .pc\:w-64 {
    width: 16rem;
  }

  .pc\:w-72 {
    width: 18rem;
  }

  .pc\:w-80 {
    width: 20rem;
  }

  .pc\:w-96 {
    width: 24rem;
  }

  .pc\:w-auto {
    width: auto;
  }

  .pc\:w-1x {
    width: 1em;
  }

  .pc\:w-2x {
    width: 2em;
  }

  .pc\:w-3x {
    width: 3em;
  }

  .pc\:w-1\/2 {
    width: 50%;
  }

  .pc\:w-1\/3 {
    width: 33.333333%;
  }

  .pc\:w-2\/3 {
    width: 66.666667%;
  }

  .pc\:w-1\/4 {
    width: 25%;
  }

  .pc\:w-2\/4 {
    width: 50%;
  }

  .pc\:w-3\/4 {
    width: 75%;
  }

  .pc\:w-1\/5 {
    width: 20%;
  }

  .pc\:w-2\/5 {
    width: 40%;
  }

  .pc\:w-3\/5 {
    width: 60%;
  }

  .pc\:w-4\/5 {
    width: 80%;
  }

  .pc\:w-1\/6 {
    width: 16.666667%;
  }

  .pc\:w-2\/6 {
    width: 33.333333%;
  }

  .pc\:w-3\/6 {
    width: 50%;
  }

  .pc\:w-4\/6 {
    width: 66.666667%;
  }

  .pc\:w-5\/6 {
    width: 83.333333%;
  }

  .pc\:w-1\/12 {
    width: 8.333333%;
  }

  .pc\:w-2\/12 {
    width: 16.666667%;
  }

  .pc\:w-3\/12 {
    width: 25%;
  }

  .pc\:w-4\/12 {
    width: 33.333333%;
  }

  .pc\:w-5\/12 {
    width: 41.666667%;
  }

  .pc\:w-6\/12 {
    width: 50%;
  }

  .pc\:w-7\/12 {
    width: 58.333333%;
  }

  .pc\:w-8\/12 {
    width: 66.666667%;
  }

  .pc\:w-9\/12 {
    width: 75%;
  }

  .pc\:w-10\/12 {
    width: 83.333333%;
  }

  .pc\:w-11\/12 {
    width: 91.666667%;
  }

  .pc\:w-full {
    width: 100%;
  }

  .pc\:w-screen {
    width: 100vw;
  }

  .pc\:w-min {
    width: min-content;
  }

  .pc\:w-max {
    width: max-content;
  }

  .pc\:min-w-0 {
    min-width: 0px;
  }

  .pc\:min-w-full {
    min-width: 100%;
  }

  .pc\:min-w-min {
    min-width: min-content;
  }

  .pc\:min-w-max {
    min-width: max-content;
  }

  .pc\:max-w-none {
    max-width: none;
  }

  .pc\:max-w-0 {
    max-width: 0rem;
  }

  .pc\:max-w-xs {
    max-width: 20rem;
  }

  .pc\:max-w-sm {
    max-width: 24rem;
  }

  .pc\:max-w-md {
    max-width: 28rem;
  }

  .pc\:max-w-lg {
    max-width: 32rem;
  }

  .pc\:max-w-xl {
    max-width: 36rem;
  }

  .pc\:max-w-2xl {
    max-width: 42rem;
  }

  .pc\:max-w-3xl {
    max-width: 48rem;
  }

  .pc\:max-w-4xl {
    max-width: 56rem;
  }

  .pc\:max-w-5xl {
    max-width: 64rem;
  }

  .pc\:max-w-6xl {
    max-width: 72rem;
  }

  .pc\:max-w-7xl {
    max-width: 80rem;
  }

  .pc\:max-w-full {
    max-width: 100%;
  }

  .pc\:max-w-min {
    max-width: min-content;
  }

  .pc\:max-w-max {
    max-width: max-content;
  }

  .pc\:max-w-prose {
    max-width: 65ch;
  }
}
/*!markdown

---
title: Height
---

| Class       | Properties               |
| ----------- | ------------------------ |
| h-px | height: 0.0625rem |
| h-0 | height: 0 |
| h-none | height: 0 |
| h-0\.5 | height: 0.125rem |
| h-1 | height: 0.25rem |
| h-1\.5 | height: 0.375rem |
| h-2 | height: 0.5rem |
| h-2\.5 | height: 0.625rem |
| h-3 | height: 0.75rem |
| h-3\.5 | height: 0.875rem |
| h-4 | height: 1rem |
| h-5 | height: 1.25rem |
| h-6 | height: 1.5rem |
| h-7 | height: 1.75rem |
| h-8 | height: 2rem |
| h-9 | height: 2.25rem |
| h-10 | height: 2.5rem |
| h-11 | height: 2.75rem |
| h-12 | height: 3rem |
| h-14 | height: 3.5rem |
| h-16 | height: 4rem |
| h-18 | height: 4.5rem |
| h-20 | height: 5rem |
| h-24 | height: 6rem |
| h-28 | height: 7rem |
| h-32 | height: 8rem |
| h-36 | height: 9rem |
| h-40 | height: 10rem |
| h-44 | height: 11rem |
| h-48 | height: 12rem |
| h-52 | height: 13rem |
| h-56 | height: 14rem |
| h-60 | height: 15rem |
| h-64 | height: 16rem |
| h-72 | height: 18rem |
| h-80 | height: 20rem |
| h-96 | height: 24rem |
| h-auto | height: auto |
| h-1\/2 | height: 50% |
| h-1\/3 | height: 33.333333% |
| h-2\/3 | height: 66.666667% |
| h-1\/4 | height: 25% |
| h-2\/4 | height: 50% |
| h-3\/4 | height: 75% |
| h-1\/5 | height: 20% |
| h-2\/5 | height: 40% |
| h-3\/5 | height: 60% |
| h-4\/5 | height: 80% |
| h-1\/6 | height: 16.666667% |
| h-2\/6 | height: 33.333333% |
| h-3\/6 | height: 50% |
| h-4\/6 | height: 66.666667% |
| h-5\/6 | height: 83.333333% |
| h-full | height: 100% |
| h-screen | height: 100vh |
| min-h-0 | min-height: 0px |
| min-h-full | min-height: 100% |
| min-h-screen | min-height: 100vh |
| max-h-px | max-height: 0.0625rem |
| max-h-0 | max-height: 0 |
| max-h-none | max-height: 0 |
| max-h-0\.5 | max-height: 0.125rem |
| max-h-1 | max-height: 0.25rem |
| max-h-1\.5 | max-height: 0.375rem |
| max-h-2 | max-height: 0.5rem |
| max-h-2\.5 | max-height: 0.625rem |
| max-h-3 | max-height: 0.75rem |
| max-h-3\.5 | max-height: 0.875rem |
| max-h-4 | max-height: 1rem |
| max-h-5 | max-height: 1.25rem |
| max-h-6 | max-height: 1.5rem |
| max-h-7 | max-height: 1.75rem |
| max-h-8 | max-height: 2rem |
| max-h-9 | max-height: 2.25rem |
| max-h-10 | max-height: 2.5rem |
| max-h-11 | max-height: 2.75rem |
| max-h-12 | max-height: 3rem |
| max-h-14 | max-height: 3.5rem |
| max-h-16 | max-height: 4rem |
| max-h-18 | max-height: 4.5rem |
| max-h-20 | max-height: 5rem |
| max-h-24 | max-height: 6rem |
| max-h-28 | max-height: 7rem |
| max-h-32 | max-height: 8rem |
| max-h-36 | max-height: 9rem |
| max-h-40 | max-height: 10rem |
| max-h-44 | max-height: 11rem |
| max-h-48 | max-height: 12rem |
| max-h-52 | max-height: 13rem |
| max-h-56 | max-height: 14rem |
| max-h-60 | max-height: 15rem |
| max-h-64 | max-height: 16rem |
| max-h-72 | max-height: 18rem |
| max-h-80 | max-height: 20rem |
| max-h-96 | max-height: 24rem |
| max-h-full | max-height: 100% |
| max-h-screen | max-height: 100vh |


*/
.h-px {
  height: 0.0625rem;
}

.h-0 {
  height: 0;
}

.h-none {
  height: 0;
}

.h-0\.5 {
  height: 0.125rem;
}

.h-1 {
  height: 0.25rem;
}

.h-1\.5 {
  height: 0.375rem;
}

.h-2 {
  height: 0.5rem;
}

.h-2\.5 {
  height: 0.625rem;
}

.h-3 {
  height: 0.75rem;
}

.h-3\.5 {
  height: 0.875rem;
}

.h-4 {
  height: 1rem;
}

.h-5 {
  height: 1.25rem;
}

.h-6 {
  height: 1.5rem;
}

.h-7 {
  height: 1.75rem;
}

.h-8 {
  height: 2rem;
}

.h-9 {
  height: 2.25rem;
}

.h-10 {
  height: 2.5rem;
}

.h-11 {
  height: 2.75rem;
}

.h-12 {
  height: 3rem;
}

.h-14 {
  height: 3.5rem;
}

.h-16 {
  height: 4rem;
}

.h-18 {
  height: 4.5rem;
}

.h-20 {
  height: 5rem;
}

.h-24 {
  height: 6rem;
}

.h-28 {
  height: 7rem;
}

.h-32 {
  height: 8rem;
}

.h-36 {
  height: 9rem;
}

.h-40 {
  height: 10rem;
}

.h-44 {
  height: 11rem;
}

.h-48 {
  height: 12rem;
}

.h-52 {
  height: 13rem;
}

.h-56 {
  height: 14rem;
}

.h-60 {
  height: 15rem;
}

.h-64 {
  height: 16rem;
}

.h-72 {
  height: 18rem;
}

.h-80 {
  height: 20rem;
}

.h-96 {
  height: 24rem;
}

.h-auto {
  height: auto;
}

.h-1\/2 {
  height: 50%;
}

.h-1\/3 {
  height: 33.333333%;
}

.h-2\/3 {
  height: 66.666667%;
}

.h-1\/4 {
  height: 25%;
}

.h-2\/4 {
  height: 50%;
}

.h-3\/4 {
  height: 75%;
}

.h-1\/5 {
  height: 20%;
}

.h-2\/5 {
  height: 40%;
}

.h-3\/5 {
  height: 60%;
}

.h-4\/5 {
  height: 80%;
}

.h-1\/6 {
  height: 16.666667%;
}

.h-2\/6 {
  height: 33.333333%;
}

.h-3\/6 {
  height: 50%;
}

.h-4\/6 {
  height: 66.666667%;
}

.h-5\/6 {
  height: 83.333333%;
}

.h-full {
  height: 100%;
}

.h-screen {
  height: 100vh;
}

.min-h-0 {
  min-height: 0px;
}

.min-h-full {
  min-height: 100%;
}

.min-h-screen {
  min-height: 100vh;
}

.max-h-px {
  max-height: 0.0625rem;
}

.max-h-0 {
  max-height: 0;
}

.max-h-none {
  max-height: 0;
}

.max-h-0\.5 {
  max-height: 0.125rem;
}

.max-h-1 {
  max-height: 0.25rem;
}

.max-h-1\.5 {
  max-height: 0.375rem;
}

.max-h-2 {
  max-height: 0.5rem;
}

.max-h-2\.5 {
  max-height: 0.625rem;
}

.max-h-3 {
  max-height: 0.75rem;
}

.max-h-3\.5 {
  max-height: 0.875rem;
}

.max-h-4 {
  max-height: 1rem;
}

.max-h-5 {
  max-height: 1.25rem;
}

.max-h-6 {
  max-height: 1.5rem;
}

.max-h-7 {
  max-height: 1.75rem;
}

.max-h-8 {
  max-height: 2rem;
}

.max-h-9 {
  max-height: 2.25rem;
}

.max-h-10 {
  max-height: 2.5rem;
}

.max-h-11 {
  max-height: 2.75rem;
}

.max-h-12 {
  max-height: 3rem;
}

.max-h-14 {
  max-height: 3.5rem;
}

.max-h-16 {
  max-height: 4rem;
}

.max-h-18 {
  max-height: 4.5rem;
}

.max-h-20 {
  max-height: 5rem;
}

.max-h-24 {
  max-height: 6rem;
}

.max-h-28 {
  max-height: 7rem;
}

.max-h-32 {
  max-height: 8rem;
}

.max-h-36 {
  max-height: 9rem;
}

.max-h-40 {
  max-height: 10rem;
}

.max-h-44 {
  max-height: 11rem;
}

.max-h-48 {
  max-height: 12rem;
}

.max-h-52 {
  max-height: 13rem;
}

.max-h-56 {
  max-height: 14rem;
}

.max-h-60 {
  max-height: 15rem;
}

.max-h-64 {
  max-height: 16rem;
}

.max-h-72 {
  max-height: 18rem;
}

.max-h-80 {
  max-height: 20rem;
}

.max-h-96 {
  max-height: 24rem;
}

.max-h-full {
  max-height: 100%;
}

.max-h-screen {
  max-height: 100vh;
}

@media (max-width: 768px) {
  .m\:h-px {
    height: 0.0625rem;
  }

  .m\:h-0 {
    height: 0;
  }

  .m\:h-none {
    height: 0;
  }

  .m\:h-0\.5 {
    height: 0.125rem;
  }

  .m\:h-1 {
    height: 0.25rem;
  }

  .m\:h-1\.5 {
    height: 0.375rem;
  }

  .m\:h-2 {
    height: 0.5rem;
  }

  .m\:h-2\.5 {
    height: 0.625rem;
  }

  .m\:h-3 {
    height: 0.75rem;
  }

  .m\:h-3\.5 {
    height: 0.875rem;
  }

  .m\:h-4 {
    height: 1rem;
  }

  .m\:h-5 {
    height: 1.25rem;
  }

  .m\:h-6 {
    height: 1.5rem;
  }

  .m\:h-7 {
    height: 1.75rem;
  }

  .m\:h-8 {
    height: 2rem;
  }

  .m\:h-9 {
    height: 2.25rem;
  }

  .m\:h-10 {
    height: 2.5rem;
  }

  .m\:h-11 {
    height: 2.75rem;
  }

  .m\:h-12 {
    height: 3rem;
  }

  .m\:h-14 {
    height: 3.5rem;
  }

  .m\:h-16 {
    height: 4rem;
  }

  .m\:h-18 {
    height: 4.5rem;
  }

  .m\:h-20 {
    height: 5rem;
  }

  .m\:h-24 {
    height: 6rem;
  }

  .m\:h-28 {
    height: 7rem;
  }

  .m\:h-32 {
    height: 8rem;
  }

  .m\:h-36 {
    height: 9rem;
  }

  .m\:h-40 {
    height: 10rem;
  }

  .m\:h-44 {
    height: 11rem;
  }

  .m\:h-48 {
    height: 12rem;
  }

  .m\:h-52 {
    height: 13rem;
  }

  .m\:h-56 {
    height: 14rem;
  }

  .m\:h-60 {
    height: 15rem;
  }

  .m\:h-64 {
    height: 16rem;
  }

  .m\:h-72 {
    height: 18rem;
  }

  .m\:h-80 {
    height: 20rem;
  }

  .m\:h-96 {
    height: 24rem;
  }

  .m\:h-auto {
    height: auto;
  }

  .m\:h-1\/2 {
    height: 50%;
  }

  .m\:h-1\/3 {
    height: 33.333333%;
  }

  .m\:h-2\/3 {
    height: 66.666667%;
  }

  .m\:h-1\/4 {
    height: 25%;
  }

  .m\:h-2\/4 {
    height: 50%;
  }

  .m\:h-3\/4 {
    height: 75%;
  }

  .m\:h-1\/5 {
    height: 20%;
  }

  .m\:h-2\/5 {
    height: 40%;
  }

  .m\:h-3\/5 {
    height: 60%;
  }

  .m\:h-4\/5 {
    height: 80%;
  }

  .m\:h-1\/6 {
    height: 16.666667%;
  }

  .m\:h-2\/6 {
    height: 33.333333%;
  }

  .m\:h-3\/6 {
    height: 50%;
  }

  .m\:h-4\/6 {
    height: 66.666667%;
  }

  .m\:h-5\/6 {
    height: 83.333333%;
  }

  .m\:h-full {
    height: 100%;
  }

  .m\:h-screen {
    height: 100vh;
  }

  .m\:min-h-0 {
    min-height: 0px;
  }

  .m\:min-h-full {
    min-height: 100%;
  }

  .m\:min-h-screen {
    min-height: 100vh;
  }

  .m\:max-h-px {
    max-height: 0.0625rem;
  }

  .m\:max-h-0 {
    max-height: 0;
  }

  .m\:max-h-none {
    max-height: 0;
  }

  .m\:max-h-0\.5 {
    max-height: 0.125rem;
  }

  .m\:max-h-1 {
    max-height: 0.25rem;
  }

  .m\:max-h-1\.5 {
    max-height: 0.375rem;
  }

  .m\:max-h-2 {
    max-height: 0.5rem;
  }

  .m\:max-h-2\.5 {
    max-height: 0.625rem;
  }

  .m\:max-h-3 {
    max-height: 0.75rem;
  }

  .m\:max-h-3\.5 {
    max-height: 0.875rem;
  }

  .m\:max-h-4 {
    max-height: 1rem;
  }

  .m\:max-h-5 {
    max-height: 1.25rem;
  }

  .m\:max-h-6 {
    max-height: 1.5rem;
  }

  .m\:max-h-7 {
    max-height: 1.75rem;
  }

  .m\:max-h-8 {
    max-height: 2rem;
  }

  .m\:max-h-9 {
    max-height: 2.25rem;
  }

  .m\:max-h-10 {
    max-height: 2.5rem;
  }

  .m\:max-h-11 {
    max-height: 2.75rem;
  }

  .m\:max-h-12 {
    max-height: 3rem;
  }

  .m\:max-h-14 {
    max-height: 3.5rem;
  }

  .m\:max-h-16 {
    max-height: 4rem;
  }

  .m\:max-h-18 {
    max-height: 4.5rem;
  }

  .m\:max-h-20 {
    max-height: 5rem;
  }

  .m\:max-h-24 {
    max-height: 6rem;
  }

  .m\:max-h-28 {
    max-height: 7rem;
  }

  .m\:max-h-32 {
    max-height: 8rem;
  }

  .m\:max-h-36 {
    max-height: 9rem;
  }

  .m\:max-h-40 {
    max-height: 10rem;
  }

  .m\:max-h-44 {
    max-height: 11rem;
  }

  .m\:max-h-48 {
    max-height: 12rem;
  }

  .m\:max-h-52 {
    max-height: 13rem;
  }

  .m\:max-h-56 {
    max-height: 14rem;
  }

  .m\:max-h-60 {
    max-height: 15rem;
  }

  .m\:max-h-64 {
    max-height: 16rem;
  }

  .m\:max-h-72 {
    max-height: 18rem;
  }

  .m\:max-h-80 {
    max-height: 20rem;
  }

  .m\:max-h-96 {
    max-height: 24rem;
  }

  .m\:max-h-full {
    max-height: 100%;
  }

  .m\:max-h-screen {
    max-height: 100vh;
  }
}
@media (min-width: 769px) {
  .pc\:h-px {
    height: 0.0625rem;
  }

  .pc\:h-0 {
    height: 0;
  }

  .pc\:h-none {
    height: 0;
  }

  .pc\:h-0\.5 {
    height: 0.125rem;
  }

  .pc\:h-1 {
    height: 0.25rem;
  }

  .pc\:h-1\.5 {
    height: 0.375rem;
  }

  .pc\:h-2 {
    height: 0.5rem;
  }

  .pc\:h-2\.5 {
    height: 0.625rem;
  }

  .pc\:h-3 {
    height: 0.75rem;
  }

  .pc\:h-3\.5 {
    height: 0.875rem;
  }

  .pc\:h-4 {
    height: 1rem;
  }

  .pc\:h-5 {
    height: 1.25rem;
  }

  .pc\:h-6 {
    height: 1.5rem;
  }

  .pc\:h-7 {
    height: 1.75rem;
  }

  .pc\:h-8 {
    height: 2rem;
  }

  .pc\:h-9 {
    height: 2.25rem;
  }

  .pc\:h-10 {
    height: 2.5rem;
  }

  .pc\:h-11 {
    height: 2.75rem;
  }

  .pc\:h-12 {
    height: 3rem;
  }

  .pc\:h-14 {
    height: 3.5rem;
  }

  .pc\:h-16 {
    height: 4rem;
  }

  .pc\:h-18 {
    height: 4.5rem;
  }

  .pc\:h-20 {
    height: 5rem;
  }

  .pc\:h-24 {
    height: 6rem;
  }

  .pc\:h-28 {
    height: 7rem;
  }

  .pc\:h-32 {
    height: 8rem;
  }

  .pc\:h-36 {
    height: 9rem;
  }

  .pc\:h-40 {
    height: 10rem;
  }

  .pc\:h-44 {
    height: 11rem;
  }

  .pc\:h-48 {
    height: 12rem;
  }

  .pc\:h-52 {
    height: 13rem;
  }

  .pc\:h-56 {
    height: 14rem;
  }

  .pc\:h-60 {
    height: 15rem;
  }

  .pc\:h-64 {
    height: 16rem;
  }

  .pc\:h-72 {
    height: 18rem;
  }

  .pc\:h-80 {
    height: 20rem;
  }

  .pc\:h-96 {
    height: 24rem;
  }

  .pc\:h-auto {
    height: auto;
  }

  .pc\:h-1\/2 {
    height: 50%;
  }

  .pc\:h-1\/3 {
    height: 33.333333%;
  }

  .pc\:h-2\/3 {
    height: 66.666667%;
  }

  .pc\:h-1\/4 {
    height: 25%;
  }

  .pc\:h-2\/4 {
    height: 50%;
  }

  .pc\:h-3\/4 {
    height: 75%;
  }

  .pc\:h-1\/5 {
    height: 20%;
  }

  .pc\:h-2\/5 {
    height: 40%;
  }

  .pc\:h-3\/5 {
    height: 60%;
  }

  .pc\:h-4\/5 {
    height: 80%;
  }

  .pc\:h-1\/6 {
    height: 16.666667%;
  }

  .pc\:h-2\/6 {
    height: 33.333333%;
  }

  .pc\:h-3\/6 {
    height: 50%;
  }

  .pc\:h-4\/6 {
    height: 66.666667%;
  }

  .pc\:h-5\/6 {
    height: 83.333333%;
  }

  .pc\:h-full {
    height: 100%;
  }

  .pc\:h-screen {
    height: 100vh;
  }

  .pc\:min-h-0 {
    min-height: 0px;
  }

  .pc\:min-h-full {
    min-height: 100%;
  }

  .pc\:min-h-screen {
    min-height: 100vh;
  }

  .pc\:max-h-px {
    max-height: 0.0625rem;
  }

  .pc\:max-h-0 {
    max-height: 0;
  }

  .pc\:max-h-none {
    max-height: 0;
  }

  .pc\:max-h-0\.5 {
    max-height: 0.125rem;
  }

  .pc\:max-h-1 {
    max-height: 0.25rem;
  }

  .pc\:max-h-1\.5 {
    max-height: 0.375rem;
  }

  .pc\:max-h-2 {
    max-height: 0.5rem;
  }

  .pc\:max-h-2\.5 {
    max-height: 0.625rem;
  }

  .pc\:max-h-3 {
    max-height: 0.75rem;
  }

  .pc\:max-h-3\.5 {
    max-height: 0.875rem;
  }

  .pc\:max-h-4 {
    max-height: 1rem;
  }

  .pc\:max-h-5 {
    max-height: 1.25rem;
  }

  .pc\:max-h-6 {
    max-height: 1.5rem;
  }

  .pc\:max-h-7 {
    max-height: 1.75rem;
  }

  .pc\:max-h-8 {
    max-height: 2rem;
  }

  .pc\:max-h-9 {
    max-height: 2.25rem;
  }

  .pc\:max-h-10 {
    max-height: 2.5rem;
  }

  .pc\:max-h-11 {
    max-height: 2.75rem;
  }

  .pc\:max-h-12 {
    max-height: 3rem;
  }

  .pc\:max-h-14 {
    max-height: 3.5rem;
  }

  .pc\:max-h-16 {
    max-height: 4rem;
  }

  .pc\:max-h-18 {
    max-height: 4.5rem;
  }

  .pc\:max-h-20 {
    max-height: 5rem;
  }

  .pc\:max-h-24 {
    max-height: 6rem;
  }

  .pc\:max-h-28 {
    max-height: 7rem;
  }

  .pc\:max-h-32 {
    max-height: 8rem;
  }

  .pc\:max-h-36 {
    max-height: 9rem;
  }

  .pc\:max-h-40 {
    max-height: 10rem;
  }

  .pc\:max-h-44 {
    max-height: 11rem;
  }

  .pc\:max-h-48 {
    max-height: 12rem;
  }

  .pc\:max-h-52 {
    max-height: 13rem;
  }

  .pc\:max-h-56 {
    max-height: 14rem;
  }

  .pc\:max-h-60 {
    max-height: 15rem;
  }

  .pc\:max-h-64 {
    max-height: 16rem;
  }

  .pc\:max-h-72 {
    max-height: 18rem;
  }

  .pc\:max-h-80 {
    max-height: 20rem;
  }

  .pc\:max-h-96 {
    max-height: 24rem;
  }

  .pc\:max-h-full {
    max-height: 100%;
  }

  .pc\:max-h-screen {
    max-height: 100vh;
  }
}
/*!markdown

---
title: Font Family
---

| Class       | Properties               |
| ----------- | ------------------------ |
| font-sans | ui-sans-serif, system-ui, -apple-system, BlinkMacSystemFont 'Segoe UI', Roboto, 'Helvetica Neue', Arial, 'Noto Sans', sans-serif, 'Apple Color Emoji', 'Segoe UI Emoji', 'Segoe UI Symbol', 'Noto Color Emoji' |
| font-serif | font-family: ui-serif, Georgia, Cambria, 'Times New Roman', Times, serif |
| font-mono | font-family: ui-monospace, SFMono-Regular, Menlo, Monaco, Consolas, 'Liberation Mono', 'Courier New', monospace |

*/
.font-sans {
  font-family: ui-sans-serif, system-ui, -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, "Helvetica Neue", Arial, "Noto Sans", sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol", "Noto Color Emoji";
}

.font-serif {
  font-family: ui-serif, Georgia, Cambria, "Times New Roman", Times, serif;
}

.font-mono {
  font-family: ui-monospace, SFMono-Regular, Menlo, Monaco, Consolas, "Liberation Mono", "Courier New", monospace;
}

/*!markdown

---
title: Font Size
---

| Class       | Properties               |
| ----------- | ------------------------ |
| text-xs | font-size: 0.75rem; line-height: 1rem |
| text-sm | font-size: 0.875rem; line-height: 1.25rem |
| text-base | font-size: 1rem; line-height: 1.5rem |
| text-md | font-size: 1.125rem; line-height: 1.75rem |
| text-lg | font-size: 1.25rem; line-height: 1.75rem |
| text-xl | font-size: 1.5rem; line-height: 2rem |
| text-2xl | font-size: 1.875rem; line-height: 2.25rem |
| text-3xl | font-size: 2.25rem; line-height: 2.5rem |
| text-4xl | font-size: 3rem; line-height: 1 |
| text-5xl | font-size: 3.75rem; line-height: 1 |
| text-6xl | font-size: 4.5rem; line-height: 1 |
| text-7xl | font-size: 6rem; line-height: 1 |
| text-8xl | font-size: 8rem; line-height: 1 |



*/
.text-xs {
  font-size: 0.75rem;
  line-height: 1rem;
}

.text-sm {
  font-size: 0.875rem;
  line-height: 1.25rem;
}

.text-base {
  font-size: 1rem;
  line-height: 1.5rem;
}

.text-md {
  font-size: 1.125rem;
  line-height: 1.75rem;
}

.text-lg {
  font-size: 1.25rem;
  line-height: 1.75rem;
}

.text-xl {
  font-size: 1.5rem;
  line-height: 2rem;
}

.text-2xl {
  font-size: 1.875rem;
  line-height: 2.25rem;
}

.text-3xl {
  font-size: 2.25rem;
  line-height: 2.5rem;
}

.text-4xl {
  font-size: 3rem;
  line-height: 1;
}

.text-5xl {
  font-size: 3.75rem;
  line-height: 1;
}

.text-6xl {
  font-size: 4.5rem;
  line-height: 1;
}

.text-7xl {
  font-size: 6rem;
  line-height: 1;
}

.text-8xl {
  font-size: 8rem;
  line-height: 1;
}

@media (max-width: 768px) {
  .m\:text-xs {
    font-size: 0.75rem;
    line-height: 1rem;
  }

  .m\:text-sm {
    font-size: 0.875rem;
    line-height: 1.25rem;
  }

  .m\:text-base {
    font-size: 1rem;
    line-height: 1.5rem;
  }

  .m\:text-md {
    font-size: 1.125rem;
    line-height: 1.75rem;
  }

  .m\:text-lg {
    font-size: 1.25rem;
    line-height: 1.75rem;
  }

  .m\:text-xl {
    font-size: 1.5rem;
    line-height: 2rem;
  }

  .m\:text-2xl {
    font-size: 1.875rem;
    line-height: 2.25rem;
  }

  .m\:text-3xl {
    font-size: 2.25rem;
    line-height: 2.5rem;
  }

  .m\:text-4xl {
    font-size: 3rem;
    line-height: 1;
  }

  .m\:text-5xl {
    font-size: 3.75rem;
    line-height: 1;
  }

  .m\:text-6xl {
    font-size: 4.5rem;
    line-height: 1;
  }

  .m\:text-7xl {
    font-size: 6rem;
    line-height: 1;
  }

  .m\:text-8xl {
    font-size: 8rem;
    line-height: 1;
  }
}
@media (min-width: 769px) {
  .pc\:text-xs {
    font-size: 0.75rem;
    line-height: 1rem;
  }

  .pc\:text-sm {
    font-size: 0.875rem;
    line-height: 1.25rem;
  }

  .pc\:text-base {
    font-size: 1rem;
    line-height: 1.5rem;
  }

  .pc\:text-md {
    font-size: 1.125rem;
    line-height: 1.75rem;
  }

  .pc\:text-lg {
    font-size: 1.25rem;
    line-height: 1.75rem;
  }

  .pc\:text-xl {
    font-size: 1.5rem;
    line-height: 2rem;
  }

  .pc\:text-2xl {
    font-size: 1.875rem;
    line-height: 2.25rem;
  }

  .pc\:text-3xl {
    font-size: 2.25rem;
    line-height: 2.5rem;
  }

  .pc\:text-4xl {
    font-size: 3rem;
    line-height: 1;
  }

  .pc\:text-5xl {
    font-size: 3.75rem;
    line-height: 1;
  }

  .pc\:text-6xl {
    font-size: 4.5rem;
    line-height: 1;
  }

  .pc\:text-7xl {
    font-size: 6rem;
    line-height: 1;
  }

  .pc\:text-8xl {
    font-size: 8rem;
    line-height: 1;
  }
}
/*!markdown

---
title: Font Style
---

| Class       | Properties               |
| ----------- | ------------------------ |
| italic | font-style: italic |
| not-italic | font-style: normal |


*/
.italic {
  font-style: italic;
}

.not-italic {
  font-style: normal;
}

@media (max-width: 768px) {
  .m\:italic {
    font-style: italic;
  }

  .m\:not-italic {
    font-style: normal;
  }
}
@media (min-width: 769px) {
  .pc\:italic {
    font-style: italic;
  }

  .pc\:not-italic {
    font-style: normal;
  }
}
/*!markdown

---
title: Font Weight
---

| Class       | Properties               |
| ----------- | ------------------------ |
| font-thin | font-weight: 100 |
| font-extralight | font-weight: 200 |
| font-light | font-weight: 300 |
| font-normal | font-weight: 400 |
| font-medium | font-weight: 500 |
| font-semibold | font-weight: 600 |
| font-bold | font-weight: 700 |
| font-extrabold | font-weight: 800 |
| font-black | font-weight: 900 |


*/
.font-thin {
  font-weight: 100;
}

.font-extralight {
  font-weight: 200;
}

.font-light {
  font-weight: 300;
}

.font-normal {
  font-weight: 400;
}

.font-medium {
  font-weight: 500;
}

.font-semibold {
  font-weight: 600;
}

.font-bold {
  font-weight: 700;
}

.font-extrabold {
  font-weight: 800;
}

.font-black {
  font-weight: 900;
}

@media (max-width: 768px) {
  .m\:font-thin {
    font-weight: 100;
  }

  .m\:font-extralight {
    font-weight: 200;
  }

  .m\:font-light {
    font-weight: 300;
  }

  .m\:font-normal {
    font-weight: 400;
  }

  .m\:font-medium {
    font-weight: 500;
  }

  .m\:font-semibold {
    font-weight: 600;
  }

  .m\:font-bold {
    font-weight: 700;
  }

  .m\:font-extrabold {
    font-weight: 800;
  }

  .m\:font-black {
    font-weight: 900;
  }
}
@media (min-width: 769px) {
  .pc\:font-thin {
    font-weight: 100;
  }

  .pc\:font-extralight {
    font-weight: 200;
  }

  .pc\:font-light {
    font-weight: 300;
  }

  .pc\:font-normal {
    font-weight: 400;
  }

  .pc\:font-medium {
    font-weight: 500;
  }

  .pc\:font-semibold {
    font-weight: 600;
  }

  .pc\:font-bold {
    font-weight: 700;
  }

  .pc\:font-extrabold {
    font-weight: 800;
  }

  .pc\:font-black {
    font-weight: 900;
  }
}
/*!markdown

---
title: Line Height
---

| Class       | Properties               |
| ----------- | ------------------------ |
| leading-3 | line-height: 0.75rem |
| leading-4 | line-height: 1rem |
| leading-5 | line-height: 1.25rem |
| leading-6 | line-height: 1.5rem |
| leading-7 | line-height: 1.75rem |
| leading-8 | line-height: 2rem |
| leading-9 | line-height: 2.25rem |
| leading-10 | line-height: 2.5rem |
| leading-none | line-height: 1 |
| leading-tight | line-height: 1.25 |
| leading-snug | line-height: 1.375 |
| leading-normal | line-height: 1.5 |
| leading-relaxed | line-height: 1.625 |
| leading-loose | line-height: 2 |


*/
.leading-3 {
  line-height: 0.75rem;
}

.leading-4 {
  line-height: 1rem;
}

.leading-5 {
  line-height: 1.25rem;
}

.leading-6 {
  line-height: 1.5rem;
}

.leading-7 {
  line-height: 1.75rem;
}

.leading-8 {
  line-height: 2rem;
}

.leading-9 {
  line-height: 2.25rem;
}

.leading-10 {
  line-height: 2.5rem;
}

.leading-none {
  line-height: 1;
}

.leading-tight {
  line-height: 1.25;
}

.leading-snug {
  line-height: 1.375;
}

.leading-normal {
  line-height: 1.5;
}

.leading-relaxed {
  line-height: 1.625;
}

.leading-loose {
  line-height: 2;
}

@media (max-width: 768px) {
  .m\:leading-3 {
    line-height: 0.75rem;
  }

  .m\:leading-4 {
    line-height: 1rem;
  }

  .m\:leading-5 {
    line-height: 1.25rem;
  }

  .m\:leading-6 {
    line-height: 1.5rem;
  }

  .m\:leading-7 {
    line-height: 1.75rem;
  }

  .m\:leading-8 {
    line-height: 2rem;
  }

  .m\:leading-9 {
    line-height: 2.25rem;
  }

  .m\:leading-10 {
    line-height: 2.5rem;
  }

  .m\:leading-none {
    line-height: 1;
  }

  .m\:leading-tight {
    line-height: 1.25;
  }

  .m\:leading-snug {
    line-height: 1.375;
  }

  .m\:leading-normal {
    line-height: 1.5;
  }

  .m\:leading-relaxed {
    line-height: 1.625;
  }

  .m\:leading-loose {
    line-height: 2;
  }
}
@media (min-width: 769px) {
  .pc\:leading-3 {
    line-height: 0.75rem;
  }

  .pc\:leading-4 {
    line-height: 1rem;
  }

  .pc\:leading-5 {
    line-height: 1.25rem;
  }

  .pc\:leading-6 {
    line-height: 1.5rem;
  }

  .pc\:leading-7 {
    line-height: 1.75rem;
  }

  .pc\:leading-8 {
    line-height: 2rem;
  }

  .pc\:leading-9 {
    line-height: 2.25rem;
  }

  .pc\:leading-10 {
    line-height: 2.5rem;
  }

  .pc\:leading-none {
    line-height: 1;
  }

  .pc\:leading-tight {
    line-height: 1.25;
  }

  .pc\:leading-snug {
    line-height: 1.375;
  }

  .pc\:leading-normal {
    line-height: 1.5;
  }

  .pc\:leading-relaxed {
    line-height: 1.625;
  }

  .pc\:leading-loose {
    line-height: 2;
  }
}
/*!markdown

---
title: List Style Type
---

| Class       | Properties               |
| ----------- | ------------------------ |
| list-none | list-style-type: none |
| list-disc | list-style-type: disc |
| list-decimal | list-style-type: decimal |
| list-inside | list-style-position: inside |
| list-outside | list-style-position: outside |


*/
.list-none {
  list-style-type: none;
}

.list-disc {
  list-style-type: disc;
}

.list-decimal {
  list-style-type: decimal;
}

.list-inside {
  list-style-position: inside;
}

.list-outside {
  list-style-position: outside;
}

@media (max-width: 768px) {
  .m\:list-none {
    list-style-type: none;
  }

  .m\:list-disc {
    list-style-type: disc;
  }

  .m\:list-decimal {
    list-style-type: decimal;
  }

  .m\:list-inside {
    list-style-position: inside;
  }

  .m\:list-outside {
    list-style-position: outside;
  }
}
@media (min-width: 769px) {
  .pc\:list-none {
    list-style-type: none;
  }

  .pc\:list-disc {
    list-style-type: disc;
  }

  .pc\:list-decimal {
    list-style-type: decimal;
  }

  .pc\:list-inside {
    list-style-position: inside;
  }

  .pc\:list-outside {
    list-style-position: outside;
  }
}
/*!markdown

---
title: Text Align
---

| Class       | Properties               |
| ----------- | ------------------------ |
| text-left | text-align: left |
| text-center | text-align: center |
| text-right | text-align: right |
| text-justify | text-align: justify |


*/
.text-left {
  text-align: left;
}

.text-center {
  text-align: center;
}

.text-right {
  text-align: right;
}

.text-justify {
  text-align: justify;
}

@media (max-width: 768px) {
  .m\:text-left {
    text-align: left;
  }

  .m\:text-center {
    text-align: center;
  }

  .m\:text-right {
    text-align: right;
  }

  .m\:text-justify {
    text-align: justify;
  }
}
@media (min-width: 769px) {
  .pc\:text-left {
    text-align: left;
  }

  .pc\:text-center {
    text-align: center;
  }

  .pc\:text-right {
    text-align: right;
  }

  .pc\:text-justify {
    text-align: justify;
  }
}
/*!markdown

---
title: Text Color
---

| Class       | Properties               |
| ----------- | ------------------------ |
| text-transparent | color: transparent |
| text-current | color: currentColor |
| text-black | color: #000 |
| text-white | color: #fff |
| text-primary | color: #007bff |
| text-secondary | color: #6c757d |
| text-success | color: #28a745 |
| text-info | color: #17a2b8 |
| text-warning | color: #fad733 |
| text-danger | color: #dc3545 |
| text-light | color: #f8f9fa |
| text-dark | color: #343a40 |
| text-gray-50 | color: #f9fafb |
| text-gray-100 | color: #f3f4f6 |
| text-gray-200 | color: #e5e7eb |
| text-gray-300 | color: #d1d5db |
| text-gray-400 | color: #9ca3af |
| text-gray-500 | color: #6b7280 |
| text-gray-600 | color: #4b5563 |
| text-gray-700 | color: #374151 |
| text-gray-800 | color: #1f2937 |
| text-gray-900 | color: #111827 |
| text-red-50 | color: #fef2f2 |
| text-red-100 | color: #fee2e2 |
| text-red-200 | color: #fecaca |
| text-red-300 | color: #fca5a5 |
| text-red-400 | color: #f87171 |
| text-red-500 | color: #ef4444 |
| text-red-600 | color: #dc2626 |
| text-red-700 | color: #b91c1c |
| text-red-800 | color: #991b1b |
| text-red-900 | color: #7f1d1d |
| text-yellow-50 | color: #fffbeb |
| text-yellow-100 | color: #fef3c7 |
| text-yellow-200 | color: #fde68a |
| text-yellow-300 | color: #fcd34d |
| text-yellow-400 | color: #fbbf24 |
| text-yellow-500 | color: #f59e0b |
| text-yellow-600 | color: #d97706 |
| text-yellow-700 | color: #b45309 |
| text-yellow-800 | color: #92400e |
| text-yellow-900 | color: #78350f |
| text-green-50 | color: #ecfdf5 |
| text-green-100 | color: #d1fae5 |
| text-green-200 | color: #a7f3d0 |
| text-green-300 | color: #6ee7b7 |
| text-green-400 | color: #34d399 |
| text-green-500 | color: #10b981 |
| text-green-600 | color: #059669 |
| text-green-700 | color: #047857 |
| text-green-800 | color: #065f46 |
| text-green-900 | color: #064e3b |
| text-blue-50 | color: #eff6ff |
| text-blue-100 | color: #dbeafe |
| text-blue-200 | color: #bfdbfe |
| text-blue-300 | color: #93c5fd |
| text-blue-400 | color: #60a5fa |
| text-blue-500 | color: #3b82f6 |
| text-blue-600 | color: #2563eb |
| text-blue-700 | color: #1d4ed8 |
| text-blue-800 | color: #1e40af |
| text-blue-900 | color: #1e3a8a |
| text-cyan-50 | color: #ecfeff |
| text-cyan-100 | color: #cffafe |
| text-cyan-200 | color: #a5f3fc |
| text-cyan-300 | color: #67e8f9 |
| text-cyan-400 | color: #22d3ee |
| text-cyan-500 | color: #06b6d4 |
| text-cyan-600 | color: #0891b2 |
| text-cyan-700 | color: #0e7490 |
| text-cyan-800 | color: #155e75 |
| text-cyan-900 | color: #164e63 |
| text-indigo-50 | color: #eef2ff |
| text-indigo-100 | color: #e0e7ff |
| text-indigo-200 | color: #c7d2fe |
| text-indigo-300 | color: #a5b4fc |
| text-indigo-400 | color: #818cf8 |
| text-indigo-500 | color: #6366f1 |
| text-indigo-600 | color: #4f46e5 |
| text-indigo-700 | color: #4338ca |
| text-indigo-800 | color: #3730a3 |
| text-indigo-900 | color: #312e81 |
| text-purple-50 | color: #f5f3ff |
| text-purple-100 | color: #ede9fe |
| text-purple-200 | color: #ddd6fe |
| text-purple-300 | color: #c4b5fd |
| text-purple-400 | color: #a78bfa |
| text-purple-500 | color: #8b5cf6 |
| text-purple-600 | color: #7c3aed |
| text-purple-700 | color: #6d28d9 |
| text-purple-800 | color: #5b21b6 |
| text-purple-900 | color: #4c1d95 |
| text-pink-50 | color: #fdf2f8 |
| text-pink-100 | color: #fce7f3 |
| text-pink-200 | color: #fbcfe8 |
| text-pink-300 | color: #f9a8d4 |
| text-pink-400 | color: #f472b6 |
| text-pink-500 | color: #ec4899 |
| text-pink-600 | color: #db2777 |
| text-pink-700 | color: #be185d |
| text-pink-800 | color: #9d174d |
| text-pink-900 | color: #831843 |

还有 hover、active、focus、disabled 扩展，比如 `hover:text-black`

*/
.text-transparent {
  color: transparent;
}

.text-current {
  color: currentColor;
}

.text-black {
  color: #000;
}

.text-white {
  color: #fff;
}

.text-primary {
  color: #007bff;
}

.text-secondary {
  color: #6c757d;
}

.text-success {
  color: #28a745;
}

.text-info {
  color: #17a2b8;
}

.text-warning {
  color: #fad733;
}

.text-danger {
  color: #dc3545;
}

.text-light {
  color: #f8f9fa;
}

.text-dark {
  color: #343a40;
}

.text-gray-50 {
  color: #f9fafb;
}

.text-gray-100 {
  color: #f3f4f6;
}

.text-gray-200 {
  color: #e5e7eb;
}

.text-gray-300 {
  color: #d1d5db;
}

.text-gray-400 {
  color: #9ca3af;
}

.text-gray-500 {
  color: #6b7280;
}

.text-gray-600 {
  color: #4b5563;
}

.text-gray-700 {
  color: #374151;
}

.text-gray-800 {
  color: #1f2937;
}

.text-gray-900 {
  color: #111827;
}

.text-red-50 {
  color: #fef2f2;
}

.text-red-100 {
  color: #fee2e2;
}

.text-red-200 {
  color: #fecaca;
}

.text-red-300 {
  color: #fca5a5;
}

.text-red-400 {
  color: #f87171;
}

.text-red-500 {
  color: #ef4444;
}

.text-red-600 {
  color: #dc2626;
}

.text-red-700 {
  color: #b91c1c;
}

.text-red-800 {
  color: #991b1b;
}

.text-red-900 {
  color: #7f1d1d;
}

.text-yellow-50 {
  color: #fffbeb;
}

.text-yellow-100 {
  color: #fef3c7;
}

.text-yellow-200 {
  color: #fde68a;
}

.text-yellow-300 {
  color: #fcd34d;
}

.text-yellow-400 {
  color: #fbbf24;
}

.text-yellow-500 {
  color: #f59e0b;
}

.text-yellow-600 {
  color: #d97706;
}

.text-yellow-700 {
  color: #b45309;
}

.text-yellow-800 {
  color: #92400e;
}

.text-yellow-900 {
  color: #78350f;
}

.text-green-50 {
  color: #ecfdf5;
}

.text-green-100 {
  color: #d1fae5;
}

.text-green-200 {
  color: #a7f3d0;
}

.text-green-300 {
  color: #6ee7b7;
}

.text-green-400 {
  color: #34d399;
}

.text-green-500 {
  color: #10b981;
}

.text-green-600 {
  color: #059669;
}

.text-green-700 {
  color: #047857;
}

.text-green-800 {
  color: #065f46;
}

.text-green-900 {
  color: #064e3b;
}

.text-blue-50 {
  color: #eff6ff;
}

.text-blue-100 {
  color: #dbeafe;
}

.text-blue-200 {
  color: #bfdbfe;
}

.text-blue-300 {
  color: #93c5fd;
}

.text-blue-400 {
  color: #60a5fa;
}

.text-blue-500 {
  color: #3b82f6;
}

.text-blue-600 {
  color: #2563eb;
}

.text-blue-700 {
  color: #1d4ed8;
}

.text-blue-800 {
  color: #1e40af;
}

.text-blue-900 {
  color: #1e3a8a;
}

.text-cyan-50 {
  color: #ecfeff;
}

.text-cyan-100 {
  color: #cffafe;
}

.text-cyan-200 {
  color: #a5f3fc;
}

.text-cyan-300 {
  color: #67e8f9;
}

.text-cyan-400 {
  color: #22d3ee;
}

.text-cyan-500 {
  color: #06b6d4;
}

.text-cyan-600 {
  color: #0891b2;
}

.text-cyan-700 {
  color: #0e7490;
}

.text-cyan-800 {
  color: #155e75;
}

.text-cyan-900 {
  color: #164e63;
}

.text-indigo-50 {
  color: #eef2ff;
}

.text-indigo-100 {
  color: #e0e7ff;
}

.text-indigo-200 {
  color: #c7d2fe;
}

.text-indigo-300 {
  color: #a5b4fc;
}

.text-indigo-400 {
  color: #818cf8;
}

.text-indigo-500 {
  color: #6366f1;
}

.text-indigo-600 {
  color: #4f46e5;
}

.text-indigo-700 {
  color: #4338ca;
}

.text-indigo-800 {
  color: #3730a3;
}

.text-indigo-900 {
  color: #312e81;
}

.text-purple-50 {
  color: #f5f3ff;
}

.text-purple-100 {
  color: #ede9fe;
}

.text-purple-200 {
  color: #ddd6fe;
}

.text-purple-300 {
  color: #c4b5fd;
}

.text-purple-400 {
  color: #a78bfa;
}

.text-purple-500 {
  color: #8b5cf6;
}

.text-purple-600 {
  color: #7c3aed;
}

.text-purple-700 {
  color: #6d28d9;
}

.text-purple-800 {
  color: #5b21b6;
}

.text-purple-900 {
  color: #4c1d95;
}

.text-pink-50 {
  color: #fdf2f8;
}

.text-pink-100 {
  color: #fce7f3;
}

.text-pink-200 {
  color: #fbcfe8;
}

.text-pink-300 {
  color: #f9a8d4;
}

.text-pink-400 {
  color: #f472b6;
}

.text-pink-500 {
  color: #ec4899;
}

.text-pink-600 {
  color: #db2777;
}

.text-pink-700 {
  color: #be185d;
}

.text-pink-800 {
  color: #9d174d;
}

.text-pink-900 {
  color: #831843;
}

.hover\:text-transparent:hover {
  color: transparent;
}

.hover\:text-current:hover {
  color: currentColor;
}

.hover\:text-black:hover {
  color: #000;
}

.hover\:text-white:hover {
  color: #fff;
}

.hover\:text-primary:hover {
  color: #007bff;
}

.hover\:text-secondary:hover {
  color: #6c757d;
}

.hover\:text-success:hover {
  color: #28a745;
}

.hover\:text-info:hover {
  color: #17a2b8;
}

.hover\:text-warning:hover {
  color: #fad733;
}

.hover\:text-danger:hover {
  color: #dc3545;
}

.hover\:text-light:hover {
  color: #f8f9fa;
}

.hover\:text-dark:hover {
  color: #343a40;
}

.hover\:text-gray-50:hover {
  color: #f9fafb;
}

.hover\:text-gray-100:hover {
  color: #f3f4f6;
}

.hover\:text-gray-200:hover {
  color: #e5e7eb;
}

.hover\:text-gray-300:hover {
  color: #d1d5db;
}

.hover\:text-gray-400:hover {
  color: #9ca3af;
}

.hover\:text-gray-500:hover {
  color: #6b7280;
}

.hover\:text-gray-600:hover {
  color: #4b5563;
}

.hover\:text-gray-700:hover {
  color: #374151;
}

.hover\:text-gray-800:hover {
  color: #1f2937;
}

.hover\:text-gray-900:hover {
  color: #111827;
}

.hover\:text-red-50:hover {
  color: #fef2f2;
}

.hover\:text-red-100:hover {
  color: #fee2e2;
}

.hover\:text-red-200:hover {
  color: #fecaca;
}

.hover\:text-red-300:hover {
  color: #fca5a5;
}

.hover\:text-red-400:hover {
  color: #f87171;
}

.hover\:text-red-500:hover {
  color: #ef4444;
}

.hover\:text-red-600:hover {
  color: #dc2626;
}

.hover\:text-red-700:hover {
  color: #b91c1c;
}

.hover\:text-red-800:hover {
  color: #991b1b;
}

.hover\:text-red-900:hover {
  color: #7f1d1d;
}

.hover\:text-yellow-50:hover {
  color: #fffbeb;
}

.hover\:text-yellow-100:hover {
  color: #fef3c7;
}

.hover\:text-yellow-200:hover {
  color: #fde68a;
}

.hover\:text-yellow-300:hover {
  color: #fcd34d;
}

.hover\:text-yellow-400:hover {
  color: #fbbf24;
}

.hover\:text-yellow-500:hover {
  color: #f59e0b;
}

.hover\:text-yellow-600:hover {
  color: #d97706;
}

.hover\:text-yellow-700:hover {
  color: #b45309;
}

.hover\:text-yellow-800:hover {
  color: #92400e;
}

.hover\:text-yellow-900:hover {
  color: #78350f;
}

.hover\:text-green-50:hover {
  color: #ecfdf5;
}

.hover\:text-green-100:hover {
  color: #d1fae5;
}

.hover\:text-green-200:hover {
  color: #a7f3d0;
}

.hover\:text-green-300:hover {
  color: #6ee7b7;
}

.hover\:text-green-400:hover {
  color: #34d399;
}

.hover\:text-green-500:hover {
  color: #10b981;
}

.hover\:text-green-600:hover {
  color: #059669;
}

.hover\:text-green-700:hover {
  color: #047857;
}

.hover\:text-green-800:hover {
  color: #065f46;
}

.hover\:text-green-900:hover {
  color: #064e3b;
}

.hover\:text-blue-50:hover {
  color: #eff6ff;
}

.hover\:text-blue-100:hover {
  color: #dbeafe;
}

.hover\:text-blue-200:hover {
  color: #bfdbfe;
}

.hover\:text-blue-300:hover {
  color: #93c5fd;
}

.hover\:text-blue-400:hover {
  color: #60a5fa;
}

.hover\:text-blue-500:hover {
  color: #3b82f6;
}

.hover\:text-blue-600:hover {
  color: #2563eb;
}

.hover\:text-blue-700:hover {
  color: #1d4ed8;
}

.hover\:text-blue-800:hover {
  color: #1e40af;
}

.hover\:text-blue-900:hover {
  color: #1e3a8a;
}

.hover\:text-cyan-50:hover {
  color: #ecfeff;
}

.hover\:text-cyan-100:hover {
  color: #cffafe;
}

.hover\:text-cyan-200:hover {
  color: #a5f3fc;
}

.hover\:text-cyan-300:hover {
  color: #67e8f9;
}

.hover\:text-cyan-400:hover {
  color: #22d3ee;
}

.hover\:text-cyan-500:hover {
  color: #06b6d4;
}

.hover\:text-cyan-600:hover {
  color: #0891b2;
}

.hover\:text-cyan-700:hover {
  color: #0e7490;
}

.hover\:text-cyan-800:hover {
  color: #155e75;
}

.hover\:text-cyan-900:hover {
  color: #164e63;
}

.hover\:text-indigo-50:hover {
  color: #eef2ff;
}

.hover\:text-indigo-100:hover {
  color: #e0e7ff;
}

.hover\:text-indigo-200:hover {
  color: #c7d2fe;
}

.hover\:text-indigo-300:hover {
  color: #a5b4fc;
}

.hover\:text-indigo-400:hover {
  color: #818cf8;
}

.hover\:text-indigo-500:hover {
  color: #6366f1;
}

.hover\:text-indigo-600:hover {
  color: #4f46e5;
}

.hover\:text-indigo-700:hover {
  color: #4338ca;
}

.hover\:text-indigo-800:hover {
  color: #3730a3;
}

.hover\:text-indigo-900:hover {
  color: #312e81;
}

.hover\:text-purple-50:hover {
  color: #f5f3ff;
}

.hover\:text-purple-100:hover {
  color: #ede9fe;
}

.hover\:text-purple-200:hover {
  color: #ddd6fe;
}

.hover\:text-purple-300:hover {
  color: #c4b5fd;
}

.hover\:text-purple-400:hover {
  color: #a78bfa;
}

.hover\:text-purple-500:hover {
  color: #8b5cf6;
}

.hover\:text-purple-600:hover {
  color: #7c3aed;
}

.hover\:text-purple-700:hover {
  color: #6d28d9;
}

.hover\:text-purple-800:hover {
  color: #5b21b6;
}

.hover\:text-purple-900:hover {
  color: #4c1d95;
}

.hover\:text-pink-50:hover {
  color: #fdf2f8;
}

.hover\:text-pink-100:hover {
  color: #fce7f3;
}

.hover\:text-pink-200:hover {
  color: #fbcfe8;
}

.hover\:text-pink-300:hover {
  color: #f9a8d4;
}

.hover\:text-pink-400:hover {
  color: #f472b6;
}

.hover\:text-pink-500:hover {
  color: #ec4899;
}

.hover\:text-pink-600:hover {
  color: #db2777;
}

.hover\:text-pink-700:hover {
  color: #be185d;
}

.hover\:text-pink-800:hover {
  color: #9d174d;
}

.hover\:text-pink-900:hover {
  color: #831843;
}

.active\:text-transparent.is-active {
  color: transparent;
}

.active\:text-current.is-active {
  color: currentColor;
}

.active\:text-black.is-active,
.active\:text-black:active {
  color: #000;
}

.active\:text-white.is-active,
.active\:text-white:active {
  color: #fff;
}

.active\:text-primary.is-active,
.active\:text-primary:active {
  color: #007bff;
}

.active\:text-secondary.is-active,
.active\:text-secondary:active {
  color: #6c757d;
}

.active\:text-success.is-active,
.active\:text-success:active {
  color: #28a745;
}

.active\:text-info.is-active,
.active\:text-info:active {
  color: #17a2b8;
}

.active\:text-warning.is-active,
.active\:text-warning:active {
  color: #fad733;
}

.active\:text-danger.is-active,
.active\:text-danger:active {
  color: #dc3545;
}

.active\:text-light.is-active,
.active\:text-light:active {
  color: #f8f9fa;
}

.active\:text-dark.is-active,
.active\:text-dark:active {
  color: #343a40;
}

.active\:text-gray-50.is-active,
.active\:text-gray-50:active {
  color: #f9fafb;
}

.active\:text-gray-100.is-active,
.active\:text-gray-100:active {
  color: #f3f4f6;
}

.active\:text-gray-200.is-active,
.active\:text-gray-200:active {
  color: #e5e7eb;
}

.active\:text-gray-300.is-active,
.active\:text-gray-300:active {
  color: #d1d5db;
}

.active\:text-gray-400.is-active,
.active\:text-gray-400:active {
  color: #9ca3af;
}

.active\:text-gray-500.is-active,
.active\:text-gray-500:active {
  color: #6b7280;
}

.active\:text-gray-600.is-active,
.active\:text-gray-600:active {
  color: #4b5563;
}

.active\:text-gray-700.is-active,
.active\:text-gray-700:active {
  color: #374151;
}

.active\:text-gray-800.is-active,
.active\:text-gray-800:active {
  color: #1f2937;
}

.active\:text-gray-900.is-active,
.active\:text-gray-900:active {
  color: #111827;
}

.active\:text-red-50.is-active,
.active\:text-red-50:active {
  color: #fef2f2;
}

.active\:text-red-100.is-active,
.active\:text-red-100:active {
  color: #fee2e2;
}

.active\:text-red-200.is-active,
.active\:text-red-200:active {
  color: #fecaca;
}

.active\:text-red-300.is-active,
.active\:text-red-300:active {
  color: #fca5a5;
}

.active\:text-red-400.is-active,
.active\:text-red-400:active {
  color: #f87171;
}

.active\:text-red-500.is-active,
.active\:text-red-500:active {
  color: #ef4444;
}

.active\:text-red-600.is-active,
.active\:text-red-600:active {
  color: #dc2626;
}

.active\:text-red-700.is-active,
.active\:text-red-700:active {
  color: #b91c1c;
}

.active\:text-red-800.is-active,
.active\:text-red-800:active {
  color: #991b1b;
}

.active\:text-red-900.is-active,
.active\:text-red-900:active {
  color: #7f1d1d;
}

.active\:text-yellow-50.is-active,
.active\:text-yellow-50:active {
  color: #fffbeb;
}

.active\:text-yellow-100.is-active,
.active\:text-yellow-100:active {
  color: #fef3c7;
}

.active\:text-yellow-200.is-active,
.active\:text-yellow-200:active {
  color: #fde68a;
}

.active\:text-yellow-300.is-active,
.active\:text-yellow-300:active {
  color: #fcd34d;
}

.active\:text-yellow-400.is-active,
.active\:text-yellow-400:active {
  color: #fbbf24;
}

.active\:text-yellow-500.is-active,
.active\:text-yellow-500:active {
  color: #f59e0b;
}

.active\:text-yellow-600.is-active,
.active\:text-yellow-600:active {
  color: #d97706;
}

.active\:text-yellow-700.is-active,
.active\:text-yellow-700:active {
  color: #b45309;
}

.active\:text-yellow-800.is-active,
.active\:text-yellow-800:active {
  color: #92400e;
}

.active\:text-yellow-900.is-active,
.active\:text-yellow-900:active {
  color: #78350f;
}

.active\:text-green-50.is-active,
.active\:text-green-50:active {
  color: #ecfdf5;
}

.active\:text-green-100.is-active,
.active\:text-green-100:active {
  color: #d1fae5;
}

.active\:text-green-200.is-active,
.active\:text-green-200:active {
  color: #a7f3d0;
}

.active\:text-green-300.is-active,
.active\:text-green-300:active {
  color: #6ee7b7;
}

.active\:text-green-400.is-active,
.active\:text-green-400:active {
  color: #34d399;
}

.active\:text-green-500.is-active,
.active\:text-green-500:active {
  color: #10b981;
}

.active\:text-green-600.is-active,
.active\:text-green-600:active {
  color: #059669;
}

.active\:text-green-700.is-active,
.active\:text-green-700:active {
  color: #047857;
}

.active\:text-green-800.is-active,
.active\:text-green-800:active {
  color: #065f46;
}

.active\:text-green-900.is-active,
.active\:text-green-900:active {
  color: #064e3b;
}

.active\:text-blue-50.is-active,
.active\:text-blue-50:active {
  color: #eff6ff;
}

.active\:text-blue-100.is-active,
.active\:text-blue-100:active {
  color: #dbeafe;
}

.active\:text-blue-200.is-active,
.active\:text-blue-200:active {
  color: #bfdbfe;
}

.active\:text-blue-300.is-active,
.active\:text-blue-300:active {
  color: #93c5fd;
}

.active\:text-blue-400.is-active,
.active\:text-blue-400:active {
  color: #60a5fa;
}

.active\:text-blue-500.is-active,
.active\:text-blue-500:active {
  color: #3b82f6;
}

.active\:text-blue-600.is-active,
.active\:text-blue-600:active {
  color: #2563eb;
}

.active\:text-blue-700.is-active,
.active\:text-blue-700:active {
  color: #1d4ed8;
}

.active\:text-blue-800.is-active,
.active\:text-blue-800:active {
  color: #1e40af;
}

.active\:text-blue-900.is-active,
.active\:text-blue-900:active {
  color: #1e3a8a;
}

.active\:text-cyan-50.is-active,
.active\:text-cyan-50:active {
  color: #ecfeff;
}

.active\:text-cyan-100.is-active,
.active\:text-cyan-100:active {
  color: #cffafe;
}

.active\:text-cyan-200.is-active,
.active\:text-cyan-200:active {
  color: #a5f3fc;
}

.active\:text-cyan-300.is-active,
.active\:text-cyan-300:active {
  color: #67e8f9;
}

.active\:text-cyan-400.is-active,
.active\:text-cyan-400:active {
  color: #22d3ee;
}

.active\:text-cyan-500.is-active,
.active\:text-cyan-500:active {
  color: #06b6d4;
}

.active\:text-cyan-600.is-active,
.active\:text-cyan-600:active {
  color: #0891b2;
}

.active\:text-cyan-700.is-active,
.active\:text-cyan-700:active {
  color: #0e7490;
}

.active\:text-cyan-800.is-active,
.active\:text-cyan-800:active {
  color: #155e75;
}

.active\:text-cyan-900.is-active,
.active\:text-cyan-900:active {
  color: #164e63;
}

.active\:text-indigo-50.is-active,
.active\:text-indigo-50:active {
  color: #eef2ff;
}

.active\:text-indigo-100.is-active,
.active\:text-indigo-100:active {
  color: #e0e7ff;
}

.active\:text-indigo-200.is-active,
.active\:text-indigo-200:active {
  color: #c7d2fe;
}

.active\:text-indigo-300.is-active,
.active\:text-indigo-300:active {
  color: #a5b4fc;
}

.active\:text-indigo-400.is-active,
.active\:text-indigo-400:active {
  color: #818cf8;
}

.active\:text-indigo-500.is-active,
.active\:text-indigo-500:active {
  color: #6366f1;
}

.active\:text-indigo-600.is-active,
.active\:text-indigo-600:active {
  color: #4f46e5;
}

.active\:text-indigo-700.is-active,
.active\:text-indigo-700:active {
  color: #4338ca;
}

.active\:text-indigo-800.is-active,
.active\:text-indigo-800:active {
  color: #3730a3;
}

.active\:text-indigo-900.is-active,
.active\:text-indigo-900:active {
  color: #312e81;
}

.active\:text-purple-50.is-active,
.active\:text-purple-50:active {
  color: #f5f3ff;
}

.active\:text-purple-100.is-active,
.active\:text-purple-100:active {
  color: #ede9fe;
}

.active\:text-purple-200.is-active,
.active\:text-purple-200:active {
  color: #ddd6fe;
}

.active\:text-purple-300.is-active,
.active\:text-purple-300:active {
  color: #c4b5fd;
}

.active\:text-purple-400.is-active,
.active\:text-purple-400:active {
  color: #a78bfa;
}

.active\:text-purple-500.is-active,
.active\:text-purple-500:active {
  color: #8b5cf6;
}

.active\:text-purple-600.is-active,
.active\:text-purple-600:active {
  color: #7c3aed;
}

.active\:text-purple-700.is-active,
.active\:text-purple-700:active {
  color: #6d28d9;
}

.active\:text-purple-800.is-active,
.active\:text-purple-800:active {
  color: #5b21b6;
}

.active\:text-purple-900.is-active,
.active\:text-purple-900:active {
  color: #4c1d95;
}

.active\:text-pink-50.is-active,
.active\:text-pink-50:active {
  color: #fdf2f8;
}

.active\:text-pink-100.is-active,
.active\:text-pink-100:active {
  color: #fce7f3;
}

.active\:text-pink-200.is-active,
.active\:text-pink-200:active {
  color: #fbcfe8;
}

.active\:text-pink-300.is-active,
.active\:text-pink-300:active {
  color: #f9a8d4;
}

.active\:text-pink-400.is-active,
.active\:text-pink-400:active {
  color: #f472b6;
}

.active\:text-pink-500.is-active,
.active\:text-pink-500:active {
  color: #ec4899;
}

.active\:text-pink-600.is-active,
.active\:text-pink-600:active {
  color: #db2777;
}

.active\:text-pink-700.is-active,
.active\:text-pink-700:active {
  color: #be185d;
}

.active\:text-pink-800.is-active,
.active\:text-pink-800:active {
  color: #9d174d;
}

.active\:text-pink-900.is-active,
.active\:text-pink-900:active {
  color: #831843;
}

.focus\:text-transparent:focus {
  color: transparent;
}

.focus\:text-current:focus {
  color: currentColor;
}

.focus\:text-black:focus {
  color: #000;
}

.focus\:text-white:focus {
  color: #fff;
}

.focus\:text-primary:focus {
  color: #007bff;
}

.focus\:text-secondary:focus {
  color: #6c757d;
}

.focus\:text-success:focus {
  color: #28a745;
}

.focus\:text-info:focus {
  color: #17a2b8;
}

.focus\:text-warning:focus {
  color: #fad733;
}

.focus\:text-danger:focus {
  color: #dc3545;
}

.focus\:text-light:focus {
  color: #f8f9fa;
}

.focus\:text-dark:focus {
  color: #343a40;
}

.focus\:text-gray-50:focus {
  color: #f9fafb;
}

.focus\:text-gray-100:focus {
  color: #f3f4f6;
}

.focus\:text-gray-200:focus {
  color: #e5e7eb;
}

.focus\:text-gray-300:focus {
  color: #d1d5db;
}

.focus\:text-gray-400:focus {
  color: #9ca3af;
}

.focus\:text-gray-500:focus {
  color: #6b7280;
}

.focus\:text-gray-600:focus {
  color: #4b5563;
}

.focus\:text-gray-700:focus {
  color: #374151;
}

.focus\:text-gray-800:focus {
  color: #1f2937;
}

.focus\:text-gray-900:focus {
  color: #111827;
}

.focus\:text-red-50:focus {
  color: #fef2f2;
}

.focus\:text-red-100:focus {
  color: #fee2e2;
}

.focus\:text-red-200:focus {
  color: #fecaca;
}

.focus\:text-red-300:focus {
  color: #fca5a5;
}

.focus\:text-red-400:focus {
  color: #f87171;
}

.focus\:text-red-500:focus {
  color: #ef4444;
}

.focus\:text-red-600:focus {
  color: #dc2626;
}

.focus\:text-red-700:focus {
  color: #b91c1c;
}

.focus\:text-red-800:focus {
  color: #991b1b;
}

.focus\:text-red-900:focus {
  color: #7f1d1d;
}

.focus\:text-yellow-50:focus {
  color: #fffbeb;
}

.focus\:text-yellow-100:focus {
  color: #fef3c7;
}

.focus\:text-yellow-200:focus {
  color: #fde68a;
}

.focus\:text-yellow-300:focus {
  color: #fcd34d;
}

.focus\:text-yellow-400:focus {
  color: #fbbf24;
}

.focus\:text-yellow-500:focus {
  color: #f59e0b;
}

.focus\:text-yellow-600:focus {
  color: #d97706;
}

.focus\:text-yellow-700:focus {
  color: #b45309;
}

.focus\:text-yellow-800:focus {
  color: #92400e;
}

.focus\:text-yellow-900:focus {
  color: #78350f;
}

.focus\:text-green-50:focus {
  color: #ecfdf5;
}

.focus\:text-green-100:focus {
  color: #d1fae5;
}

.focus\:text-green-200:focus {
  color: #a7f3d0;
}

.focus\:text-green-300:focus {
  color: #6ee7b7;
}

.focus\:text-green-400:focus {
  color: #34d399;
}

.focus\:text-green-500:focus {
  color: #10b981;
}

.focus\:text-green-600:focus {
  color: #059669;
}

.focus\:text-green-700:focus {
  color: #047857;
}

.focus\:text-green-800:focus {
  color: #065f46;
}

.focus\:text-green-900:focus {
  color: #064e3b;
}

.focus\:text-blue-50:focus {
  color: #eff6ff;
}

.focus\:text-blue-100:focus {
  color: #dbeafe;
}

.focus\:text-blue-200:focus {
  color: #bfdbfe;
}

.focus\:text-blue-300:focus {
  color: #93c5fd;
}

.focus\:text-blue-400:focus {
  color: #60a5fa;
}

.focus\:text-blue-500:focus {
  color: #3b82f6;
}

.focus\:text-blue-600:focus {
  color: #2563eb;
}

.focus\:text-blue-700:focus {
  color: #1d4ed8;
}

.focus\:text-blue-800:focus {
  color: #1e40af;
}

.focus\:text-blue-900:focus {
  color: #1e3a8a;
}

.focus\:text-cyan-50:focus {
  color: #ecfeff;
}

.focus\:text-cyan-100:focus {
  color: #cffafe;
}

.focus\:text-cyan-200:focus {
  color: #a5f3fc;
}

.focus\:text-cyan-300:focus {
  color: #67e8f9;
}

.focus\:text-cyan-400:focus {
  color: #22d3ee;
}

.focus\:text-cyan-500:focus {
  color: #06b6d4;
}

.focus\:text-cyan-600:focus {
  color: #0891b2;
}

.focus\:text-cyan-700:focus {
  color: #0e7490;
}

.focus\:text-cyan-800:focus {
  color: #155e75;
}

.focus\:text-cyan-900:focus {
  color: #164e63;
}

.focus\:text-indigo-50:focus {
  color: #eef2ff;
}

.focus\:text-indigo-100:focus {
  color: #e0e7ff;
}

.focus\:text-indigo-200:focus {
  color: #c7d2fe;
}

.focus\:text-indigo-300:focus {
  color: #a5b4fc;
}

.focus\:text-indigo-400:focus {
  color: #818cf8;
}

.focus\:text-indigo-500:focus {
  color: #6366f1;
}

.focus\:text-indigo-600:focus {
  color: #4f46e5;
}

.focus\:text-indigo-700:focus {
  color: #4338ca;
}

.focus\:text-indigo-800:focus {
  color: #3730a3;
}

.focus\:text-indigo-900:focus {
  color: #312e81;
}

.focus\:text-purple-50:focus {
  color: #f5f3ff;
}

.focus\:text-purple-100:focus {
  color: #ede9fe;
}

.focus\:text-purple-200:focus {
  color: #ddd6fe;
}

.focus\:text-purple-300:focus {
  color: #c4b5fd;
}

.focus\:text-purple-400:focus {
  color: #a78bfa;
}

.focus\:text-purple-500:focus {
  color: #8b5cf6;
}

.focus\:text-purple-600:focus {
  color: #7c3aed;
}

.focus\:text-purple-700:focus {
  color: #6d28d9;
}

.focus\:text-purple-800:focus {
  color: #5b21b6;
}

.focus\:text-purple-900:focus {
  color: #4c1d95;
}

.focus\:text-pink-50:focus {
  color: #fdf2f8;
}

.focus\:text-pink-100:focus {
  color: #fce7f3;
}

.focus\:text-pink-200:focus {
  color: #fbcfe8;
}

.focus\:text-pink-300:focus {
  color: #f9a8d4;
}

.focus\:text-pink-400:focus {
  color: #f472b6;
}

.focus\:text-pink-500:focus {
  color: #ec4899;
}

.focus\:text-pink-600:focus {
  color: #db2777;
}

.focus\:text-pink-700:focus {
  color: #be185d;
}

.focus\:text-pink-800:focus {
  color: #9d174d;
}

.focus\:text-pink-900:focus {
  color: #831843;
}

.disabled\:text-transparent.is-disabled {
  color: transparent;
}

.disabled\:text-current.is-disabled {
  color: currentColor;
}

.disabled\:text-black.is-disabled,
.disabled\:text-black:disabled {
  color: #000;
}

.disabled\:text-white.is-disabled,
.disabled\:text-white:disabled {
  color: #fff;
}

.disabled\:text-primary.is-disabled,
.disabled\:text-primary:disabled {
  color: #007bff;
}

.disabled\:text-secondary.is-disabled,
.disabled\:text-secondary:disabled {
  color: #6c757d;
}

.disabled\:text-success.is-disabled,
.disabled\:text-success:disabled {
  color: #28a745;
}

.disabled\:text-info.is-disabled,
.disabled\:text-info:disabled {
  color: #17a2b8;
}

.disabled\:text-warning.is-disabled,
.disabled\:text-warning:disabled {
  color: #fad733;
}

.disabled\:text-danger.is-disabled,
.disabled\:text-danger:disabled {
  color: #dc3545;
}

.disabled\:text-light.is-disabled,
.disabled\:text-light:disabled {
  color: #f8f9fa;
}

.disabled\:text-dark.is-disabled,
.disabled\:text-dark:disabled {
  color: #343a40;
}

.disabled\:text-gray-50.is-disabled,
.disabled\:text-gray-50:disabled {
  color: #f9fafb;
}

.disabled\:text-gray-100.is-disabled,
.disabled\:text-gray-100:disabled {
  color: #f3f4f6;
}

.disabled\:text-gray-200.is-disabled,
.disabled\:text-gray-200:disabled {
  color: #e5e7eb;
}

.disabled\:text-gray-300.is-disabled,
.disabled\:text-gray-300:disabled {
  color: #d1d5db;
}

.disabled\:text-gray-400.is-disabled,
.disabled\:text-gray-400:disabled {
  color: #9ca3af;
}

.disabled\:text-gray-500.is-disabled,
.disabled\:text-gray-500:disabled {
  color: #6b7280;
}

.disabled\:text-gray-600.is-disabled,
.disabled\:text-gray-600:disabled {
  color: #4b5563;
}

.disabled\:text-gray-700.is-disabled,
.disabled\:text-gray-700:disabled {
  color: #374151;
}

.disabled\:text-gray-800.is-disabled,
.disabled\:text-gray-800:disabled {
  color: #1f2937;
}

.disabled\:text-gray-900.is-disabled,
.disabled\:text-gray-900:disabled {
  color: #111827;
}

.disabled\:text-red-50.is-disabled,
.disabled\:text-red-50:disabled {
  color: #fef2f2;
}

.disabled\:text-red-100.is-disabled,
.disabled\:text-red-100:disabled {
  color: #fee2e2;
}

.disabled\:text-red-200.is-disabled,
.disabled\:text-red-200:disabled {
  color: #fecaca;
}

.disabled\:text-red-300.is-disabled,
.disabled\:text-red-300:disabled {
  color: #fca5a5;
}

.disabled\:text-red-400.is-disabled,
.disabled\:text-red-400:disabled {
  color: #f87171;
}

.disabled\:text-red-500.is-disabled,
.disabled\:text-red-500:disabled {
  color: #ef4444;
}

.disabled\:text-red-600.is-disabled,
.disabled\:text-red-600:disabled {
  color: #dc2626;
}

.disabled\:text-red-700.is-disabled,
.disabled\:text-red-700:disabled {
  color: #b91c1c;
}

.disabled\:text-red-800.is-disabled,
.disabled\:text-red-800:disabled {
  color: #991b1b;
}

.disabled\:text-red-900.is-disabled,
.disabled\:text-red-900:disabled {
  color: #7f1d1d;
}

.disabled\:text-yellow-50.is-disabled,
.disabled\:text-yellow-50:disabled {
  color: #fffbeb;
}

.disabled\:text-yellow-100.is-disabled,
.disabled\:text-yellow-100:disabled {
  color: #fef3c7;
}

.disabled\:text-yellow-200.is-disabled,
.disabled\:text-yellow-200:disabled {
  color: #fde68a;
}

.disabled\:text-yellow-300.is-disabled,
.disabled\:text-yellow-300:disabled {
  color: #fcd34d;
}

.disabled\:text-yellow-400.is-disabled,
.disabled\:text-yellow-400:disabled {
  color: #fbbf24;
}

.disabled\:text-yellow-500.is-disabled,
.disabled\:text-yellow-500:disabled {
  color: #f59e0b;
}

.disabled\:text-yellow-600.is-disabled,
.disabled\:text-yellow-600:disabled {
  color: #d97706;
}

.disabled\:text-yellow-700.is-disabled,
.disabled\:text-yellow-700:disabled {
  color: #b45309;
}

.disabled\:text-yellow-800.is-disabled,
.disabled\:text-yellow-800:disabled {
  color: #92400e;
}

.disabled\:text-yellow-900.is-disabled,
.disabled\:text-yellow-900:disabled {
  color: #78350f;
}

.disabled\:text-green-50.is-disabled,
.disabled\:text-green-50:disabled {
  color: #ecfdf5;
}

.disabled\:text-green-100.is-disabled,
.disabled\:text-green-100:disabled {
  color: #d1fae5;
}

.disabled\:text-green-200.is-disabled,
.disabled\:text-green-200:disabled {
  color: #a7f3d0;
}

.disabled\:text-green-300.is-disabled,
.disabled\:text-green-300:disabled {
  color: #6ee7b7;
}

.disabled\:text-green-400.is-disabled,
.disabled\:text-green-400:disabled {
  color: #34d399;
}

.disabled\:text-green-500.is-disabled,
.disabled\:text-green-500:disabled {
  color: #10b981;
}

.disabled\:text-green-600.is-disabled,
.disabled\:text-green-600:disabled {
  color: #059669;
}

.disabled\:text-green-700.is-disabled,
.disabled\:text-green-700:disabled {
  color: #047857;
}

.disabled\:text-green-800.is-disabled,
.disabled\:text-green-800:disabled {
  color: #065f46;
}

.disabled\:text-green-900.is-disabled,
.disabled\:text-green-900:disabled {
  color: #064e3b;
}

.disabled\:text-blue-50.is-disabled,
.disabled\:text-blue-50:disabled {
  color: #eff6ff;
}

.disabled\:text-blue-100.is-disabled,
.disabled\:text-blue-100:disabled {
  color: #dbeafe;
}

.disabled\:text-blue-200.is-disabled,
.disabled\:text-blue-200:disabled {
  color: #bfdbfe;
}

.disabled\:text-blue-300.is-disabled,
.disabled\:text-blue-300:disabled {
  color: #93c5fd;
}

.disabled\:text-blue-400.is-disabled,
.disabled\:text-blue-400:disabled {
  color: #60a5fa;
}

.disabled\:text-blue-500.is-disabled,
.disabled\:text-blue-500:disabled {
  color: #3b82f6;
}

.disabled\:text-blue-600.is-disabled,
.disabled\:text-blue-600:disabled {
  color: #2563eb;
}

.disabled\:text-blue-700.is-disabled,
.disabled\:text-blue-700:disabled {
  color: #1d4ed8;
}

.disabled\:text-blue-800.is-disabled,
.disabled\:text-blue-800:disabled {
  color: #1e40af;
}

.disabled\:text-blue-900.is-disabled,
.disabled\:text-blue-900:disabled {
  color: #1e3a8a;
}

.disabled\:text-cyan-50.is-disabled,
.disabled\:text-cyan-50:disabled {
  color: #ecfeff;
}

.disabled\:text-cyan-100.is-disabled,
.disabled\:text-cyan-100:disabled {
  color: #cffafe;
}

.disabled\:text-cyan-200.is-disabled,
.disabled\:text-cyan-200:disabled {
  color: #a5f3fc;
}

.disabled\:text-cyan-300.is-disabled,
.disabled\:text-cyan-300:disabled {
  color: #67e8f9;
}

.disabled\:text-cyan-400.is-disabled,
.disabled\:text-cyan-400:disabled {
  color: #22d3ee;
}

.disabled\:text-cyan-500.is-disabled,
.disabled\:text-cyan-500:disabled {
  color: #06b6d4;
}

.disabled\:text-cyan-600.is-disabled,
.disabled\:text-cyan-600:disabled {
  color: #0891b2;
}

.disabled\:text-cyan-700.is-disabled,
.disabled\:text-cyan-700:disabled {
  color: #0e7490;
}

.disabled\:text-cyan-800.is-disabled,
.disabled\:text-cyan-800:disabled {
  color: #155e75;
}

.disabled\:text-cyan-900.is-disabled,
.disabled\:text-cyan-900:disabled {
  color: #164e63;
}

.disabled\:text-indigo-50.is-disabled,
.disabled\:text-indigo-50:disabled {
  color: #eef2ff;
}

.disabled\:text-indigo-100.is-disabled,
.disabled\:text-indigo-100:disabled {
  color: #e0e7ff;
}

.disabled\:text-indigo-200.is-disabled,
.disabled\:text-indigo-200:disabled {
  color: #c7d2fe;
}

.disabled\:text-indigo-300.is-disabled,
.disabled\:text-indigo-300:disabled {
  color: #a5b4fc;
}

.disabled\:text-indigo-400.is-disabled,
.disabled\:text-indigo-400:disabled {
  color: #818cf8;
}

.disabled\:text-indigo-500.is-disabled,
.disabled\:text-indigo-500:disabled {
  color: #6366f1;
}

.disabled\:text-indigo-600.is-disabled,
.disabled\:text-indigo-600:disabled {
  color: #4f46e5;
}

.disabled\:text-indigo-700.is-disabled,
.disabled\:text-indigo-700:disabled {
  color: #4338ca;
}

.disabled\:text-indigo-800.is-disabled,
.disabled\:text-indigo-800:disabled {
  color: #3730a3;
}

.disabled\:text-indigo-900.is-disabled,
.disabled\:text-indigo-900:disabled {
  color: #312e81;
}

.disabled\:text-purple-50.is-disabled,
.disabled\:text-purple-50:disabled {
  color: #f5f3ff;
}

.disabled\:text-purple-100.is-disabled,
.disabled\:text-purple-100:disabled {
  color: #ede9fe;
}

.disabled\:text-purple-200.is-disabled,
.disabled\:text-purple-200:disabled {
  color: #ddd6fe;
}

.disabled\:text-purple-300.is-disabled,
.disabled\:text-purple-300:disabled {
  color: #c4b5fd;
}

.disabled\:text-purple-400.is-disabled,
.disabled\:text-purple-400:disabled {
  color: #a78bfa;
}

.disabled\:text-purple-500.is-disabled,
.disabled\:text-purple-500:disabled {
  color: #8b5cf6;
}

.disabled\:text-purple-600.is-disabled,
.disabled\:text-purple-600:disabled {
  color: #7c3aed;
}

.disabled\:text-purple-700.is-disabled,
.disabled\:text-purple-700:disabled {
  color: #6d28d9;
}

.disabled\:text-purple-800.is-disabled,
.disabled\:text-purple-800:disabled {
  color: #5b21b6;
}

.disabled\:text-purple-900.is-disabled,
.disabled\:text-purple-900:disabled {
  color: #4c1d95;
}

.disabled\:text-pink-50.is-disabled,
.disabled\:text-pink-50:disabled {
  color: #fdf2f8;
}

.disabled\:text-pink-100.is-disabled,
.disabled\:text-pink-100:disabled {
  color: #fce7f3;
}

.disabled\:text-pink-200.is-disabled,
.disabled\:text-pink-200:disabled {
  color: #fbcfe8;
}

.disabled\:text-pink-300.is-disabled,
.disabled\:text-pink-300:disabled {
  color: #f9a8d4;
}

.disabled\:text-pink-400.is-disabled,
.disabled\:text-pink-400:disabled {
  color: #f472b6;
}

.disabled\:text-pink-500.is-disabled,
.disabled\:text-pink-500:disabled {
  color: #ec4899;
}

.disabled\:text-pink-600.is-disabled,
.disabled\:text-pink-600:disabled {
  color: #db2777;
}

.disabled\:text-pink-700.is-disabled,
.disabled\:text-pink-700:disabled {
  color: #be185d;
}

.disabled\:text-pink-800.is-disabled,
.disabled\:text-pink-800:disabled {
  color: #9d174d;
}

.disabled\:text-pink-900.is-disabled,
.disabled\:text-pink-900:disabled {
  color: #831843;
}

.group:hover .group-hover\:text-transparent {
  color: transparent;
}

.group:hover .group-hover\:text-current {
  color: currentColor;
}

.group:hover .group-hover\:text-black {
  color: #000;
}

.group:hover .group-hover\:text-white {
  color: #fff;
}

.group:hover .group-hover\:text-primary {
  color: #007bff;
}

.group:hover .group-hover\:text-secondary {
  color: #6c757d;
}

.group:hover .group-hover\:text-success {
  color: #28a745;
}

.group:hover .group-hover\:text-info {
  color: #17a2b8;
}

.group:hover .group-hover\:text-warning {
  color: #fad733;
}

.group:hover .group-hover\:text-danger {
  color: #dc3545;
}

.group:hover .group-hover\:text-light {
  color: #f8f9fa;
}

.group:hover .group-hover\:text-dark {
  color: #343a40;
}

.group:hover .group-hover\:text-gray-50 {
  color: #f9fafb;
}

.group:hover .group-hover\:text-gray-100 {
  color: #f3f4f6;
}

.group:hover .group-hover\:text-gray-200 {
  color: #e5e7eb;
}

.group:hover .group-hover\:text-gray-300 {
  color: #d1d5db;
}

.group:hover .group-hover\:text-gray-400 {
  color: #9ca3af;
}

.group:hover .group-hover\:text-gray-500 {
  color: #6b7280;
}

.group:hover .group-hover\:text-gray-600 {
  color: #4b5563;
}

.group:hover .group-hover\:text-gray-700 {
  color: #374151;
}

.group:hover .group-hover\:text-gray-800 {
  color: #1f2937;
}

.group:hover .group-hover\:text-gray-900 {
  color: #111827;
}

.group:hover .group-hover\:text-red-50 {
  color: #fef2f2;
}

.group:hover .group-hover\:text-red-100 {
  color: #fee2e2;
}

.group:hover .group-hover\:text-red-200 {
  color: #fecaca;
}

.group:hover .group-hover\:text-red-300 {
  color: #fca5a5;
}

.group:hover .group-hover\:text-red-400 {
  color: #f87171;
}

.group:hover .group-hover\:text-red-500 {
  color: #ef4444;
}

.group:hover .group-hover\:text-red-600 {
  color: #dc2626;
}

.group:hover .group-hover\:text-red-700 {
  color: #b91c1c;
}

.group:hover .group-hover\:text-red-800 {
  color: #991b1b;
}

.group:hover .group-hover\:text-red-900 {
  color: #7f1d1d;
}

.group:hover .group-hover\:text-yellow-50 {
  color: #fffbeb;
}

.group:hover .group-hover\:text-yellow-100 {
  color: #fef3c7;
}

.group:hover .group-hover\:text-yellow-200 {
  color: #fde68a;
}

.group:hover .group-hover\:text-yellow-300 {
  color: #fcd34d;
}

.group:hover .group-hover\:text-yellow-400 {
  color: #fbbf24;
}

.group:hover .group-hover\:text-yellow-500 {
  color: #f59e0b;
}

.group:hover .group-hover\:text-yellow-600 {
  color: #d97706;
}

.group:hover .group-hover\:text-yellow-700 {
  color: #b45309;
}

.group:hover .group-hover\:text-yellow-800 {
  color: #92400e;
}

.group:hover .group-hover\:text-yellow-900 {
  color: #78350f;
}

.group:hover .group-hover\:text-green-50 {
  color: #ecfdf5;
}

.group:hover .group-hover\:text-green-100 {
  color: #d1fae5;
}

.group:hover .group-hover\:text-green-200 {
  color: #a7f3d0;
}

.group:hover .group-hover\:text-green-300 {
  color: #6ee7b7;
}

.group:hover .group-hover\:text-green-400 {
  color: #34d399;
}

.group:hover .group-hover\:text-green-500 {
  color: #10b981;
}

.group:hover .group-hover\:text-green-600 {
  color: #059669;
}

.group:hover .group-hover\:text-green-700 {
  color: #047857;
}

.group:hover .group-hover\:text-green-800 {
  color: #065f46;
}

.group:hover .group-hover\:text-green-900 {
  color: #064e3b;
}

.group:hover .group-hover\:text-blue-50 {
  color: #eff6ff;
}

.group:hover .group-hover\:text-blue-100 {
  color: #dbeafe;
}

.group:hover .group-hover\:text-blue-200 {
  color: #bfdbfe;
}

.group:hover .group-hover\:text-blue-300 {
  color: #93c5fd;
}

.group:hover .group-hover\:text-blue-400 {
  color: #60a5fa;
}

.group:hover .group-hover\:text-blue-500 {
  color: #3b82f6;
}

.group:hover .group-hover\:text-blue-600 {
  color: #2563eb;
}

.group:hover .group-hover\:text-blue-700 {
  color: #1d4ed8;
}

.group:hover .group-hover\:text-blue-800 {
  color: #1e40af;
}

.group:hover .group-hover\:text-blue-900 {
  color: #1e3a8a;
}

.group:hover .group-hover\:text-cyan-50 {
  color: #ecfeff;
}

.group:hover .group-hover\:text-cyan-100 {
  color: #cffafe;
}

.group:hover .group-hover\:text-cyan-200 {
  color: #a5f3fc;
}

.group:hover .group-hover\:text-cyan-300 {
  color: #67e8f9;
}

.group:hover .group-hover\:text-cyan-400 {
  color: #22d3ee;
}

.group:hover .group-hover\:text-cyan-500 {
  color: #06b6d4;
}

.group:hover .group-hover\:text-cyan-600 {
  color: #0891b2;
}

.group:hover .group-hover\:text-cyan-700 {
  color: #0e7490;
}

.group:hover .group-hover\:text-cyan-800 {
  color: #155e75;
}

.group:hover .group-hover\:text-cyan-900 {
  color: #164e63;
}

.group:hover .group-hover\:text-indigo-50 {
  color: #eef2ff;
}

.group:hover .group-hover\:text-indigo-100 {
  color: #e0e7ff;
}

.group:hover .group-hover\:text-indigo-200 {
  color: #c7d2fe;
}

.group:hover .group-hover\:text-indigo-300 {
  color: #a5b4fc;
}

.group:hover .group-hover\:text-indigo-400 {
  color: #818cf8;
}

.group:hover .group-hover\:text-indigo-500 {
  color: #6366f1;
}

.group:hover .group-hover\:text-indigo-600 {
  color: #4f46e5;
}

.group:hover .group-hover\:text-indigo-700 {
  color: #4338ca;
}

.group:hover .group-hover\:text-indigo-800 {
  color: #3730a3;
}

.group:hover .group-hover\:text-indigo-900 {
  color: #312e81;
}

.group:hover .group-hover\:text-purple-50 {
  color: #f5f3ff;
}

.group:hover .group-hover\:text-purple-100 {
  color: #ede9fe;
}

.group:hover .group-hover\:text-purple-200 {
  color: #ddd6fe;
}

.group:hover .group-hover\:text-purple-300 {
  color: #c4b5fd;
}

.group:hover .group-hover\:text-purple-400 {
  color: #a78bfa;
}

.group:hover .group-hover\:text-purple-500 {
  color: #8b5cf6;
}

.group:hover .group-hover\:text-purple-600 {
  color: #7c3aed;
}

.group:hover .group-hover\:text-purple-700 {
  color: #6d28d9;
}

.group:hover .group-hover\:text-purple-800 {
  color: #5b21b6;
}

.group:hover .group-hover\:text-purple-900 {
  color: #4c1d95;
}

.group:hover .group-hover\:text-pink-50 {
  color: #fdf2f8;
}

.group:hover .group-hover\:text-pink-100 {
  color: #fce7f3;
}

.group:hover .group-hover\:text-pink-200 {
  color: #fbcfe8;
}

.group:hover .group-hover\:text-pink-300 {
  color: #f9a8d4;
}

.group:hover .group-hover\:text-pink-400 {
  color: #f472b6;
}

.group:hover .group-hover\:text-pink-500 {
  color: #ec4899;
}

.group:hover .group-hover\:text-pink-600 {
  color: #db2777;
}

.group:hover .group-hover\:text-pink-700 {
  color: #be185d;
}

.group:hover .group-hover\:text-pink-800 {
  color: #9d174d;
}

.group:hover .group-hover\:text-pink-900 {
  color: #831843;
}

@media (max-width: 768px) {
  .m\:text-transparent {
    color: transparent;
  }

  .m\:text-current {
    color: currentColor;
  }

  .m\:text-black {
    color: #000;
  }

  .m\:text-white {
    color: #fff;
  }

  .m\:text-primary {
    color: #007bff;
  }

  .m\:text-secondary {
    color: #6c757d;
  }

  .m\:text-success {
    color: #28a745;
  }

  .m\:text-info {
    color: #17a2b8;
  }

  .m\:text-warning {
    color: #fad733;
  }

  .m\:text-danger {
    color: #dc3545;
  }

  .m\:text-light {
    color: #f8f9fa;
  }

  .m\:text-dark {
    color: #343a40;
  }

  .m\:text-gray-50 {
    color: #f9fafb;
  }

  .m\:text-gray-100 {
    color: #f3f4f6;
  }

  .m\:text-gray-200 {
    color: #e5e7eb;
  }

  .m\:text-gray-300 {
    color: #d1d5db;
  }

  .m\:text-gray-400 {
    color: #9ca3af;
  }

  .m\:text-gray-500 {
    color: #6b7280;
  }

  .m\:text-gray-600 {
    color: #4b5563;
  }

  .m\:text-gray-700 {
    color: #374151;
  }

  .m\:text-gray-800 {
    color: #1f2937;
  }

  .m\:text-gray-900 {
    color: #111827;
  }

  .m\:text-red-50 {
    color: #fef2f2;
  }

  .m\:text-red-100 {
    color: #fee2e2;
  }

  .m\:text-red-200 {
    color: #fecaca;
  }

  .m\:text-red-300 {
    color: #fca5a5;
  }

  .m\:text-red-400 {
    color: #f87171;
  }

  .m\:text-red-500 {
    color: #ef4444;
  }

  .m\:text-red-600 {
    color: #dc2626;
  }

  .m\:text-red-700 {
    color: #b91c1c;
  }

  .m\:text-red-800 {
    color: #991b1b;
  }

  .m\:text-red-900 {
    color: #7f1d1d;
  }

  .m\:text-yellow-50 {
    color: #fffbeb;
  }

  .m\:text-yellow-100 {
    color: #fef3c7;
  }

  .m\:text-yellow-200 {
    color: #fde68a;
  }

  .m\:text-yellow-300 {
    color: #fcd34d;
  }

  .m\:text-yellow-400 {
    color: #fbbf24;
  }

  .m\:text-yellow-500 {
    color: #f59e0b;
  }

  .m\:text-yellow-600 {
    color: #d97706;
  }

  .m\:text-yellow-700 {
    color: #b45309;
  }

  .m\:text-yellow-800 {
    color: #92400e;
  }

  .m\:text-yellow-900 {
    color: #78350f;
  }

  .m\:text-green-50 {
    color: #ecfdf5;
  }

  .m\:text-green-100 {
    color: #d1fae5;
  }

  .m\:text-green-200 {
    color: #a7f3d0;
  }

  .m\:text-green-300 {
    color: #6ee7b7;
  }

  .m\:text-green-400 {
    color: #34d399;
  }

  .m\:text-green-500 {
    color: #10b981;
  }

  .m\:text-green-600 {
    color: #059669;
  }

  .m\:text-green-700 {
    color: #047857;
  }

  .m\:text-green-800 {
    color: #065f46;
  }

  .m\:text-green-900 {
    color: #064e3b;
  }

  .m\:text-blue-50 {
    color: #eff6ff;
  }

  .m\:text-blue-100 {
    color: #dbeafe;
  }

  .m\:text-blue-200 {
    color: #bfdbfe;
  }

  .m\:text-blue-300 {
    color: #93c5fd;
  }

  .m\:text-blue-400 {
    color: #60a5fa;
  }

  .m\:text-blue-500 {
    color: #3b82f6;
  }

  .m\:text-blue-600 {
    color: #2563eb;
  }

  .m\:text-blue-700 {
    color: #1d4ed8;
  }

  .m\:text-blue-800 {
    color: #1e40af;
  }

  .m\:text-blue-900 {
    color: #1e3a8a;
  }

  .m\:text-cyan-50 {
    color: #ecfeff;
  }

  .m\:text-cyan-100 {
    color: #cffafe;
  }

  .m\:text-cyan-200 {
    color: #a5f3fc;
  }

  .m\:text-cyan-300 {
    color: #67e8f9;
  }

  .m\:text-cyan-400 {
    color: #22d3ee;
  }

  .m\:text-cyan-500 {
    color: #06b6d4;
  }

  .m\:text-cyan-600 {
    color: #0891b2;
  }

  .m\:text-cyan-700 {
    color: #0e7490;
  }

  .m\:text-cyan-800 {
    color: #155e75;
  }

  .m\:text-cyan-900 {
    color: #164e63;
  }

  .m\:text-indigo-50 {
    color: #eef2ff;
  }

  .m\:text-indigo-100 {
    color: #e0e7ff;
  }

  .m\:text-indigo-200 {
    color: #c7d2fe;
  }

  .m\:text-indigo-300 {
    color: #a5b4fc;
  }

  .m\:text-indigo-400 {
    color: #818cf8;
  }

  .m\:text-indigo-500 {
    color: #6366f1;
  }

  .m\:text-indigo-600 {
    color: #4f46e5;
  }

  .m\:text-indigo-700 {
    color: #4338ca;
  }

  .m\:text-indigo-800 {
    color: #3730a3;
  }

  .m\:text-indigo-900 {
    color: #312e81;
  }

  .m\:text-purple-50 {
    color: #f5f3ff;
  }

  .m\:text-purple-100 {
    color: #ede9fe;
  }

  .m\:text-purple-200 {
    color: #ddd6fe;
  }

  .m\:text-purple-300 {
    color: #c4b5fd;
  }

  .m\:text-purple-400 {
    color: #a78bfa;
  }

  .m\:text-purple-500 {
    color: #8b5cf6;
  }

  .m\:text-purple-600 {
    color: #7c3aed;
  }

  .m\:text-purple-700 {
    color: #6d28d9;
  }

  .m\:text-purple-800 {
    color: #5b21b6;
  }

  .m\:text-purple-900 {
    color: #4c1d95;
  }

  .m\:text-pink-50 {
    color: #fdf2f8;
  }

  .m\:text-pink-100 {
    color: #fce7f3;
  }

  .m\:text-pink-200 {
    color: #fbcfe8;
  }

  .m\:text-pink-300 {
    color: #f9a8d4;
  }

  .m\:text-pink-400 {
    color: #f472b6;
  }

  .m\:text-pink-500 {
    color: #ec4899;
  }

  .m\:text-pink-600 {
    color: #db2777;
  }

  .m\:text-pink-700 {
    color: #be185d;
  }

  .m\:text-pink-800 {
    color: #9d174d;
  }

  .m\:text-pink-900 {
    color: #831843;
  }

  .m\:hover\:text-transparent:hover {
    color: transparent;
  }

  .m\:hover\:text-current:hover {
    color: currentColor;
  }

  .m\:hover\:text-black:hover {
    color: #000;
  }

  .m\:hover\:text-white:hover {
    color: #fff;
  }

  .m\:hover\:text-primary:hover {
    color: #007bff;
  }

  .m\:hover\:text-secondary:hover {
    color: #6c757d;
  }

  .m\:hover\:text-success:hover {
    color: #28a745;
  }

  .m\:hover\:text-info:hover {
    color: #17a2b8;
  }

  .m\:hover\:text-warning:hover {
    color: #fad733;
  }

  .m\:hover\:text-danger:hover {
    color: #dc3545;
  }

  .m\:hover\:text-light:hover {
    color: #f8f9fa;
  }

  .m\:hover\:text-dark:hover {
    color: #343a40;
  }

  .m\:hover\:text-gray-50:hover {
    color: #f9fafb;
  }

  .m\:hover\:text-gray-100:hover {
    color: #f3f4f6;
  }

  .m\:hover\:text-gray-200:hover {
    color: #e5e7eb;
  }

  .m\:hover\:text-gray-300:hover {
    color: #d1d5db;
  }

  .m\:hover\:text-gray-400:hover {
    color: #9ca3af;
  }

  .m\:hover\:text-gray-500:hover {
    color: #6b7280;
  }

  .m\:hover\:text-gray-600:hover {
    color: #4b5563;
  }

  .m\:hover\:text-gray-700:hover {
    color: #374151;
  }

  .m\:hover\:text-gray-800:hover {
    color: #1f2937;
  }

  .m\:hover\:text-gray-900:hover {
    color: #111827;
  }

  .m\:hover\:text-red-50:hover {
    color: #fef2f2;
  }

  .m\:hover\:text-red-100:hover {
    color: #fee2e2;
  }

  .m\:hover\:text-red-200:hover {
    color: #fecaca;
  }

  .m\:hover\:text-red-300:hover {
    color: #fca5a5;
  }

  .m\:hover\:text-red-400:hover {
    color: #f87171;
  }

  .m\:hover\:text-red-500:hover {
    color: #ef4444;
  }

  .m\:hover\:text-red-600:hover {
    color: #dc2626;
  }

  .m\:hover\:text-red-700:hover {
    color: #b91c1c;
  }

  .m\:hover\:text-red-800:hover {
    color: #991b1b;
  }

  .m\:hover\:text-red-900:hover {
    color: #7f1d1d;
  }

  .m\:hover\:text-yellow-50:hover {
    color: #fffbeb;
  }

  .m\:hover\:text-yellow-100:hover {
    color: #fef3c7;
  }

  .m\:hover\:text-yellow-200:hover {
    color: #fde68a;
  }

  .m\:hover\:text-yellow-300:hover {
    color: #fcd34d;
  }

  .m\:hover\:text-yellow-400:hover {
    color: #fbbf24;
  }

  .m\:hover\:text-yellow-500:hover {
    color: #f59e0b;
  }

  .m\:hover\:text-yellow-600:hover {
    color: #d97706;
  }

  .m\:hover\:text-yellow-700:hover {
    color: #b45309;
  }

  .m\:hover\:text-yellow-800:hover {
    color: #92400e;
  }

  .m\:hover\:text-yellow-900:hover {
    color: #78350f;
  }

  .m\:hover\:text-green-50:hover {
    color: #ecfdf5;
  }

  .m\:hover\:text-green-100:hover {
    color: #d1fae5;
  }

  .m\:hover\:text-green-200:hover {
    color: #a7f3d0;
  }

  .m\:hover\:text-green-300:hover {
    color: #6ee7b7;
  }

  .m\:hover\:text-green-400:hover {
    color: #34d399;
  }

  .m\:hover\:text-green-500:hover {
    color: #10b981;
  }

  .m\:hover\:text-green-600:hover {
    color: #059669;
  }

  .m\:hover\:text-green-700:hover {
    color: #047857;
  }

  .m\:hover\:text-green-800:hover {
    color: #065f46;
  }

  .m\:hover\:text-green-900:hover {
    color: #064e3b;
  }

  .m\:hover\:text-blue-50:hover {
    color: #eff6ff;
  }

  .m\:hover\:text-blue-100:hover {
    color: #dbeafe;
  }

  .m\:hover\:text-blue-200:hover {
    color: #bfdbfe;
  }

  .m\:hover\:text-blue-300:hover {
    color: #93c5fd;
  }

  .m\:hover\:text-blue-400:hover {
    color: #60a5fa;
  }

  .m\:hover\:text-blue-500:hover {
    color: #3b82f6;
  }

  .m\:hover\:text-blue-600:hover {
    color: #2563eb;
  }

  .m\:hover\:text-blue-700:hover {
    color: #1d4ed8;
  }

  .m\:hover\:text-blue-800:hover {
    color: #1e40af;
  }

  .m\:hover\:text-blue-900:hover {
    color: #1e3a8a;
  }

  .m\:hover\:text-cyan-50:hover {
    color: #ecfeff;
  }

  .m\:hover\:text-cyan-100:hover {
    color: #cffafe;
  }

  .m\:hover\:text-cyan-200:hover {
    color: #a5f3fc;
  }

  .m\:hover\:text-cyan-300:hover {
    color: #67e8f9;
  }

  .m\:hover\:text-cyan-400:hover {
    color: #22d3ee;
  }

  .m\:hover\:text-cyan-500:hover {
    color: #06b6d4;
  }

  .m\:hover\:text-cyan-600:hover {
    color: #0891b2;
  }

  .m\:hover\:text-cyan-700:hover {
    color: #0e7490;
  }

  .m\:hover\:text-cyan-800:hover {
    color: #155e75;
  }

  .m\:hover\:text-cyan-900:hover {
    color: #164e63;
  }

  .m\:hover\:text-indigo-50:hover {
    color: #eef2ff;
  }

  .m\:hover\:text-indigo-100:hover {
    color: #e0e7ff;
  }

  .m\:hover\:text-indigo-200:hover {
    color: #c7d2fe;
  }

  .m\:hover\:text-indigo-300:hover {
    color: #a5b4fc;
  }

  .m\:hover\:text-indigo-400:hover {
    color: #818cf8;
  }

  .m\:hover\:text-indigo-500:hover {
    color: #6366f1;
  }

  .m\:hover\:text-indigo-600:hover {
    color: #4f46e5;
  }

  .m\:hover\:text-indigo-700:hover {
    color: #4338ca;
  }

  .m\:hover\:text-indigo-800:hover {
    color: #3730a3;
  }

  .m\:hover\:text-indigo-900:hover {
    color: #312e81;
  }

  .m\:hover\:text-purple-50:hover {
    color: #f5f3ff;
  }

  .m\:hover\:text-purple-100:hover {
    color: #ede9fe;
  }

  .m\:hover\:text-purple-200:hover {
    color: #ddd6fe;
  }

  .m\:hover\:text-purple-300:hover {
    color: #c4b5fd;
  }

  .m\:hover\:text-purple-400:hover {
    color: #a78bfa;
  }

  .m\:hover\:text-purple-500:hover {
    color: #8b5cf6;
  }

  .m\:hover\:text-purple-600:hover {
    color: #7c3aed;
  }

  .m\:hover\:text-purple-700:hover {
    color: #6d28d9;
  }

  .m\:hover\:text-purple-800:hover {
    color: #5b21b6;
  }

  .m\:hover\:text-purple-900:hover {
    color: #4c1d95;
  }

  .m\:hover\:text-pink-50:hover {
    color: #fdf2f8;
  }

  .m\:hover\:text-pink-100:hover {
    color: #fce7f3;
  }

  .m\:hover\:text-pink-200:hover {
    color: #fbcfe8;
  }

  .m\:hover\:text-pink-300:hover {
    color: #f9a8d4;
  }

  .m\:hover\:text-pink-400:hover {
    color: #f472b6;
  }

  .m\:hover\:text-pink-500:hover {
    color: #ec4899;
  }

  .m\:hover\:text-pink-600:hover {
    color: #db2777;
  }

  .m\:hover\:text-pink-700:hover {
    color: #be185d;
  }

  .m\:hover\:text-pink-800:hover {
    color: #9d174d;
  }

  .m\:hover\:text-pink-900:hover {
    color: #831843;
  }

  .m\:active\:text-transparent.is-active {
    color: transparent;
  }

  .m\:active\:text-current.is-active {
    color: currentColor;
  }

  .m\:active\:text-black.is-active,
.m\:active\:text-black:active {
    color: #000;
  }

  .m\:active\:text-white.is-active,
.m\:active\:text-white:active {
    color: #fff;
  }

  .m\:active\:text-primary.is-active,
.m\:active\:text-primary:active {
    color: #007bff;
  }

  .m\:active\:text-secondary.is-active,
.m\:active\:text-secondary:active {
    color: #6c757d;
  }

  .m\:active\:text-success.is-active,
.m\:active\:text-success:active {
    color: #28a745;
  }

  .m\:active\:text-info.is-active,
.m\:active\:text-info:active {
    color: #17a2b8;
  }

  .m\:active\:text-warning.is-active,
.m\:active\:text-warning:active {
    color: #fad733;
  }

  .m\:active\:text-danger.is-active,
.m\:active\:text-danger:active {
    color: #dc3545;
  }

  .m\:active\:text-light.is-active,
.m\:active\:text-light:active {
    color: #f8f9fa;
  }

  .m\:active\:text-dark.is-active,
.m\:active\:text-dark:active {
    color: #343a40;
  }

  .m\:active\:text-gray-50.is-active,
.m\:active\:text-gray-50:active {
    color: #f9fafb;
  }

  .m\:active\:text-gray-100.is-active,
.m\:active\:text-gray-100:active {
    color: #f3f4f6;
  }

  .m\:active\:text-gray-200.is-active,
.m\:active\:text-gray-200:active {
    color: #e5e7eb;
  }

  .m\:active\:text-gray-300.is-active,
.m\:active\:text-gray-300:active {
    color: #d1d5db;
  }

  .m\:active\:text-gray-400.is-active,
.m\:active\:text-gray-400:active {
    color: #9ca3af;
  }

  .m\:active\:text-gray-500.is-active,
.m\:active\:text-gray-500:active {
    color: #6b7280;
  }

  .m\:active\:text-gray-600.is-active,
.m\:active\:text-gray-600:active {
    color: #4b5563;
  }

  .m\:active\:text-gray-700.is-active,
.m\:active\:text-gray-700:active {
    color: #374151;
  }

  .m\:active\:text-gray-800.is-active,
.m\:active\:text-gray-800:active {
    color: #1f2937;
  }

  .m\:active\:text-gray-900.is-active,
.m\:active\:text-gray-900:active {
    color: #111827;
  }

  .m\:active\:text-red-50.is-active,
.m\:active\:text-red-50:active {
    color: #fef2f2;
  }

  .m\:active\:text-red-100.is-active,
.m\:active\:text-red-100:active {
    color: #fee2e2;
  }

  .m\:active\:text-red-200.is-active,
.m\:active\:text-red-200:active {
    color: #fecaca;
  }

  .m\:active\:text-red-300.is-active,
.m\:active\:text-red-300:active {
    color: #fca5a5;
  }

  .m\:active\:text-red-400.is-active,
.m\:active\:text-red-400:active {
    color: #f87171;
  }

  .m\:active\:text-red-500.is-active,
.m\:active\:text-red-500:active {
    color: #ef4444;
  }

  .m\:active\:text-red-600.is-active,
.m\:active\:text-red-600:active {
    color: #dc2626;
  }

  .m\:active\:text-red-700.is-active,
.m\:active\:text-red-700:active {
    color: #b91c1c;
  }

  .m\:active\:text-red-800.is-active,
.m\:active\:text-red-800:active {
    color: #991b1b;
  }

  .m\:active\:text-red-900.is-active,
.m\:active\:text-red-900:active {
    color: #7f1d1d;
  }

  .m\:active\:text-yellow-50.is-active,
.m\:active\:text-yellow-50:active {
    color: #fffbeb;
  }

  .m\:active\:text-yellow-100.is-active,
.m\:active\:text-yellow-100:active {
    color: #fef3c7;
  }

  .m\:active\:text-yellow-200.is-active,
.m\:active\:text-yellow-200:active {
    color: #fde68a;
  }

  .m\:active\:text-yellow-300.is-active,
.m\:active\:text-yellow-300:active {
    color: #fcd34d;
  }

  .m\:active\:text-yellow-400.is-active,
.m\:active\:text-yellow-400:active {
    color: #fbbf24;
  }

  .m\:active\:text-yellow-500.is-active,
.m\:active\:text-yellow-500:active {
    color: #f59e0b;
  }

  .m\:active\:text-yellow-600.is-active,
.m\:active\:text-yellow-600:active {
    color: #d97706;
  }

  .m\:active\:text-yellow-700.is-active,
.m\:active\:text-yellow-700:active {
    color: #b45309;
  }

  .m\:active\:text-yellow-800.is-active,
.m\:active\:text-yellow-800:active {
    color: #92400e;
  }

  .m\:active\:text-yellow-900.is-active,
.m\:active\:text-yellow-900:active {
    color: #78350f;
  }

  .m\:active\:text-green-50.is-active,
.m\:active\:text-green-50:active {
    color: #ecfdf5;
  }

  .m\:active\:text-green-100.is-active,
.m\:active\:text-green-100:active {
    color: #d1fae5;
  }

  .m\:active\:text-green-200.is-active,
.m\:active\:text-green-200:active {
    color: #a7f3d0;
  }

  .m\:active\:text-green-300.is-active,
.m\:active\:text-green-300:active {
    color: #6ee7b7;
  }

  .m\:active\:text-green-400.is-active,
.m\:active\:text-green-400:active {
    color: #34d399;
  }

  .m\:active\:text-green-500.is-active,
.m\:active\:text-green-500:active {
    color: #10b981;
  }

  .m\:active\:text-green-600.is-active,
.m\:active\:text-green-600:active {
    color: #059669;
  }

  .m\:active\:text-green-700.is-active,
.m\:active\:text-green-700:active {
    color: #047857;
  }

  .m\:active\:text-green-800.is-active,
.m\:active\:text-green-800:active {
    color: #065f46;
  }

  .m\:active\:text-green-900.is-active,
.m\:active\:text-green-900:active {
    color: #064e3b;
  }

  .m\:active\:text-blue-50.is-active,
.m\:active\:text-blue-50:active {
    color: #eff6ff;
  }

  .m\:active\:text-blue-100.is-active,
.m\:active\:text-blue-100:active {
    color: #dbeafe;
  }

  .m\:active\:text-blue-200.is-active,
.m\:active\:text-blue-200:active {
    color: #bfdbfe;
  }

  .m\:active\:text-blue-300.is-active,
.m\:active\:text-blue-300:active {
    color: #93c5fd;
  }

  .m\:active\:text-blue-400.is-active,
.m\:active\:text-blue-400:active {
    color: #60a5fa;
  }

  .m\:active\:text-blue-500.is-active,
.m\:active\:text-blue-500:active {
    color: #3b82f6;
  }

  .m\:active\:text-blue-600.is-active,
.m\:active\:text-blue-600:active {
    color: #2563eb;
  }

  .m\:active\:text-blue-700.is-active,
.m\:active\:text-blue-700:active {
    color: #1d4ed8;
  }

  .m\:active\:text-blue-800.is-active,
.m\:active\:text-blue-800:active {
    color: #1e40af;
  }

  .m\:active\:text-blue-900.is-active,
.m\:active\:text-blue-900:active {
    color: #1e3a8a;
  }

  .m\:active\:text-cyan-50.is-active,
.m\:active\:text-cyan-50:active {
    color: #ecfeff;
  }

  .m\:active\:text-cyan-100.is-active,
.m\:active\:text-cyan-100:active {
    color: #cffafe;
  }

  .m\:active\:text-cyan-200.is-active,
.m\:active\:text-cyan-200:active {
    color: #a5f3fc;
  }

  .m\:active\:text-cyan-300.is-active,
.m\:active\:text-cyan-300:active {
    color: #67e8f9;
  }

  .m\:active\:text-cyan-400.is-active,
.m\:active\:text-cyan-400:active {
    color: #22d3ee;
  }

  .m\:active\:text-cyan-500.is-active,
.m\:active\:text-cyan-500:active {
    color: #06b6d4;
  }

  .m\:active\:text-cyan-600.is-active,
.m\:active\:text-cyan-600:active {
    color: #0891b2;
  }

  .m\:active\:text-cyan-700.is-active,
.m\:active\:text-cyan-700:active {
    color: #0e7490;
  }

  .m\:active\:text-cyan-800.is-active,
.m\:active\:text-cyan-800:active {
    color: #155e75;
  }

  .m\:active\:text-cyan-900.is-active,
.m\:active\:text-cyan-900:active {
    color: #164e63;
  }

  .m\:active\:text-indigo-50.is-active,
.m\:active\:text-indigo-50:active {
    color: #eef2ff;
  }

  .m\:active\:text-indigo-100.is-active,
.m\:active\:text-indigo-100:active {
    color: #e0e7ff;
  }

  .m\:active\:text-indigo-200.is-active,
.m\:active\:text-indigo-200:active {
    color: #c7d2fe;
  }

  .m\:active\:text-indigo-300.is-active,
.m\:active\:text-indigo-300:active {
    color: #a5b4fc;
  }

  .m\:active\:text-indigo-400.is-active,
.m\:active\:text-indigo-400:active {
    color: #818cf8;
  }

  .m\:active\:text-indigo-500.is-active,
.m\:active\:text-indigo-500:active {
    color: #6366f1;
  }

  .m\:active\:text-indigo-600.is-active,
.m\:active\:text-indigo-600:active {
    color: #4f46e5;
  }

  .m\:active\:text-indigo-700.is-active,
.m\:active\:text-indigo-700:active {
    color: #4338ca;
  }

  .m\:active\:text-indigo-800.is-active,
.m\:active\:text-indigo-800:active {
    color: #3730a3;
  }

  .m\:active\:text-indigo-900.is-active,
.m\:active\:text-indigo-900:active {
    color: #312e81;
  }

  .m\:active\:text-purple-50.is-active,
.m\:active\:text-purple-50:active {
    color: #f5f3ff;
  }

  .m\:active\:text-purple-100.is-active,
.m\:active\:text-purple-100:active {
    color: #ede9fe;
  }

  .m\:active\:text-purple-200.is-active,
.m\:active\:text-purple-200:active {
    color: #ddd6fe;
  }

  .m\:active\:text-purple-300.is-active,
.m\:active\:text-purple-300:active {
    color: #c4b5fd;
  }

  .m\:active\:text-purple-400.is-active,
.m\:active\:text-purple-400:active {
    color: #a78bfa;
  }

  .m\:active\:text-purple-500.is-active,
.m\:active\:text-purple-500:active {
    color: #8b5cf6;
  }

  .m\:active\:text-purple-600.is-active,
.m\:active\:text-purple-600:active {
    color: #7c3aed;
  }

  .m\:active\:text-purple-700.is-active,
.m\:active\:text-purple-700:active {
    color: #6d28d9;
  }

  .m\:active\:text-purple-800.is-active,
.m\:active\:text-purple-800:active {
    color: #5b21b6;
  }

  .m\:active\:text-purple-900.is-active,
.m\:active\:text-purple-900:active {
    color: #4c1d95;
  }

  .m\:active\:text-pink-50.is-active,
.m\:active\:text-pink-50:active {
    color: #fdf2f8;
  }

  .m\:active\:text-pink-100.is-active,
.m\:active\:text-pink-100:active {
    color: #fce7f3;
  }

  .m\:active\:text-pink-200.is-active,
.m\:active\:text-pink-200:active {
    color: #fbcfe8;
  }

  .m\:active\:text-pink-300.is-active,
.m\:active\:text-pink-300:active {
    color: #f9a8d4;
  }

  .m\:active\:text-pink-400.is-active,
.m\:active\:text-pink-400:active {
    color: #f472b6;
  }

  .m\:active\:text-pink-500.is-active,
.m\:active\:text-pink-500:active {
    color: #ec4899;
  }

  .m\:active\:text-pink-600.is-active,
.m\:active\:text-pink-600:active {
    color: #db2777;
  }

  .m\:active\:text-pink-700.is-active,
.m\:active\:text-pink-700:active {
    color: #be185d;
  }

  .m\:active\:text-pink-800.is-active,
.m\:active\:text-pink-800:active {
    color: #9d174d;
  }

  .m\:active\:text-pink-900.is-active,
.m\:active\:text-pink-900:active {
    color: #831843;
  }

  .m\:focus\:text-transparent:focus {
    color: transparent;
  }

  .m\:focus\:text-current:focus {
    color: currentColor;
  }

  .m\:focus\:text-black:focus {
    color: #000;
  }

  .m\:focus\:text-white:focus {
    color: #fff;
  }

  .m\:focus\:text-primary:focus {
    color: #007bff;
  }

  .m\:focus\:text-secondary:focus {
    color: #6c757d;
  }

  .m\:focus\:text-success:focus {
    color: #28a745;
  }

  .m\:focus\:text-info:focus {
    color: #17a2b8;
  }

  .m\:focus\:text-warning:focus {
    color: #fad733;
  }

  .m\:focus\:text-danger:focus {
    color: #dc3545;
  }

  .m\:focus\:text-light:focus {
    color: #f8f9fa;
  }

  .m\:focus\:text-dark:focus {
    color: #343a40;
  }

  .m\:focus\:text-gray-50:focus {
    color: #f9fafb;
  }

  .m\:focus\:text-gray-100:focus {
    color: #f3f4f6;
  }

  .m\:focus\:text-gray-200:focus {
    color: #e5e7eb;
  }

  .m\:focus\:text-gray-300:focus {
    color: #d1d5db;
  }

  .m\:focus\:text-gray-400:focus {
    color: #9ca3af;
  }

  .m\:focus\:text-gray-500:focus {
    color: #6b7280;
  }

  .m\:focus\:text-gray-600:focus {
    color: #4b5563;
  }

  .m\:focus\:text-gray-700:focus {
    color: #374151;
  }

  .m\:focus\:text-gray-800:focus {
    color: #1f2937;
  }

  .m\:focus\:text-gray-900:focus {
    color: #111827;
  }

  .m\:focus\:text-red-50:focus {
    color: #fef2f2;
  }

  .m\:focus\:text-red-100:focus {
    color: #fee2e2;
  }

  .m\:focus\:text-red-200:focus {
    color: #fecaca;
  }

  .m\:focus\:text-red-300:focus {
    color: #fca5a5;
  }

  .m\:focus\:text-red-400:focus {
    color: #f87171;
  }

  .m\:focus\:text-red-500:focus {
    color: #ef4444;
  }

  .m\:focus\:text-red-600:focus {
    color: #dc2626;
  }

  .m\:focus\:text-red-700:focus {
    color: #b91c1c;
  }

  .m\:focus\:text-red-800:focus {
    color: #991b1b;
  }

  .m\:focus\:text-red-900:focus {
    color: #7f1d1d;
  }

  .m\:focus\:text-yellow-50:focus {
    color: #fffbeb;
  }

  .m\:focus\:text-yellow-100:focus {
    color: #fef3c7;
  }

  .m\:focus\:text-yellow-200:focus {
    color: #fde68a;
  }

  .m\:focus\:text-yellow-300:focus {
    color: #fcd34d;
  }

  .m\:focus\:text-yellow-400:focus {
    color: #fbbf24;
  }

  .m\:focus\:text-yellow-500:focus {
    color: #f59e0b;
  }

  .m\:focus\:text-yellow-600:focus {
    color: #d97706;
  }

  .m\:focus\:text-yellow-700:focus {
    color: #b45309;
  }

  .m\:focus\:text-yellow-800:focus {
    color: #92400e;
  }

  .m\:focus\:text-yellow-900:focus {
    color: #78350f;
  }

  .m\:focus\:text-green-50:focus {
    color: #ecfdf5;
  }

  .m\:focus\:text-green-100:focus {
    color: #d1fae5;
  }

  .m\:focus\:text-green-200:focus {
    color: #a7f3d0;
  }

  .m\:focus\:text-green-300:focus {
    color: #6ee7b7;
  }

  .m\:focus\:text-green-400:focus {
    color: #34d399;
  }

  .m\:focus\:text-green-500:focus {
    color: #10b981;
  }

  .m\:focus\:text-green-600:focus {
    color: #059669;
  }

  .m\:focus\:text-green-700:focus {
    color: #047857;
  }

  .m\:focus\:text-green-800:focus {
    color: #065f46;
  }

  .m\:focus\:text-green-900:focus {
    color: #064e3b;
  }

  .m\:focus\:text-blue-50:focus {
    color: #eff6ff;
  }

  .m\:focus\:text-blue-100:focus {
    color: #dbeafe;
  }

  .m\:focus\:text-blue-200:focus {
    color: #bfdbfe;
  }

  .m\:focus\:text-blue-300:focus {
    color: #93c5fd;
  }

  .m\:focus\:text-blue-400:focus {
    color: #60a5fa;
  }

  .m\:focus\:text-blue-500:focus {
    color: #3b82f6;
  }

  .m\:focus\:text-blue-600:focus {
    color: #2563eb;
  }

  .m\:focus\:text-blue-700:focus {
    color: #1d4ed8;
  }

  .m\:focus\:text-blue-800:focus {
    color: #1e40af;
  }

  .m\:focus\:text-blue-900:focus {
    color: #1e3a8a;
  }

  .m\:focus\:text-cyan-50:focus {
    color: #ecfeff;
  }

  .m\:focus\:text-cyan-100:focus {
    color: #cffafe;
  }

  .m\:focus\:text-cyan-200:focus {
    color: #a5f3fc;
  }

  .m\:focus\:text-cyan-300:focus {
    color: #67e8f9;
  }

  .m\:focus\:text-cyan-400:focus {
    color: #22d3ee;
  }

  .m\:focus\:text-cyan-500:focus {
    color: #06b6d4;
  }

  .m\:focus\:text-cyan-600:focus {
    color: #0891b2;
  }

  .m\:focus\:text-cyan-700:focus {
    color: #0e7490;
  }

  .m\:focus\:text-cyan-800:focus {
    color: #155e75;
  }

  .m\:focus\:text-cyan-900:focus {
    color: #164e63;
  }

  .m\:focus\:text-indigo-50:focus {
    color: #eef2ff;
  }

  .m\:focus\:text-indigo-100:focus {
    color: #e0e7ff;
  }

  .m\:focus\:text-indigo-200:focus {
    color: #c7d2fe;
  }

  .m\:focus\:text-indigo-300:focus {
    color: #a5b4fc;
  }

  .m\:focus\:text-indigo-400:focus {
    color: #818cf8;
  }

  .m\:focus\:text-indigo-500:focus {
    color: #6366f1;
  }

  .m\:focus\:text-indigo-600:focus {
    color: #4f46e5;
  }

  .m\:focus\:text-indigo-700:focus {
    color: #4338ca;
  }

  .m\:focus\:text-indigo-800:focus {
    color: #3730a3;
  }

  .m\:focus\:text-indigo-900:focus {
    color: #312e81;
  }

  .m\:focus\:text-purple-50:focus {
    color: #f5f3ff;
  }

  .m\:focus\:text-purple-100:focus {
    color: #ede9fe;
  }

  .m\:focus\:text-purple-200:focus {
    color: #ddd6fe;
  }

  .m\:focus\:text-purple-300:focus {
    color: #c4b5fd;
  }

  .m\:focus\:text-purple-400:focus {
    color: #a78bfa;
  }

  .m\:focus\:text-purple-500:focus {
    color: #8b5cf6;
  }

  .m\:focus\:text-purple-600:focus {
    color: #7c3aed;
  }

  .m\:focus\:text-purple-700:focus {
    color: #6d28d9;
  }

  .m\:focus\:text-purple-800:focus {
    color: #5b21b6;
  }

  .m\:focus\:text-purple-900:focus {
    color: #4c1d95;
  }

  .m\:focus\:text-pink-50:focus {
    color: #fdf2f8;
  }

  .m\:focus\:text-pink-100:focus {
    color: #fce7f3;
  }

  .m\:focus\:text-pink-200:focus {
    color: #fbcfe8;
  }

  .m\:focus\:text-pink-300:focus {
    color: #f9a8d4;
  }

  .m\:focus\:text-pink-400:focus {
    color: #f472b6;
  }

  .m\:focus\:text-pink-500:focus {
    color: #ec4899;
  }

  .m\:focus\:text-pink-600:focus {
    color: #db2777;
  }

  .m\:focus\:text-pink-700:focus {
    color: #be185d;
  }

  .m\:focus\:text-pink-800:focus {
    color: #9d174d;
  }

  .m\:focus\:text-pink-900:focus {
    color: #831843;
  }

  .m\:disabled\:text-transparent.is-disabled {
    color: transparent;
  }

  .m\:disabled\:text-current.is-disabled {
    color: currentColor;
  }

  .m\:disabled\:text-black.is-disabled,
.m\:disabled\:text-black:disabled {
    color: #000;
  }

  .m\:disabled\:text-white.is-disabled,
.m\:disabled\:text-white:disabled {
    color: #fff;
  }

  .m\:disabled\:text-primary.is-disabled,
.m\:disabled\:text-primary:disabled {
    color: #007bff;
  }

  .m\:disabled\:text-secondary.is-disabled,
.m\:disabled\:text-secondary:disabled {
    color: #6c757d;
  }

  .m\:disabled\:text-success.is-disabled,
.m\:disabled\:text-success:disabled {
    color: #28a745;
  }

  .m\:disabled\:text-info.is-disabled,
.m\:disabled\:text-info:disabled {
    color: #17a2b8;
  }

  .m\:disabled\:text-warning.is-disabled,
.m\:disabled\:text-warning:disabled {
    color: #fad733;
  }

  .m\:disabled\:text-danger.is-disabled,
.m\:disabled\:text-danger:disabled {
    color: #dc3545;
  }

  .m\:disabled\:text-light.is-disabled,
.m\:disabled\:text-light:disabled {
    color: #f8f9fa;
  }

  .m\:disabled\:text-dark.is-disabled,
.m\:disabled\:text-dark:disabled {
    color: #343a40;
  }

  .m\:disabled\:text-gray-50.is-disabled,
.m\:disabled\:text-gray-50:disabled {
    color: #f9fafb;
  }

  .m\:disabled\:text-gray-100.is-disabled,
.m\:disabled\:text-gray-100:disabled {
    color: #f3f4f6;
  }

  .m\:disabled\:text-gray-200.is-disabled,
.m\:disabled\:text-gray-200:disabled {
    color: #e5e7eb;
  }

  .m\:disabled\:text-gray-300.is-disabled,
.m\:disabled\:text-gray-300:disabled {
    color: #d1d5db;
  }

  .m\:disabled\:text-gray-400.is-disabled,
.m\:disabled\:text-gray-400:disabled {
    color: #9ca3af;
  }

  .m\:disabled\:text-gray-500.is-disabled,
.m\:disabled\:text-gray-500:disabled {
    color: #6b7280;
  }

  .m\:disabled\:text-gray-600.is-disabled,
.m\:disabled\:text-gray-600:disabled {
    color: #4b5563;
  }

  .m\:disabled\:text-gray-700.is-disabled,
.m\:disabled\:text-gray-700:disabled {
    color: #374151;
  }

  .m\:disabled\:text-gray-800.is-disabled,
.m\:disabled\:text-gray-800:disabled {
    color: #1f2937;
  }

  .m\:disabled\:text-gray-900.is-disabled,
.m\:disabled\:text-gray-900:disabled {
    color: #111827;
  }

  .m\:disabled\:text-red-50.is-disabled,
.m\:disabled\:text-red-50:disabled {
    color: #fef2f2;
  }

  .m\:disabled\:text-red-100.is-disabled,
.m\:disabled\:text-red-100:disabled {
    color: #fee2e2;
  }

  .m\:disabled\:text-red-200.is-disabled,
.m\:disabled\:text-red-200:disabled {
    color: #fecaca;
  }

  .m\:disabled\:text-red-300.is-disabled,
.m\:disabled\:text-red-300:disabled {
    color: #fca5a5;
  }

  .m\:disabled\:text-red-400.is-disabled,
.m\:disabled\:text-red-400:disabled {
    color: #f87171;
  }

  .m\:disabled\:text-red-500.is-disabled,
.m\:disabled\:text-red-500:disabled {
    color: #ef4444;
  }

  .m\:disabled\:text-red-600.is-disabled,
.m\:disabled\:text-red-600:disabled {
    color: #dc2626;
  }

  .m\:disabled\:text-red-700.is-disabled,
.m\:disabled\:text-red-700:disabled {
    color: #b91c1c;
  }

  .m\:disabled\:text-red-800.is-disabled,
.m\:disabled\:text-red-800:disabled {
    color: #991b1b;
  }

  .m\:disabled\:text-red-900.is-disabled,
.m\:disabled\:text-red-900:disabled {
    color: #7f1d1d;
  }

  .m\:disabled\:text-yellow-50.is-disabled,
.m\:disabled\:text-yellow-50:disabled {
    color: #fffbeb;
  }

  .m\:disabled\:text-yellow-100.is-disabled,
.m\:disabled\:text-yellow-100:disabled {
    color: #fef3c7;
  }

  .m\:disabled\:text-yellow-200.is-disabled,
.m\:disabled\:text-yellow-200:disabled {
    color: #fde68a;
  }

  .m\:disabled\:text-yellow-300.is-disabled,
.m\:disabled\:text-yellow-300:disabled {
    color: #fcd34d;
  }

  .m\:disabled\:text-yellow-400.is-disabled,
.m\:disabled\:text-yellow-400:disabled {
    color: #fbbf24;
  }

  .m\:disabled\:text-yellow-500.is-disabled,
.m\:disabled\:text-yellow-500:disabled {
    color: #f59e0b;
  }

  .m\:disabled\:text-yellow-600.is-disabled,
.m\:disabled\:text-yellow-600:disabled {
    color: #d97706;
  }

  .m\:disabled\:text-yellow-700.is-disabled,
.m\:disabled\:text-yellow-700:disabled {
    color: #b45309;
  }

  .m\:disabled\:text-yellow-800.is-disabled,
.m\:disabled\:text-yellow-800:disabled {
    color: #92400e;
  }

  .m\:disabled\:text-yellow-900.is-disabled,
.m\:disabled\:text-yellow-900:disabled {
    color: #78350f;
  }

  .m\:disabled\:text-green-50.is-disabled,
.m\:disabled\:text-green-50:disabled {
    color: #ecfdf5;
  }

  .m\:disabled\:text-green-100.is-disabled,
.m\:disabled\:text-green-100:disabled {
    color: #d1fae5;
  }

  .m\:disabled\:text-green-200.is-disabled,
.m\:disabled\:text-green-200:disabled {
    color: #a7f3d0;
  }

  .m\:disabled\:text-green-300.is-disabled,
.m\:disabled\:text-green-300:disabled {
    color: #6ee7b7;
  }

  .m\:disabled\:text-green-400.is-disabled,
.m\:disabled\:text-green-400:disabled {
    color: #34d399;
  }

  .m\:disabled\:text-green-500.is-disabled,
.m\:disabled\:text-green-500:disabled {
    color: #10b981;
  }

  .m\:disabled\:text-green-600.is-disabled,
.m\:disabled\:text-green-600:disabled {
    color: #059669;
  }

  .m\:disabled\:text-green-700.is-disabled,
.m\:disabled\:text-green-700:disabled {
    color: #047857;
  }

  .m\:disabled\:text-green-800.is-disabled,
.m\:disabled\:text-green-800:disabled {
    color: #065f46;
  }

  .m\:disabled\:text-green-900.is-disabled,
.m\:disabled\:text-green-900:disabled {
    color: #064e3b;
  }

  .m\:disabled\:text-blue-50.is-disabled,
.m\:disabled\:text-blue-50:disabled {
    color: #eff6ff;
  }

  .m\:disabled\:text-blue-100.is-disabled,
.m\:disabled\:text-blue-100:disabled {
    color: #dbeafe;
  }

  .m\:disabled\:text-blue-200.is-disabled,
.m\:disabled\:text-blue-200:disabled {
    color: #bfdbfe;
  }

  .m\:disabled\:text-blue-300.is-disabled,
.m\:disabled\:text-blue-300:disabled {
    color: #93c5fd;
  }

  .m\:disabled\:text-blue-400.is-disabled,
.m\:disabled\:text-blue-400:disabled {
    color: #60a5fa;
  }

  .m\:disabled\:text-blue-500.is-disabled,
.m\:disabled\:text-blue-500:disabled {
    color: #3b82f6;
  }

  .m\:disabled\:text-blue-600.is-disabled,
.m\:disabled\:text-blue-600:disabled {
    color: #2563eb;
  }

  .m\:disabled\:text-blue-700.is-disabled,
.m\:disabled\:text-blue-700:disabled {
    color: #1d4ed8;
  }

  .m\:disabled\:text-blue-800.is-disabled,
.m\:disabled\:text-blue-800:disabled {
    color: #1e40af;
  }

  .m\:disabled\:text-blue-900.is-disabled,
.m\:disabled\:text-blue-900:disabled {
    color: #1e3a8a;
  }

  .m\:disabled\:text-cyan-50.is-disabled,
.m\:disabled\:text-cyan-50:disabled {
    color: #ecfeff;
  }

  .m\:disabled\:text-cyan-100.is-disabled,
.m\:disabled\:text-cyan-100:disabled {
    color: #cffafe;
  }

  .m\:disabled\:text-cyan-200.is-disabled,
.m\:disabled\:text-cyan-200:disabled {
    color: #a5f3fc;
  }

  .m\:disabled\:text-cyan-300.is-disabled,
.m\:disabled\:text-cyan-300:disabled {
    color: #67e8f9;
  }

  .m\:disabled\:text-cyan-400.is-disabled,
.m\:disabled\:text-cyan-400:disabled {
    color: #22d3ee;
  }

  .m\:disabled\:text-cyan-500.is-disabled,
.m\:disabled\:text-cyan-500:disabled {
    color: #06b6d4;
  }

  .m\:disabled\:text-cyan-600.is-disabled,
.m\:disabled\:text-cyan-600:disabled {
    color: #0891b2;
  }

  .m\:disabled\:text-cyan-700.is-disabled,
.m\:disabled\:text-cyan-700:disabled {
    color: #0e7490;
  }

  .m\:disabled\:text-cyan-800.is-disabled,
.m\:disabled\:text-cyan-800:disabled {
    color: #155e75;
  }

  .m\:disabled\:text-cyan-900.is-disabled,
.m\:disabled\:text-cyan-900:disabled {
    color: #164e63;
  }

  .m\:disabled\:text-indigo-50.is-disabled,
.m\:disabled\:text-indigo-50:disabled {
    color: #eef2ff;
  }

  .m\:disabled\:text-indigo-100.is-disabled,
.m\:disabled\:text-indigo-100:disabled {
    color: #e0e7ff;
  }

  .m\:disabled\:text-indigo-200.is-disabled,
.m\:disabled\:text-indigo-200:disabled {
    color: #c7d2fe;
  }

  .m\:disabled\:text-indigo-300.is-disabled,
.m\:disabled\:text-indigo-300:disabled {
    color: #a5b4fc;
  }

  .m\:disabled\:text-indigo-400.is-disabled,
.m\:disabled\:text-indigo-400:disabled {
    color: #818cf8;
  }

  .m\:disabled\:text-indigo-500.is-disabled,
.m\:disabled\:text-indigo-500:disabled {
    color: #6366f1;
  }

  .m\:disabled\:text-indigo-600.is-disabled,
.m\:disabled\:text-indigo-600:disabled {
    color: #4f46e5;
  }

  .m\:disabled\:text-indigo-700.is-disabled,
.m\:disabled\:text-indigo-700:disabled {
    color: #4338ca;
  }

  .m\:disabled\:text-indigo-800.is-disabled,
.m\:disabled\:text-indigo-800:disabled {
    color: #3730a3;
  }

  .m\:disabled\:text-indigo-900.is-disabled,
.m\:disabled\:text-indigo-900:disabled {
    color: #312e81;
  }

  .m\:disabled\:text-purple-50.is-disabled,
.m\:disabled\:text-purple-50:disabled {
    color: #f5f3ff;
  }

  .m\:disabled\:text-purple-100.is-disabled,
.m\:disabled\:text-purple-100:disabled {
    color: #ede9fe;
  }

  .m\:disabled\:text-purple-200.is-disabled,
.m\:disabled\:text-purple-200:disabled {
    color: #ddd6fe;
  }

  .m\:disabled\:text-purple-300.is-disabled,
.m\:disabled\:text-purple-300:disabled {
    color: #c4b5fd;
  }

  .m\:disabled\:text-purple-400.is-disabled,
.m\:disabled\:text-purple-400:disabled {
    color: #a78bfa;
  }

  .m\:disabled\:text-purple-500.is-disabled,
.m\:disabled\:text-purple-500:disabled {
    color: #8b5cf6;
  }

  .m\:disabled\:text-purple-600.is-disabled,
.m\:disabled\:text-purple-600:disabled {
    color: #7c3aed;
  }

  .m\:disabled\:text-purple-700.is-disabled,
.m\:disabled\:text-purple-700:disabled {
    color: #6d28d9;
  }

  .m\:disabled\:text-purple-800.is-disabled,
.m\:disabled\:text-purple-800:disabled {
    color: #5b21b6;
  }

  .m\:disabled\:text-purple-900.is-disabled,
.m\:disabled\:text-purple-900:disabled {
    color: #4c1d95;
  }

  .m\:disabled\:text-pink-50.is-disabled,
.m\:disabled\:text-pink-50:disabled {
    color: #fdf2f8;
  }

  .m\:disabled\:text-pink-100.is-disabled,
.m\:disabled\:text-pink-100:disabled {
    color: #fce7f3;
  }

  .m\:disabled\:text-pink-200.is-disabled,
.m\:disabled\:text-pink-200:disabled {
    color: #fbcfe8;
  }

  .m\:disabled\:text-pink-300.is-disabled,
.m\:disabled\:text-pink-300:disabled {
    color: #f9a8d4;
  }

  .m\:disabled\:text-pink-400.is-disabled,
.m\:disabled\:text-pink-400:disabled {
    color: #f472b6;
  }

  .m\:disabled\:text-pink-500.is-disabled,
.m\:disabled\:text-pink-500:disabled {
    color: #ec4899;
  }

  .m\:disabled\:text-pink-600.is-disabled,
.m\:disabled\:text-pink-600:disabled {
    color: #db2777;
  }

  .m\:disabled\:text-pink-700.is-disabled,
.m\:disabled\:text-pink-700:disabled {
    color: #be185d;
  }

  .m\:disabled\:text-pink-800.is-disabled,
.m\:disabled\:text-pink-800:disabled {
    color: #9d174d;
  }

  .m\:disabled\:text-pink-900.is-disabled,
.m\:disabled\:text-pink-900:disabled {
    color: #831843;
  }

  .group:hover .m\:group-hover\:text-transparent {
    color: transparent;
  }

  .group:hover .m\:group-hover\:text-current {
    color: currentColor;
  }

  .group:hover .m\:group-hover\:text-black {
    color: #000;
  }

  .group:hover .m\:group-hover\:text-white {
    color: #fff;
  }

  .group:hover .m\:group-hover\:text-primary {
    color: #007bff;
  }

  .group:hover .m\:group-hover\:text-secondary {
    color: #6c757d;
  }

  .group:hover .m\:group-hover\:text-success {
    color: #28a745;
  }

  .group:hover .m\:group-hover\:text-info {
    color: #17a2b8;
  }

  .group:hover .m\:group-hover\:text-warning {
    color: #fad733;
  }

  .group:hover .m\:group-hover\:text-danger {
    color: #dc3545;
  }

  .group:hover .m\:group-hover\:text-light {
    color: #f8f9fa;
  }

  .group:hover .m\:group-hover\:text-dark {
    color: #343a40;
  }

  .group:hover .m\:group-hover\:text-gray-50 {
    color: #f9fafb;
  }

  .group:hover .m\:group-hover\:text-gray-100 {
    color: #f3f4f6;
  }

  .group:hover .m\:group-hover\:text-gray-200 {
    color: #e5e7eb;
  }

  .group:hover .m\:group-hover\:text-gray-300 {
    color: #d1d5db;
  }

  .group:hover .m\:group-hover\:text-gray-400 {
    color: #9ca3af;
  }

  .group:hover .m\:group-hover\:text-gray-500 {
    color: #6b7280;
  }

  .group:hover .m\:group-hover\:text-gray-600 {
    color: #4b5563;
  }

  .group:hover .m\:group-hover\:text-gray-700 {
    color: #374151;
  }

  .group:hover .m\:group-hover\:text-gray-800 {
    color: #1f2937;
  }

  .group:hover .m\:group-hover\:text-gray-900 {
    color: #111827;
  }

  .group:hover .m\:group-hover\:text-red-50 {
    color: #fef2f2;
  }

  .group:hover .m\:group-hover\:text-red-100 {
    color: #fee2e2;
  }

  .group:hover .m\:group-hover\:text-red-200 {
    color: #fecaca;
  }

  .group:hover .m\:group-hover\:text-red-300 {
    color: #fca5a5;
  }

  .group:hover .m\:group-hover\:text-red-400 {
    color: #f87171;
  }

  .group:hover .m\:group-hover\:text-red-500 {
    color: #ef4444;
  }

  .group:hover .m\:group-hover\:text-red-600 {
    color: #dc2626;
  }

  .group:hover .m\:group-hover\:text-red-700 {
    color: #b91c1c;
  }

  .group:hover .m\:group-hover\:text-red-800 {
    color: #991b1b;
  }

  .group:hover .m\:group-hover\:text-red-900 {
    color: #7f1d1d;
  }

  .group:hover .m\:group-hover\:text-yellow-50 {
    color: #fffbeb;
  }

  .group:hover .m\:group-hover\:text-yellow-100 {
    color: #fef3c7;
  }

  .group:hover .m\:group-hover\:text-yellow-200 {
    color: #fde68a;
  }

  .group:hover .m\:group-hover\:text-yellow-300 {
    color: #fcd34d;
  }

  .group:hover .m\:group-hover\:text-yellow-400 {
    color: #fbbf24;
  }

  .group:hover .m\:group-hover\:text-yellow-500 {
    color: #f59e0b;
  }

  .group:hover .m\:group-hover\:text-yellow-600 {
    color: #d97706;
  }

  .group:hover .m\:group-hover\:text-yellow-700 {
    color: #b45309;
  }

  .group:hover .m\:group-hover\:text-yellow-800 {
    color: #92400e;
  }

  .group:hover .m\:group-hover\:text-yellow-900 {
    color: #78350f;
  }

  .group:hover .m\:group-hover\:text-green-50 {
    color: #ecfdf5;
  }

  .group:hover .m\:group-hover\:text-green-100 {
    color: #d1fae5;
  }

  .group:hover .m\:group-hover\:text-green-200 {
    color: #a7f3d0;
  }

  .group:hover .m\:group-hover\:text-green-300 {
    color: #6ee7b7;
  }

  .group:hover .m\:group-hover\:text-green-400 {
    color: #34d399;
  }

  .group:hover .m\:group-hover\:text-green-500 {
    color: #10b981;
  }

  .group:hover .m\:group-hover\:text-green-600 {
    color: #059669;
  }

  .group:hover .m\:group-hover\:text-green-700 {
    color: #047857;
  }

  .group:hover .m\:group-hover\:text-green-800 {
    color: #065f46;
  }

  .group:hover .m\:group-hover\:text-green-900 {
    color: #064e3b;
  }

  .group:hover .m\:group-hover\:text-blue-50 {
    color: #eff6ff;
  }

  .group:hover .m\:group-hover\:text-blue-100 {
    color: #dbeafe;
  }

  .group:hover .m\:group-hover\:text-blue-200 {
    color: #bfdbfe;
  }

  .group:hover .m\:group-hover\:text-blue-300 {
    color: #93c5fd;
  }

  .group:hover .m\:group-hover\:text-blue-400 {
    color: #60a5fa;
  }

  .group:hover .m\:group-hover\:text-blue-500 {
    color: #3b82f6;
  }

  .group:hover .m\:group-hover\:text-blue-600 {
    color: #2563eb;
  }

  .group:hover .m\:group-hover\:text-blue-700 {
    color: #1d4ed8;
  }

  .group:hover .m\:group-hover\:text-blue-800 {
    color: #1e40af;
  }

  .group:hover .m\:group-hover\:text-blue-900 {
    color: #1e3a8a;
  }

  .group:hover .m\:group-hover\:text-cyan-50 {
    color: #ecfeff;
  }

  .group:hover .m\:group-hover\:text-cyan-100 {
    color: #cffafe;
  }

  .group:hover .m\:group-hover\:text-cyan-200 {
    color: #a5f3fc;
  }

  .group:hover .m\:group-hover\:text-cyan-300 {
    color: #67e8f9;
  }

  .group:hover .m\:group-hover\:text-cyan-400 {
    color: #22d3ee;
  }

  .group:hover .m\:group-hover\:text-cyan-500 {
    color: #06b6d4;
  }

  .group:hover .m\:group-hover\:text-cyan-600 {
    color: #0891b2;
  }

  .group:hover .m\:group-hover\:text-cyan-700 {
    color: #0e7490;
  }

  .group:hover .m\:group-hover\:text-cyan-800 {
    color: #155e75;
  }

  .group:hover .m\:group-hover\:text-cyan-900 {
    color: #164e63;
  }

  .group:hover .m\:group-hover\:text-indigo-50 {
    color: #eef2ff;
  }

  .group:hover .m\:group-hover\:text-indigo-100 {
    color: #e0e7ff;
  }

  .group:hover .m\:group-hover\:text-indigo-200 {
    color: #c7d2fe;
  }

  .group:hover .m\:group-hover\:text-indigo-300 {
    color: #a5b4fc;
  }

  .group:hover .m\:group-hover\:text-indigo-400 {
    color: #818cf8;
  }

  .group:hover .m\:group-hover\:text-indigo-500 {
    color: #6366f1;
  }

  .group:hover .m\:group-hover\:text-indigo-600 {
    color: #4f46e5;
  }

  .group:hover .m\:group-hover\:text-indigo-700 {
    color: #4338ca;
  }

  .group:hover .m\:group-hover\:text-indigo-800 {
    color: #3730a3;
  }

  .group:hover .m\:group-hover\:text-indigo-900 {
    color: #312e81;
  }

  .group:hover .m\:group-hover\:text-purple-50 {
    color: #f5f3ff;
  }

  .group:hover .m\:group-hover\:text-purple-100 {
    color: #ede9fe;
  }

  .group:hover .m\:group-hover\:text-purple-200 {
    color: #ddd6fe;
  }

  .group:hover .m\:group-hover\:text-purple-300 {
    color: #c4b5fd;
  }

  .group:hover .m\:group-hover\:text-purple-400 {
    color: #a78bfa;
  }

  .group:hover .m\:group-hover\:text-purple-500 {
    color: #8b5cf6;
  }

  .group:hover .m\:group-hover\:text-purple-600 {
    color: #7c3aed;
  }

  .group:hover .m\:group-hover\:text-purple-700 {
    color: #6d28d9;
  }

  .group:hover .m\:group-hover\:text-purple-800 {
    color: #5b21b6;
  }

  .group:hover .m\:group-hover\:text-purple-900 {
    color: #4c1d95;
  }

  .group:hover .m\:group-hover\:text-pink-50 {
    color: #fdf2f8;
  }

  .group:hover .m\:group-hover\:text-pink-100 {
    color: #fce7f3;
  }

  .group:hover .m\:group-hover\:text-pink-200 {
    color: #fbcfe8;
  }

  .group:hover .m\:group-hover\:text-pink-300 {
    color: #f9a8d4;
  }

  .group:hover .m\:group-hover\:text-pink-400 {
    color: #f472b6;
  }

  .group:hover .m\:group-hover\:text-pink-500 {
    color: #ec4899;
  }

  .group:hover .m\:group-hover\:text-pink-600 {
    color: #db2777;
  }

  .group:hover .m\:group-hover\:text-pink-700 {
    color: #be185d;
  }

  .group:hover .m\:group-hover\:text-pink-800 {
    color: #9d174d;
  }

  .group:hover .m\:group-hover\:text-pink-900 {
    color: #831843;
  }
}
@media (min-width: 769px) {
  .pc\:text-transparent {
    color: transparent;
  }

  .pc\:text-current {
    color: currentColor;
  }

  .pc\:text-black {
    color: #000;
  }

  .pc\:text-white {
    color: #fff;
  }

  .pc\:text-primary {
    color: #007bff;
  }

  .pc\:text-secondary {
    color: #6c757d;
  }

  .pc\:text-success {
    color: #28a745;
  }

  .pc\:text-info {
    color: #17a2b8;
  }

  .pc\:text-warning {
    color: #fad733;
  }

  .pc\:text-danger {
    color: #dc3545;
  }

  .pc\:text-light {
    color: #f8f9fa;
  }

  .pc\:text-dark {
    color: #343a40;
  }

  .pc\:text-gray-50 {
    color: #f9fafb;
  }

  .pc\:text-gray-100 {
    color: #f3f4f6;
  }

  .pc\:text-gray-200 {
    color: #e5e7eb;
  }

  .pc\:text-gray-300 {
    color: #d1d5db;
  }

  .pc\:text-gray-400 {
    color: #9ca3af;
  }

  .pc\:text-gray-500 {
    color: #6b7280;
  }

  .pc\:text-gray-600 {
    color: #4b5563;
  }

  .pc\:text-gray-700 {
    color: #374151;
  }

  .pc\:text-gray-800 {
    color: #1f2937;
  }

  .pc\:text-gray-900 {
    color: #111827;
  }

  .pc\:text-red-50 {
    color: #fef2f2;
  }

  .pc\:text-red-100 {
    color: #fee2e2;
  }

  .pc\:text-red-200 {
    color: #fecaca;
  }

  .pc\:text-red-300 {
    color: #fca5a5;
  }

  .pc\:text-red-400 {
    color: #f87171;
  }

  .pc\:text-red-500 {
    color: #ef4444;
  }

  .pc\:text-red-600 {
    color: #dc2626;
  }

  .pc\:text-red-700 {
    color: #b91c1c;
  }

  .pc\:text-red-800 {
    color: #991b1b;
  }

  .pc\:text-red-900 {
    color: #7f1d1d;
  }

  .pc\:text-yellow-50 {
    color: #fffbeb;
  }

  .pc\:text-yellow-100 {
    color: #fef3c7;
  }

  .pc\:text-yellow-200 {
    color: #fde68a;
  }

  .pc\:text-yellow-300 {
    color: #fcd34d;
  }

  .pc\:text-yellow-400 {
    color: #fbbf24;
  }

  .pc\:text-yellow-500 {
    color: #f59e0b;
  }

  .pc\:text-yellow-600 {
    color: #d97706;
  }

  .pc\:text-yellow-700 {
    color: #b45309;
  }

  .pc\:text-yellow-800 {
    color: #92400e;
  }

  .pc\:text-yellow-900 {
    color: #78350f;
  }

  .pc\:text-green-50 {
    color: #ecfdf5;
  }

  .pc\:text-green-100 {
    color: #d1fae5;
  }

  .pc\:text-green-200 {
    color: #a7f3d0;
  }

  .pc\:text-green-300 {
    color: #6ee7b7;
  }

  .pc\:text-green-400 {
    color: #34d399;
  }

  .pc\:text-green-500 {
    color: #10b981;
  }

  .pc\:text-green-600 {
    color: #059669;
  }

  .pc\:text-green-700 {
    color: #047857;
  }

  .pc\:text-green-800 {
    color: #065f46;
  }

  .pc\:text-green-900 {
    color: #064e3b;
  }

  .pc\:text-blue-50 {
    color: #eff6ff;
  }

  .pc\:text-blue-100 {
    color: #dbeafe;
  }

  .pc\:text-blue-200 {
    color: #bfdbfe;
  }

  .pc\:text-blue-300 {
    color: #93c5fd;
  }

  .pc\:text-blue-400 {
    color: #60a5fa;
  }

  .pc\:text-blue-500 {
    color: #3b82f6;
  }

  .pc\:text-blue-600 {
    color: #2563eb;
  }

  .pc\:text-blue-700 {
    color: #1d4ed8;
  }

  .pc\:text-blue-800 {
    color: #1e40af;
  }

  .pc\:text-blue-900 {
    color: #1e3a8a;
  }

  .pc\:text-cyan-50 {
    color: #ecfeff;
  }

  .pc\:text-cyan-100 {
    color: #cffafe;
  }

  .pc\:text-cyan-200 {
    color: #a5f3fc;
  }

  .pc\:text-cyan-300 {
    color: #67e8f9;
  }

  .pc\:text-cyan-400 {
    color: #22d3ee;
  }

  .pc\:text-cyan-500 {
    color: #06b6d4;
  }

  .pc\:text-cyan-600 {
    color: #0891b2;
  }

  .pc\:text-cyan-700 {
    color: #0e7490;
  }

  .pc\:text-cyan-800 {
    color: #155e75;
  }

  .pc\:text-cyan-900 {
    color: #164e63;
  }

  .pc\:text-indigo-50 {
    color: #eef2ff;
  }

  .pc\:text-indigo-100 {
    color: #e0e7ff;
  }

  .pc\:text-indigo-200 {
    color: #c7d2fe;
  }

  .pc\:text-indigo-300 {
    color: #a5b4fc;
  }

  .pc\:text-indigo-400 {
    color: #818cf8;
  }

  .pc\:text-indigo-500 {
    color: #6366f1;
  }

  .pc\:text-indigo-600 {
    color: #4f46e5;
  }

  .pc\:text-indigo-700 {
    color: #4338ca;
  }

  .pc\:text-indigo-800 {
    color: #3730a3;
  }

  .pc\:text-indigo-900 {
    color: #312e81;
  }

  .pc\:text-purple-50 {
    color: #f5f3ff;
  }

  .pc\:text-purple-100 {
    color: #ede9fe;
  }

  .pc\:text-purple-200 {
    color: #ddd6fe;
  }

  .pc\:text-purple-300 {
    color: #c4b5fd;
  }

  .pc\:text-purple-400 {
    color: #a78bfa;
  }

  .pc\:text-purple-500 {
    color: #8b5cf6;
  }

  .pc\:text-purple-600 {
    color: #7c3aed;
  }

  .pc\:text-purple-700 {
    color: #6d28d9;
  }

  .pc\:text-purple-800 {
    color: #5b21b6;
  }

  .pc\:text-purple-900 {
    color: #4c1d95;
  }

  .pc\:text-pink-50 {
    color: #fdf2f8;
  }

  .pc\:text-pink-100 {
    color: #fce7f3;
  }

  .pc\:text-pink-200 {
    color: #fbcfe8;
  }

  .pc\:text-pink-300 {
    color: #f9a8d4;
  }

  .pc\:text-pink-400 {
    color: #f472b6;
  }

  .pc\:text-pink-500 {
    color: #ec4899;
  }

  .pc\:text-pink-600 {
    color: #db2777;
  }

  .pc\:text-pink-700 {
    color: #be185d;
  }

  .pc\:text-pink-800 {
    color: #9d174d;
  }

  .pc\:text-pink-900 {
    color: #831843;
  }

  .pc\:hover\:text-transparent:hover {
    color: transparent;
  }

  .pc\:hover\:text-current:hover {
    color: currentColor;
  }

  .pc\:hover\:text-black:hover {
    color: #000;
  }

  .pc\:hover\:text-white:hover {
    color: #fff;
  }

  .pc\:hover\:text-primary:hover {
    color: #007bff;
  }

  .pc\:hover\:text-secondary:hover {
    color: #6c757d;
  }

  .pc\:hover\:text-success:hover {
    color: #28a745;
  }

  .pc\:hover\:text-info:hover {
    color: #17a2b8;
  }

  .pc\:hover\:text-warning:hover {
    color: #fad733;
  }

  .pc\:hover\:text-danger:hover {
    color: #dc3545;
  }

  .pc\:hover\:text-light:hover {
    color: #f8f9fa;
  }

  .pc\:hover\:text-dark:hover {
    color: #343a40;
  }

  .pc\:hover\:text-gray-50:hover {
    color: #f9fafb;
  }

  .pc\:hover\:text-gray-100:hover {
    color: #f3f4f6;
  }

  .pc\:hover\:text-gray-200:hover {
    color: #e5e7eb;
  }

  .pc\:hover\:text-gray-300:hover {
    color: #d1d5db;
  }

  .pc\:hover\:text-gray-400:hover {
    color: #9ca3af;
  }

  .pc\:hover\:text-gray-500:hover {
    color: #6b7280;
  }

  .pc\:hover\:text-gray-600:hover {
    color: #4b5563;
  }

  .pc\:hover\:text-gray-700:hover {
    color: #374151;
  }

  .pc\:hover\:text-gray-800:hover {
    color: #1f2937;
  }

  .pc\:hover\:text-gray-900:hover {
    color: #111827;
  }

  .pc\:hover\:text-red-50:hover {
    color: #fef2f2;
  }

  .pc\:hover\:text-red-100:hover {
    color: #fee2e2;
  }

  .pc\:hover\:text-red-200:hover {
    color: #fecaca;
  }

  .pc\:hover\:text-red-300:hover {
    color: #fca5a5;
  }

  .pc\:hover\:text-red-400:hover {
    color: #f87171;
  }

  .pc\:hover\:text-red-500:hover {
    color: #ef4444;
  }

  .pc\:hover\:text-red-600:hover {
    color: #dc2626;
  }

  .pc\:hover\:text-red-700:hover {
    color: #b91c1c;
  }

  .pc\:hover\:text-red-800:hover {
    color: #991b1b;
  }

  .pc\:hover\:text-red-900:hover {
    color: #7f1d1d;
  }

  .pc\:hover\:text-yellow-50:hover {
    color: #fffbeb;
  }

  .pc\:hover\:text-yellow-100:hover {
    color: #fef3c7;
  }

  .pc\:hover\:text-yellow-200:hover {
    color: #fde68a;
  }

  .pc\:hover\:text-yellow-300:hover {
    color: #fcd34d;
  }

  .pc\:hover\:text-yellow-400:hover {
    color: #fbbf24;
  }

  .pc\:hover\:text-yellow-500:hover {
    color: #f59e0b;
  }

  .pc\:hover\:text-yellow-600:hover {
    color: #d97706;
  }

  .pc\:hover\:text-yellow-700:hover {
    color: #b45309;
  }

  .pc\:hover\:text-yellow-800:hover {
    color: #92400e;
  }

  .pc\:hover\:text-yellow-900:hover {
    color: #78350f;
  }

  .pc\:hover\:text-green-50:hover {
    color: #ecfdf5;
  }

  .pc\:hover\:text-green-100:hover {
    color: #d1fae5;
  }

  .pc\:hover\:text-green-200:hover {
    color: #a7f3d0;
  }

  .pc\:hover\:text-green-300:hover {
    color: #6ee7b7;
  }

  .pc\:hover\:text-green-400:hover {
    color: #34d399;
  }

  .pc\:hover\:text-green-500:hover {
    color: #10b981;
  }

  .pc\:hover\:text-green-600:hover {
    color: #059669;
  }

  .pc\:hover\:text-green-700:hover {
    color: #047857;
  }

  .pc\:hover\:text-green-800:hover {
    color: #065f46;
  }

  .pc\:hover\:text-green-900:hover {
    color: #064e3b;
  }

  .pc\:hover\:text-blue-50:hover {
    color: #eff6ff;
  }

  .pc\:hover\:text-blue-100:hover {
    color: #dbeafe;
  }

  .pc\:hover\:text-blue-200:hover {
    color: #bfdbfe;
  }

  .pc\:hover\:text-blue-300:hover {
    color: #93c5fd;
  }

  .pc\:hover\:text-blue-400:hover {
    color: #60a5fa;
  }

  .pc\:hover\:text-blue-500:hover {
    color: #3b82f6;
  }

  .pc\:hover\:text-blue-600:hover {
    color: #2563eb;
  }

  .pc\:hover\:text-blue-700:hover {
    color: #1d4ed8;
  }

  .pc\:hover\:text-blue-800:hover {
    color: #1e40af;
  }

  .pc\:hover\:text-blue-900:hover {
    color: #1e3a8a;
  }

  .pc\:hover\:text-cyan-50:hover {
    color: #ecfeff;
  }

  .pc\:hover\:text-cyan-100:hover {
    color: #cffafe;
  }

  .pc\:hover\:text-cyan-200:hover {
    color: #a5f3fc;
  }

  .pc\:hover\:text-cyan-300:hover {
    color: #67e8f9;
  }

  .pc\:hover\:text-cyan-400:hover {
    color: #22d3ee;
  }

  .pc\:hover\:text-cyan-500:hover {
    color: #06b6d4;
  }

  .pc\:hover\:text-cyan-600:hover {
    color: #0891b2;
  }

  .pc\:hover\:text-cyan-700:hover {
    color: #0e7490;
  }

  .pc\:hover\:text-cyan-800:hover {
    color: #155e75;
  }

  .pc\:hover\:text-cyan-900:hover {
    color: #164e63;
  }

  .pc\:hover\:text-indigo-50:hover {
    color: #eef2ff;
  }

  .pc\:hover\:text-indigo-100:hover {
    color: #e0e7ff;
  }

  .pc\:hover\:text-indigo-200:hover {
    color: #c7d2fe;
  }

  .pc\:hover\:text-indigo-300:hover {
    color: #a5b4fc;
  }

  .pc\:hover\:text-indigo-400:hover {
    color: #818cf8;
  }

  .pc\:hover\:text-indigo-500:hover {
    color: #6366f1;
  }

  .pc\:hover\:text-indigo-600:hover {
    color: #4f46e5;
  }

  .pc\:hover\:text-indigo-700:hover {
    color: #4338ca;
  }

  .pc\:hover\:text-indigo-800:hover {
    color: #3730a3;
  }

  .pc\:hover\:text-indigo-900:hover {
    color: #312e81;
  }

  .pc\:hover\:text-purple-50:hover {
    color: #f5f3ff;
  }

  .pc\:hover\:text-purple-100:hover {
    color: #ede9fe;
  }

  .pc\:hover\:text-purple-200:hover {
    color: #ddd6fe;
  }

  .pc\:hover\:text-purple-300:hover {
    color: #c4b5fd;
  }

  .pc\:hover\:text-purple-400:hover {
    color: #a78bfa;
  }

  .pc\:hover\:text-purple-500:hover {
    color: #8b5cf6;
  }

  .pc\:hover\:text-purple-600:hover {
    color: #7c3aed;
  }

  .pc\:hover\:text-purple-700:hover {
    color: #6d28d9;
  }

  .pc\:hover\:text-purple-800:hover {
    color: #5b21b6;
  }

  .pc\:hover\:text-purple-900:hover {
    color: #4c1d95;
  }

  .pc\:hover\:text-pink-50:hover {
    color: #fdf2f8;
  }

  .pc\:hover\:text-pink-100:hover {
    color: #fce7f3;
  }

  .pc\:hover\:text-pink-200:hover {
    color: #fbcfe8;
  }

  .pc\:hover\:text-pink-300:hover {
    color: #f9a8d4;
  }

  .pc\:hover\:text-pink-400:hover {
    color: #f472b6;
  }

  .pc\:hover\:text-pink-500:hover {
    color: #ec4899;
  }

  .pc\:hover\:text-pink-600:hover {
    color: #db2777;
  }

  .pc\:hover\:text-pink-700:hover {
    color: #be185d;
  }

  .pc\:hover\:text-pink-800:hover {
    color: #9d174d;
  }

  .pc\:hover\:text-pink-900:hover {
    color: #831843;
  }

  .pc\:active\:text-transparent.is-active {
    color: transparent;
  }

  .pc\:active\:text-current.is-active {
    color: currentColor;
  }

  .pc\:active\:text-black.is-active,
.pc\:active\:text-black:active {
    color: #000;
  }

  .pc\:active\:text-white.is-active,
.pc\:active\:text-white:active {
    color: #fff;
  }

  .pc\:active\:text-primary.is-active,
.pc\:active\:text-primary:active {
    color: #007bff;
  }

  .pc\:active\:text-secondary.is-active,
.pc\:active\:text-secondary:active {
    color: #6c757d;
  }

  .pc\:active\:text-success.is-active,
.pc\:active\:text-success:active {
    color: #28a745;
  }

  .pc\:active\:text-info.is-active,
.pc\:active\:text-info:active {
    color: #17a2b8;
  }

  .pc\:active\:text-warning.is-active,
.pc\:active\:text-warning:active {
    color: #fad733;
  }

  .pc\:active\:text-danger.is-active,
.pc\:active\:text-danger:active {
    color: #dc3545;
  }

  .pc\:active\:text-light.is-active,
.pc\:active\:text-light:active {
    color: #f8f9fa;
  }

  .pc\:active\:text-dark.is-active,
.pc\:active\:text-dark:active {
    color: #343a40;
  }

  .pc\:active\:text-gray-50.is-active,
.pc\:active\:text-gray-50:active {
    color: #f9fafb;
  }

  .pc\:active\:text-gray-100.is-active,
.pc\:active\:text-gray-100:active {
    color: #f3f4f6;
  }

  .pc\:active\:text-gray-200.is-active,
.pc\:active\:text-gray-200:active {
    color: #e5e7eb;
  }

  .pc\:active\:text-gray-300.is-active,
.pc\:active\:text-gray-300:active {
    color: #d1d5db;
  }

  .pc\:active\:text-gray-400.is-active,
.pc\:active\:text-gray-400:active {
    color: #9ca3af;
  }

  .pc\:active\:text-gray-500.is-active,
.pc\:active\:text-gray-500:active {
    color: #6b7280;
  }

  .pc\:active\:text-gray-600.is-active,
.pc\:active\:text-gray-600:active {
    color: #4b5563;
  }

  .pc\:active\:text-gray-700.is-active,
.pc\:active\:text-gray-700:active {
    color: #374151;
  }

  .pc\:active\:text-gray-800.is-active,
.pc\:active\:text-gray-800:active {
    color: #1f2937;
  }

  .pc\:active\:text-gray-900.is-active,
.pc\:active\:text-gray-900:active {
    color: #111827;
  }

  .pc\:active\:text-red-50.is-active,
.pc\:active\:text-red-50:active {
    color: #fef2f2;
  }

  .pc\:active\:text-red-100.is-active,
.pc\:active\:text-red-100:active {
    color: #fee2e2;
  }

  .pc\:active\:text-red-200.is-active,
.pc\:active\:text-red-200:active {
    color: #fecaca;
  }

  .pc\:active\:text-red-300.is-active,
.pc\:active\:text-red-300:active {
    color: #fca5a5;
  }

  .pc\:active\:text-red-400.is-active,
.pc\:active\:text-red-400:active {
    color: #f87171;
  }

  .pc\:active\:text-red-500.is-active,
.pc\:active\:text-red-500:active {
    color: #ef4444;
  }

  .pc\:active\:text-red-600.is-active,
.pc\:active\:text-red-600:active {
    color: #dc2626;
  }

  .pc\:active\:text-red-700.is-active,
.pc\:active\:text-red-700:active {
    color: #b91c1c;
  }

  .pc\:active\:text-red-800.is-active,
.pc\:active\:text-red-800:active {
    color: #991b1b;
  }

  .pc\:active\:text-red-900.is-active,
.pc\:active\:text-red-900:active {
    color: #7f1d1d;
  }

  .pc\:active\:text-yellow-50.is-active,
.pc\:active\:text-yellow-50:active {
    color: #fffbeb;
  }

  .pc\:active\:text-yellow-100.is-active,
.pc\:active\:text-yellow-100:active {
    color: #fef3c7;
  }

  .pc\:active\:text-yellow-200.is-active,
.pc\:active\:text-yellow-200:active {
    color: #fde68a;
  }

  .pc\:active\:text-yellow-300.is-active,
.pc\:active\:text-yellow-300:active {
    color: #fcd34d;
  }

  .pc\:active\:text-yellow-400.is-active,
.pc\:active\:text-yellow-400:active {
    color: #fbbf24;
  }

  .pc\:active\:text-yellow-500.is-active,
.pc\:active\:text-yellow-500:active {
    color: #f59e0b;
  }

  .pc\:active\:text-yellow-600.is-active,
.pc\:active\:text-yellow-600:active {
    color: #d97706;
  }

  .pc\:active\:text-yellow-700.is-active,
.pc\:active\:text-yellow-700:active {
    color: #b45309;
  }

  .pc\:active\:text-yellow-800.is-active,
.pc\:active\:text-yellow-800:active {
    color: #92400e;
  }

  .pc\:active\:text-yellow-900.is-active,
.pc\:active\:text-yellow-900:active {
    color: #78350f;
  }

  .pc\:active\:text-green-50.is-active,
.pc\:active\:text-green-50:active {
    color: #ecfdf5;
  }

  .pc\:active\:text-green-100.is-active,
.pc\:active\:text-green-100:active {
    color: #d1fae5;
  }

  .pc\:active\:text-green-200.is-active,
.pc\:active\:text-green-200:active {
    color: #a7f3d0;
  }

  .pc\:active\:text-green-300.is-active,
.pc\:active\:text-green-300:active {
    color: #6ee7b7;
  }

  .pc\:active\:text-green-400.is-active,
.pc\:active\:text-green-400:active {
    color: #34d399;
  }

  .pc\:active\:text-green-500.is-active,
.pc\:active\:text-green-500:active {
    color: #10b981;
  }

  .pc\:active\:text-green-600.is-active,
.pc\:active\:text-green-600:active {
    color: #059669;
  }

  .pc\:active\:text-green-700.is-active,
.pc\:active\:text-green-700:active {
    color: #047857;
  }

  .pc\:active\:text-green-800.is-active,
.pc\:active\:text-green-800:active {
    color: #065f46;
  }

  .pc\:active\:text-green-900.is-active,
.pc\:active\:text-green-900:active {
    color: #064e3b;
  }

  .pc\:active\:text-blue-50.is-active,
.pc\:active\:text-blue-50:active {
    color: #eff6ff;
  }

  .pc\:active\:text-blue-100.is-active,
.pc\:active\:text-blue-100:active {
    color: #dbeafe;
  }

  .pc\:active\:text-blue-200.is-active,
.pc\:active\:text-blue-200:active {
    color: #bfdbfe;
  }

  .pc\:active\:text-blue-300.is-active,
.pc\:active\:text-blue-300:active {
    color: #93c5fd;
  }

  .pc\:active\:text-blue-400.is-active,
.pc\:active\:text-blue-400:active {
    color: #60a5fa;
  }

  .pc\:active\:text-blue-500.is-active,
.pc\:active\:text-blue-500:active {
    color: #3b82f6;
  }

  .pc\:active\:text-blue-600.is-active,
.pc\:active\:text-blue-600:active {
    color: #2563eb;
  }

  .pc\:active\:text-blue-700.is-active,
.pc\:active\:text-blue-700:active {
    color: #1d4ed8;
  }

  .pc\:active\:text-blue-800.is-active,
.pc\:active\:text-blue-800:active {
    color: #1e40af;
  }

  .pc\:active\:text-blue-900.is-active,
.pc\:active\:text-blue-900:active {
    color: #1e3a8a;
  }

  .pc\:active\:text-cyan-50.is-active,
.pc\:active\:text-cyan-50:active {
    color: #ecfeff;
  }

  .pc\:active\:text-cyan-100.is-active,
.pc\:active\:text-cyan-100:active {
    color: #cffafe;
  }

  .pc\:active\:text-cyan-200.is-active,
.pc\:active\:text-cyan-200:active {
    color: #a5f3fc;
  }

  .pc\:active\:text-cyan-300.is-active,
.pc\:active\:text-cyan-300:active {
    color: #67e8f9;
  }

  .pc\:active\:text-cyan-400.is-active,
.pc\:active\:text-cyan-400:active {
    color: #22d3ee;
  }

  .pc\:active\:text-cyan-500.is-active,
.pc\:active\:text-cyan-500:active {
    color: #06b6d4;
  }

  .pc\:active\:text-cyan-600.is-active,
.pc\:active\:text-cyan-600:active {
    color: #0891b2;
  }

  .pc\:active\:text-cyan-700.is-active,
.pc\:active\:text-cyan-700:active {
    color: #0e7490;
  }

  .pc\:active\:text-cyan-800.is-active,
.pc\:active\:text-cyan-800:active {
    color: #155e75;
  }

  .pc\:active\:text-cyan-900.is-active,
.pc\:active\:text-cyan-900:active {
    color: #164e63;
  }

  .pc\:active\:text-indigo-50.is-active,
.pc\:active\:text-indigo-50:active {
    color: #eef2ff;
  }

  .pc\:active\:text-indigo-100.is-active,
.pc\:active\:text-indigo-100:active {
    color: #e0e7ff;
  }

  .pc\:active\:text-indigo-200.is-active,
.pc\:active\:text-indigo-200:active {
    color: #c7d2fe;
  }

  .pc\:active\:text-indigo-300.is-active,
.pc\:active\:text-indigo-300:active {
    color: #a5b4fc;
  }

  .pc\:active\:text-indigo-400.is-active,
.pc\:active\:text-indigo-400:active {
    color: #818cf8;
  }

  .pc\:active\:text-indigo-500.is-active,
.pc\:active\:text-indigo-500:active {
    color: #6366f1;
  }

  .pc\:active\:text-indigo-600.is-active,
.pc\:active\:text-indigo-600:active {
    color: #4f46e5;
  }

  .pc\:active\:text-indigo-700.is-active,
.pc\:active\:text-indigo-700:active {
    color: #4338ca;
  }

  .pc\:active\:text-indigo-800.is-active,
.pc\:active\:text-indigo-800:active {
    color: #3730a3;
  }

  .pc\:active\:text-indigo-900.is-active,
.pc\:active\:text-indigo-900:active {
    color: #312e81;
  }

  .pc\:active\:text-purple-50.is-active,
.pc\:active\:text-purple-50:active {
    color: #f5f3ff;
  }

  .pc\:active\:text-purple-100.is-active,
.pc\:active\:text-purple-100:active {
    color: #ede9fe;
  }

  .pc\:active\:text-purple-200.is-active,
.pc\:active\:text-purple-200:active {
    color: #ddd6fe;
  }

  .pc\:active\:text-purple-300.is-active,
.pc\:active\:text-purple-300:active {
    color: #c4b5fd;
  }

  .pc\:active\:text-purple-400.is-active,
.pc\:active\:text-purple-400:active {
    color: #a78bfa;
  }

  .pc\:active\:text-purple-500.is-active,
.pc\:active\:text-purple-500:active {
    color: #8b5cf6;
  }

  .pc\:active\:text-purple-600.is-active,
.pc\:active\:text-purple-600:active {
    color: #7c3aed;
  }

  .pc\:active\:text-purple-700.is-active,
.pc\:active\:text-purple-700:active {
    color: #6d28d9;
  }

  .pc\:active\:text-purple-800.is-active,
.pc\:active\:text-purple-800:active {
    color: #5b21b6;
  }

  .pc\:active\:text-purple-900.is-active,
.pc\:active\:text-purple-900:active {
    color: #4c1d95;
  }

  .pc\:active\:text-pink-50.is-active,
.pc\:active\:text-pink-50:active {
    color: #fdf2f8;
  }

  .pc\:active\:text-pink-100.is-active,
.pc\:active\:text-pink-100:active {
    color: #fce7f3;
  }

  .pc\:active\:text-pink-200.is-active,
.pc\:active\:text-pink-200:active {
    color: #fbcfe8;
  }

  .pc\:active\:text-pink-300.is-active,
.pc\:active\:text-pink-300:active {
    color: #f9a8d4;
  }

  .pc\:active\:text-pink-400.is-active,
.pc\:active\:text-pink-400:active {
    color: #f472b6;
  }

  .pc\:active\:text-pink-500.is-active,
.pc\:active\:text-pink-500:active {
    color: #ec4899;
  }

  .pc\:active\:text-pink-600.is-active,
.pc\:active\:text-pink-600:active {
    color: #db2777;
  }

  .pc\:active\:text-pink-700.is-active,
.pc\:active\:text-pink-700:active {
    color: #be185d;
  }

  .pc\:active\:text-pink-800.is-active,
.pc\:active\:text-pink-800:active {
    color: #9d174d;
  }

  .pc\:active\:text-pink-900.is-active,
.pc\:active\:text-pink-900:active {
    color: #831843;
  }

  .pc\:focus\:text-transparent:focus {
    color: transparent;
  }

  .pc\:focus\:text-current:focus {
    color: currentColor;
  }

  .pc\:focus\:text-black:focus {
    color: #000;
  }

  .pc\:focus\:text-white:focus {
    color: #fff;
  }

  .pc\:focus\:text-primary:focus {
    color: #007bff;
  }

  .pc\:focus\:text-secondary:focus {
    color: #6c757d;
  }

  .pc\:focus\:text-success:focus {
    color: #28a745;
  }

  .pc\:focus\:text-info:focus {
    color: #17a2b8;
  }

  .pc\:focus\:text-warning:focus {
    color: #fad733;
  }

  .pc\:focus\:text-danger:focus {
    color: #dc3545;
  }

  .pc\:focus\:text-light:focus {
    color: #f8f9fa;
  }

  .pc\:focus\:text-dark:focus {
    color: #343a40;
  }

  .pc\:focus\:text-gray-50:focus {
    color: #f9fafb;
  }

  .pc\:focus\:text-gray-100:focus {
    color: #f3f4f6;
  }

  .pc\:focus\:text-gray-200:focus {
    color: #e5e7eb;
  }

  .pc\:focus\:text-gray-300:focus {
    color: #d1d5db;
  }

  .pc\:focus\:text-gray-400:focus {
    color: #9ca3af;
  }

  .pc\:focus\:text-gray-500:focus {
    color: #6b7280;
  }

  .pc\:focus\:text-gray-600:focus {
    color: #4b5563;
  }

  .pc\:focus\:text-gray-700:focus {
    color: #374151;
  }

  .pc\:focus\:text-gray-800:focus {
    color: #1f2937;
  }

  .pc\:focus\:text-gray-900:focus {
    color: #111827;
  }

  .pc\:focus\:text-red-50:focus {
    color: #fef2f2;
  }

  .pc\:focus\:text-red-100:focus {
    color: #fee2e2;
  }

  .pc\:focus\:text-red-200:focus {
    color: #fecaca;
  }

  .pc\:focus\:text-red-300:focus {
    color: #fca5a5;
  }

  .pc\:focus\:text-red-400:focus {
    color: #f87171;
  }

  .pc\:focus\:text-red-500:focus {
    color: #ef4444;
  }

  .pc\:focus\:text-red-600:focus {
    color: #dc2626;
  }

  .pc\:focus\:text-red-700:focus {
    color: #b91c1c;
  }

  .pc\:focus\:text-red-800:focus {
    color: #991b1b;
  }

  .pc\:focus\:text-red-900:focus {
    color: #7f1d1d;
  }

  .pc\:focus\:text-yellow-50:focus {
    color: #fffbeb;
  }

  .pc\:focus\:text-yellow-100:focus {
    color: #fef3c7;
  }

  .pc\:focus\:text-yellow-200:focus {
    color: #fde68a;
  }

  .pc\:focus\:text-yellow-300:focus {
    color: #fcd34d;
  }

  .pc\:focus\:text-yellow-400:focus {
    color: #fbbf24;
  }

  .pc\:focus\:text-yellow-500:focus {
    color: #f59e0b;
  }

  .pc\:focus\:text-yellow-600:focus {
    color: #d97706;
  }

  .pc\:focus\:text-yellow-700:focus {
    color: #b45309;
  }

  .pc\:focus\:text-yellow-800:focus {
    color: #92400e;
  }

  .pc\:focus\:text-yellow-900:focus {
    color: #78350f;
  }

  .pc\:focus\:text-green-50:focus {
    color: #ecfdf5;
  }

  .pc\:focus\:text-green-100:focus {
    color: #d1fae5;
  }

  .pc\:focus\:text-green-200:focus {
    color: #a7f3d0;
  }

  .pc\:focus\:text-green-300:focus {
    color: #6ee7b7;
  }

  .pc\:focus\:text-green-400:focus {
    color: #34d399;
  }

  .pc\:focus\:text-green-500:focus {
    color: #10b981;
  }

  .pc\:focus\:text-green-600:focus {
    color: #059669;
  }

  .pc\:focus\:text-green-700:focus {
    color: #047857;
  }

  .pc\:focus\:text-green-800:focus {
    color: #065f46;
  }

  .pc\:focus\:text-green-900:focus {
    color: #064e3b;
  }

  .pc\:focus\:text-blue-50:focus {
    color: #eff6ff;
  }

  .pc\:focus\:text-blue-100:focus {
    color: #dbeafe;
  }

  .pc\:focus\:text-blue-200:focus {
    color: #bfdbfe;
  }

  .pc\:focus\:text-blue-300:focus {
    color: #93c5fd;
  }

  .pc\:focus\:text-blue-400:focus {
    color: #60a5fa;
  }

  .pc\:focus\:text-blue-500:focus {
    color: #3b82f6;
  }

  .pc\:focus\:text-blue-600:focus {
    color: #2563eb;
  }

  .pc\:focus\:text-blue-700:focus {
    color: #1d4ed8;
  }

  .pc\:focus\:text-blue-800:focus {
    color: #1e40af;
  }

  .pc\:focus\:text-blue-900:focus {
    color: #1e3a8a;
  }

  .pc\:focus\:text-cyan-50:focus {
    color: #ecfeff;
  }

  .pc\:focus\:text-cyan-100:focus {
    color: #cffafe;
  }

  .pc\:focus\:text-cyan-200:focus {
    color: #a5f3fc;
  }

  .pc\:focus\:text-cyan-300:focus {
    color: #67e8f9;
  }

  .pc\:focus\:text-cyan-400:focus {
    color: #22d3ee;
  }

  .pc\:focus\:text-cyan-500:focus {
    color: #06b6d4;
  }

  .pc\:focus\:text-cyan-600:focus {
    color: #0891b2;
  }

  .pc\:focus\:text-cyan-700:focus {
    color: #0e7490;
  }

  .pc\:focus\:text-cyan-800:focus {
    color: #155e75;
  }

  .pc\:focus\:text-cyan-900:focus {
    color: #164e63;
  }

  .pc\:focus\:text-indigo-50:focus {
    color: #eef2ff;
  }

  .pc\:focus\:text-indigo-100:focus {
    color: #e0e7ff;
  }

  .pc\:focus\:text-indigo-200:focus {
    color: #c7d2fe;
  }

  .pc\:focus\:text-indigo-300:focus {
    color: #a5b4fc;
  }

  .pc\:focus\:text-indigo-400:focus {
    color: #818cf8;
  }

  .pc\:focus\:text-indigo-500:focus {
    color: #6366f1;
  }

  .pc\:focus\:text-indigo-600:focus {
    color: #4f46e5;
  }

  .pc\:focus\:text-indigo-700:focus {
    color: #4338ca;
  }

  .pc\:focus\:text-indigo-800:focus {
    color: #3730a3;
  }

  .pc\:focus\:text-indigo-900:focus {
    color: #312e81;
  }

  .pc\:focus\:text-purple-50:focus {
    color: #f5f3ff;
  }

  .pc\:focus\:text-purple-100:focus {
    color: #ede9fe;
  }

  .pc\:focus\:text-purple-200:focus {
    color: #ddd6fe;
  }

  .pc\:focus\:text-purple-300:focus {
    color: #c4b5fd;
  }

  .pc\:focus\:text-purple-400:focus {
    color: #a78bfa;
  }

  .pc\:focus\:text-purple-500:focus {
    color: #8b5cf6;
  }

  .pc\:focus\:text-purple-600:focus {
    color: #7c3aed;
  }

  .pc\:focus\:text-purple-700:focus {
    color: #6d28d9;
  }

  .pc\:focus\:text-purple-800:focus {
    color: #5b21b6;
  }

  .pc\:focus\:text-purple-900:focus {
    color: #4c1d95;
  }

  .pc\:focus\:text-pink-50:focus {
    color: #fdf2f8;
  }

  .pc\:focus\:text-pink-100:focus {
    color: #fce7f3;
  }

  .pc\:focus\:text-pink-200:focus {
    color: #fbcfe8;
  }

  .pc\:focus\:text-pink-300:focus {
    color: #f9a8d4;
  }

  .pc\:focus\:text-pink-400:focus {
    color: #f472b6;
  }

  .pc\:focus\:text-pink-500:focus {
    color: #ec4899;
  }

  .pc\:focus\:text-pink-600:focus {
    color: #db2777;
  }

  .pc\:focus\:text-pink-700:focus {
    color: #be185d;
  }

  .pc\:focus\:text-pink-800:focus {
    color: #9d174d;
  }

  .pc\:focus\:text-pink-900:focus {
    color: #831843;
  }

  .pc\:disabled\:text-transparent.is-disabled {
    color: transparent;
  }

  .pc\:disabled\:text-current.is-disabled {
    color: currentColor;
  }

  .pc\:disabled\:text-black.is-disabled,
.pc\:disabled\:text-black:disabled {
    color: #000;
  }

  .pc\:disabled\:text-white.is-disabled,
.pc\:disabled\:text-white:disabled {
    color: #fff;
  }

  .pc\:disabled\:text-primary.is-disabled,
.pc\:disabled\:text-primary:disabled {
    color: #007bff;
  }

  .pc\:disabled\:text-secondary.is-disabled,
.pc\:disabled\:text-secondary:disabled {
    color: #6c757d;
  }

  .pc\:disabled\:text-success.is-disabled,
.pc\:disabled\:text-success:disabled {
    color: #28a745;
  }

  .pc\:disabled\:text-info.is-disabled,
.pc\:disabled\:text-info:disabled {
    color: #17a2b8;
  }

  .pc\:disabled\:text-warning.is-disabled,
.pc\:disabled\:text-warning:disabled {
    color: #fad733;
  }

  .pc\:disabled\:text-danger.is-disabled,
.pc\:disabled\:text-danger:disabled {
    color: #dc3545;
  }

  .pc\:disabled\:text-light.is-disabled,
.pc\:disabled\:text-light:disabled {
    color: #f8f9fa;
  }

  .pc\:disabled\:text-dark.is-disabled,
.pc\:disabled\:text-dark:disabled {
    color: #343a40;
  }

  .pc\:disabled\:text-gray-50.is-disabled,
.pc\:disabled\:text-gray-50:disabled {
    color: #f9fafb;
  }

  .pc\:disabled\:text-gray-100.is-disabled,
.pc\:disabled\:text-gray-100:disabled {
    color: #f3f4f6;
  }

  .pc\:disabled\:text-gray-200.is-disabled,
.pc\:disabled\:text-gray-200:disabled {
    color: #e5e7eb;
  }

  .pc\:disabled\:text-gray-300.is-disabled,
.pc\:disabled\:text-gray-300:disabled {
    color: #d1d5db;
  }

  .pc\:disabled\:text-gray-400.is-disabled,
.pc\:disabled\:text-gray-400:disabled {
    color: #9ca3af;
  }

  .pc\:disabled\:text-gray-500.is-disabled,
.pc\:disabled\:text-gray-500:disabled {
    color: #6b7280;
  }

  .pc\:disabled\:text-gray-600.is-disabled,
.pc\:disabled\:text-gray-600:disabled {
    color: #4b5563;
  }

  .pc\:disabled\:text-gray-700.is-disabled,
.pc\:disabled\:text-gray-700:disabled {
    color: #374151;
  }

  .pc\:disabled\:text-gray-800.is-disabled,
.pc\:disabled\:text-gray-800:disabled {
    color: #1f2937;
  }

  .pc\:disabled\:text-gray-900.is-disabled,
.pc\:disabled\:text-gray-900:disabled {
    color: #111827;
  }

  .pc\:disabled\:text-red-50.is-disabled,
.pc\:disabled\:text-red-50:disabled {
    color: #fef2f2;
  }

  .pc\:disabled\:text-red-100.is-disabled,
.pc\:disabled\:text-red-100:disabled {
    color: #fee2e2;
  }

  .pc\:disabled\:text-red-200.is-disabled,
.pc\:disabled\:text-red-200:disabled {
    color: #fecaca;
  }

  .pc\:disabled\:text-red-300.is-disabled,
.pc\:disabled\:text-red-300:disabled {
    color: #fca5a5;
  }

  .pc\:disabled\:text-red-400.is-disabled,
.pc\:disabled\:text-red-400:disabled {
    color: #f87171;
  }

  .pc\:disabled\:text-red-500.is-disabled,
.pc\:disabled\:text-red-500:disabled {
    color: #ef4444;
  }

  .pc\:disabled\:text-red-600.is-disabled,
.pc\:disabled\:text-red-600:disabled {
    color: #dc2626;
  }

  .pc\:disabled\:text-red-700.is-disabled,
.pc\:disabled\:text-red-700:disabled {
    color: #b91c1c;
  }

  .pc\:disabled\:text-red-800.is-disabled,
.pc\:disabled\:text-red-800:disabled {
    color: #991b1b;
  }

  .pc\:disabled\:text-red-900.is-disabled,
.pc\:disabled\:text-red-900:disabled {
    color: #7f1d1d;
  }

  .pc\:disabled\:text-yellow-50.is-disabled,
.pc\:disabled\:text-yellow-50:disabled {
    color: #fffbeb;
  }

  .pc\:disabled\:text-yellow-100.is-disabled,
.pc\:disabled\:text-yellow-100:disabled {
    color: #fef3c7;
  }

  .pc\:disabled\:text-yellow-200.is-disabled,
.pc\:disabled\:text-yellow-200:disabled {
    color: #fde68a;
  }

  .pc\:disabled\:text-yellow-300.is-disabled,
.pc\:disabled\:text-yellow-300:disabled {
    color: #fcd34d;
  }

  .pc\:disabled\:text-yellow-400.is-disabled,
.pc\:disabled\:text-yellow-400:disabled {
    color: #fbbf24;
  }

  .pc\:disabled\:text-yellow-500.is-disabled,
.pc\:disabled\:text-yellow-500:disabled {
    color: #f59e0b;
  }

  .pc\:disabled\:text-yellow-600.is-disabled,
.pc\:disabled\:text-yellow-600:disabled {
    color: #d97706;
  }

  .pc\:disabled\:text-yellow-700.is-disabled,
.pc\:disabled\:text-yellow-700:disabled {
    color: #b45309;
  }

  .pc\:disabled\:text-yellow-800.is-disabled,
.pc\:disabled\:text-yellow-800:disabled {
    color: #92400e;
  }

  .pc\:disabled\:text-yellow-900.is-disabled,
.pc\:disabled\:text-yellow-900:disabled {
    color: #78350f;
  }

  .pc\:disabled\:text-green-50.is-disabled,
.pc\:disabled\:text-green-50:disabled {
    color: #ecfdf5;
  }

  .pc\:disabled\:text-green-100.is-disabled,
.pc\:disabled\:text-green-100:disabled {
    color: #d1fae5;
  }

  .pc\:disabled\:text-green-200.is-disabled,
.pc\:disabled\:text-green-200:disabled {
    color: #a7f3d0;
  }

  .pc\:disabled\:text-green-300.is-disabled,
.pc\:disabled\:text-green-300:disabled {
    color: #6ee7b7;
  }

  .pc\:disabled\:text-green-400.is-disabled,
.pc\:disabled\:text-green-400:disabled {
    color: #34d399;
  }

  .pc\:disabled\:text-green-500.is-disabled,
.pc\:disabled\:text-green-500:disabled {
    color: #10b981;
  }

  .pc\:disabled\:text-green-600.is-disabled,
.pc\:disabled\:text-green-600:disabled {
    color: #059669;
  }

  .pc\:disabled\:text-green-700.is-disabled,
.pc\:disabled\:text-green-700:disabled {
    color: #047857;
  }

  .pc\:disabled\:text-green-800.is-disabled,
.pc\:disabled\:text-green-800:disabled {
    color: #065f46;
  }

  .pc\:disabled\:text-green-900.is-disabled,
.pc\:disabled\:text-green-900:disabled {
    color: #064e3b;
  }

  .pc\:disabled\:text-blue-50.is-disabled,
.pc\:disabled\:text-blue-50:disabled {
    color: #eff6ff;
  }

  .pc\:disabled\:text-blue-100.is-disabled,
.pc\:disabled\:text-blue-100:disabled {
    color: #dbeafe;
  }

  .pc\:disabled\:text-blue-200.is-disabled,
.pc\:disabled\:text-blue-200:disabled {
    color: #bfdbfe;
  }

  .pc\:disabled\:text-blue-300.is-disabled,
.pc\:disabled\:text-blue-300:disabled {
    color: #93c5fd;
  }

  .pc\:disabled\:text-blue-400.is-disabled,
.pc\:disabled\:text-blue-400:disabled {
    color: #60a5fa;
  }

  .pc\:disabled\:text-blue-500.is-disabled,
.pc\:disabled\:text-blue-500:disabled {
    color: #3b82f6;
  }

  .pc\:disabled\:text-blue-600.is-disabled,
.pc\:disabled\:text-blue-600:disabled {
    color: #2563eb;
  }

  .pc\:disabled\:text-blue-700.is-disabled,
.pc\:disabled\:text-blue-700:disabled {
    color: #1d4ed8;
  }

  .pc\:disabled\:text-blue-800.is-disabled,
.pc\:disabled\:text-blue-800:disabled {
    color: #1e40af;
  }

  .pc\:disabled\:text-blue-900.is-disabled,
.pc\:disabled\:text-blue-900:disabled {
    color: #1e3a8a;
  }

  .pc\:disabled\:text-cyan-50.is-disabled,
.pc\:disabled\:text-cyan-50:disabled {
    color: #ecfeff;
  }

  .pc\:disabled\:text-cyan-100.is-disabled,
.pc\:disabled\:text-cyan-100:disabled {
    color: #cffafe;
  }

  .pc\:disabled\:text-cyan-200.is-disabled,
.pc\:disabled\:text-cyan-200:disabled {
    color: #a5f3fc;
  }

  .pc\:disabled\:text-cyan-300.is-disabled,
.pc\:disabled\:text-cyan-300:disabled {
    color: #67e8f9;
  }

  .pc\:disabled\:text-cyan-400.is-disabled,
.pc\:disabled\:text-cyan-400:disabled {
    color: #22d3ee;
  }

  .pc\:disabled\:text-cyan-500.is-disabled,
.pc\:disabled\:text-cyan-500:disabled {
    color: #06b6d4;
  }

  .pc\:disabled\:text-cyan-600.is-disabled,
.pc\:disabled\:text-cyan-600:disabled {
    color: #0891b2;
  }

  .pc\:disabled\:text-cyan-700.is-disabled,
.pc\:disabled\:text-cyan-700:disabled {
    color: #0e7490;
  }

  .pc\:disabled\:text-cyan-800.is-disabled,
.pc\:disabled\:text-cyan-800:disabled {
    color: #155e75;
  }

  .pc\:disabled\:text-cyan-900.is-disabled,
.pc\:disabled\:text-cyan-900:disabled {
    color: #164e63;
  }

  .pc\:disabled\:text-indigo-50.is-disabled,
.pc\:disabled\:text-indigo-50:disabled {
    color: #eef2ff;
  }

  .pc\:disabled\:text-indigo-100.is-disabled,
.pc\:disabled\:text-indigo-100:disabled {
    color: #e0e7ff;
  }

  .pc\:disabled\:text-indigo-200.is-disabled,
.pc\:disabled\:text-indigo-200:disabled {
    color: #c7d2fe;
  }

  .pc\:disabled\:text-indigo-300.is-disabled,
.pc\:disabled\:text-indigo-300:disabled {
    color: #a5b4fc;
  }

  .pc\:disabled\:text-indigo-400.is-disabled,
.pc\:disabled\:text-indigo-400:disabled {
    color: #818cf8;
  }

  .pc\:disabled\:text-indigo-500.is-disabled,
.pc\:disabled\:text-indigo-500:disabled {
    color: #6366f1;
  }

  .pc\:disabled\:text-indigo-600.is-disabled,
.pc\:disabled\:text-indigo-600:disabled {
    color: #4f46e5;
  }

  .pc\:disabled\:text-indigo-700.is-disabled,
.pc\:disabled\:text-indigo-700:disabled {
    color: #4338ca;
  }

  .pc\:disabled\:text-indigo-800.is-disabled,
.pc\:disabled\:text-indigo-800:disabled {
    color: #3730a3;
  }

  .pc\:disabled\:text-indigo-900.is-disabled,
.pc\:disabled\:text-indigo-900:disabled {
    color: #312e81;
  }

  .pc\:disabled\:text-purple-50.is-disabled,
.pc\:disabled\:text-purple-50:disabled {
    color: #f5f3ff;
  }

  .pc\:disabled\:text-purple-100.is-disabled,
.pc\:disabled\:text-purple-100:disabled {
    color: #ede9fe;
  }

  .pc\:disabled\:text-purple-200.is-disabled,
.pc\:disabled\:text-purple-200:disabled {
    color: #ddd6fe;
  }

  .pc\:disabled\:text-purple-300.is-disabled,
.pc\:disabled\:text-purple-300:disabled {
    color: #c4b5fd;
  }

  .pc\:disabled\:text-purple-400.is-disabled,
.pc\:disabled\:text-purple-400:disabled {
    color: #a78bfa;
  }

  .pc\:disabled\:text-purple-500.is-disabled,
.pc\:disabled\:text-purple-500:disabled {
    color: #8b5cf6;
  }

  .pc\:disabled\:text-purple-600.is-disabled,
.pc\:disabled\:text-purple-600:disabled {
    color: #7c3aed;
  }

  .pc\:disabled\:text-purple-700.is-disabled,
.pc\:disabled\:text-purple-700:disabled {
    color: #6d28d9;
  }

  .pc\:disabled\:text-purple-800.is-disabled,
.pc\:disabled\:text-purple-800:disabled {
    color: #5b21b6;
  }

  .pc\:disabled\:text-purple-900.is-disabled,
.pc\:disabled\:text-purple-900:disabled {
    color: #4c1d95;
  }

  .pc\:disabled\:text-pink-50.is-disabled,
.pc\:disabled\:text-pink-50:disabled {
    color: #fdf2f8;
  }

  .pc\:disabled\:text-pink-100.is-disabled,
.pc\:disabled\:text-pink-100:disabled {
    color: #fce7f3;
  }

  .pc\:disabled\:text-pink-200.is-disabled,
.pc\:disabled\:text-pink-200:disabled {
    color: #fbcfe8;
  }

  .pc\:disabled\:text-pink-300.is-disabled,
.pc\:disabled\:text-pink-300:disabled {
    color: #f9a8d4;
  }

  .pc\:disabled\:text-pink-400.is-disabled,
.pc\:disabled\:text-pink-400:disabled {
    color: #f472b6;
  }

  .pc\:disabled\:text-pink-500.is-disabled,
.pc\:disabled\:text-pink-500:disabled {
    color: #ec4899;
  }

  .pc\:disabled\:text-pink-600.is-disabled,
.pc\:disabled\:text-pink-600:disabled {
    color: #db2777;
  }

  .pc\:disabled\:text-pink-700.is-disabled,
.pc\:disabled\:text-pink-700:disabled {
    color: #be185d;
  }

  .pc\:disabled\:text-pink-800.is-disabled,
.pc\:disabled\:text-pink-800:disabled {
    color: #9d174d;
  }

  .pc\:disabled\:text-pink-900.is-disabled,
.pc\:disabled\:text-pink-900:disabled {
    color: #831843;
  }

  .group:hover .pc\:group-hover\:text-transparent {
    color: transparent;
  }

  .group:hover .pc\:group-hover\:text-current {
    color: currentColor;
  }

  .group:hover .pc\:group-hover\:text-black {
    color: #000;
  }

  .group:hover .pc\:group-hover\:text-white {
    color: #fff;
  }

  .group:hover .pc\:group-hover\:text-primary {
    color: #007bff;
  }

  .group:hover .pc\:group-hover\:text-secondary {
    color: #6c757d;
  }

  .group:hover .pc\:group-hover\:text-success {
    color: #28a745;
  }

  .group:hover .pc\:group-hover\:text-info {
    color: #17a2b8;
  }

  .group:hover .pc\:group-hover\:text-warning {
    color: #fad733;
  }

  .group:hover .pc\:group-hover\:text-danger {
    color: #dc3545;
  }

  .group:hover .pc\:group-hover\:text-light {
    color: #f8f9fa;
  }

  .group:hover .pc\:group-hover\:text-dark {
    color: #343a40;
  }

  .group:hover .pc\:group-hover\:text-gray-50 {
    color: #f9fafb;
  }

  .group:hover .pc\:group-hover\:text-gray-100 {
    color: #f3f4f6;
  }

  .group:hover .pc\:group-hover\:text-gray-200 {
    color: #e5e7eb;
  }

  .group:hover .pc\:group-hover\:text-gray-300 {
    color: #d1d5db;
  }

  .group:hover .pc\:group-hover\:text-gray-400 {
    color: #9ca3af;
  }

  .group:hover .pc\:group-hover\:text-gray-500 {
    color: #6b7280;
  }

  .group:hover .pc\:group-hover\:text-gray-600 {
    color: #4b5563;
  }

  .group:hover .pc\:group-hover\:text-gray-700 {
    color: #374151;
  }

  .group:hover .pc\:group-hover\:text-gray-800 {
    color: #1f2937;
  }

  .group:hover .pc\:group-hover\:text-gray-900 {
    color: #111827;
  }

  .group:hover .pc\:group-hover\:text-red-50 {
    color: #fef2f2;
  }

  .group:hover .pc\:group-hover\:text-red-100 {
    color: #fee2e2;
  }

  .group:hover .pc\:group-hover\:text-red-200 {
    color: #fecaca;
  }

  .group:hover .pc\:group-hover\:text-red-300 {
    color: #fca5a5;
  }

  .group:hover .pc\:group-hover\:text-red-400 {
    color: #f87171;
  }

  .group:hover .pc\:group-hover\:text-red-500 {
    color: #ef4444;
  }

  .group:hover .pc\:group-hover\:text-red-600 {
    color: #dc2626;
  }

  .group:hover .pc\:group-hover\:text-red-700 {
    color: #b91c1c;
  }

  .group:hover .pc\:group-hover\:text-red-800 {
    color: #991b1b;
  }

  .group:hover .pc\:group-hover\:text-red-900 {
    color: #7f1d1d;
  }

  .group:hover .pc\:group-hover\:text-yellow-50 {
    color: #fffbeb;
  }

  .group:hover .pc\:group-hover\:text-yellow-100 {
    color: #fef3c7;
  }

  .group:hover .pc\:group-hover\:text-yellow-200 {
    color: #fde68a;
  }

  .group:hover .pc\:group-hover\:text-yellow-300 {
    color: #fcd34d;
  }

  .group:hover .pc\:group-hover\:text-yellow-400 {
    color: #fbbf24;
  }

  .group:hover .pc\:group-hover\:text-yellow-500 {
    color: #f59e0b;
  }

  .group:hover .pc\:group-hover\:text-yellow-600 {
    color: #d97706;
  }

  .group:hover .pc\:group-hover\:text-yellow-700 {
    color: #b45309;
  }

  .group:hover .pc\:group-hover\:text-yellow-800 {
    color: #92400e;
  }

  .group:hover .pc\:group-hover\:text-yellow-900 {
    color: #78350f;
  }

  .group:hover .pc\:group-hover\:text-green-50 {
    color: #ecfdf5;
  }

  .group:hover .pc\:group-hover\:text-green-100 {
    color: #d1fae5;
  }

  .group:hover .pc\:group-hover\:text-green-200 {
    color: #a7f3d0;
  }

  .group:hover .pc\:group-hover\:text-green-300 {
    color: #6ee7b7;
  }

  .group:hover .pc\:group-hover\:text-green-400 {
    color: #34d399;
  }

  .group:hover .pc\:group-hover\:text-green-500 {
    color: #10b981;
  }

  .group:hover .pc\:group-hover\:text-green-600 {
    color: #059669;
  }

  .group:hover .pc\:group-hover\:text-green-700 {
    color: #047857;
  }

  .group:hover .pc\:group-hover\:text-green-800 {
    color: #065f46;
  }

  .group:hover .pc\:group-hover\:text-green-900 {
    color: #064e3b;
  }

  .group:hover .pc\:group-hover\:text-blue-50 {
    color: #eff6ff;
  }

  .group:hover .pc\:group-hover\:text-blue-100 {
    color: #dbeafe;
  }

  .group:hover .pc\:group-hover\:text-blue-200 {
    color: #bfdbfe;
  }

  .group:hover .pc\:group-hover\:text-blue-300 {
    color: #93c5fd;
  }

  .group:hover .pc\:group-hover\:text-blue-400 {
    color: #60a5fa;
  }

  .group:hover .pc\:group-hover\:text-blue-500 {
    color: #3b82f6;
  }

  .group:hover .pc\:group-hover\:text-blue-600 {
    color: #2563eb;
  }

  .group:hover .pc\:group-hover\:text-blue-700 {
    color: #1d4ed8;
  }

  .group:hover .pc\:group-hover\:text-blue-800 {
    color: #1e40af;
  }

  .group:hover .pc\:group-hover\:text-blue-900 {
    color: #1e3a8a;
  }

  .group:hover .pc\:group-hover\:text-cyan-50 {
    color: #ecfeff;
  }

  .group:hover .pc\:group-hover\:text-cyan-100 {
    color: #cffafe;
  }

  .group:hover .pc\:group-hover\:text-cyan-200 {
    color: #a5f3fc;
  }

  .group:hover .pc\:group-hover\:text-cyan-300 {
    color: #67e8f9;
  }

  .group:hover .pc\:group-hover\:text-cyan-400 {
    color: #22d3ee;
  }

  .group:hover .pc\:group-hover\:text-cyan-500 {
    color: #06b6d4;
  }

  .group:hover .pc\:group-hover\:text-cyan-600 {
    color: #0891b2;
  }

  .group:hover .pc\:group-hover\:text-cyan-700 {
    color: #0e7490;
  }

  .group:hover .pc\:group-hover\:text-cyan-800 {
    color: #155e75;
  }

  .group:hover .pc\:group-hover\:text-cyan-900 {
    color: #164e63;
  }

  .group:hover .pc\:group-hover\:text-indigo-50 {
    color: #eef2ff;
  }

  .group:hover .pc\:group-hover\:text-indigo-100 {
    color: #e0e7ff;
  }

  .group:hover .pc\:group-hover\:text-indigo-200 {
    color: #c7d2fe;
  }

  .group:hover .pc\:group-hover\:text-indigo-300 {
    color: #a5b4fc;
  }

  .group:hover .pc\:group-hover\:text-indigo-400 {
    color: #818cf8;
  }

  .group:hover .pc\:group-hover\:text-indigo-500 {
    color: #6366f1;
  }

  .group:hover .pc\:group-hover\:text-indigo-600 {
    color: #4f46e5;
  }

  .group:hover .pc\:group-hover\:text-indigo-700 {
    color: #4338ca;
  }

  .group:hover .pc\:group-hover\:text-indigo-800 {
    color: #3730a3;
  }

  .group:hover .pc\:group-hover\:text-indigo-900 {
    color: #312e81;
  }

  .group:hover .pc\:group-hover\:text-purple-50 {
    color: #f5f3ff;
  }

  .group:hover .pc\:group-hover\:text-purple-100 {
    color: #ede9fe;
  }

  .group:hover .pc\:group-hover\:text-purple-200 {
    color: #ddd6fe;
  }

  .group:hover .pc\:group-hover\:text-purple-300 {
    color: #c4b5fd;
  }

  .group:hover .pc\:group-hover\:text-purple-400 {
    color: #a78bfa;
  }

  .group:hover .pc\:group-hover\:text-purple-500 {
    color: #8b5cf6;
  }

  .group:hover .pc\:group-hover\:text-purple-600 {
    color: #7c3aed;
  }

  .group:hover .pc\:group-hover\:text-purple-700 {
    color: #6d28d9;
  }

  .group:hover .pc\:group-hover\:text-purple-800 {
    color: #5b21b6;
  }

  .group:hover .pc\:group-hover\:text-purple-900 {
    color: #4c1d95;
  }

  .group:hover .pc\:group-hover\:text-pink-50 {
    color: #fdf2f8;
  }

  .group:hover .pc\:group-hover\:text-pink-100 {
    color: #fce7f3;
  }

  .group:hover .pc\:group-hover\:text-pink-200 {
    color: #fbcfe8;
  }

  .group:hover .pc\:group-hover\:text-pink-300 {
    color: #f9a8d4;
  }

  .group:hover .pc\:group-hover\:text-pink-400 {
    color: #f472b6;
  }

  .group:hover .pc\:group-hover\:text-pink-500 {
    color: #ec4899;
  }

  .group:hover .pc\:group-hover\:text-pink-600 {
    color: #db2777;
  }

  .group:hover .pc\:group-hover\:text-pink-700 {
    color: #be185d;
  }

  .group:hover .pc\:group-hover\:text-pink-800 {
    color: #9d174d;
  }

  .group:hover .pc\:group-hover\:text-pink-900 {
    color: #831843;
  }
}
/*!markdown

---
title: Text Decoration
---

| Class       | Properties               |
| ----------- | ------------------------ |
| underline | text-decoration: underline |
| line-through | text-decoration: line-through |
| no-underline | text-decoration: none |


*/
.underline {
  text-decoration: underline;
}

.line-through {
  text-decoration: line-through;
}

.no-underline {
  text-decoration: none;
}

@media (max-width: 768px) {
  .m\:underline {
    text-decoration: underline;
  }

  .m\:line-through {
    text-decoration: line-through;
  }

  .m\:no-underline {
    text-decoration: none;
  }
}
@media (min-width: 769px) {
  .pc\:underline {
    text-decoration: underline;
  }

  .pc\:line-through {
    text-decoration: line-through;
  }

  .pc\:no-underline {
    text-decoration: none;
  }
}
/*!markdown

---
title: Text Transform
---

| Class       | Properties               |
| ----------- | ------------------------ |
| uppercase | text-transform: uppercase |
| lowercase | text-transform: lowercase |
| capitalize | text-transform: capitalize |
| normal-case | text-transform: none |



*/
.uppercase {
  text-transform: uppercase;
}

.lowercase {
  text-transform: lowercase;
}

.capitalize {
  text-transform: capitalize;
}

.normal-case {
  text-transform: none;
}

@media (max-width: 768px) {
  .m\:uppercase {
    text-transform: uppercase;
  }

  .m\:lowercase {
    text-transform: lowercase;
  }

  .m\:capitalize {
    text-transform: capitalize;
  }

  .m\:normal-case {
    text-transform: none;
  }
}
@media (min-width: 769px) {
  .pc\:uppercase {
    text-transform: uppercase;
  }

  .pc\:lowercase {
    text-transform: lowercase;
  }

  .pc\:capitalize {
    text-transform: capitalize;
  }

  .pc\:normal-case {
    text-transform: none;
  }
}
/*!markdown

---
title: Whitespace
---

| Class       | Properties               |
| ----------- | ------------------------ |
| white-space-normal | align: normal |
| white-space-nowrap | white-space: nowrap |
| white-space-pre | white-space: pre |
| white-space-pre-line | white-space: pre-line |
| white-space-pre-wrap | white-space: pre-wrap |



*/
.white-space-normal {
  white-space: normal;
}

.white-space-nowrap {
  white-space: nowrap;
}

.white-space-pre {
  white-space: pre;
}

.white-space-pre-line {
  white-space: pre-line;
}

.white-space-pre-wrap {
  white-space: pre-wrap;
}

@media (max-width: 768px) {
  .m\:white-space-normal {
    white-space: normal;
  }

  .m\:white-space-nowrap {
    white-space: nowrap;
  }

  .m\:white-space-pre {
    white-space: pre;
  }

  .m\:white-space-pre-line {
    white-space: pre-line;
  }

  .m\:white-space-pre-wrap {
    white-space: pre-wrap;
  }
}
@media (min-width: 769px) {
  .pc\:white-space-normal {
    white-space: normal;
  }

  .pc\:white-space-nowrap {
    white-space: nowrap;
  }

  .pc\:white-space-pre {
    white-space: pre;
  }

  .pc\:white-space-pre-line {
    white-space: pre-line;
  }

  .pc\:white-space-pre-wrap {
    white-space: pre-wrap;
  }
}
/*!markdown

---
title: Word Break
---

| Class       | Properties               |
| ----------- | ------------------------ |
| break-normal | overflow-wrap: normal; word-break: normal |
| break-words | overflow-wrap: break-word |
| break-all | word-break: break-all |



*/
.break-normal {
  overflow-wrap: normal;
  word-break: normal;
}

.break-words {
  overflow-wrap: break-word;
}

.break-all {
  word-break: break-all;
}

@media (max-width: 768px) {
  .m\:break-normal {
    overflow-wrap: normal;
    word-break: normal;
  }

  .m\:break-words {
    overflow-wrap: break-word;
  }

  .m\:break-all {
    word-break: break-all;
  }
}
@media (min-width: 769px) {
  .pc\:break-normal {
    overflow-wrap: normal;
    word-break: normal;
  }

  .pc\:break-words {
    overflow-wrap: break-word;
  }

  .pc\:break-all {
    word-break: break-all;
  }
}

/*# sourceMappingURL=helper.css.map */